(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1138191,      36292]*)
(*NotebookOutlinePosition[   1151644,      36671]*)
(*  CellTagsIndexPosition[   1151378,      36658]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Classical Methods of Control Theory", "Section",
  CellTags->"5.0"],

Cell[TextData[{
  "This chapter introduces several classical control theory tools available \
in ",
  StyleBox["Control System Professional", "TI"],
  ". Some of the functions described here are routines adapted from the ",
  StyleBox["Electrical Engineering", "TI"],
  " package; the proper extensions have been added to allow handling of the \
control objects. If you already have ",
  StyleBox["Electrical Engineering", "TI"],
  " installed, all the functionality you are accustomed to should still be \
available. "
}], "Text",
  CellTags->"5.0"],

Cell[CellGroupData[{

Cell["5.1 Root Loci", "Subsection",
  CellTags->"5.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["RootLocusPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"k", 
                        StyleBox[",",
                          "MR"], " ", "kmin", 
                        StyleBox[",",
                          "MR"], " ", "kmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"5.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["generatea",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["root",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["locus",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["when",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["parameter",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["k",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["varies",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["kmin",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["kmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"5.1"],

Cell["Plotting the root loci. ", "Caption",
  CellTags->"5.1"],

Cell[TextData[{
  StyleBox["RootLocusPlot", "MR"],
  " graphs the roots of the characteristic equation (the ",
  StyleBox["root loci", "TI"],
  ") while some parameter, typically (but not necessarily) the gain, varies. \
The input system may be in state\[Hyphen]space or transfer function form and \
may or may not depend on the parameter ",
  StyleBox["k", "TI"],
  ". In the latter case, the parameter is assumed to be the gain of the open\
\[Hyphen]loop system. Both discrete\[Hyphen] and continuous\[Hyphen]time \
systems can be analyzed using this function. As in the ",
  StyleBox["Electrical Engineering", "TI"],
  " package, ",
  StyleBox["RootLocusPlot", "MR"],
  " (as well as ",
  StyleBox["BodePlot", "MR"],
  ", ",
  StyleBox["NyquistPlot", "MR"],
  ", and ",
  StyleBox["NicholsPlot", "MR"],
  ") also accepts the body of the transfer function object as the input \
system.  "
}], "Text",
  CellTags->"5.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"5.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"5.1"],

Cell["Here is a double\[Hyphen]integrator system. ", "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["TransferFunction[s, (s+1)/s^2]", "Input",
  CellLabel->"In[2]:=",
  CellTags->"5.1"],

Cell[BoxData[
    \(TransferFunction[s, {{\(1 + s\)\/s\^2}}]\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->"5.1"]
}, Open  ]],

Cell[TextData[{
  "This plots the root loci. Note that because the system does not contain \
the parameter ",
  StyleBox["k", "MR"],
  ", it is assumed to be the gain. "
}], "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["RootLocusPlot[%, {k, 0, 10}];", "Input",
  CellLabel->"In[3]:=",
  CellTags->"5.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.163854 0.309017 0.296136 [
[.15692 .29652 -6 -9 ]
[.15692 .29652 6 0 ]
[.32077 .29652 -6 -9 ]
[.32077 .29652 6 0 ]
[.48463 .29652 -6 -9 ]
[.48463 .29652 6 0 ]
[.64848 .29652 -6 -9 ]
[.64848 .29652 6 0 ]
[.81234 .29652 -6 -9 ]
[.81234 .29652 6 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 16 6.28125 ]
[.96369 .01288 -12 -4.5 ]
[.96369 .01288 0 4.5 ]
[.96369 .16095 -24 -4.5 ]
[.96369 .16095 0 4.5 ]
[.96369 .45708 -18 -4.5 ]
[.96369 .45708 0 4.5 ]
[.96369 .60515 -6 -4.5 ]
[.96369 .60515 0 4.5 ]
[.97619 .64303 -8 0 ]
[.97619 .64303 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.15692 .30902 m
.15692 .31527 L
s
[(-5)] .15692 .29652 0 1 Mshowa
.32077 .30902 m
.32077 .31527 L
s
[(-4)] .32077 .29652 0 1 Mshowa
.48463 .30902 m
.48463 .31527 L
s
[(-3)] .48463 .29652 0 1 Mshowa
.64848 .30902 m
.64848 .31527 L
s
[(-2)] .64848 .29652 0 1 Mshowa
.81234 .30902 m
.81234 .31527 L
s
[(-1)] .81234 .29652 0 1 Mshowa
.125 Mabswid
.02584 .30902 m
.02584 .31277 L
s
.05861 .30902 m
.05861 .31277 L
s
.09138 .30902 m
.09138 .31277 L
s
.12415 .30902 m
.12415 .31277 L
s
.18969 .30902 m
.18969 .31277 L
s
.22246 .30902 m
.22246 .31277 L
s
.25523 .30902 m
.25523 .31277 L
s
.288 .30902 m
.288 .31277 L
s
.35355 .30902 m
.35355 .31277 L
s
.38632 .30902 m
.38632 .31277 L
s
.41909 .30902 m
.41909 .31277 L
s
.45186 .30902 m
.45186 .31277 L
s
.5174 .30902 m
.5174 .31277 L
s
.55017 .30902 m
.55017 .31277 L
s
.58294 .30902 m
.58294 .31277 L
s
.61571 .30902 m
.61571 .31277 L
s
.68125 .30902 m
.68125 .31277 L
s
.71402 .30902 m
.71402 .31277 L
s
.74679 .30902 m
.74679 .31277 L
s
.77957 .30902 m
.77957 .31277 L
s
.84511 .30902 m
.84511 .31277 L
s
.87788 .30902 m
.87788 .31277 L
s
.91065 .30902 m
.91065 .31277 L
s
.94342 .30902 m
.94342 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .01288 m
.98244 .01288 L
s
[(-1)] .96369 .01288 1 0 Mshowa
.97619 .16095 m
.98244 .16095 L
s
[(-0.5)] .96369 .16095 1 0 Mshowa
.97619 .45708 m
.98244 .45708 L
s
[(0.5)] .96369 .45708 1 0 Mshowa
.97619 .60515 m
.98244 .60515 L
s
[(1)] .96369 .60515 1 0 Mshowa
.125 Mabswid
.97619 .04249 m
.97994 .04249 L
s
.97619 .07211 m
.97994 .07211 L
s
.97619 .10172 m
.97994 .10172 L
s
.97619 .13134 m
.97994 .13134 L
s
.97619 .19056 m
.97994 .19056 L
s
.97619 .22018 m
.97994 .22018 L
s
.97619 .24979 m
.97994 .24979 L
s
.97619 .2794 m
.97994 .2794 L
s
.97619 .33863 m
.97994 .33863 L
s
.97619 .36824 m
.97994 .36824 L
s
.97619 .39786 m
.97994 .39786 L
s
.97619 .42747 m
.97994 .42747 L
s
.97619 .4867 m
.97994 .4867 L
s
.97619 .51631 m
.97994 .51631 L
s
.97619 .54593 m
.97994 .54593 L
s
.97619 .57554 m
.97994 .57554 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
gsave
.97619 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.97619 .30902 Mdot
.97619 .30902 Mdot
.88516 .04374 Mdot
.88516 .5743 Mdot
.79413 .01472 Mdot
.79413 .60332 Mdot
.7031 .08829 Mdot
.7031 .52974 Mdot
.49693 .30902 Mdot
.72722 .30902 Mdot
.2802 .30902 Mdot
.76188 .30902 Mdot
.08458 .30902 Mdot
.77545 .30902 Mdot
.78307 .30902 Mdot
.78803 .30902 Mdot
.79152 .30902 Mdot
1 0 0 r
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
.81234 .30902 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[3]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003mOol0
0`00Oomoo`0POol00?Aoo`D000Aoo`03001oogoo021oo`00cGoo0`009Woo00<007ooOol017oo00<0
07ooOol087oo003<Ool5000OOol30003Ool00`00Oomoo`04Ool2000QOol00<aoo`D002Eoo`03001o
ogoo00Aoo`03001oogoo021oo`00c7oo1@009Goo00<007ooOol017oo00<007ooOol087oo003=Ool3
000UOol20006Ool00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003U
Ool3000EOol00`00Oomoo`0POol00>Aoo`D001Aoo`03001oogoo021oo`00i7oo1@0057oo0P008Goo
003TOol5000DOol00`00Oomoo`0POol00>Eoo`<001Eoo`03001oogoo021oo`00oGoo00<007ooOol0
87oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol2
000QOol00?eoo`03001oogoo021oo`00]Woo0`00A7oo00<007ooOol087oo002eOol50013Ool00`00
Oomoo`0POol00;Eoo`D004=oo`03001oogoo021oo`00]Goo1@00@goo00<007ooOol087oo002fOol3
0014Ool00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo0P008Goo003mOol00`00Oomoo`0P
Ool00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03
001oogoo021oo`00oGoo00<007ooOol087oo003mOol2000QOol00?eoo`03001oogoo021oo`00oGoo
00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol0
87oo003/Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0POol00>]o
o`03001oo`0000Moo`03001oo`0000Eoo`03001oogoo021oo`00iWoo0`000Woo00<007oo00002Goo
00<007ooOol00goo0P008Goo003[Ool00`00Ool00007Ool20006Ool00`00Oomoo`0POol00>]oo`03
001oo`0000Moo`03001oogoo00Eoo`03001oogoo021oo`00k7oo00<007ooOol01Woo0`001Goo00<0
07ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo
003mOol2000QOol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0P
Ool00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03
001oogoo021oo`00oGoo0P008Goo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo
00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol0
87oo003mOol2000QOol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomo
o`0POol002moo`03001oogoo02Ioo`<002Ioo`8002Qoo`<002Eoo`D002Eoo`03001oogoo021oo`00
;Woo00<007oo0000:7oo00<007ooOol09goo00<007ooOol09Goo00<007ooOol09goo00<007ooOol0
9Goo00<007ooOol087oo000YOol30004Ool00`00Oomoo`0OOol30002Ool4000QOol30003Ool00`00
Oomoo`0QOol30003Ool00`00Oomoo`0POol30003Ool00`00Oomoo`0UOol00`00Oomoo`0POol002io
o`8002Moo`03001oo`0002Uoo`03001oogoo02Ioo`03001oogoo02Ioo`03001oogoo02Eoo`03001o
ogoo021oo`00;Woo00<007ooOol09goo0P009goo00<007oo00009goo00<007oo00009goo00<007oo
Ool09Goo0P008Goo000^Ool3000XOol00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0UOol2
000WOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00
Oomoo`0POol001Uoo`<002moo`<003Aoo`<003Moo`<000Ioo`<00003Ool0000000D0009oo`=l02Mo
o`<0025oo`0067oo1@00;Goo1@00<Woo1@00=Goo1@0017oo3@001G`09Goo1@002goo0`0000Aoo`00
Oomoo`8000aoo`001Gooc0001G`0;P0027oo00H007ooOol007oo000>Ool000aoo`03001oogoo00Eo
o`04001oogooOol50007Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool01000Oomoogoo1@001goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol01Goo1P000Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo1P000Woo00<007oo000030001G`0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo1@0037oo0`00
0Woo0`0037oo000IOol3000AOol00`00Oomoo`0KOol30008Ool00`00Oomoo`0WOol00`00Ool00002
000UOol00`00Oomoo`0?Ool30006Ool300000goo000000050002Ool3O00WOol3000=Ool01@00Oomo
o`00Ool00`0037oo003mOol00`00Oomoo`0<Ool01000Oomoo`0047oo003mOol00`00Oomoo`0;Ool4
000AOol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eo
o`80025oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00
oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo0P008Goo
003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00
Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol0
0?eoo`80025oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021o
o`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo0P00
8Goo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol0
0`00Oomoo`0POol00?eoo`03001oogoo021oo`00k7oo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol087oo003[Ool00`00Ool00007Ool00`00Ool00005Ool00`00Oomoo`0P
Ool00>]oo`03001oo`0000Uoo`03001oogoo00=oo`80025oo`00jgoo00<007oo00001goo0P001Woo
00<007ooOol087oo003[Ool00`00Ool00007Ool00`00Oomoo`05Ool00`00Oomoo`0POol00>aoo`03
001oogoo00Ioo`<000Eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0P
Ool00?eoo`03001oogoo021oo`00oGoo0P008Goo003mOol00`00Oomoo`0POol00?eoo`03001oogoo
021oo`00oGoo00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo
00<007ooOol087oo003mOol00`00Oomoo`0POol00?eoo`80025oo`00]Woo0`00A7oo00<007ooOol0
87oo002eOol50013Ool00`00Oomoo`0POol00;Eoo`D004=oo`03001oogoo021oo`00]Goo1@00@goo
00<007ooOol087oo002fOol30014Ool00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo0P00
8Goo003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003mOol0
0`00Oomoo`0POol00>Eoo`<001Eoo`03001oogoo021oo`00i7oo1@0057oo00<007ooOol087oo003T
Ool5000DOol00`00Oomoo`0POol00>Aoo`D001Aoo`80025oo`00iGoo0`005Goo00<007ooOol087oo
003mOol00`00Oomoo`0POol00?eoo`03001oogoo021oo`00oGoo00<007ooOol087oo003=Ool3000T
Ool50004Ool00`00Oomoo`0POol00<aoo`D002Eoo`03001oogoo00Aoo`03001oogoo021oo`00c7oo
1@009Goo00<007ooOol017oo0P008Goo003<Ool5000UOol00`00Oomoo`04Ool00`00Oomoo`0POol0
0<eoo`<002Ioo`03001oogoo00Aoo`03001oogoo021oo`00mGoo0P001Woo00<007ooOol087oo003m
Ool00`00Oomoo`0POol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00n7oo0`0000Ioo`00Ool007oo000OOol0
0?Uoo`08001oogoo001oo`00Ool001moo`00nGoo00P007ooOol007oo001oo`007goo003iOol00`00
Oomoo`0200000goo001oo`0OOol00?Uoo`03001oogoo02Aoo`00n7oo0`009Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-6.08939, -1.05991, 
  0.0240553, 0.01331}},
  CellTags->"5.1"]
}, Open  ]],

Cell[TextData[{
  StyleBox["RootLocusPlot", "MR"],
  " accepts the options for ",
  StyleBox["ListPlot", "MR"],
  " as well as several specific options that define the appearances of poles \
and zeros, and the number of points at which to sample the range for ",
  StyleBox["k", "MR"],
  ". "
}], "Text",
  CellTags->"5.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["PoleStyle",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(styles\ for\ poled\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ZeroStyle",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(styles\ for\ zeros\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["PlotPoints",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["10",
                "StandardForm"],
              "Text"], 
            StyleBox[\(number\ of\ times\ the\ parameter\ is\ sampled\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"5.1"],

Cell[TextData[{
  "Options specific to ",
  StyleBox["RootLocusPlot", "MR"],
  ". "
}], "Caption",
  CellTags->"5.1"],

Cell[TextData[{
  "As an example of using ",
  StyleBox["RootLocusPlot", "MR"],
  " in feedback design, consider the system shown in \
Figure\[NonBreakingSpace]5.1, for which we find coefficients ",
  StyleBox["k", "MR"],
  " such that the damping ratio of the dominant closed\[Hyphen]loop poles is \
",
  StyleBox["0.4", "MR"],
  " (",
  StyleBox["cf.", "TI"],
  " Ogata (1990)).  \n"
}], "Text",
  CellTags->"5.1"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 280 72
%%HiResBoundingBox: 47 4 280 72
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (11:24:55 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 76 translate 1 -1 scale
gsave
47 72 translate
233 -68 scale
1 string
925 270 1 [925 0 0 270 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000
000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000
000000000000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000
000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF7FFDFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFEFFFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFDFFFF7FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFD5FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFBFFFFBFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFA3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF3FDFF1FFFFFFFF
FFFFFFFFFFFFFFFF5FFFFFFFFFFFC1FFFFFFF007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFA3F83F3E37FBFFFFFFFF
FE0FFFFF3FFF9FBEEFFFFFFFFFFFE3FFFFFE803FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFC3FC7F7E71FDFFFFFFFF
FF1FFFFF7FFFDF3DF7FFFFFFFFFFC1FFFFC0001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFE3FE3E7EFBFCFFFFFFFF
FFBFFFFF3FFFCE7FF3FFFFFFFFFFE3FFFA00002AAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFE1FE3E7FF1FC7FF5557F
FF1FFFFF7FFFC47FF3FFFFFFFFFFC1FD0000000000000000000000000000
0000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFF3FE3E7FF3FEFFE0007F
FFBFFFFF3FFFEEFFE3FFFFFFFFFFE3E00000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000000000000001FFFF1FF1C7FE3FC7FF5557F
FF1FFFFF7FFFC4FFC7FFFFFFFFFFC0000000000000000000000000000000
0000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000
0000000000000000000000000000000000003FFFF9FF3EFFE7FEFFFFFFFF
FFBFFFC000FFE4FF8FFFFFFFFFFFE3E80000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000000000000001FFFF1FF1C7FC7FC7FFFFFFF
FF1FFFC001FFE4FF0FFFFFFFFFFFC1FF4000000000000000000000000000
0000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000
0000000000000000000000000000000000003FFFF8FF9EFF8FFEFFFFFFFF
FFBFFFFF3FFFE3FFBFFFFFFFFFFFE3FFFA00003FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000000000000001FFFF8001C7F9FFC7FF0007F
FF1FFFFF7FFFF3BF1DFFFFFFFFFFC1FFFFD0001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA83FFFF8FF8E7F9EFCFFEAAAFF
FFBFFFFF3FFFF3DFBDFFFFFFFFFFE3FFFFFFA00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFC7F8E7FC47CFFFFFFFF
FF1FFFFF7FFFF14791FFFFFFFFFFC1FFFFFFF407FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFCFF8F3FFFF9FFFFFFFF
FFBFFFFF3FFFFBFFFFFFFFFFFFFFE3FFFFFFFFFAFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFC7FC73FFFF9FFFFFFFF
FF1FFFFF7FFFF9FFFFFFFFFFFFFFC1FFFFFFFFFF7FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFE7FCFBFFFFBFFFFFFFF
FFBFFFFFFFFFF9FFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFC7FC7DFFFF7FFFFFFFF
FF1FFFFFFFFFFDFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFE3FE3FFFFFFFFFFFFFF
FE3FFFFFFFFFF8FFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFC1FC1F7FFDFFFFFFFFF
FF1FFFFFFFFFFCFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000
000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000
000000000000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000
000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000
000000000000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF03DFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF839FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7031FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3833FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1021FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0823FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000000000000000000000000000000000001FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000000000000000000000000000000000001FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF
FFFFFFFFDFFFDFFFFFFFFFFFFFFDFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF
FFFFFFFFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF
FFFFFFFFF7FF7FFFFFFFFFFFFFFF7FFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFFFFFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFFFFFFFDFC7FFFFFFFFFFFFFFF1FFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFABF9FABFFF
FBFFFEABFCFEFEBFFFFEFFFFFFBFBFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1DF9F1DFFF
F3FFFF87FCFDF1DFFFFCFFFFFF3FDFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEFBFFCFFF
F3FFFFCFFEF9FBEFFFFEFFFFFF3FCFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C71F7CFFF
F3FFFFCFFC71FFC7FFFCFFFFFF3FCFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF3FF8FFF
F3FFFFCFFE7BFFEFFFFEFFFFFF3FEFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F3FF1FFF
F3FFFFCFFE71FF8FFFFCFFFF0007C7FFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F3FF9FFE
A2AFFFCFFE7BFF8FFFA8ABFE2A2FEFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F3FE1FFC
000FFFCFFE71FF1FFF0003FF7F3FC7FFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3F3FE3FFF
F3FFFFCFFE7BFE3FFFFEFFFFBF3FEFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7F3FC77FF
F3FFFFCFFE71FE7FFFFCFFFFDF3FC7FFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFB3FEFFFF
F3FFFFCFFE7BFE7BFFFEFFFFEF3FCFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE771FE77FF
F3FFFFCFFC71FF73FFFCFFFFE73FCFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBBBFFBBFF
F3FFFFCFFEF9FFBBFFFEFFFFF73FCFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFF
F3FFFFCFFCFDFFFFFFFCFFFFF33FDFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFFFFCFFDFCFFFFFFFFFFFFFB3FBFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFF
FFFFFFCFFDFC7FFFFFFFFFFFFD3F3FFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFF
FFFFFE8FFBFFFFFFFFFFFFFFFE3F7FFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFF
FFFFFF0FF7FF3FFFFFFFFFFFFF3E7FFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF
FFFFFFEFEFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFC7FFC7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFF9FFFF7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00003FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFAFFFBFFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005401FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFC507F7C57F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FF80FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFF8FE7E7EFBF9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF17FFFFFFFFF05DDC07FFFFF
FFFFFFFFC5FFFFFFFFF0FFFFF1FC7E7DF1FDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFE0FFFF07FFFFF
FFFFFFFFF8BFFFFFFFE0FFFFE3FE3EFFFBFCFFEAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFAFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0057FFFFFC1777703FFFFF
FFFFFFFFFC017FFFFFF0FFFFE3FE3C7FF1FC7FE0007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFC001FFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE002FFFFFE3FFFF83FFFFF
FFFFFFFFFF002FFFFFE0FFFFE3FE3EFFE3FCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFC000FFFFFFFFFFFFFFFFFFFF80BFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00005FFFC1DDDDC1FFFFF
FFFFFFFFFF80005FFFF0FFFFC7FF1C7FC7FC7FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFF80007FFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000BFF83FFFFE3FFFFF
FFFFFFFFFFC00002FFE0FFFFE3FF1EFF8FFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFF8002FFFFFFFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000178377774000000
000000000000000007F0FFFFC3FC047F8FFC7FFFFFFFFFFFC00000000000
0000000000000000000000000000000FFFFFFFFFFFE00000000000000000
0000000000000000000000000000000000000005FFFFFFFFFFF8
FFFFFFFFFE000000000000000000000000000000000000283FFFFE000000
000000000000000000A0FFFFE3FFFEFF9EFCFFE0007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000
00000000000000000000000000000000000000003FFFFFFFFFF8
FFFFFFFFFE000000000000000000000000000000000000105DDDDC000000
00000000000000000000FFFFE1FFFC7F9CFCFFF0007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000
0000000000000000000000000000000000000000017FFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000000BF83FFFFE000000
00000000000000000BE0FFFFE3FFFEFFEEF8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000
0000000000000000000000000000000000000000003FFFFFFFF8
FFFFFFFFFE00000000000000000000000000000000005FF8777774000000
00000000000000005FF0FFFFF1FFFE7FF7FDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000000
0000000000000000000000000000000000000000017FFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0002FFFF83FFFFE3FFFFF
FFFFFFFFFF80002FFFE0FFFFF8FFFF3FFFFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFF00003FFFFFFFFFFFFFFFFFFFF800000BFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFC1DDDDC1FFFFF
FFFFFFFFFF0001FFFFF0FFFFFC7FDF3FFFF3FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFF00007FFFFFFFFFFFFFFFFFFFF000017FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFC3FFFFC3FFFFF
FFFFFFFFFE00FFFFFFE0FFFFFE7FEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFE000BFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FFFFFFFC1777703FFFFF
FFFFFFFFF417FFFFFFF0FFFFFF1F47DFFFE7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFF80007FFFFFFFFFFFFFFFFFFFC005FFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFE0FFFF83FFFFF
FFFFFFFFEBFFFFFFFFE0FFFFFFAA2FEFFFEFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFE001FFFFFFFFFFFFFFFFFFFF82FFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE05DDD07FFFFF
FFFFFFFFDFFFFFFFFFF0FFFFFFF5F7F7FFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFF001FFFFFFFFFFFFFFFFFFFC5FFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFE0FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007700FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF802A03FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00007FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFD557F17FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE003E7BFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF003C71FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFABFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFBFB8F9FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFDFD9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE7F1FC7FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF3F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFF8
FFFFFFFFF15FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF9F1FC7FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FFFFFFFFFF8
FFFFFFFFE020FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF9F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFF8
FFFFFFFFE101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC71FC7FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF73FFFFFFFFFF8
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFEF9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFF8
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC71FC7FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFF8
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE79FCFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFF8
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFDFC71FC7FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFF8
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFEFE78F8FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFF8
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE787CF9FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFF8
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFA0FEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF8
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF41FF07FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FFFFFFFFF8
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE37FFFFFFFFF8
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FFFFFFFFF8
FFFFFFFFEBABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83BFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF879FFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87BFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07DFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEABAFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF05555555555555555555555555555555555555555
55555555555555555555555555555555555555555541FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000000000000000000000000000000000001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000000000000000000000000000000000001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{233, 68},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000A1000`40O003h00OjGoo003YOol00>Uo
o`00H7oo00<icQ2448@04A2400<8@Q2448@07Q2400<DYAS6Ool0DGoo001POol00c6<DYAoo`0bOol0
0f]J48Aoo`1AOol0061oo`03<HaBU7oo039oo`03JeX@Q7oo055oo`00H7oo00<aS5:DOol0<Woo00=[
FQ24Ool0DGoo001POol00c6<DYAoo`0bOol00f]J48Aoo`1AOol0061oo`03<HaBU7oo039oo`03JeX@
Q7oo055oo`00H7oo00<aS5:DOol0<Woo00=[FQ24Ool0DGoo001POol00c6<DYAoo`08Ool01FLiOomo
ogooIcT09Goo00=[FQ24Ool027oo00=g_FmkOol0AWoo001POol00c6<DYAoo`02Ool01E:DKg]oodYB
Mkd00VLi00ES65kgKg]g_E[F00Uoo`03Mke:DWoo00Aoo`0:IcUoogooOomW>GooIcU_NfLiMkd:Ool0
0f]J48Aoo`03Ool01WNmG_M:DRU:8@QJeTQoo`00<Woo00=_NekgG_L0:ekg00<YBU:DOol00Woo0U:D
00YoodYBE[DicWooMkeNmeJeOolicP9oo`05G_M:DT8@@Q1W>@03Ool00d8@Oomoo`03Ool02U:DOomo
ogooBU9246mkOomW>DYB2Woo00I[FQ24G_LicRU:6<H400000`Q248@@Q00E48@00`Q248@@Q00748@0
0cW>Oomoo`0UOol0039oo`03DY@0000002`0000:DYAoogooOomg_BU:G_M>LdYB@Q02Ool0136<Oomo
od8@0Woo00Eg_EkgG_MNmgNm00=oo`08@Q1oogooOomS648@:DY:DP9oo`06IcTaS7NmOolYBWNm2Woo
00Q[FQ24OomW>E:D>LhHaPQ20P0000<8@T8@@Q007T8@00<@Q36<Ool09Woo000bOol00e:D001_N`0N
Kg/00gNmKg]_N`0:Kg/00b48DYAoo`03Ool02bU:Oomoob48DYA_NgooE[ENmgoo@Q000Woo00Ag_F]J
Kg]_N`Aoo`03@Q1oogoo00=oo`03DYAoogoo009oo`05@Q1NmgNmIcUNm`0:Ool00f]J48Aoo`05Ool0
1GNmDYA245kgKg/07Woo00<Q236<Ool09Woo000bOol00e:D001oo`0[Ool00c6<DYAoo`03Ool0136<
IcUooc6<0VLi0goo00=_NgNmOol027oo00=g_CW>Ool02Goo00=247ooOol037oo00=[FQ24Ool0:7oo
00<Q236<Ool09Woo000bOol00eJe001oo`0[Ool00cF]E[Eoo`0SOol00f]JOomoo`0<Ool00g>L5:Eo
o`0XOol00b48=Jeoo`0VOol0039oo`03DY@007oo02]oo`03<HaBU7oo039oo`03JeX@Q7oo02Qoo`03
8@PaS7oo02Ioo`00<Woo00=BU000Ool0:goo00<aS5:DOol0<Woo00=[FQ24Ool0:7oo00<Q236<Ool0
9Woo000bOol00e:D001oo`0[Ool00c6<DYAoo`0bOol00f]J48Aoo`0XOol00b48<Haoo`0VOol0039o
o`03DY@007oo02]oo`03<HaBU7oo039oo`03JeX@Q7oo02Qoo`038@PaS7oo02Ioo`00<Woo00=BU000
Ool0:goo00<aS5:DOol0<Woo00=[FQ24Ool0:7oo00<Q236<Ool09Woo000bOol00e:D001oo`0[Ool0
0c6<DYAoo`0bOol00f]J48Aoo`0XOol00b48<Haoo`0VOol0039oo`03DY@007oo02]oo`03<HaBU7oo
039oo`03JeX@Q7oo02Qoo`038@PaS7oo02Ioo`00<Woo00=BU000Ool0:goo00<aS2U:@Q00<T8@00<e
[A24Ool0:7oo00<Q236<Ool09Woo000bOol00e:D001oo`0[Ool00e[F@Q12400c@Q000dYBOomoo`0W
Ool00b48<Haoo`0VOol0039oo`03DY@007oo08]oo`038@PaS7oo02Ioo`00<Woo00=BU000Ool0Rgoo
00<Q236<Ool09Woo000bOol00e:D001oo`2;Ool00b48<Haoo`0VOol0039oo`03DY@007oo08]oo`03
8@PaS7oo02Ioo`00<Woo00=BU000Ool0Rgoo00<Q236<Ool09Woo000bOol00e:D001oo`2;Ool00b48
<Haoo`0VOol0039oo`03DY@007oo08]oo`038@PaS7oo02Ioo`00<Woo00=BU000Ool0Rgoo00<Q236<
Ool09Woo000bOol00e:D001oo`2;Ool00b48<Haoo`0VOol0039oo`03DY@007oo08]oo`038@PaS7oo
02Ioo`00<7oo00Ag_GooDY@008aoo`038@PaS7oo02Ioo`00<7oo00Ig_D8@DY@005[FIcV:Ool00b48
<Haoo`0VOol0035oo`058@P@Q00048Ag_@0IOol00e[F@Q12401C@Q000gNmOomoo`0HOol00b48<Hao
o`0VOol0035oo`04@Q00000048@JOol00c6<8@Q2401B@Q000`00Kg]oo`0IOol00b48<Haoo`0VOol0
035oo`04JeX00000<H`JOol00c6<@Q1oo`0QOol00fmkOomoo`0;Ool01FmkOomoogooKg/03Woo00=g
_GooOol03Goo00<006mkOol06Goo00<Q236<Ool09Woo000bOol00a24000icP0JOol00c6<@Q1oo`0M
Ool01fmkMkeooeJeOom[FWNm00Aoo`0<MkeoogooOomg_FmkMkeooeJeOomNmfmk0WNm17oo00=g_Goo
Ool017oo00=g_GooBU803Woo00<006mkOol06Goo00<Q236<Ool09Woo000bOol00c6<001F]@0JOol0
0c6<@Q1oo`0LOol026mkIcU:DVmkDYA_Nf]J@Q04Ool00d8@Oomoo`02Ool02SW>Mkeooe:DKg]:DWoo
G_MJeWNm0goo00=BU7ooOol017oo00A247ooG_MW>@eoo`03001_Ngoo01Uoo`038@PaS7oo02Ioo`00
<Woo00=BU000Kg/06Woo00<aS48@Ool07Goo00MW>D8@G_MNmgooJeXaS002Ool016LiDY@YBU:D0goo
00=247ooOol00Ukg00A247ooMkdYBP=oo`0<DY@aS5:DIcUoogNm>LiBU2U:Mke[FU:D3Goo00<006mk
Ool06Goo00<Q236<Ool09Woo000bOol00fmk001g_@0JOol00c6<@Q1oo`0MOol01U:DKg]JeUJeOomF
]@9W>@=oo`03@Q1oogoo009oo`08@Q1oogooE[EW>CW>Oom_N`9Nm`=oo`03DYAoogoo009oo`04IcU_
Nd8@Ool2E[D=Ool00`00Kg]oo`0IOol00b48<Haoo`0VOol003=oo`03<Haoogoo01Uoo`03<Ha247oo
021oo`03DYAoogoo00Eoo`06Kg]oogooOomg_CW>0Woo00AF]GooF]Ig_@Ioo`03Kg]oogoo00=oo`04
E[E247ooBU8>Ool00`00Kg]oo`0IOol00b48<Haoo`0VOol0035oo`04MkeBU2U:BU8JOol00c6<@Q1o
o`09Ool01FLiOomoogooIcT04Woo0WNm2goo00AF]GooMkeg_@9oo`03Kg]oogoo00]oo`03HaQg_GNm
00ioo`03001_Ngoo01Uoo`038@PaS7oo02Ioo`00<7oo00MJePQ2:DXaS1S6249W>@0HOol00c6<@Q1o
o`04Ool015:DG_MBU7oo0VLi00ENmfmkMkeg_E[F04=oo`03001_Ngoo01Uoo`038@PaS7oo02Ioo`00
9Goo00IW>D8@<Ha:DUkgMkd4Ool00gNm48AF]@03Kg/00cW>48Aoo`0=Ool01Ekg<Ha245:DMkd01Goo
00<aS48@Ool00goo00a:DUJeOolicVLiBU9oogNmG_MBU7oo@Q02Ool016LiDYABU5:D?Goo00<006mk
Ool067oo00@icP006<IW>A9oo`05MkeJeTYBJeYg_@0?Ool000Uoo`03Kg]2448@01Y24003>Lh00000
00800007248aS48@G_M241S6Mkd016mk00<@Q3W>@Q003D8@00/icP00000000Q26<HicTYBIcTaS48@
00Aoo`04<HaW>GooE[D2@Q02Ool012U:Mkeooc6<0Woo00A_NekgG_MNm`Ioo`03IcUNmekg02QNm`03
Mkeoogoo00Uoo`03000icT8@01M24005<H`00000000HaP0D@Q0021S600000124<Ha245JeMkd:Ool0
00Uoo`03G_L0000002000006249245Je=JdYBW>L16]J00<8@P0000004`0000D8@RU:E[DQ248@00Ao
o`9:DP=oo`07@Q1oogooE[ENmgoo@Q000Woo00Ag_EJeE[EF]Ceooc/000035:Eg_Goo00Moo`009Goo
00Mg_DYB6<HicT8@IcUg_@03Ool00eJe48Ag_@03Kg/00fLi249g_@0=Ool01gNm<H`@Q36<@Q1F]GNm
00=oo`03<Ha247oo00Aoo`06>Li_NgNmF]I_Nekg0goo00=W>FmkOol0@Woo00<006mkOol05goo00EB
U0000000024801Aoo`08<H`000008@PicTYBIcUg_@Yoo`009Goo00=g_GooOol027oo00D@Q248G_M_
NfLi008YBPioo`03IcUoogoo00Moo`03<Ha247oo00Eoo`05IcUNmfLiOom_N`03Ool00fmkOomoo`12
Ool00`00Kg]oo`0HOol015:D6<HaS6mk4goo00=NmeJeMkd047oo000`Ool01VLi=Jd00124248aS1Uo
o`03<Ha247oo02moo`07Kg/aS36<F]IW>EJeF]H077oo00<006mkOol0@Woo000bOol00gNmKg]oo`0J
Ool00c6<@Q1oo`0`Ool01ekgMke_Nc6<Oom247Nm01]oo`03001_Ngoo03Eoo`03Mkeoogoo00Yoo`00
27oo00A_Nc6<>Li:DT=oo`03<Ha247oo035oo`06@Q1g_C6<Oom246mk6goo00<006mkOol0=Goo0T8@
00=g_GooOol027oo0008Ool015:D<HaBU36<@goo00<aS48@Ool0;goo00Qg_GooDYAW>C6<Oom246mk
6goo00<006mkOol0=Woo00=g_DYBOol02Goo0008Ool015:D<HaBU36<@goo00<aS48@Ool0;goo00M_
Ne:D:DY_Ne:DG_M:DP0LOol00`00Kg]oo`0fOol00dYB8@Qoo`09Ool000Qoo`04G_MBU5JeDYA3Ool0
0c6<@Q1oo`1BOol00`00Kg]oo`0fOol00aS6DYAW>@09Ool004moo`03<Ha247oo059oo`03001_Ngoo
03Eoo`04Kg/aS7NmG_L9Ool004moo`05<H`icVmkKg][FP0PKg/00gNmKg]_N`0NKg/00f]JKg]_N`0<
Kg/00`00Kg]oo`12Ool004moo`03<H`0000005<00003Kg]oogoo045oo`00jGoo003YOol00>Uoo`00
jGoo003YOol00>Uoo`00\
\>"],
  CellTags->"5.1"],

Cell[TextData[{
  StyleBox["Figure 5.1. ",
    FontWeight->"Bold"],
  "Example system for root locus construction."
}], "Caption",
  CellTags->"5.1"],

Cell[TextData[{
  "This describes the block with the transfer function ",
  Cell[BoxData[
      \(TraditionalForm\`G(s)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". "
}], "MathCaption",
  CellTags->"5.1"],

Cell["g = TransferFunction[s, 20/(s(s+1)(s+4))];", "Input",
  CellLabel->"In[4]:=",
  CellTags->"5.1"],

Cell[TextData[{
  "This defines the transfer function ",
  Cell[BoxData[
      \(TraditionalForm\`H(s)\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ". "
}], "MathCaption",
  CellTags->"5.1"],

Cell["h = TransferFunction[s, (1+k s)];", "Input",
  CellLabel->"In[5]:=",
  CellTags->"5.1"],

Cell["\<\
The open\[Hyphen]loop system is formed by the serial connection of \
the blocks. \
\>", "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["SeriesConnect[g, h]", "Input",
  CellLabel->"In[6]:=",
  CellTags->"5.1"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(20\ \((1 + k\ s)\)\)\/\(s\ \((1 + s)\)\ \((4 + s)\)\)}}]\)], 
  "Output",
  CellLabel->"Out[6]=",
  CellTags->"5.1"]
}, Open  ]],

Cell[TextData[{
  "The suitable values of ",
  StyleBox["k", "MR"],
  " correspond to intersections of the root locus curve with the straight \
line depicting the locus of poles of the generic second\[Hyphen]order system \
"
}], "Text",
  CellTags->"5.1"],

Cell[BoxData[
    \(TraditionalForm
    \`H(s) = \[Omega]\_n\%2\/\(s\^2 + 2 \( \[Zeta]\[Omega]\_n\) s + 
          \[Omega]\_n\%2\)\)], "DisplayFormula",
  CellTags->"5.1"],

Cell[TextData[{
  "for the chosen value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)], "InlineFormula",
    CellTags->"S0.0.2"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " is the natural frequency and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " is the damping ratio.    "
}], "Text",
  CellTags->"5.1"],

Cell[TextData[{
  "This plots root loci together with the line for the cosen value of ",
  StyleBox["zeta", "MR"],
  ". The natural frequency ",
  StyleBox["wn", "MR"],
  " has been picked quite arbitrarily, just to display the line in some \
bounds. Note that in this case parameter ",
  StyleBox["k", "MR"],
  " is ",
  StyleBox["not", "TI"],
  " the gain. \nAs we can see, the line intersects the root locus branch \
somewhere between 5 and 6 points, and then again between points 14 and 15. "
}], "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["\<\
RootLocusPlot[%, {k, 0, 2},
 PlotPoints -> 20,
 PoleStyle -> PointSize[.005],
 Epilog -> Line[{{0, 0},
 {-zeta wn, wn Sqrt[1-zeta^2]} /.
 {wn -> 10, zeta -> .4}}
 ],
 PlotLabel -> \"Root Loci\"
]\
\>", "Input",
  CellLabel->"In[7]:=",
  CellTags->"5.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.201414 0.309017 0.0485629 [
[.17053 .29652 -6 -9 ]
[.17053 .29652 6 0 ]
[.37195 .29652 -6 -9 ]
[.37195 .29652 6 0 ]
[.57336 .29652 -6 -9 ]
[.57336 .29652 6 0 ]
[.77478 .29652 -6 -9 ]
[.77478 .29652 6 0 ]
[1.025 .30902 0 -6.28125 ]
[1.025 .30902 16 6.28125 ]
[.96369 .01764 -12 -4.5 ]
[.96369 .01764 0 4.5 ]
[.96369 .11477 -12 -4.5 ]
[.96369 .11477 0 4.5 ]
[.96369 .21189 -12 -4.5 ]
[.96369 .21189 0 4.5 ]
[.96369 .40614 -6 -4.5 ]
[.96369 .40614 0 4.5 ]
[.96369 .50327 -6 -4.5 ]
[.96369 .50327 0 4.5 ]
[.96369 .60039 -6 -4.5 ]
[.96369 .60039 0 4.5 ]
[.97619 .64303 -8 0 ]
[.97619 .64303 8 12.5625 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17053 .30902 m
.17053 .31527 L
s
[(-4)] .17053 .29652 0 1 Mshowa
.37195 .30902 m
.37195 .31527 L
s
[(-3)] .37195 .29652 0 1 Mshowa
.57336 .30902 m
.57336 .31527 L
s
[(-2)] .57336 .29652 0 1 Mshowa
.77478 .30902 m
.77478 .31527 L
s
[(-1)] .77478 .29652 0 1 Mshowa
.125 Mabswid
.21082 .30902 m
.21082 .31277 L
s
.2511 .30902 m
.2511 .31277 L
s
.29138 .30902 m
.29138 .31277 L
s
.33167 .30902 m
.33167 .31277 L
s
.41223 .30902 m
.41223 .31277 L
s
.45251 .30902 m
.45251 .31277 L
s
.4928 .30902 m
.4928 .31277 L
s
.53308 .30902 m
.53308 .31277 L
s
.61365 .30902 m
.61365 .31277 L
s
.65393 .30902 m
.65393 .31277 L
s
.69421 .30902 m
.69421 .31277 L
s
.73449 .30902 m
.73449 .31277 L
s
.81506 .30902 m
.81506 .31277 L
s
.85534 .30902 m
.85534 .31277 L
s
.89562 .30902 m
.89562 .31277 L
s
.93591 .30902 m
.93591 .31277 L
s
.13025 .30902 m
.13025 .31277 L
s
.08997 .30902 m
.08997 .31277 L
s
.04969 .30902 m
.04969 .31277 L
s
.0094 .30902 m
.0094 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .01764 m
.98244 .01764 L
s
[(-6)] .96369 .01764 1 0 Mshowa
.97619 .11477 m
.98244 .11477 L
s
[(-4)] .96369 .11477 1 0 Mshowa
.97619 .21189 m
.98244 .21189 L
s
[(-2)] .96369 .21189 1 0 Mshowa
.97619 .40614 m
.98244 .40614 L
s
[(2)] .96369 .40614 1 0 Mshowa
.97619 .50327 m
.98244 .50327 L
s
[(4)] .96369 .50327 1 0 Mshowa
.97619 .60039 m
.98244 .60039 L
s
[(6)] .96369 .60039 1 0 Mshowa
.125 Mabswid
.97619 .04192 m
.97994 .04192 L
s
.97619 .0662 m
.97994 .0662 L
s
.97619 .09048 m
.97994 .09048 L
s
.97619 .13905 m
.97994 .13905 L
s
.97619 .16333 m
.97994 .16333 L
s
.97619 .18761 m
.97994 .18761 L
s
.97619 .23617 m
.97994 .23617 L
s
.97619 .26045 m
.97994 .26045 L
s
.97619 .28474 m
.97994 .28474 L
s
.97619 .3333 m
.97994 .3333 L
s
.97619 .35758 m
.97994 .35758 L
s
.97619 .38186 m
.97994 .38186 L
s
.97619 .43042 m
.97994 .43042 L
s
.97619 .45471 m
.97994 .45471 L
s
.97619 .47899 m
.97994 .47899 L
s
.97619 .52755 m
.97994 .52755 L
s
.97619 .55183 m
.97994 .55183 L
s
.97619 .57611 m
.97994 .57611 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
gsave
.97619 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Root) show
93.000000 12.812500 moveto
(Loci) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.005 w
.97619 .21189 Mdot
.97619 .40614 Mdot
.04646 .30902 Mdot
.93752 .20836 Mdot
.93752 .40967 Mdot
.1342 .30902 Mdot
.89365 .20468 Mdot
.89365 .41336 Mdot
.23622 .30902 Mdot
.84264 .20038 Mdot
.84264 .41765 Mdot
.3567 .30902 Mdot
.7824 .19433 Mdot
.7824 .4237 Mdot
.4899 .30902 Mdot
.7158 .18414 Mdot
.7158 .43389 Mdot
.60328 .30902 Mdot
.65911 .16891 Mdot
.65911 .44913 Mdot
.62151 .15218 Mdot
.62151 .46585 Mdot
.67849 .30902 Mdot
.59705 .13631 Mdot
.59705 .48173 Mdot
.72741 .30902 Mdot
.58006 .12166 Mdot
.58006 .49637 Mdot
.76137 .30902 Mdot
.56753 .10812 Mdot
.56753 .50991 Mdot
.78644 .30902 Mdot
.55784 .09551 Mdot
.55784 .52253 Mdot
.80582 .30902 Mdot
.55009 .08366 Mdot
.55009 .53437 Mdot
.82131 .30902 Mdot
.54373 .07246 Mdot
.54373 .54557 Mdot
.83404 .30902 Mdot
.5384 .06182 Mdot
.5384 .55622 Mdot
.8447 .30902 Mdot
.53386 .05165 Mdot
.53386 .56638 Mdot
.85379 .30902 Mdot
.52993 .0419 Mdot
.52993 .57613 Mdot
.86163 .30902 Mdot
.52651 .03252 Mdot
.52651 .58551 Mdot
.86849 .30902 Mdot
.52348 .02347 Mdot
.52348 .59457 Mdot
.87453 .30902 Mdot
.5208 .01472 Mdot
.5208 .60332 Mdot
.87991 .30902 Mdot
1 0 0 r
.02 w
.01947 .30902 Mdot
.33838 .30902 Mdot
.49783 .30902 Mdot
.5935 .30902 Mdot
.65728 .30902 Mdot
.70284 .30902 Mdot
.73701 .30902 Mdot
.76359 .30902 Mdot
.78485 .30902 Mdot
.80224 .30902 Mdot
.81674 .30902 Mdot
.829 .30902 Mdot
.83952 .30902 Mdot
.84863 .30902 Mdot
.8566 .30902 Mdot
.86364 .30902 Mdot
.86989 .30902 Mdot
.87548 .30902 Mdot
0 g
.5 Mabswid
.97619 .30902 m
0 0 rlineto s
.97619 .30902 m
.41683 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[7]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OoWoo00<007ooOol0
7goo003nOol00`00Oomoo`0OOol008Uoo`03001oogoo06Yoo`8000Ioo`03001oogoo01moo`00mWoo
00<007oo00001Goo00<007ooOol07goo003aOol30002Ool00`00Ool00005Ool2000POol008Yoo`03
001oogoo06Uoo`8000Ioo`03001oogoo01moo`00mWoo00<007ooOol01Goo00<007ooOol07goo002:
Ool00`00Oomoo`1ZOol20005Ool00`00Oomoo`0OOol00?ioo`03001oogoo01moo`00Rgoo00<007oo
Ool0L7oo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03001oogoo01moo`00S7oo00<0
07ooOol0Kgoo00<007ooOol07goo003nOol00`00Oomoo`0OOol008eoo`03001oogoo06ioo`03001o
ogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol008moo`03001oogoo06aoo`03
001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol0091oo`03001oogoo06]o
o`03001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol0099oo`03001oogoo
06Uoo`03001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol009Eoo`03001o
ogoo06Ioo`03001oogoo01moo`00mgoo0`0017oo00<007ooOol07goo003hOol00`00Oomoo`03Ool0
0`00Oomoo`0OOol00?5oo`<0009oo`@000Aoo`80021oo`00V7oo00<007ooOol0Fgoo00<007oo0000
1Goo00<007ooOol07goo003gOol20005Ool00`00Oomoo`0OOol00?Qoo`03001oogoo00=oo`03001o
ogoo01moo`00oWoo00<007ooOol07goo002LOol00`00Oomoo`1OOol00`00Oomoo`0OOol00?ioo`03
001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol00:=oo`03001oogoo05Qo
o`03001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03001oogoo
01moo`00[7oo00<007ooOol0Cgoo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03001o
ogoo01moo`00oWoo00<007ooOol07goo002kOol00`00Oomoo`10Ool00`00Oomoo`0OOol00?ioo`03
001oogoo01moo`00c7oo00<007ooOol0;goo00<007ooOol07goo003nOol00`00Oomoo`0OOol00=]o
o`03001oogoo021oo`03001oogoo01moo`00j7oo00<007ooOol04goo00<007ooOol07goo003dOol0
0`00Ool000020005Ool00`00Oomoo`0OOol00?Ioo`03001oogoo00Aoo`80025oo`00lGoo0`000goo
00<007ooOol017oo0P0087oo003gOol00`00Oomoo`04Ool00`00Oomoo`0OOol00?Ioo`03001oo`00
00Eoo`03001oogoo01moo`00mgoo00<007ooOol017oo00<007ooOol07goo003nOol00`00Oomoo`0O
Ool00?ioo`03001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03
001oogoo01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03001oogoo01mo
o`00oWoo00<007ooOol07goo000bOol3000_Ool2000bOol3000_Ool5000_Ool00`00Oomoo`0OOol0
03=oo`03001oogoo031oo`03001oogoo02moo`03001oogoo035oo`03001oogoo02moo`03001oogoo
01moo`00;7oo0`000Woo1000:Woo0`000goo00<007ooOol0:goo0`000goo00<007ooOol0:Woo0`00
0goo00<007ooOol0;goo00<007ooOol07goo000aOol00`00Ool0000bOol00`00Oomoo`0`Ool00`00
Oomoo`0`Ool00`00Oomoo`0_Ool00`00Oomoo`0OOol0039oo`80031oo`03001oo`00035oo`03001o
o`00035oo`03001oogoo02moo`03001oogoo01moo`00<goo00<007ooOol0;goo00<007ooOol0<Goo
00<007ooOol0;goo0P00<Goo00<007ooOol07goo003nOol00`00Oomoo`0OOol00?ioo`03001oogoo
01moo`00oWoo00<007ooOol07goo003nOol00`00Oomoo`0OOol000Qoo`=l04ioo`=l02Ioo`=l01Io
o`=l00eoo`=l00Uoo`=l00Eoo`=l00Aoo`=l00=oo`=l0005Ooml07`0O01oo`0BO00HOol00`00Oomo
o`0;Ool3000017oo001oogoo0P002goo0007Ool5O004Ool00`00Oomoo`0COol00`00Oomoo`0GOol0
0`00Oomoo`0EOol5O002Ool00`00Oomoo`0OOol5O00DOol5O00;Ool5O002Ool00`00Oomoo`02Ool5
O003Ool5O002Ool5O0000gooO01l000JO00GOol00`00Oomoo`0<Ool01P00Oomoo`00Ool000eoo`00
17oo0`001G`0C0001G`090001G`050001G`02`001G`01`001G`00`001G`00P001G`000<007`0O000
6W`07P0027oo0`000Woo0`002goo0006Ool00`00O01l0003O005Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool5O006Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool5O006Ool00`00Oomo
o`08Ool00`00Oomoo`05O002Ool00`00Oomoo`06Ool5O006Ool00`00O01l0003O003Ool5O002Ool5
O0000`00O01l000JO002Ool00`00Oomoo`07Ool00`00Oomoo`06Ool3000>Ool01@00Oomoo`00Ool0
0`002goo0008Ool3O01>Ool3O00VOol3O00FOol3O00=Ool3O009Ool3O005Ool3O004Ool3O003Ool3
O0001GooO01l07`0Ool04W`057oo0P000Woo00<007ooOol037oo00@007ooOol000moo`00n7oo0P00
17oo00<007ooOol02goo100047oo003fOol20006Ool00`00Oomoo`0OOol00?Eoo`03001oogoo00Io
o`03001oogoo01moo`00lgoo0P002Goo00<007ooOol07goo003aOol2000;Ool00`00Oomoo`0OOol0
0>moo`8000eoo`03001oogoo01moo`00kGoo0P003goo00<007ooOol07goo003[Ool2000AOol00`00
Oomoo`0OOol00>Yoo`03001oogoo015oo`03001oogoo01moo`00j7oo0P0057oo00<007ooOol07goo
003VOol2000FOol00`00Oomoo`0OOol00>Aoo`8001Qoo`03001oogoo01moo`00hWoo0P006Woo00<0
07ooOol07goo003QOol00`00Oomoo`0JOol00`00Oomoo`0OOol00=moo`8001eoo`03001oogoo01mo
o`00gGoo0P007goo00<007ooOol07goo003KOol2000QOol00`00Oomoo`0OOol00=Uoo`8002=oo`03
001oogoo01moo`00f7oo00<007ooOol08goo00<007ooOol07goo003FOol2000NOol30005Ool00`00
Oomoo`0OOol00=Aoo`80021oo`03001oogoo00Eoo`03001oogoo01moo`00dWoo0P0087oo00@007oo
Ool000Eoo`<0021oo`00d7oo0P005Woo00<007ooOol037oo00<007ooOol017oo00<007ooOol07goo
003?Ool00`00Oomoo`09Ool00`00Oomoo`0HOol00`00Ool00005Ool00`00Oomoo`0OOol00<eoo`80
02Qoo`03001oogoo00Aoo`03001oogoo01moo`00bgoo0P00<Goo00<007ooOol07goo0039Ool2000c
Ool00`00Oomoo`0OOol00<Moo`8003Eoo`03001oogoo01moo`00^goo00<007ooOol01goo0P00=goo
00<007ooOol07goo0034Ool00`00Oomoo`0gOol00`00Oomoo`0OOol00<9oo`8003Yoo`03001oogoo
01moo`00[7oo00<007ooOol04Goo0P00?7oo00<007ooOol07goo002nOol2000nOol00`00Oomoo`0O
Ool00;aoo`80041oo`03001oogoo01moo`00^goo00<007ooOol0@7oo00<007ooOol07goo002iOol2
0013Ool00`00Oomoo`0OOol00:=oo`03001oogoo015oo`8004Eoo`03001oogoo01moo`00]Goo0P00
Agoo00<007ooOol07goo002cOol20019Ool00`00Oomoo`0OOol00;9oo`03001oogoo04Uoo`03001o
ogoo01moo`00W7oo00<007ooOol04Goo0P00C7oo00<007ooOol07goo002^Ool2001>Ool00`00Oomo
o`0OOol00:aoo`80051oo`03001oogoo01moo`00ZWoo0P00DWoo00<007ooOol07goo002HOol00`00
Oomoo`0>Ool00`00Oomoo`1;Ool30004Ool00`00Oomoo`0OOol00:Moo`8004moo`03001oogoo00=o
o`03001oogoo01moo`00YGoo0P00Cgoo100017oo0P0087oo002EOol00`00Oomoo`0;Ool2001AOol0
0`00Ool00005Ool00`00Oomoo`0OOol00:5oo`8005Aoo`8000Eoo`03001oogoo01moo`00Wgoo0P00
Egoo00<007ooOol00goo00<007ooOol07goo002BOol00`00Oomoo`09Ool00`00Oomoo`1MOol00`00
Oomoo`0OOol009aoo`80061oo`03001oogoo01moo`00VWoo0P00HWoo00<007ooOol07goo002@Ool0
0`00Oomoo`05Ool2001TOol00`00Oomoo`0OOol009Ioo`8006Ioo`03001oogoo01moo`00UGoo00<0
07ooOol0IWoo00<007ooOol07goo002?Ool01000Oomoogoo0P00JGoo00<007ooOol07goo002AOol2
001[Ool00`00Oomoo`0OOol008moo`8006eoo`03001oogoo01moo`00SGoo0P00Kgoo00<007ooOol0
7goo002<Ool00`00Oomoo`1_Ool00`00Oomoo`0OOol008Yoo`<0075oo`03001oogoo01moo`00R7oo
0P00M7oo00<007ooOol07goo0026Ool2001fOol00`00Oomoo`0OOol008Aoo`8000Eoo`03001oogoo
071oo`03001oogoo01moo`00Pgoo00<007ooOol0N7oo00<007ooOol07goo0021Ool20007Ool00`00
Oomoo`1aOol00`00Oomoo`0OOol007moo`8007eoo`03001oogoo01moo`00OGoo0P00Ogoo00<007oo
Ool07goo001kOol2000=Ool00`00Oomoo`1YOol20006Ool00`00Oomoo`0OOol007Uoo`8007]oo`03
001oo`0000Eoo`03001oogoo01moo`00N7oo00<007ooOol03Woo00<007ooOol0JWoo00<007oo0000
1Goo0P0087oo001fOol2001nOol20006Ool00`00Oomoo`0OOol007Aoo`80081oo`03001oogoo00Eo
o`03001oogoo01moo`00LWoo0P00Pgoo0P001Goo00<007ooOol07goo001`Ool2002<Ool00`00Oomo
o`0OOol006moo`03001oogoo08aoo`03001oogoo01moo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00JGoo0`0000Aoo`00Oomoo`8000=oo`8000=oo`8000]oo`D0
009oo`80009oo`<0009oo`<008Ioo`00JWoo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Oomoo`09Ool01P00Oomoo`00Ool0009oo`03001oo`0000Eoo`03001oogoo08Eo
o`00JWoo0`000Woo00H007ooOol007oo0002Ool00`00Ool0000>Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000Eoo`03001oogoo08Eoo`00JWoo00@007ooOol0009oo`8000=oo`800003Ool000000080
00aoo`03001oogoo00=oo`80009oo`<0009oo`8008Moo`00JWoo00@007ooOol000]oo`03001oogoo
00aoo`03001oogoo06ioo`<00006Ool007oo001oo`007Woo001YOol4000JOol3000>Ool00`00Oomo
o`1OOol02000Oomoo`00Ool007oo000NOol00?Yoo`08001oogoo001oo`00Ool001ioo`00nWoo00<0
07ooOol00P0000=oo`00Ool07Woo003jOol00`00Oomoo`0SOol00?Uoo`<002Aoo`00ogoo8Goo003o
OolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.93395, -6.3633, 
  0.0194227, 0.0805555}},
  CellTags->"5.1"]
}, Open  ]],

Cell[TextData[{
  "Roughly estimating that the intersections are 0.2 and 0.5 off the \
respective points, we get some estimates of parameter ",
  StyleBox["k", "MR"],
  " that provide the required damping ratio. "
}], "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["\<\
(
   kmax = 2; points = 20;
   kmax/(points-1)(#-1)& /@ {5.2, 14.5}
)\
\>", "Input",
  CellLabel->"In[8]:=",
  CellTags->"5.1"],

Cell[BoxData[
    \({0.442105263157894778`, 1.42105263157894734`}\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"5.1"]
}, Open  ]],

Cell["\<\
Here are the corresponding expressions for the closed\[Hyphen]loop \
system. \
\>", "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["\<\
results = FeedbackConnect[g, h] /.
 Map[List, Thread[k -> %]] //Simplify\
\>", "Input",
  CellLabel->"In[9]:=",
  CellTags->"5.1"],

Cell[BoxData[
    \({TransferFunction[
        s, {{20\/\(20 + 12.8421052631578969`\ s + 5\ s\^2 + s\^3\)}}], 
      TransferFunction[
        s, {{20\/\(20 + 32.421052631578946`\ s + 5\ s\^2 + s\^3\)}}]}\)], 
  "Output",
  CellLabel->"Out[9]=",
  CellTags->"5.1"]
}, Open  ]],

Cell[TextData[{
  "This simulates the step responses for the chosen values of ",
  StyleBox["k", "MR"],
  ". The first system exhibits a faster response with reasonable overshoot \
compared to the second system. "
}], "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell["\<\
SimulationPlot[#, UnitStep[t], {t, 5},
 Sampled -> Period[.2],
 PlotRange -> All,
 PlotLabel -> \"Step Response\"
]& /@ results\
\>", "Input",
  CellLabel->"In[10]:=",
  CellTags->"5.1"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.507699 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11625 -18 -4.5 ]
[.01131 .11625 0 4.5 ]
[.01131 .21779 -18 -4.5 ]
[.01131 .21779 0 4.5 ]
[.01131 .31933 -18 -4.5 ]
[.01131 .31933 0 4.5 ]
[.01131 .42087 -18 -4.5 ]
[.01131 .42087 0 4.5 ]
[.01131 .52241 -6 -4.5 ]
[.01131 .52241 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11625 m
.03006 .11625 L
s
[(0.2)] .01131 .11625 1 0 Mshowa
.02381 .21779 m
.03006 .21779 L
s
[(0.4)] .01131 .21779 1 0 Mshowa
.02381 .31933 m
.03006 .31933 L
s
[(0.6)] .01131 .31933 1 0 Mshowa
.02381 .42087 m
.03006 .42087 L
s
[(0.8)] .01131 .42087 1 0 Mshowa
.02381 .52241 m
.03006 .52241 L
s
[(1)] .01131 .52241 1 0 Mshowa
.125 Mabswid
.02381 .0401 m
.02756 .0401 L
s
.02381 .06549 m
.02756 .06549 L
s
.02381 .09087 m
.02756 .09087 L
s
.02381 .14164 m
.02756 .14164 L
s
.02381 .16702 m
.02756 .16702 L
s
.02381 .19241 m
.02756 .19241 L
s
.02381 .24318 m
.02756 .24318 L
s
.02381 .26856 m
.02756 .26856 L
s
.02381 .29395 m
.02756 .29395 L
s
.02381 .34472 m
.02756 .34472 L
s
.02381 .3701 m
.02756 .3701 L
s
.02381 .39549 m
.02756 .39549 L
s
.02381 .44626 m
.02756 .44626 L
s
.02381 .47164 m
.02756 .47164 L
s
.02381 .49703 m
.02756 .49703 L
s
.02381 .5478 m
.02756 .5478 L
s
.02381 .57318 m
.02756 .57318 L
s
.02381 .59857 m
.02756 .59857 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Step) show
93.000000 12.812500 moveto
(Response) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 Mabswid
.02381 .01472 m
.0619 .02518 L
.1 .07851 L
.1381 .17619 L
.17619 .2973 L
.21429 .41604 L
.25238 .51207 L
.29048 .57474 L
.32857 .60309 L
.36667 .60332 L
.40476 .5853 L
.44286 .55935 L
.48095 .53393 L
.51905 .51447 L
.55714 .50325 L
.59524 .49995 L
.63333 .50264 L
.67143 .50872 L
.70952 .51573 L
.74762 .52183 L
.78571 .526 L
.82381 .52798 L
.8619 .52808 L
.9 .52692 L
.9381 .52516 L
.97619 .5234 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001=Ool5
000/Ool3000/Ool2000^Ool3000/Ool00`00Oomoo`0AOol004moo`03001oogoo02aoo`03001oogoo
02ioo`03001oogoo02aoo`03001oogoo02Yoo`03001oo`00019oo`00Cgoo00<007ooOol0;Goo00<0
07ooOol0;7oo00<007ooOol0:goo1000;Goo00<007ooOol047oo001?Ool00`00Oomoo`0]Ool00`00
Oomoo`0]Ool00`00Oomoo`0ZOol00`00Ool0000/Ool2000COol004moo`03001oogoo02aoo`03001o
o`0002aoo`03001oo`0002eoo`8002aoo`03001oogoo019oo`00CWoo0P00;goo00<007ooOol0;7oo
00<007ooOol0;Goo00<007ooOol0:Woo0`004Woo003oOolQOol0025oo`03001oogoo0?aoo`008Goo
00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`006goon0003Goo000Q
Ool00`00Oomoo`040002Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0AOol0025oo`03001oogoo00Aoo`<00?Eoo`008Goo00<007ooOol01goo00<0
07ooOol0lWoo000QOol00`00Oomoo`08Ool00`00Oomoo`3aOol0025oo`03001oogoo00Qoo`03001o
ogoo0?5oo`008Goo0P002Woo00<007ooOol0l7oo000QOol00`00Oomoo`0:Ool00`00Oomoo`3_Ool0
025oo`03001oogoo00]oo`03001oogoo0>ioo`008Goo00<007ooOol02goo00<007ooOol0kWoo000Q
Ool00`00Oomoo`0<Ool00`00Oomoo`3]Ool0025oo`03001oogoo00eoo`03001oogoo0>aoo`008Goo
0P003goo00<007ooOol0jgoo000QOol00`00Oomoo`0>Ool00`00Oomoo`3[Ool0025oo`03001oogoo
00moo`03001oogoo0>Yoo`008Goo00<007ooOol047oo00<007ooOol0jGoo000QOol00`00Oomoo`0@
Ool00`00Oomoo`3YOol0025oo`03001oogoo015oo`03001oogoo0>Qoo`008Goo0P004Woo00<007oo
Ool0j7oo000QOol00`00Oomoo`0AOol00`00Oomoo`3XOol0025oo`03001oogoo019oo`03001oogoo
0>Moo`008Goo00<007ooOol04Woo00<007ooOol0igoo000QOol00`00Oomoo`0COol00`00Oomoo`3V
Ool0015oo`03001oogoo009oo`04001oogooOol30004Ool00`00Oomoo`0COol00`00Oomoo`3VOol0
011oo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo0>Ioo`0047oo00<0
07oo000027oo00<007ooOol00goo0P005Goo00<007ooOol0iGoo000@Ool00`00Ool00008Ool00`00
Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`3UOol0011oo`03001oo`0000Moo`03001oo`0000Ao
o`03001oogoo01Aoo`03001oogoo0>Eoo`004Goo00<007ooOol01goo00<007ooOol00goo00<007oo
Ool05Goo00<007ooOol0i7oo000QOol00`00Oomoo`0EOol00`00Oomoo`3TOol0025oo`03001oogoo
01Eoo`03001oogoo0>Aoo`008Goo0P005goo00<007ooOol0hgoo000QOol00`00Oomoo`0FOol00`00
Oomoo`3SOol0025oo`03001oogoo01Ioo`03001oogoo0>=oo`008Goo00<007ooOol05goo00<007oo
Ool0hWoo000QOol00`00Oomoo`0GOol00`00Oomoo`3ROol0025oo`03001oogoo01Qoo`03001oogoo
0>5oo`008Goo0P006Goo00<007ooOol0hGoo000QOol00`00Oomoo`0HOol00`00Oomoo`3QOol0025o
o`03001oogoo01Uoo`03001oogoo0>1oo`008Goo00<007ooOol06Goo00<007ooOol0h7oo000QOol0
0`00Oomoo`0IOol00`00Oomoo`3POol0025oo`03001oogoo01Yoo`03001oogoo0=moo`008Goo00<0
07ooOol06Woo00<007ooOol0ggoo000QOol2000KOol00`00Oomoo`3OOol0025oo`03001oogoo01]o
o`03001oogoo0=ioo`008Goo00<007ooOol06goo00<007ooOol0gWoo000QOol00`00Oomoo`0KOol0
0`00Oomoo`3NOol0015oo`03001oogoo009oo`03001oogoo009oo`<000=oo`03001oogoo01aoo`03
001oogoo0=eoo`0047oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol077oo00<007ooOol0
gGoo000@Ool00`00Ool00007Ool40003Ool2000MOol00`00Oomoo`3MOol0011oo`03001oo`0000Mo
o`03001oo`0000Aoo`03001oogoo01eoo`03001oogoo0=aoo`0047oo00<007oo000027oo0P0017oo
00<007ooOol07Goo00<007ooOol0g7oo000AOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`0MOol00`00Oomoo`3LOol0025oo`03001oogoo01ioo`03001oogoo0=]oo`008Goo00<007ooOol0
7Woo00<007ooOol0fgoo000QOol2000OOol00`00Oomoo`3KOol0025oo`03001oogoo01moo`03001o
ogoo0=Yoo`008Goo00<007ooOol07goo00<007ooOol0fWoo000QOol00`00Oomoo`0OOol00`00Oomo
o`3JOol0025oo`03001oogoo021oo`03001oogoo0=Uoo`008Goo00<007ooOol087oo00<007ooOol0
fGoo000QOol2000QOol00`00Oomoo`3IOol0025oo`03001oogoo025oo`03001oogoo0=Qoo`008Goo
00<007ooOol08Goo00<007ooOol0f7oo000QOol00`00Oomoo`0QOol00`00Oomoo`3HOol0025oo`03
001oogoo029oo`03001oogoo0=Moo`008Goo00<007ooOol08Woo00<007ooOol0egoo000QOol00`00
Oomoo`0ROol00`00Oomoo`3GOol0025oo`8002Aoo`03001oogoo0=Ioo`008Goo00<007ooOol08goo
00<007ooOol0eWoo000QOol00`00Oomoo`0SOol00`00Oomoo`3FOol0025oo`03001oogoo02Aoo`03
001oogoo0=Eoo`004Goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo02Aoo`03001o
ogoo0=Eoo`0047oo00<007oo00001goo00<007oo000017oo00<007ooOol097oo00<007ooOol0eGoo
000@Ool00`00Ool00007Ool00`00Ool00004Ool2000VOol00`00Oomoo`3DOol0011oo`03001oo`00
00Moo`8000Eoo`03001oogoo02Eoo`03001oogoo0=Aoo`0047oo00<007oo00001goo00<007ooOol0
17oo00<007ooOol09Goo00<007ooOol0e7oo000AOol00`00Oomoo`07Ool20004Ool00`00Oomoo`0U
Ool00`00Oomoo`3DOol0025oo`03001oogoo02Ioo`03001oogoo0==oo`008Goo00<007ooOol09Woo
00<007ooOol0dgoo000QOol2000WOol00`00Oomoo`3COol0025oo`03001oogoo02Moo`03001oogoo
0=9oo`008Goo00<007ooOol09goo00<007ooOol0dWoo000QOol00`00Oomoo`0WOol00`00Oomoo`3B
Ool0025oo`03001oogoo02Qoo`03001oogoo0=5oo`008Goo00<007ooOol0:7oo00<007ooOol0dGoo
000QOol00`00Oomoo`0XOol00`00Oomoo`3AOol0025oo`8002Yoo`03001oogoo0=1oo`008Goo00<0
07ooOol0:Goo00<007ooOol0d7oo000QOol00`00Oomoo`0YOol00`00Oomoo`3@Ool0025oo`03001o
ogoo02Yoo`03001oogoo0<moo`008Goo00<007ooOol0:Woo00<007ooOol0cgoo000QOol00`00Oomo
o`0ZOol00`00Oomoo`3?Ool0025oo`8002]oo`03001oogoo0<moo`008Goo00<007ooOol0:goo00<0
07ooOol0cWoo000QOol00`00Oomoo`0[Ool00`00Oomoo`3>Ool0025oo`03001oogoo02]oo`03001o
ogoo0<ioo`004Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;7oo
00<007ooOol0cGoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0/Ool00`00Oomo
o`3=Ool0011oo`03001oo`0000Moo`03001oo`0000Aoo`8002eoo`03001oogoo0<eoo`0047oo00<0
07oo000027oo00<007ooOol00goo00<007ooOol0;Goo00<007ooOol0c7oo000@Ool00`00Ool00007
Ool00`00Ool00004Ool00`00Oomoo`0]Ool00`00Oomoo`3<Ool0015oo`03001oogoo00Moo`03001o
ogoo00=oo`03001oogoo02ioo`03001oogoo0<]oo`008Goo00<007ooOol0;Woo00<007ooOol0bgoo
000QOol00`00Oomoo`0^Ool00`00Oomoo`3;Ool0025oo`80031oo`03001oogoo0<Yoo`008Goo00<0
07ooOol0;goo00<007ooOol0bWoo000QOol00`00Oomoo`0_Ool00`00Oomoo`3:Ool0025oo`03001o
ogoo031oo`03001oogoo0<Uoo`008Goo00<007ooOol0<7oo00<007ooOol0bGoo000QOol00`00Oomo
o`0aOol00`00Oomoo`38Ool0025oo`03001oogoo035oo`03001oogoo0<Qoo`008Goo0P00<Woo00<0
07ooOol0b7oo000QOol00`00Oomoo`0bOol00`00Oomoo`37Ool0025oo`03001oogoo039oo`03001o
ogoo0<Moo`008Goo00<007ooOol0<Woo00<007ooOol0agoo000QOol00`00Oomoo`0cOol00`00Oomo
o`36Ool0025oo`03001oogoo03=oo`03001oogoo0<Ioo`008Goo0P00=Goo00<007ooOol0aGoo000Q
Ool00`00Oomoo`0dOol00`00Oomoo`19OolG001UOol0025oo`03001oogoo03Aoo`03001oogoo04Io
o`<001Moo`@0065oo`008Goo00<007ooOol0=Goo00<007ooOol0@Goo10007Woo1@00G7oo000IOol5
0003Ool00`00Oomoo`0eOol00`00Oomoo`0oOol2000WOol4001HOol001]oo`03001oogoo00=oo`03
001oogoo03Ioo`03001oogoo03aoo`8002eoo`L0055oo`006goo00<007ooOol00goo0P00=goo00<0
07ooOol0>Woo0P00=Woo2P00;goo1@004goo000KOol00`00Oomoo`03Ool00`00Oomoo`0gOol00`00
Oomoo`0gOol20012Ool9000DOolB000HOol001]oo`03001oogoo00=oo`03001oogoo03Qoo`03001o
ogoo03Aoo`8004eooa@002Yoo`006Woo0P001Goo00<007ooOol0>7oo00<007ooOol0<goo00<007oo
Ool0Rgoo000QOol00`00Oomoo`0iOol00`00Oomoo`0`Ool2002>Ool0025oo`03001oogoo03Yoo`03
001oogoo02eoo`80091oo`008Goo0P00>goo00<007ooOol0;7oo00<007ooOol0T7oo000QOol00`00
Oomoo`0kOol00`00Oomoo`0YOol2002COol0025oo`03001oogoo03aoo`03001oogoo02Ioo`8009Eo
o`008Goo00<007ooOol0?7oo00<007ooOol09Goo00<007ooOol0UGoo000QOol00`00Oomoo`0mOol0
0`00Oomoo`0SOol00`00Oomoo`2FOol0025oo`03001oogoo03ioo`03001oogoo021oo`8009Uoo`00
8Goo00<007ooOol0?Woo00<007ooOol07goo00<007ooOol0VGoo000QOol20010Ool00`00Oomoo`0M
Ool00`00Oomoo`2JOol0025oo`03001oogoo041oo`03001oogoo01Yoo`8009eoo`008Goo00<007oo
Ool0@Goo0P006Goo00<007ooOol0WGoo000QOol00`00Oomoo`13Ool00`00Oomoo`0DOol2002POol0
025oo`03001oogoo04Aoo`03001oogoo015oo`800:9oo`008Goo00<007ooOol0AGoo0P003goo0P00
Y7oo000QOol20018Ool00`00Oomoo`0:Ool2002VOol0025oo`03001oogoo04Qoo``00:Qoo`008Goo
00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`008Goo00<007ooOol0
o7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ogoo0`006goo0`00P7oo
0020Ool00`00Oomoo`0KOol00`00Oomoo`1oOol0075oo`<000=oo`8000=oo`80009oo`<000]oo`<0
0004Ool007ooOol20002Ool20003Ool30003Ool200000goo00000002Ool01000Ool0000017oo0P00
Jgoo001aOol00`00Ool00002Ool01P00Oomoo`00Ool000Aoo`04001oogoo000;Ool01P00Oomoo`00
Ool000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00000Woo
00<007ooOol0Jgoo001cOol01000Oomoo`0017oo0`000Woo00@007ooOol000]oo`<0009oo`<000=o
o`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`000goo0`00Jgoo
001bOol00`00Oomoo`040002Ool300000goo00000002000<Ool01@00Oomoo`00Ool00`000goo0P00
00=oo`0000000P000goo0P0000=oo`0000000P000goo0P000Woo0`00Jgoo001aOol00`00Ool00002
Ool00`00Oomoo`0FOol01000Oomoo`00SGoo001aOol3000JOol4002>Ool00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.707935, -0.0963033, 
  0.0212303, 0.00796509}},
  CellTags->"5.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0147151 0.611062 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13693 -18 -4.5 ]
[.01131 .13693 0 4.5 ]
[.01131 .25914 -18 -4.5 ]
[.01131 .25914 0 4.5 ]
[.01131 .38135 -18 -4.5 ]
[.01131 .38135 0 4.5 ]
[.01131 .50357 -18 -4.5 ]
[.01131 .50357 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(1)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(2)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(3)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(4)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(5)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.0619 .01472 m
.0619 .01847 L
s
.1 .01472 m
.1 .01847 L
s
.1381 .01472 m
.1381 .01847 L
s
.17619 .01472 m
.17619 .01847 L
s
.25238 .01472 m
.25238 .01847 L
s
.29048 .01472 m
.29048 .01847 L
s
.32857 .01472 m
.32857 .01847 L
s
.36667 .01472 m
.36667 .01847 L
s
.44286 .01472 m
.44286 .01847 L
s
.48095 .01472 m
.48095 .01847 L
s
.51905 .01472 m
.51905 .01847 L
s
.55714 .01472 m
.55714 .01847 L
s
.63333 .01472 m
.63333 .01847 L
s
.67143 .01472 m
.67143 .01847 L
s
.70952 .01472 m
.70952 .01847 L
s
.74762 .01472 m
.74762 .01847 L
s
.82381 .01472 m
.82381 .01847 L
s
.8619 .01472 m
.8619 .01847 L
s
.9 .01472 m
.9 .01847 L
s
.9381 .01472 m
.9381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13693 m
.03006 .13693 L
s
[(0.2)] .01131 .13693 1 0 Mshowa
.02381 .25914 m
.03006 .25914 L
s
[(0.4)] .01131 .25914 1 0 Mshowa
.02381 .38135 m
.03006 .38135 L
s
[(0.6)] .01131 .38135 1 0 Mshowa
.02381 .50357 m
.03006 .50357 L
s
[(0.8)] .01131 .50357 1 0 Mshowa
.125 Mabswid
.02381 .04527 m
.02756 .04527 L
s
.02381 .07582 m
.02756 .07582 L
s
.02381 .10637 m
.02756 .10637 L
s
.02381 .16748 m
.02756 .16748 L
s
.02381 .19803 m
.02756 .19803 L
s
.02381 .22859 m
.02756 .22859 L
s
.02381 .28969 m
.02756 .28969 L
s
.02381 .32025 m
.02756 .32025 L
s
.02381 .3508 m
.02756 .3508 L
s
.02381 .41191 m
.02756 .41191 L
s
.02381 .44246 m
.02756 .44246 L
s
.02381 .47301 m
.02756 .47301 L
s
.02381 .53412 m
.02756 .53412 L
s
.02381 .56467 m
.02756 .56467 L
s
.02381 .59522 m
.02756 .59522 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Step) show
93.000000 12.812500 moveto
(Response) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 Mabswid
.02381 .01472 m
.0619 .02687 L
.1 .08207 L
.1381 .16392 L
.17619 .24034 L
.21429 .29639 L
.25238 .3357 L
.29048 .36773 L
.32857 .39815 L
.36667 .4274 L
.40476 .4538 L
.44286 .47633 L
.48095 .49527 L
.51905 .51151 L
.55714 .52579 L
.59524 .53845 L
.63333 .54961 L
.67143 .55933 L
.70952 .56777 L
.74762 .57511 L
.78571 .58152 L
.82381 .58713 L
.8619 .59203 L
.9 .59632 L
.9381 .60006 L
.97619 .60332 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[10]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001=Ool5
000/Ool3000/Ool2000^Ool3000/Ool00`00Oomoo`0AOol004moo`03001oogoo02aoo`03001oogoo
02ioo`03001oogoo02aoo`03001oogoo02Yoo`03001oo`00019oo`00Cgoo00<007ooOol0;Goo00<0
07ooOol0;7oo00<007ooOol0:goo1000;Goo00<007ooOol047oo001?Ool00`00Oomoo`0]Ool00`00
Oomoo`0]Ool00`00Oomoo`0ZOol00`00Ool0000/Ool2000COol004moo`03001oogoo02aoo`03001o
o`0002aoo`03001oo`0002eoo`8002aoo`03001oogoo019oo`00CWoo0P00;goo00<007ooOol0;7oo
00<007ooOol0;Goo00<007ooOol0:Woo0`004Woo003oOolQOol0025oo`03001oogoo0?aoo`008Goo
00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`006goon0003Goo000Q
Ool00`00Ool000020004Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`0AOol0025oo`03001oogoo009oo`<00?Moo`008Goo00<007ooOol01Goo0P00
mGoo000QOol00`00Oomoo`07Ool00`00Oomoo`3bOol0025oo`03001oogoo00Qoo`03001oogoo0?5o
o`008Goo00<007ooOol027oo00<007ooOol0lGoo000QOol2000:Ool00`00Oomoo`3`Ool0025oo`03
001oogoo00Yoo`03001oogoo0>moo`008Goo00<007ooOol02goo00<007ooOol0kWoo000QOol00`00
Oomoo`0;Ool00`00Oomoo`3^Ool0025oo`03001oogoo00aoo`03001oogoo0>eoo`008Goo00<007oo
Ool03Goo00<007ooOol0k7oo000QOol00`00Oomoo`0>Ool00`00Oomoo`3[Ool0025oo`03001oogoo
00ioo`03001oogoo0>]oo`008Goo0P0047oo00<007ooOol0jWoo000QOol00`00Oomoo`0@Ool00`00
Oomoo`3YOol0025oo`03001oogoo011oo`03001oogoo0>Uoo`008Goo00<007ooOol04Goo00<007oo
Ool0j7oo000QOol00`00Oomoo`0AOol00`00Oomoo`3XOol0025oo`03001oogoo019oo`03001oogoo
0>Moo`008Goo00<007ooOol04Woo00<007ooOol0igoo000QOol2000DOol00`00Oomoo`3VOol0025o
o`03001oogoo01=oo`03001oogoo0>Ioo`008Goo00<007ooOol04goo00<007ooOol0iWoo000QOol0
0`00Oomoo`0DOol00`00Oomoo`3UOol0025oo`03001oogoo01Aoo`03001oogoo0>Eoo`008Goo00<0
07ooOol05Goo00<007ooOol0i7oo000AOol00`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007oo
Ool05Goo00<007ooOol0i7oo000@Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0FOol0
0`00Oomoo`3SOol0011oo`03001oo`0000Qoo`03001oogoo00=oo`8001Moo`03001oogoo0>=oo`00
47oo00<007oo000027oo00<007ooOol00goo00<007ooOol05Woo00<007ooOol0hgoo000@Ool00`00
Ool00007Ool00`00Ool00004Ool00`00Oomoo`0GOol00`00Oomoo`3ROol0015oo`03001oogoo00Mo
o`03001oogoo00=oo`03001oogoo01Moo`03001oogoo0>9oo`008Goo00<007ooOol067oo00<007oo
Ool0hGoo000QOol00`00Oomoo`0HOol00`00Oomoo`3QOol0025oo`03001oogoo01Uoo`03001oogoo
0>1oo`008Goo0P006Woo00<007ooOol0h7oo000QOol00`00Oomoo`0JOol00`00Oomoo`3OOol0025o
o`03001oogoo01Yoo`03001oogoo0=moo`008Goo00<007ooOol06goo00<007ooOol0gWoo000QOol0
0`00Oomoo`0KOol00`00Oomoo`3NOol0025oo`03001oogoo01aoo`03001oogoo0=eoo`008Goo00<0
07ooOol077oo00<007ooOol0gGoo000QOol00`00Oomoo`0MOol00`00Oomoo`3LOol0025oo`8001io
o`03001oogoo0=aoo`008Goo00<007ooOol07Woo00<007ooOol0fgoo000QOol00`00Oomoo`0OOol0
0`00Oomoo`3JOol0025oo`03001oogoo01moo`03001oogoo0=Yoo`008Goo00<007ooOol087oo00<0
07ooOol0fGoo000QOol00`00Oomoo`0POol00`00Oomoo`3IOol0025oo`03001oogoo025oo`03001o
ogoo0=Qoo`008Goo00<007ooOol08Goo00<007ooOol0f7oo000QOol2000SOol00`00Oomoo`3GOol0
025oo`03001oogoo029oo`03001oogoo0=Moo`008Goo00<007ooOol08goo00<007ooOol0eWoo000Q
Ool00`00Oomoo`0TOol00`00Oomoo`3EOol0025oo`03001oogoo02Aoo`03001oogoo0=Eoo`004Goo
00<007ooOol00Woo00<007ooOol00Woo0`000goo00<007ooOol09Goo00<007ooOol0e7oo000@Ool0
0`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`3COol0011oo`03001oo`00
00Moo`@000=oo`8002Moo`03001oogoo0==oo`0047oo00<007oo00001goo00<007oo000017oo00<0
07ooOol09goo00<007ooOol0dWoo000@Ool00`00Ool00008Ool20004Ool00`00Oomoo`0XOol00`00
Oomoo`3AOol0015oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo02Qoo`03001oogoo0=5o
o`008Goo00<007ooOol0:Goo00<007ooOol0d7oo000QOol00`00Oomoo`0YOol00`00Oomoo`3@Ool0
025oo`03001oogoo02Yoo`03001oogoo0<moo`008Goo00<007ooOol0:goo00<007ooOol0cWoo000Q
Ool2000/Ool00`00Oomoo`3>Ool0025oo`03001oogoo02aoo`03001oogoo0<eoo`008Goo00<007oo
Ool0;Goo00<007ooOol0c7oo000QOol00`00Oomoo`0^Ool00`00Oomoo`3;Ool0025oo`03001oogoo
02moo`03001oogoo0<Yoo`008Goo00<007ooOol0<7oo00<007ooOol0bGoo000QOol00`00Oomoo`0a
Ool00`00Oomoo`38Ool0025oo`80039oo`03001oogoo0<Qoo`008Goo00<007ooOol0<Woo00<007oo
Ool0agoo000QOol00`00Oomoo`0cOol00`00Oomoo`36Ool0025oo`03001oogoo03Aoo`03001oogoo
0<Eoo`008Goo00<007ooOol0=Goo00<007ooOol0a7oo000QOol00`00Oomoo`0fOol00`00Oomoo`33
Ool0025oo`03001oogoo03Moo`800<=oo`008Goo00<007ooOol0>Goo00<007ooOol0`7oo000QOol2
000kOol00`00Oomoo`2oOol0025oo`03001oogoo03]oo`03001oogoo0;ioo`008Goo00<007ooOol0
?7oo0P00_Woo000QOol00`00Oomoo`0nOol00`00Oomoo`2kOol0025oo`03001oogoo03moo`03001o
ogoo0;Yoo`004Goo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo041oo`03001oogoo
0;Uoo`0047oo00<007oo00001goo00<007oo000017oo00<007ooOol0@Goo0P00^Goo000@Ool00`00
Ool00007Ool00`00Ool00004Ool20014Ool00`00Oomoo`2fOol0011oo`03001oo`0000Moo`8000Eo
o`03001oogoo04Aoo`03001oogoo0;Eoo`0047oo00<007oo00001goo00<007ooOol017oo00<007oo
Ool0AGoo0P00]Goo000AOol00`00Oomoo`07Ool20004Ool00`00Oomoo`17Ool00`00Oomoo`2bOol0
025oo`03001oogoo04Qoo`03001oogoo0;5oo`008Goo00<007ooOol0BGoo00<007ooOol0/7oo000Q
Ool00`00Oomoo`1:Ool2002`Ool0025oo`03001oogoo04aoo`03001oogoo0:eoo`008Goo0P00CWoo
00<007ooOol0[7oo000QOol00`00Oomoo`1>Ool00`00Oomoo`2[Ool0025oo`03001oogoo04moo`80
0:]oo`008Goo00<007ooOol0DGoo00<007ooOol0Z7oo000QOol00`00Oomoo`1BOol00`00Oomoo`2W
Ool0025oo`03001oogoo05=oo`800:Moo`008Goo00<007ooOol0EGoo00<007ooOol0Y7oo000QOol2
001GOol2002TOol0025oo`03001oogoo05Qoo`03001oogoo0:5oo`008Goo00<007ooOol0FGoo0P00
XGoo000QOol00`00Oomoo`1KOol00`00Oomoo`2NOol0025oo`03001oogoo05aoo`8009ioo`008Goo
00<007ooOol0GWoo00<007ooOol0Vgoo000QOol00`00Oomoo`1OOol2002KOol0025oo`03001oogoo
065oo`03001oogoo09Qoo`008Goo0P00Hgoo0P00V7oo000QOol00`00Oomoo`1TOol2002FOol0025o
o`03001oogoo06Ioo`8009Aoo`008Goo00<007ooOol0J7oo0`00TGoo000QOol00`00Oomoo`1[Ool2
002?Ool0025oo`03001oogoo06eoo`8008eoo`004Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol0Kgoo0P00Rgoo000@Ool00`00Ool00007Ool00`00Ool00004Ool00`00
Oomoo`1aOol20029Ool0011oo`03001oo`0000Moo`03001oo`0000Aoo`8007Aoo`8008Moo`0047oo
00<007oo000027oo00<007ooOol00goo00<007ooOol0MGoo0P00QGoo000@Ool00`00Ool00007Ool0
0`00Ool00004Ool00`00Oomoo`1gOol20023Ool0015oo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo07Uoo`<0081oo`008Goo00<007ooOol0O7oo1000O7oo000QOol00`00Oomoo`20Ool3001i
Ool0025oo`03001oogoo08=oo`<007Ioo`008Goo0P00Qgoo0`00Lgoo000QOol00`00Oomoo`29Ool3
001`Ool0025oo`03001oogoo08aoo`<006eoo`008Goo00<007ooOol0Sgoo1000JGoo000QOol00`00
Oomoo`2COol4001UOol0025oo`03001oogoo09Moo`@0065oo`008Goo00<007ooOol0Vgoo1@00G7oo
000QOol00`00Oomoo`2POol4001HOol0025oo`800:Eoo`D005=oo`008Goo00<007ooOol0ZGoo1@00
CWoo000QOol00`00Oomoo`2^Ool50019Ool0025oo`03001oogoo0;=oo`@004Eoo`008Goo00<007oo
Ool0]goo1`00?Woo000QOol00`00Oomoo`2nOol:000dOol0025oo`03001oogoo0<Qoo`T002]oo`00
8Goo0P00dWoo2P008Goo000QOol00`00Oomoo`3KOol9000HOol0025oo`03001oogoo0>Aoo`D001=o
o`008Goo00<007ooOol0o7oo000QOol00`00Oomoo`3lOol0025oo`03001oogoo0?aoo`008Goo00<0
07ooOol0o7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ogoo0`006goo
0`00P7oo0020Ool00`00Oomoo`0KOol00`00Oomoo`1oOol0075oo`<000=oo`8000=oo`80009oo`<0
00]oo`<00004Ool007ooOol20002Ool20003Ool30003Ool200000goo00000002Ool01000Ool00000
17oo0P00Jgoo001aOol00`00Ool00002Ool01P00Oomoo`00Ool000Aoo`04001oogoo000;Ool01P00
Oomoo`00Ool000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo
00000Woo00<007ooOol0Jgoo001cOol01000Oomoo`0017oo0`000Woo00@007ooOol000]oo`<0009o
o`<000=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool00002Ool01000Oomoo`000goo
0`00Jgoo001bOol00`00Oomoo`040002Ool300000goo00000002000<Ool01@00Oomoo`00Ool00`00
0goo0P0000=oo`0000000P000goo0P0000=oo`0000000P000goo0P000Woo0`00Jgoo001aOol00`00
Ool00002Ool00`00Oomoo`0FOol01000Oomoo`00SGoo001aOol3000JOol4002>Ool00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.707935, -0.0800133, 
  0.0212303, 0.00661777}},
  CellTags->"5.1"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["RootLocusAnimation", "MR"],
  " complements ",
  StyleBox["RootLocusPlot", "MR"],
  " and provides information on the direction of the evolution of root loci. \
The syntax for the two function is identical; the only exception is that the \
option ",
  StyleBox["PlotPoints", "MR"],
  " is meaningless for the animation and is replaced by ",
  StyleBox["Frames", "MR"],
  ", which determines the number of frames the animation should contain. "
}], "Text",
  CellTags->"5.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["RootLocusAnimation",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"k", 
                        StyleBox[",",
                          "MR"], " ", "kmin", 
                        StyleBox[",",
                          "MR"], " ", "kmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"5.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sequence",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["root",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["locus",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plots",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["with",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["parameter",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["k",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["running",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["kmin",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["kmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"5.1"],

Cell["Animating the root loci. ", "Caption",
  CellTags->"5.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 The Bode Plot", "Subsection",
  CellTags->{"5.2", "5.2.1"}],

Cell[CellGroupData[{

Cell["The Basic Function", "Subsubsection",
  CellTags->"5.2.1"],

Cell[TextData[{
  "The Bode plot is the first example of the ",
  StyleBox["frequency response", "TI"],
  " analysis tools that we consider in this chapter. By frequency response, \
we mean the response to purely ",
  StyleBox["sinusoidal", "TI"],
  " signals. ",
  StyleBox["BodePlot", "MR"],
  " depicts, in the form of ",
  StyleBox["GraphicsArray", "MR"],
  ", the frequency dependence of the magnitude and phase response. The \
magnitude response is the ratio of the span of the output sinusoid to the \
input one, and the phase response is the phase difference between them. The \
magnitude and phase dependencies are plotted in the \
double\[Hyphen]logarithmic and semilogarithmic scales, respectively. "
}], "Text",
  CellTags->"5.2.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["BodePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Bode",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  CellTags->"5.2.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["BodePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"w", 
                        StyleBox[",",
                          "MR"], " ", "wmin", 
                        StyleBox[",",
                          "MR"], " ", "wmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.2.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Bode",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["frequency",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["w",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["running",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmin",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"5.2.1"],

Cell["Creating the Bode plots. ", "Caption",
  CellTags->"5.2.1"],

Cell[TextData[{
  "Like all other plotting routines in ",
  StyleBox["Control System Professional", "TI"],
  ", ",
  StyleBox["BodePlot", "MR"],
  " accepts a system in state\[Hyphen]space or transfer function form in the \
continuous\[Hyphen] or discrete\[Hyphen]time domain. Specifying the frequency \
range is optional. If it is not supplied, ",
  StyleBox["BodePlot", "MR"],
  " will try to determine a suitable range internally. Also optional is the \
naming of the frequency variable in supplying the desired frequency range; ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S0.0.3"],
  StyleBox["w", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["wmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["wmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " works as well as ",
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S0.0.3"],
  StyleBox["wmin", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["wmax", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ". This should come as no surprise if you recall that the variable in ",
  StyleBox["TransferFunction", "MR"],
  " is an internal parameter and does not have any meaning outside the scope \
of the ",
  StyleBox["TransferFunction", "MR"],
  " object. "
}], "Text",
  CellTags->"5.2.1"],

Cell["Consider again the second\[Hyphen]order system. ", "MathCaption",
  CellTags->"5.2.1"],

Cell["\<\
s2[wn_, zeta_]  = TransferFunction[s,
 wn^2/(s^2 + 2 zeta wn s + wn^2)];\
\>", "Input",
  CellLabel->"In[11]:=",
  CellTags->"5.2.1"],

Cell["\<\
This is the Bode plot for the unity natural frequency and damping \
ratio. The frequency range is not specified and is determined automatically. \
\
\>", "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{

Cell["BodePlot[s2[1, 1]]", "Input",
  CellLabel->"In[12]:=",
  CellTags->"5.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.646095 0.00374531 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.16716 -0.0125 -11 -12.5625 ]
[.16716 -0.0125 11 0 ]
[.35665 -0.0125 -11 -12.5625 ]
[.35665 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.64335 -0.0125 -5 -12.5625 ]
[.64335 -0.0125 5 0 ]
[.83284 -0.0125 -5 -12.5625 ]
[.83284 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .0843 -24 -4.5 ]
[-0.0125 .0843 0 4.5 ]
[-0.0125 .17793 -24 -4.5 ]
[-0.0125 .17793 0 4.5 ]
[-0.0125 .27156 -24 -4.5 ]
[-0.0125 .27156 0 4.5 ]
[-0.0125 .3652 -18 -4.5 ]
[-0.0125 .3652 0 4.5 ]
[-0.0125 .45883 -18 -4.5 ]
[-0.0125 .45883 0 4.5 ]
[-0.0125 .55246 -18 -4.5 ]
[-0.0125 .55246 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.16716 .63053 -11 0 ]
[.16716 .63053 11 12.5625 ]
[.35665 .63053 -11 0 ]
[.35665 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.64335 .63053 -5 0 ]
[.64335 .63053 5 12.5625 ]
[.83284 .63053 -5 0 ]
[.83284 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.35665 0 m
.35665 .61803 L
s
.5 0 m
.5 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.83284 0 m
.83284 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.39436 0 m
.39436 .61803 L
s
.42624 0 m
.42624 .61803 L
s
.45385 0 m
.45385 .61803 L
s
.47821 0 m
.47821 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.7867 0 m
.7867 .61803 L
s
.87055 0 m
.87055 .61803 L
s
.90243 0 m
.90243 .61803 L
s
.93004 0 m
.93004 .61803 L
s
.9544 0 m
.9544 .61803 L
s
0 .0843 m
1 .0843 L
s
0 .17793 m
1 .17793 L
s
0 .27156 m
1 .27156 L
s
0 .3652 m
1 .3652 L
s
0 .45883 m
1 .45883 L
s
0 .55246 m
1 .55246 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .0843 m
.00625 .0843 L
s
[(-150)] -0.0125 .0843 1 0 Mshowa
0 .17793 m
.00625 .17793 L
s
[(-125)] -0.0125 .17793 1 0 Mshowa
0 .27156 m
.00625 .27156 L
s
[(-100)] -0.0125 .27156 1 0 Mshowa
0 .3652 m
.00625 .3652 L
s
[(-75)] -0.0125 .3652 1 0 Mshowa
0 .45883 m
.00625 .45883 L
s
[(-50)] -0.0125 .45883 1 0 Mshowa
0 .55246 m
.00625 .55246 L
s
[(-25)] -0.0125 .55246 1 0 Mshowa
.125 Mabswid
0 .10303 m
.00375 .10303 L
s
0 .12175 m
.00375 .12175 L
s
0 .14048 m
.00375 .14048 L
s
0 .1592 m
.00375 .1592 L
s
0 .19666 m
.00375 .19666 L
s
0 .21538 m
.00375 .21538 L
s
0 .23411 m
.00375 .23411 L
s
0 .25284 m
.00375 .25284 L
s
0 .29029 m
.00375 .29029 L
s
0 .30902 m
.00375 .30902 L
s
0 .32774 m
.00375 .32774 L
s
0 .34647 m
.00375 .34647 L
s
0 .38392 m
.00375 .38392 L
s
0 .40265 m
.00375 .40265 L
s
0 .42138 m
.00375 .42138 L
s
0 .4401 m
.00375 .4401 L
s
0 .47756 m
.00375 .47756 L
s
0 .49628 m
.00375 .49628 L
s
0 .51501 m
.00375 .51501 L
s
0 .53374 m
.00375 .53374 L
s
0 .06557 m
.00375 .06557 L
s
0 .04685 m
.00375 .04685 L
s
0 .02812 m
.00375 .02812 L
s
0 .00939 m
.00375 .00939 L
s
0 .57119 m
.00375 .57119 L
s
0 .58992 m
.00375 .58992 L
s
0 .60864 m
.00375 .60864 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 .61178 m
.16716 .61803 L
s
gsave
.16716 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 .61178 m
.35665 .61803 L
s
gsave
.35665 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 .61178 m
.64335 .61803 L
s
gsave
.64335 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 .61178 m
.83284 .61803 L
s
gsave
.83284 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 .61428 m
.25101 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.39436 .61428 m
.39436 .61803 L
s
.42624 .61428 m
.42624 .61803 L
s
.45385 .61428 m
.45385 .61803 L
s
.47821 .61428 m
.47821 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.7867 .61428 m
.7867 .61803 L
s
.87055 .61428 m
.87055 .61803 L
s
.90243 .61428 m
.90243 .61803 L
s
.93004 .61428 m
.93004 .61803 L
s
.9544 .61428 m
.9544 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0843 m
1 .0843 L
s
.99375 .17793 m
1 .17793 L
s
.99375 .27156 m
1 .27156 L
s
.99375 .3652 m
1 .3652 L
s
.99375 .45883 m
1 .45883 L
s
.99375 .55246 m
1 .55246 L
s
.125 Mabswid
.99625 .10303 m
1 .10303 L
s
.99625 .12175 m
1 .12175 L
s
.99625 .14048 m
1 .14048 L
s
.99625 .1592 m
1 .1592 L
s
.99625 .19666 m
1 .19666 L
s
.99625 .21538 m
1 .21538 L
s
.99625 .23411 m
1 .23411 L
s
.99625 .25284 m
1 .25284 L
s
.99625 .29029 m
1 .29029 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32774 m
1 .32774 L
s
.99625 .34647 m
1 .34647 L
s
.99625 .38392 m
1 .38392 L
s
.99625 .40265 m
1 .40265 L
s
.99625 .42138 m
1 .42138 L
s
.99625 .4401 m
1 .4401 L
s
.99625 .47756 m
1 .47756 L
s
.99625 .49628 m
1 .49628 L
s
.99625 .51501 m
1 .51501 L
s
.99625 .53374 m
1 .53374 L
s
.99625 .06557 m
1 .06557 L
s
.99625 .04685 m
1 .04685 L
s
.99625 .02812 m
1 .02812 L
s
.99625 .00939 m
1 .00939 L
s
.99625 .57119 m
1 .57119 L
s
.99625 .58992 m
1 .58992 L
s
.99625 .60864 m
1 .60864 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59602 L
.08949 .5875 L
.12233 .57757 L
.15517 .56603 L
.18801 .55266 L
.22085 .53721 L
.25369 .51947 L
.28654 .49923 L
.31938 .47634 L
.35222 .45076 L
.38506 .42258 L
.4179 .39206 L
.45074 .35966 L
.48358 .32604 L
.51642 .292 L
.54926 .25838 L
.5821 .22598 L
.61494 .19545 L
.64778 .16727 L
.68062 .14169 L
.71346 .11881 L
.74631 .09857 L
.77915 .08083 L
.81199 .06538 L
.84483 .052 L
.87767 .04046 L
.91051 .03053 L
.94335 .02202 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.603319 0.0146834 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.16716 -0.0125 -11 -12.5625 ]
[.16716 -0.0125 11 0 ]
[.35665 -0.0125 -11 -12.5625 ]
[.35665 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.64335 -0.0125 -5 -12.5625 ]
[.64335 -0.0125 5 0 ]
[.83284 -0.0125 -5 -12.5625 ]
[.83284 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01598 -18 -4.5 ]
[-0.0125 .01598 0 4.5 ]
[-0.0125 .16282 -18 -4.5 ]
[-0.0125 .16282 0 4.5 ]
[-0.0125 .30965 -18 -4.5 ]
[-0.0125 .30965 0 4.5 ]
[-0.0125 .45649 -18 -4.5 ]
[-0.0125 .45649 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.16716 .63053 -11 0 ]
[.16716 .63053 11 12.5625 ]
[.35665 .63053 -11 0 ]
[.35665 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.64335 .63053 -5 0 ]
[.64335 .63053 5 12.5625 ]
[.83284 .63053 -5 0 ]
[.83284 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.35665 0 m
.35665 .61803 L
s
.5 0 m
.5 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.83284 0 m
.83284 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.39436 0 m
.39436 .61803 L
s
.42624 0 m
.42624 .61803 L
s
.45385 0 m
.45385 .61803 L
s
.47821 0 m
.47821 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.7867 0 m
.7867 .61803 L
s
.87055 0 m
.87055 .61803 L
s
.90243 0 m
.90243 .61803 L
s
.93004 0 m
.93004 .61803 L
s
.9544 0 m
.9544 .61803 L
s
0 .16282 m
1 .16282 L
s
0 .30965 m
1 .30965 L
s
0 .45649 m
1 .45649 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01598 m
.00625 .01598 L
s
[(-40)] -0.0125 .01598 1 0 Mshowa
0 .16282 m
.00625 .16282 L
s
[(-30)] -0.0125 .16282 1 0 Mshowa
0 .30965 m
.00625 .30965 L
s
[(-20)] -0.0125 .30965 1 0 Mshowa
0 .45649 m
.00625 .45649 L
s
[(-10)] -0.0125 .45649 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04535 m
.00375 .04535 L
s
0 .07472 m
.00375 .07472 L
s
0 .10408 m
.00375 .10408 L
s
0 .13345 m
.00375 .13345 L
s
0 .19218 m
.00375 .19218 L
s
0 .22155 m
.00375 .22155 L
s
0 .25092 m
.00375 .25092 L
s
0 .28028 m
.00375 .28028 L
s
0 .33902 m
.00375 .33902 L
s
0 .36838 m
.00375 .36838 L
s
0 .39775 m
.00375 .39775 L
s
0 .42712 m
.00375 .42712 L
s
0 .48585 m
.00375 .48585 L
s
0 .51522 m
.00375 .51522 L
s
0 .54459 m
.00375 .54459 L
s
0 .57395 m
.00375 .57395 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 .61178 m
.16716 .61803 L
s
gsave
.16716 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 .61178 m
.35665 .61803 L
s
gsave
.35665 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 .61178 m
.64335 .61803 L
s
gsave
.64335 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 .61178 m
.83284 .61803 L
s
gsave
.83284 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 .61428 m
.25101 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.39436 .61428 m
.39436 .61803 L
s
.42624 .61428 m
.42624 .61803 L
s
.45385 .61428 m
.45385 .61803 L
s
.47821 .61428 m
.47821 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.7867 .61428 m
.7867 .61803 L
s
.87055 .61428 m
.87055 .61803 L
s
.90243 .61428 m
.90243 .61803 L
s
.93004 .61428 m
.93004 .61803 L
s
.9544 .61428 m
.9544 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01598 m
1 .01598 L
s
.99375 .16282 m
1 .16282 L
s
.99375 .30965 m
1 .30965 L
s
.99375 .45649 m
1 .45649 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04535 m
1 .04535 L
s
.99625 .07472 m
1 .07472 L
s
.99625 .10408 m
1 .10408 L
s
.99625 .13345 m
1 .13345 L
s
.99625 .19218 m
1 .19218 L
s
.99625 .22155 m
1 .22155 L
s
.99625 .25092 m
1 .25092 L
s
.99625 .28028 m
1 .28028 L
s
.99625 .33902 m
1 .33902 L
s
.99625 .36838 m
1 .36838 L
s
.99625 .39775 m
1 .39775 L
s
.99625 .42712 m
1 .42712 L
s
.99625 .48585 m
1 .48585 L
s
.99625 .51522 m
1 .51522 L
s
.99625 .54459 m
1 .54459 L
s
.99625 .57395 m
1 .57395 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60205 m
.05665 .60158 L
.08949 .60093 L
.12233 .60005 L
.15517 .59885 L
.18801 .59723 L
.22085 .59502 L
.25369 .59205 L
.28654 .58808 L
.31938 .58282 L
.35222 .57594 L
.38506 .56704 L
.4179 .55575 L
.45074 .54171 L
.48358 .52464 L
.51642 .50439 L
.54926 .48095 L
.5821 .45449 L
.61494 .42527 L
.64778 .39366 L
.68062 .36004 L
.71346 .32479 L
.74631 .28826 L
.77915 .25072 L
.81199 .21242 L
.84483 .17354 L
.87767 .13424 L
.91051 .09461 L
.94335 .05475 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001?Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0NOol0051oo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo01eoo`00?Goo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01aoo`00?Woo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol077oo000nOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01aoo`00?Woo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0LOol003ioo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0MOol003eo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo01io
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000dOol00`00Oomoo`02Ool00`00Oomo
o`050007Ool00`00Oomoo`02Ool01000Oomoogoo0`0047oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol02goo1@004Goo0`006Goo00<007ooOol03Goo1@000Woo00<007ooOol05Goo000cOol0
0`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007Ool00`00Oomoo`0?Ool00`00Ool00007Ool0
0`00Ool0000>Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Ool0000@Ool01`00Oomoogoo001o
o`0001Ioo`00<goo00<007oo000027oo00<007ooOol01Woo00<007oo000027oo00<007ooOol03Woo
00<007oo00002Goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol03Woo
00L007ooOomoo`00Ool0000FOol003=oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Qo
o`03001oogoo00ioo`03001oo`0000Moo`8000moo`03001oogoo019oo`03001oogoo01Moo`80015o
o`07001oogooOol007oo00005Woo000cOol00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007
Ool00`00Ool0000?Ool00`00Ool00007Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Ool0000H
Ool00`00Oomoo`0@Ool01`00Oomoogoo001oo`0001Ioo`00=7oo00<007ooOol01Woo0P002Goo00<0
07ooOol01goo00<007ooOol03goo00<007ooOol01Woo0`003Goo0P0057oo00<007ooOol05goo0`00
3goo0P0017oo00<007ooOol05Goo003MOol00=eoo`00gGoo000gOonA000EOol003Moo`05001oogoo
Ool0000COol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol001Aoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomo
ogoo00000Woo00<007ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`00=goo00D007oo
Oomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
o`000080009oo`03001oogoo01=oo`00=goo0P000Woo00<03gooOol04Goo00<03gooOol02Woo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoogoo1@000Woo00@03goo000001Eoo`00=goo00D007ooOomoo`0?
01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00@03gooOomoo`D0000400moogoo00l3Ool0100?Oomoo`005Goo
000gOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?00000000Ool03`=oo`0400mo
ogoo00l3Ool0100?Oomoo`005Goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0400moogooOol2
0004Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol003Moo`05001oogooOol03`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0600l00000001oo`0?17oo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00
Oomoo`0COol003Moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`03
00moogoo00Uoo`0300moogoo00Eoo`0300moogoo00=oo`8000Aoo`0300moogoo009oo`0500moogoo
Ool03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol0
0`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo
00<00003Ool03goo00=oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`80
01Eoo`009goo1@000Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`0300moogoo015oo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03`00000017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00
Oomoo`0COol002Uoo`07001oogooOol007oo00000Woo00<007oo00000Woo00D007ooOomoo`0?01=o
o`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol017oo0P001Woo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00
Oomoo`0COol001=oo`03001oogoo009oo`03001oogoo00Qoo`<000=oo`03001oogoo00=oo`06001o
ogoo001oo`000Woo0P00K@0?00<0000?00l07@0?0P005Goo000COol6000@Ool01000Oomoogoo0P00
0goo00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo
00<03gooOol02Goo00@03gooOomoo`80009oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000COol01P00Oomo
o`00Ool0011oo`05001oogooOol00004Ool00`00Ool00002Ool20002Ool00`0?Oomoo`0AOol00`0?
Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0400moo`000004Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000E
Ool001=oo`04001oogoo000AOol20003Ool30003Ool01@00Oomoogoo00000goo00<03gooOol04Goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool20006Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001o
ogoo01=oo`0057oo0P008Goo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
57oo00<03gooOol01goo0P0000<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`80009o
o`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol01Woo00@007oo
Ool03`Moo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1P0?Oomoogoo00moo`8001Eoo`004goo00<007ooOol00Woo00<007ooOol077oo00D007ooOomoo`0?
01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol017oo0P000goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500mo
ogooOol03`02Ool00`00Oomoo`0COol001=oo`H001ioo`05001oogooOol03`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03aAoo`0300moogoo00=oo`03001oogoo00=oo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
0Woo00<007ooOol04goo000EOol01000Oomoo`007Woo0P000Woo00<03gooOol04Goo00<03gooOol0
2Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00lDOol00`0?Oomoo`02Ool00`00Oomoo`04Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?
Ool2000EOol001Eoo`03001oogoo01moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol03aAoo`0300moogoo008000Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000F
Ool3000NOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300l0
000000Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`0067oo00<007ooOol037oo1@0000Aoo`000000
00=oo`05001oogooOol00003Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAo
o`03001oogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000YOol01@00Oomoogoo
000017oo00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
4goo00<0000?Ool02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol001Moo`8000Yoo`<0
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo008005T03`0300003`0?03403`8001Eo
o`005Goo00@007oo0000011oo`03001oogoo009oo`04001oogooOol20003Ool01@00Oomoogoo00l0
4goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00lAOol01000Oomoo`0?2goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol0
3`02Ool00`00Oomoo`0COol001Eoo`04001oo`00000@Ool01`00Oomoogoo001oo`00009oo`03001o
ogoo009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03a1oo`05001oogoo
Ool03`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`005Goo10003goo0P0017oo00@0
07ooOomoo`<0009oo`80009oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?3goo
00<007ooOol00Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000HOol00`00Oomo
o`0LOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l>Ool00`00Oomoo`03
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00=goo0P000Woo00<0
3gooOol04Goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l=Ool00`00Oomoo`04Ool00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00H03gooOomoo`0?Ool2000EOol001Eoo`800003Ool007oo01eoo`05001oogooOol03`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol03`aoo`03001oogoo00Eoo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1@0?Oomoogoo00l00Woo00<007ooOol04goo000EOol200000goo001oo`0MOol01@00Oomoogoo00l0
4goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00l;Ool00`00Oomoo`06Ool00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?009oo`03001oogoo01=oo`005Goo0P0000=oo`00Ool07Goo0P000Woo00<03goo
Ool04Goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00l:Ool00`00Oomoo`07Ool00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00H03gooOomoo`0?Ool2000EOol001Eoo`03001oo`0001moo`05001oogooOol03`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol03`Uoo`03001oogoo00Qoo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l00Woo00<007ooOol04goo000gOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00l8Ool00`00Oomoo`09Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001o
ogoo01=oo`009goo1@000Woo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo015oo`03
00moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1goo00<007ooOol02Woo00<03gooOol02Goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600mo
ogooOol03goo0P005Goo000FOol2000AOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`05
001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Ioo`03001oogoo00]oo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000EOol200000goo001oo`09Ool3
0003Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`8004`03`0300003`0?03h03`8001Eo
o`005Goo0P0000=oo`00Ool03goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool01@00Oomo
ogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l4Ool00`00Oomoo`0=Ool00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`005Woo00<007oo000047oo00L007ooOomo
o`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00l3Ool00`00Oomoo`0>Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo
01=oo`00:7oo0P0017oo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo015oo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`0?0Woo00<007ooOol03goo00<03gooOol02Goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogoo
Ool03goo0P005Goo000gOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogoo00mo
o`004Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`05001o
ogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOol03`0001=oo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1@0?Oomoogoo00l00Woo00<007ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol001Aoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`00=goo
00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Ool0000?57oo00<03gooOol02Goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`80009oo`0300moogoo015oo`0300moogoo
00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?001oo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000g
Ool01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04001oogoo00lDOol00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00=goo00D007ooOomoo`0?01=oo`0300moogoo
00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0800moogoo
Ool03goo00003`9oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<0
07ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00l2Ool00`0?Oomo
o`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol001Eoo`@001Eoo`03001oogoo
009oo`05001oogooOol00003Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000Woo00@03gooOol03aAo
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000DOol00`00Oomoo`02
Ool00`00Oomoo`0BOol01`00Oomoogoo001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`00
00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol0
4goo000COol00`00Oomoo`04Ool00`00Oomoo`0;Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`02
000n00l00`0000l03`1<00l2000EOol002moo`03001oogoo008000=oo`05001oogooOol03`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?001oogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo
00<007ooOol04goo000]Ool00`00Ool00002Ool00`00Oomoo`02Ool01@00Oomoogoo00l04goo00<0
3gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
07ooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03
001oogoo01=oo`005Woo0P005Goo0`000Woo0`000Woo0P000Woo00<03gooOol04Goo00<03gooOol0
2Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOomoo`0000l3Ool0100?
Oomoo`0?0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000E
Ool01000Oomoo`007Woo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00@03gooOol03`9oo`0300moogoo019o
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000COol00`00Ool00002
Ool00`00Oomoo`0LOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAo
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`004goo1P007Woo00D007ooOomoo`0?
01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol0
3`02Ool00`00Oomoo`0COol001Qoo`03001oogoo01aoo`05001oogooOol03`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol0
4goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0600moogooOol03goo0P005Goo000FOol2000OOol01@00Oomoogoo00l04goo00<03gooOol0
2Woo00<03gooOol01Goo00<03gooOol017oo00H03gooOol007oo00l4Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000E
Ool200000goo001oo`0MOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<0
3gooOol017oo00<03`0000000Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lD
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`005Goo0P0000=oo`00
Ool057oo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo015oo`0300moogoo00Yoo`03
00moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000FOol00`00
Ool0000DOol00`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol02Woo
00<03gooOol01Goo00<03gooOol00goo00<0000?Ool00goo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=o
o`00:7oo0`0017oo00H007ooOol007oo0002Ool2000`00l00`0000l03`1J00l2000EOol002eoo`80
00=oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`020002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
3aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000FOol20002Ool0
0`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol0
2Woo00<03gooOol01Goo00<03goo000017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo
01=oo`005Goo00H007ooOol007oo000BOol30003Ool01000Oomoogoo0P000Woo00<03gooOol04Goo
00<03gooOol02Woo00<03gooOol01Goo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2
000EOol001Eoo`06001oogoo001oo`0077oo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`03001oogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol001Eo
o`D001eoo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`03Ool200000`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000EOol00`00Oomoo`0OOol20002
Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`02Ool01000Oomoo`0?1Woo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00H03gooOomoo`0?Ool2000EOol003Moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`020003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000C
Ool00`00Oomoo`04Ool00`00Oomoo`0JOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
00000005Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`0057oo00<007oo
Ool00Woo00<007ooOol06goo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`03001oogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol001Eoo`@001ioo`05
001oogooOol03`0COol00`0?Oomoo`08Ool200000`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomo
o`06Ool20002Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`80
01Eoo`00;Goo0`000goo00D007ooOomoo`0000=oo`0300moogoo015oo`0300moogoo00Aoo`8000Ao
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0C
Ool002eoo`03001oogoo009oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`02Ool2
0006Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007oo
Ool04goo000XOol30003Ool00`00Oomoo`03Ool00`00Oomoo`02000I00l2001b00l2000EOol002io
o`04001oogooOol20003Ool01@00Oomoogoo00l04goo00<03`0000002Woo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lD
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00;Goo00<007oo0000
0Woo00<007ooOol00Woo0P000Woo00<03gooOol03Woo100037oo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?
Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol002ioo`04001oogooOol30002Ool01@00Oomo
ogoo00l037oo10000goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?009oo`03001oogoo01=oo`00=goo00D007ooOomoo`0?00Yoo`8000Moo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00
Oomoo`0COol003Moo`80009oo`0300moogoo00Eoo`<000Uoo`0300moogoo00Yoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000gOol01@00Oomoogoo00l0
0Woo1@0037oo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03goo
Oomoo`0?009oo`03001oogoo01=oo`00=goo00@007ooOomoo`<0015oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Mo
o`80009oo`03001oogoo015oo`03001oogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`03001o
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0057oo00<007ooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0600moogooOol007oo0P005Goo000gOonA000EOol00=eoo`00gGoo003MOol00=eoo`00gGoo
003MOol003Aoo`03001oogoo009oo`03001oogoo00D000Moo`03001oogoo009oo`04001oogooOol3
000@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool5000AOol3000IOol00`00Oomo
o`0=Ool50002Ool00`00Oomoo`0EOol003=oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`00
00Moo`03001oogoo00moo`03001oo`0000Moo`03001oo`0000ioo`03001oogoo015oo`03001oogoo
01Qoo`03001oo`00011oo`07001oogooOol007oo00005Woo000cOol00`00Ool00008Ool00`00Oomo
o`06Ool00`00Ool00008Ool00`00Oomoo`0>Ool00`00Ool00009Ool00`00Oomoo`0<Ool00`00Oomo
o`0BOol00`00Oomoo`0IOol00`00Oomoo`0>Ool01`00Oomoogoo001oo`0001Ioo`00<goo00<007oo
000027oo00<007ooOol01Woo00<007oo000027oo00<007ooOol03Woo00<007oo00001goo0P003goo
00<007ooOol04Woo00<007ooOol05goo0P004Goo00L007ooOomoo`00Ool0000FOol003=oo`03001o
o`0000Qoo`03001oogoo00Ioo`03001oo`0000Moo`03001oo`0000moo`03001oo`0000Moo`03001o
ogoo00ioo`03001oogoo015oo`03001oo`0001Qoo`03001oogoo011oo`07001oogooOol007oo0000
5Woo000dOol00`00Oomoo`06Ool20009Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`06
Ool3000=Ool2000DOol00`00Oomoo`0GOol3000?Ool20004Ool00`00Oomoo`0EOol00=eoo`00gGoo
003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo
003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomoo`0lOol00`00Oomoo`0QOol004eo
o`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo02Qoo`03001oogoo021o
o`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P0000=oo`0000000Woo00<007oo0000
0P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo00@0009oo`<000Eoo`03001oogoo
009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03001oogoo00<000Uoo`03001oogoo
01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06001oogoo001oo`000Woo00<007oo
000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00Oomoo`02Ool01@00Oomoo`00Ool0
0`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`03001o
ogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol07goo
000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007ooOol007oo0002Ool00`00Ool00002
0002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001oogoo009oo`<000Aoo`04001oogoo
0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`030002Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo01moo`00>goo0P000goo
100000Aoo`00000000=oo`D00004Ool00000Ool300000goo000000020002Ool3000017oo000007oo
0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<000Ioo`03001oogoo009oo`04001o
ogooOol30002Ool30003Ool200000goo000000020003Ool30009Ool00`00Oomoo`0OOol003]oo`04
001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo00<007ooOol017oo00L007ooOomo
o`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yoo`D003]oo`03001oo`0000<000Uo
o`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025oo`00gGoo003MOol00=eoo`00gGoo
003MOol00=eoo`00gGoo000aOol00`00Oomoo`02Ool00`00Oomoo`050007Ool00`00Oomoo`02Ool0
1000Oomoogoo0`0047oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02goo1@004Goo0`00
6Goo00<007ooOol03Goo1@000Woo00<007ooOol067oo000`Ool00`00Ool00008Ool00`00Oomoo`06
Ool00`00Ool00007Ool00`00Oomoo`0?Ool00`00Ool00007Ool00`00Ool0000>Ool00`00Oomoo`0A
Ool00`00Oomoo`0HOol00`00Ool0000@Ool01`00Oomoogoo001oo`0001Uoo`00<7oo00<007oo0000
27oo00<007ooOol01Woo00<007oo000027oo00<007ooOol03Woo00<007oo00002Goo00<007ooOol0
37oo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol03Woo00L007ooOomoo`00Ool0000IOol0
031oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo00ioo`03001oo`00
00Moo`8000moo`03001oogoo019oo`03001oogoo01Moo`80015oo`07001oogooOol007oo00006Goo
000`Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007Ool00`00Ool0000?Ool00`00Ool0
0007Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Ool0000HOol00`00Oomoo`0@Ool01`00Oomo
ogoo001oo`0001Uoo`00<Goo00<007ooOol01Woo0P002Goo00<007ooOol01goo00<007ooOol03goo
00<007ooOol01Woo0`003Goo0P0057oo00<007ooOol05goo0`003goo0P0017oo00<007ooOol067oo
003MOol00=eoo`00gGoo000dOonA000HOol002]oo`<0009oo`05001oogooOol00003Ool00`00Oomo
o`0AOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000Woo00@007ooOol001Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`00
0Woo00<007ooOol05Woo000/Ool01P00Oomoo`00Ool0009oo`05001oogooOol03`0COol00`0?Oomo
o`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol0
5Woo000UOol30002Ool4000017oo001oo`000Woo0P000Woo00<03gooOol04Goo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOol007oo008001Qoo`005Woo1P00
3Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moo`0000l2Ool00`00Oomoo`0FOol001Ioo`<0
009oo`03001oogoo00eoo`80009oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?001oo`0?0Woo00<007ooOol05Woo
000IOol00`00Oomoo`0@Ool01@00Oomoogoo00000goo00D007ooOomoo`0?01=oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04001oogoo00l2Ool00`00Oomoo`0FOol0
01Ioo`<0009oo`03001oogoo01Ioo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0500003gooOol03`02Ool00`00Oomoo`0FOol001Ioo`H0
01Qoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0900moogooOol0
3goo001oo`0?009oo`0400moogoo000HOol001Ioo`03001oogoo009oo`03001oogoo01Ioo`05001o
ogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03`000Woo00@0
3gooOol03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0000=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Yoo`80
01Qoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOol0
000?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`04001oo`00000HOol01@00Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00@03gooOol0
3`9oo`03001oogoo01Ioo`0067oo00@007oo000001Qoo`05001oogooOol03`0COol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moo`00Ool03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo
000HOol4000HOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?
Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
001oogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006goo00<007ooOol05Woo0P000Woo
00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@00Oomoogoo00l00goo00@0
3gooOol03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D007ooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Uoo`80
009oo`03001oogoo01Aoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAo
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0600moogooOol0
000?0goo00D03gooOomoo`0?009oo`0400moogoo000HOol001Qoo`06001oogoo001oo`005Woo00D0
07ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l0
0Woo00@03gooOol001Qoo`0067oo00H007ooOol007oo000FOol01@00Oomoogoo00l04goo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool01P0?Oomoo`00Ool03`=oo`0500moogooOol03`02Ool0100?Oomoo`0067oo000H
Ool5000GOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol00`00Oomoo`0IOol01@00Oomo
ogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`03001oogoo01Ioo`0067oo00@007ooOol000ioo`8000Aoo`05001oogooOol00003Ool0
0`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`03001oogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00<007ooOol05Woo000HOol4000@Ool01P00Oomoo`00Ool0009oo`05001oogooOol0
3`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00
Oomoo`0FOol001Qoo`03001oogoo00Yoo`<000=oo`07001oogooOol007oo00000Woo0P00N@0?00<0
000?00l04@0?0P0067oo000HOol00`00Oomoo`0AOol01P00Oomoo`00Ool0009oo`05001oogooOol0
3`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00<007ooOol05Woo000IOol3000>Ool00`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?001oo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`03001oogoo01Ioo`006goo00<007ooOol03Goo00<007ooOol00Woo00D007ooOomoo`0000=o
o`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol00goo00<0000?Ool0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Ao
o`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00=oo`0300003goo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol01000Oomoo`0067oo00D007ooOomoo`0?01=o
o`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03goo
Ool00Woo00<007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
0`00Oomoo`0FOol001Ioo`03001oo`0000<001Qoo`05001oogooOol03`0COol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0500moogooOol00002Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Io
o`006goo00<007ooOol05Woo0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0100?Oomoo`000goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogoo
Ool03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moo`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol05Woo000HOol00`00Oomoo`0IOol01@00Oomoogoo00l04goo00<03gooOol0
2Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?001oo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Io
o`005goo10006Goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol02Goo00<03gooOol01Goo00<007ooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`04001oogoo000HOol20002
Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300mo
ogoo00Aoo`0300003goo00Eoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000HOol01000Oomoo`0067oo00D007ooOomoo`0?01=oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol00goo00<007oo00l0
1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00
Oomoo`0FOol001Qoo`03001oo`0001Uoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol03aAoo`0300moogoo00Uoo`0300moogoo00=oo`03001oo`0?00Ioo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000dOol01@00
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomo
o`02Ool01000Oomoo`0?1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool00`00Oomoo`0FOol001Qoo`03001oogoo01Uoo`05001oogooOol03`0COol00`0?
Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0500moogooOol00003Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03
001oogoo01Ioo`0067oo0`006Goo0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00lDOol00`0?Oomoo`09Ool01@0?Oomoogoo00000goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001]oo`03
001oogoo01Ioo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300mo
ogoo00Uoo`0400moogoo0004Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo00<007oo00003goo0`000goo
00D007ooOomoo`0000=oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol02Goo00<03goo00001Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`@000ioo`03001oogoo009o
o`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`03
00moogoo00Uoo`0300l007oo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000KOol00`00Oomoo`07Ool30003
Ool01`00Oomoogoo001oo`00009oo`8006L03`0300003`0?02<03`8001Qoo`00:goo00L007ooOomo
o`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?
Oomoo`08Ool00`0000moo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006Goo0P003goo00<007oo00000Woo
00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol01goo00<007oo00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`04001oogoo000?Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
00lDOol00`0?Oomoo`06Ool01000Oomoo`0?1goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`03001oo`00
009oo`03001oogoo01Ioo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
57oo00<03gooOol01Goo00D007ooOomoo`0?00Moo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000FOol6000HOol0
1@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`04Ool00`00
Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006goo00<007ooOol05Woo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol00goo00<007ooOol0
0goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0COol00`0?Oomo
o`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol03aAoo`0300moogoo009oo`03001oogoo00Aoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00<007ooOol05Woo000IOol2000IOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0500moogooOol00007Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00
67oo0P0000=oo`00Ool05goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
57oo00@03gooOol000Qoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol200000goo001o
o`0GOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Ool00009
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006Goo00<007oo000067oo00D007ooOomoo`0?
01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03`00Ool02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
3aAoo`03001oogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000dOol20002Ool00`0?
Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03a=oo`0300003goo00Yoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00lBOol00`00Ool03`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00=7oo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?4Woo00<007oo00l02goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol03a5oo`04001oogoo00l;Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00=7oo0P00
0Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l@Ool01@00Oomoogoo00l02goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0COol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03`moo`03001oogoo009oo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00<007ooOol05Woo000YOol50002Ool01@00Oomoogoo00000goo00<03gooOol04Goo00<03gooOol0
2Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00l=Ool20005Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001o
ogoo01Ioo`00:goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo00l<Ool00`00Oomoo`05Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03
001oogoo01Ioo`0067oo10002Goo0`000goo00L007ooOomoo`00Ool00002Ool2001B00l00`0000l0
3`0h00l2000HOol001Moo`03001oogoo009oo`03001oogoo00aoo`07001oogooOol007oo00000Woo
00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?2Woo00<007ooOol01goo00<0
3gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Aoo`03001o
ogoo00]oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?27oo0P002Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol0
02Yoo`8000Aoo`05001oogooOol00003Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool03`Moo`03001oogoo00Yoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo
000dOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Ioo`03001oogoo
00]oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000IOol2000IOol01@00
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0<Ool00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo00@007ooOol001Qoo`05001oogoo
Ool03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`=oo`8000moo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00Ool00002Ool00`00Oomoo`0FOol01@00Oomo
ogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l2Ool00`00Oomoo`0?Ool00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`005Woo1P0067oo0P000Woo00<03gooOol04Goo
00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00l2000BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`03001oogoo01Ioo`006goo00<007ooOol05Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Ool0000057oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Io
o`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo0P00
00=oo`0?Ool04goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`H0
01Qoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00P0000@03gooOol03aAoo`0300moogoo00Uo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00Ool00002Ool00`00Oomoo`0FOol0
1@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00<03goo00000P000Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00Ool00002Ool00`00Oomoo`0FOol20002Ool0
0`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool20002Ool0100?Oomoo`0?0Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool00`00Oomoo`0FOol001Moo`04001oo`00000IOol01@00Oomoogoo00l04goo00<0
3gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00P0000D0
3gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001o
ogoo01Ioo`00=7oo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300l00000009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0COol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Ool000030004Ool01@0?Oomoogoo
00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo
000FOol00`00Oomoo`04Ool00`00Oomoo`0DOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool0100?Oomoogoo1@000goo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`005goo00<007oo
Ool00Woo00<007ooOol05Goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`@0
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`@001Aoo`05001oogooOol0
0003Ool00`0?Oomoo`0AOol00`0?Oomoo`08Ool:00000`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol05Woo000_Ool00`00Ool00002Ool01@00Oomoogoo00l047oo3P0000=oo`0?
Ool01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00;goo00<0
07oo00000Woo0P000Woo4@000goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00D03gooOol03goo008001Qoo`00;goo00<007oo00000Woo00D007ooOomoo`0001=oo`03
001oogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0057oo00<007ooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo0002Ool00`00
Oomoo`0FOol002moo`03001oo`00009ooi4001Qoo`00<7oo00<007ooOol0ZWoo003MOol00=eoo`00
gGoo003MOol00=eoo`00<Goo00<007ooOol00Woo00<007ooOol01@001goo00<007ooOol00Woo00@0
07ooOomoo`<0011oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00]oo`D0015oo`<001Uo
o`03001oogoo00eoo`D0009oo`03001oogoo01Qoo`00<7oo00<007oo000027oo00<007ooOol01Woo
00<007oo00001goo00<007ooOol03goo00<007oo00001goo00<007oo00003Woo00<007ooOol04Goo
00<007ooOol067oo00<007oo000047oo00L007ooOomoo`00Ool0000IOol0031oo`03001oo`0000Qo
o`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo00ioo`03001oo`0000Uoo`03001oogoo00ao
o`03001oogoo019oo`03001oogoo01Uoo`03001oogoo00ioo`07001oogooOol007oo00006Goo000`
Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`0>Ool00`00Ool00007
Ool2000?Ool00`00Oomoo`0BOol00`00Oomoo`0GOol2000AOol01`00Oomoogoo001oo`0001Uoo`00
<7oo00<007oo000027oo00<007ooOol01Woo00<007oo00001goo00<007oo00003goo00<007oo0000
1goo00<007ooOol03Woo00<007ooOol04Goo00<007oo000067oo00<007ooOol047oo00L007ooOomo
o`00Ool0000IOol0035oo`03001oogoo00Ioo`8000Uoo`03001oogoo00Moo`03001oogoo00moo`03
001oogoo00Ioo`<000eoo`8001Aoo`03001oogoo01Moo`<000moo`8000Aoo`03001oogoo01Qoo`00
gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-1.86866, -235.595, 0.0146283, 1.85989}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-1.82357, -124.964, 0.0146184, 0.474083}},
  CellTags->"5.2.1"]
}, Open  ]],

Cell["This gives the Bode plot over a wider frequency range. ", "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{

Cell["BodePlot[s2[1, 1], {.01, 100}]", "Input",
  CellLabel->"In[13]:=",
  CellTags->"5.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.607114 0.00331219 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2619 -0.0125 -11 -12.5625 ]
[.2619 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -8 -12.5625 ]
[.7381 -0.0125 8 0 ]
[.97619 -0.0125 -11 -12.5625 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .02748 -24 -4.5 ]
[-0.0125 .02748 0 4.5 ]
[-0.0125 .11029 -24 -4.5 ]
[-0.0125 .11029 0 4.5 ]
[-0.0125 .19309 -24 -4.5 ]
[-0.0125 .19309 0 4.5 ]
[-0.0125 .2759 -24 -4.5 ]
[-0.0125 .2759 0 4.5 ]
[-0.0125 .3587 -18 -4.5 ]
[-0.0125 .3587 0 4.5 ]
[-0.0125 .4415 -18 -4.5 ]
[-0.0125 .4415 0 4.5 ]
[-0.0125 .52431 -18 -4.5 ]
[-0.0125 .52431 0 4.5 ]
[-0.0125 .60711 -6 -4.5 ]
[-0.0125 .60711 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2619 .63053 -11 0 ]
[.2619 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.7381 .63053 -8 0 ]
[.7381 .63053 8 12.5625 ]
[.97619 .63053 -11 0 ]
[.97619 .63053 11 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.09548 0 m
.09548 .61803 L
s
.13741 0 m
.13741 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.19023 0 m
.19023 .61803 L
s
.20908 0 m
.20908 .61803 L
s
.22502 0 m
.22502 .61803 L
s
.23883 0 m
.23883 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.33358 0 m
.33358 .61803 L
s
.37551 0 m
.37551 .61803 L
s
.40525 0 m
.40525 .61803 L
s
.42833 0 m
.42833 .61803 L
s
.44718 0 m
.44718 .61803 L
s
.46312 0 m
.46312 .61803 L
s
.47693 0 m
.47693 .61803 L
s
.48911 0 m
.48911 .61803 L
s
.57167 0 m
.57167 .61803 L
s
.6136 0 m
.6136 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.66642 0 m
.66642 .61803 L
s
.68527 0 m
.68527 .61803 L
s
.70121 0 m
.70121 .61803 L
s
.71502 0 m
.71502 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.80977 0 m
.80977 .61803 L
s
.8517 0 m
.8517 .61803 L
s
.88144 0 m
.88144 .61803 L
s
.90452 0 m
.90452 .61803 L
s
.92337 0 m
.92337 .61803 L
s
.93931 0 m
.93931 .61803 L
s
.95312 0 m
.95312 .61803 L
s
.9653 0 m
.9653 .61803 L
s
0 .02748 m
1 .02748 L
s
0 .11029 m
1 .11029 L
s
0 .19309 m
1 .19309 L
s
0 .2759 m
1 .2759 L
s
0 .3587 m
1 .3587 L
s
0 .4415 m
1 .4415 L
s
0 .52431 m
1 .52431 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .02748 m
.00625 .02748 L
s
[(-175)] -0.0125 .02748 1 0 Mshowa
0 .11029 m
.00625 .11029 L
s
[(-150)] -0.0125 .11029 1 0 Mshowa
0 .19309 m
.00625 .19309 L
s
[(-125)] -0.0125 .19309 1 0 Mshowa
0 .2759 m
.00625 .2759 L
s
[(-100)] -0.0125 .2759 1 0 Mshowa
0 .3587 m
.00625 .3587 L
s
[(-75)] -0.0125 .3587 1 0 Mshowa
0 .4415 m
.00625 .4415 L
s
[(-50)] -0.0125 .4415 1 0 Mshowa
0 .52431 m
.00625 .52431 L
s
[(-25)] -0.0125 .52431 1 0 Mshowa
0 .60711 m
.00625 .60711 L
s
[(0)] -0.0125 .60711 1 0 Mshowa
.125 Mabswid
0 .04404 m
.00375 .04404 L
s
0 .0606 m
.00375 .0606 L
s
0 .07716 m
.00375 .07716 L
s
0 .09372 m
.00375 .09372 L
s
0 .12685 m
.00375 .12685 L
s
0 .14341 m
.00375 .14341 L
s
0 .15997 m
.00375 .15997 L
s
0 .17653 m
.00375 .17653 L
s
0 .20965 m
.00375 .20965 L
s
0 .22621 m
.00375 .22621 L
s
0 .24277 m
.00375 .24277 L
s
0 .25933 m
.00375 .25933 L
s
0 .29246 m
.00375 .29246 L
s
0 .30902 m
.00375 .30902 L
s
0 .32558 m
.00375 .32558 L
s
0 .34214 m
.00375 .34214 L
s
0 .37526 m
.00375 .37526 L
s
0 .39182 m
.00375 .39182 L
s
0 .40838 m
.00375 .40838 L
s
0 .42494 m
.00375 .42494 L
s
0 .45807 m
.00375 .45807 L
s
0 .47463 m
.00375 .47463 L
s
0 .49119 m
.00375 .49119 L
s
0 .50775 m
.00375 .50775 L
s
0 .54087 m
.00375 .54087 L
s
0 .55743 m
.00375 .55743 L
s
0 .57399 m
.00375 .57399 L
s
0 .59055 m
.00375 .59055 L
s
0 .01092 m
.00375 .01092 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02748 m
1 .02748 L
s
.99375 .11029 m
1 .11029 L
s
.99375 .19309 m
1 .19309 L
s
.99375 .2759 m
1 .2759 L
s
.99375 .3587 m
1 .3587 L
s
.99375 .4415 m
1 .4415 L
s
.99375 .52431 m
1 .52431 L
s
.99375 .60711 m
1 .60711 L
s
.125 Mabswid
.99625 .04404 m
1 .04404 L
s
.99625 .0606 m
1 .0606 L
s
.99625 .07716 m
1 .07716 L
s
.99625 .09372 m
1 .09372 L
s
.99625 .12685 m
1 .12685 L
s
.99625 .14341 m
1 .14341 L
s
.99625 .15997 m
1 .15997 L
s
.99625 .17653 m
1 .17653 L
s
.99625 .20965 m
1 .20965 L
s
.99625 .22621 m
1 .22621 L
s
.99625 .24277 m
1 .24277 L
s
.99625 .25933 m
1 .25933 L
s
.99625 .29246 m
1 .29246 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32558 m
1 .32558 L
s
.99625 .34214 m
1 .34214 L
s
.99625 .37526 m
1 .37526 L
s
.99625 .39182 m
1 .39182 L
s
.99625 .40838 m
1 .40838 L
s
.99625 .42494 m
1 .42494 L
s
.99625 .45807 m
1 .45807 L
s
.99625 .47463 m
1 .47463 L
s
.99625 .49119 m
1 .49119 L
s
.99625 .50775 m
1 .50775 L
s
.99625 .54087 m
1 .54087 L
s
.99625 .55743 m
1 .55743 L
s
.99625 .57399 m
1 .57399 L
s
.99625 .59055 m
1 .59055 L
s
.99625 .01092 m
1 .01092 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .6019 L
.08949 .59995 L
.12233 .59727 L
.15517 .5936 L
.18801 .58855 L
.22085 .58163 L
.25369 .57216 L
.28654 .55921 L
.31938 .5416 L
.35222 .51789 L
.38506 .48646 L
.4179 .44598 L
.45074 .39619 L
.48358 .33903 L
.51642 .27901 L
.54926 .22185 L
.5821 .17206 L
.61494 .13157 L
.64778 .10014 L
.68062 .07643 L
.71346 .05883 L
.74631 .04588 L
.77915 .0364 L
.81199 .02948 L
.84483 .02443 L
.87767 .02076 L
.91051 .01808 L
.94335 .01613 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.603319 0.00735747 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2619 -0.0125 -11 -12.5625 ]
[.2619 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.7381 -0.0125 -8 -12.5625 ]
[.7381 -0.0125 8 0 ]
[.97619 -0.0125 -11 -12.5625 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01472 -18 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .16187 -18 -4.5 ]
[-0.0125 .16187 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .45617 -18 -4.5 ]
[-0.0125 .45617 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2619 .63053 -11 0 ]
[.2619 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.7381 .63053 -8 0 ]
[.7381 .63053 8 12.5625 ]
[.97619 .63053 -11 0 ]
[.97619 .63053 11 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.09548 0 m
.09548 .61803 L
s
.13741 0 m
.13741 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.19023 0 m
.19023 .61803 L
s
.20908 0 m
.20908 .61803 L
s
.22502 0 m
.22502 .61803 L
s
.23883 0 m
.23883 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.33358 0 m
.33358 .61803 L
s
.37551 0 m
.37551 .61803 L
s
.40525 0 m
.40525 .61803 L
s
.42833 0 m
.42833 .61803 L
s
.44718 0 m
.44718 .61803 L
s
.46312 0 m
.46312 .61803 L
s
.47693 0 m
.47693 .61803 L
s
.48911 0 m
.48911 .61803 L
s
.57167 0 m
.57167 .61803 L
s
.6136 0 m
.6136 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.66642 0 m
.66642 .61803 L
s
.68527 0 m
.68527 .61803 L
s
.70121 0 m
.70121 .61803 L
s
.71502 0 m
.71502 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.80977 0 m
.80977 .61803 L
s
.8517 0 m
.8517 .61803 L
s
.88144 0 m
.88144 .61803 L
s
.90452 0 m
.90452 .61803 L
s
.92337 0 m
.92337 .61803 L
s
.93931 0 m
.93931 .61803 L
s
.95312 0 m
.95312 .61803 L
s
.9653 0 m
.9653 .61803 L
s
0 .16187 m
1 .16187 L
s
0 .30902 m
1 .30902 L
s
0 .45617 m
1 .45617 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(-80)] -0.0125 .01472 1 0 Mshowa
0 .16187 m
.00625 .16187 L
s
[(-60)] -0.0125 .16187 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(-40)] -0.0125 .30902 1 0 Mshowa
0 .45617 m
.00625 .45617 L
s
[(-20)] -0.0125 .45617 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .05151 m
.00375 .05151 L
s
0 .0883 m
.00375 .0883 L
s
0 .12508 m
.00375 .12508 L
s
0 .19866 m
.00375 .19866 L
s
0 .23545 m
.00375 .23545 L
s
0 .27223 m
.00375 .27223 L
s
0 .34581 m
.00375 .34581 L
s
0 .38259 m
.00375 .38259 L
s
0 .41938 m
.00375 .41938 L
s
0 .49296 m
.00375 .49296 L
s
0 .52974 m
.00375 .52974 L
s
0 .56653 m
.00375 .56653 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .16187 m
1 .16187 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .45617 m
1 .45617 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .05151 m
1 .05151 L
s
.99625 .0883 m
1 .0883 L
s
.99625 .12508 m
1 .12508 L
s
.99625 .19866 m
1 .19866 L
s
.99625 .23545 m
1 .23545 L
s
.99625 .27223 m
1 .27223 L
s
.99625 .34581 m
1 .34581 L
s
.99625 .38259 m
1 .38259 L
s
.99625 .41938 m
1 .41938 L
s
.99625 .49296 m
1 .49296 L
s
.99625 .52974 m
1 .52974 L
s
.99625 .56653 m
1 .56653 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60331 m
.05665 .60331 L
.08949 .6033 L
.12233 .60328 L
.15517 .60324 L
.18801 .60317 L
.22085 .60303 L
.25369 .60278 L
.28654 .6023 L
.31938 .60141 L
.35222 .59975 L
.38506 .59675 L
.4179 .59144 L
.45074 .58247 L
.48358 .56837 L
.51642 .54807 L
.54926 .52158 L
.5821 .48995 L
.61494 .45467 L
.64778 .41709 L
.68062 .37814 L
.71346 .33844 L
.74631 .29833 L
.77915 .25799 L
.81199 .21753 L
.84483 .17701 L
.87767 .13646 L
.91051 .09588 L
.94335 .0553 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001>Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0OOol004moo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo01ioo`00?7oo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01eoo`00?Goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07Goo000mOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01eoo`00?Goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0MOol003eoo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0NOol003ao
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo01mo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000_Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05000DOol00`00Oomoo`02Ool00`00Oomoo`05000IOol5000JOol50002Ool0
0`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0EOol002ioo`03001oo`0000Moo`03
001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07
001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol002ioo`03001o
o`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qoo`03001oogoo01]oo`03001o
ogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol0
02ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qoo`03001oogoo
01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00
Ool0000FOol002ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qo
o`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool0
0002Ool00`00Ool0000FOol002moo`03001oogoo00Moo`04001oogooOol2000FOol00`00Oomoo`06
Ool2000LOol2000MOol20004Ool00`00Oomoo`0FOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0E
Ool00=eoo`00gGoo003MOol003Iooi4001Ioo`00=Woo00@007ooOol000Yoo`03001oogoo00=oo`05
001oogooOol00002Ool03000Oomoo`00Ool007oo001oo`00Ool000Uoo`03001oogoo00=oo`05001o
ogooOol00002Ool03000Oomoo`00Ool007oo001oo`00Ool000Uoo`03001oogoo00=oo`05001oogoo
Ool00003Ool00`00Ool00002Ool01P00Ool00000Ool000Uoo`03001oogoo00=oo`03001oogoo009o
o`04001oogoo0002Ool01P00Ool007oo001oo`8000=oo`03001oogoo01Aoo`009Goo1@000Woo00<0
07ooOol00Woo00<007ooOol00Woo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?0Woo0P005Woo000WOol00`00Oomoo`02Ool01`00Oomoogoo001o
o`0000=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo
00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Ool0000@0003Ool00`00Oomoo`0DOol0025oo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`04001oogooOol2001f00l4000C00l2000FOol002Moo`03
001oogoo00=oo`03001oogoo008000Aoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00<03goo00l00Woo00H03goo00l03goo00l8Ool50002Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol002Moo`07001oogooOol007oo00000Woo00<0
07ooOol00goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?
Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool0
3goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?
Ool03`0?Ool03`=oo`D00003Ool03goo00Aoo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0
3goo00moo`803`=oo`03001oogoo01Aoo`009Woo0P000goo0`000Woo0`000goo0P0000=oo`0?Ool0
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0500moo`0?00moo`040006Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol0
03Ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00<03goo00l0
0P0000<03gooOol01goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?0goo00<007ooOol057oo000fOol200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00<03goo00l00Woo00H03`0000003goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol003Ioo`04001oogoo00l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03goo00moo`800005Ool03`0?Ool03`09Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol003Io
o`800003Ool03goo00Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Ool00000Ool03goo00803`03
Ool03goo00Qoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00mo
o`803`9oo`8001Ioo`00=Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?0000
3`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool0
1P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`004Woo00<007ooOol00Woo00<007ooOol077oo
00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool200001Woo00moogoo00moo`803`03Ool0
3goo00Qoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`80
3`=oo`03001oogoo01Aoo`004Woo1P003Goo1@000Woo00<007ooOol00Woo00<007ooOol00Woo0P00
00=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00goo00/03gooOomoo`0?Ool007oo00moo`0?009oo`0600moo`0?00moo`0?
2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0Woo
0P005Woo000BOol01P00Oomoo`00Ool000moo`07001oogooOol007oo00000Woo00<007oo00000goo
00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0600moogooOol03`000Woo00<03goo00l00Woo00H03goo00l03goo
00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3
Ool00`00Oomoo`0DOol0019oo`04001oogoo000;Ool30003Ool00`00Oomoo`03Ool01P00Oomoo`00
Ool000=oo`8005X03`0300003`0?03003`8001Ioo`004goo0P004Woo00@007ooOomoo`8000=oo`03
001oo`0000=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Ool0000000l00goo00<03goo00l00Woo00H0
3goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?Ool200l3Ool00`00Oomoo`0DOol002Moo`05001oogooOol00004Ool00`00Ool00003Ool01000
Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03`00Oomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo
00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<0
07ooOol057oo000BOol00`00Oomoo`02Ool00`00Oomoo`0<Ool20003Ool30003Ool00`00Oomoo`02
Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l9Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l0
3goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool2
00l2Ool2000FOol0019oo`H001ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`02Ool00`0000moo`02Ool01`0?Oomo
ogoo00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000DOol01000Oomoo`007Woo0P00
00=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00Woo00<0000?Ool00Woo00L03gooOomoo`0?Ool03`02Ool01P0?Ool03`0?
Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`80
3`9oo`8001Ioo`0057oo00<007ooOol07goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0700moogooOol007oo00l00goo00L03goo
Oomoo`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`005Goo0`007Woo0P0000=oo`0?
Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo
00@03gooOol0009oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`03
00moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`9oo`8001Io
o`005goo00<007ooOol077oo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0400moogoo0002Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol003Ioo`04001oogoo00l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Ool00003Ool01@0?
Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol001Ioo`8000eo
o`D00004Ool000000003Ool00`00Oomoo`02Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?001oo`03Ool01@0?Oomoogoo
00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol001Aoo`04001oo`00000?Ool01@00
Oomoogoo000017oo00<007oo00000goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300l007oo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`0057oo00@007oo000000Uoo`<000=o
o`03001oogoo009oo`03001oogoo00=oo`04001oogooOol2001@00l00`0000l03`0j00l2000FOol0
01Aoo`@000moo`03001oogoo009oo`04001oogooOol20004Ool01000Oomoo`0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?27oo00<0000?Ool017oo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000GOol00`00
Oomoo`0=Ool01`00Oomoogoo001oo`00009oo`03001oogoo00=oo`04001oogoo00l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l7Ool00`00Ool03`05Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol002Ioo`80
00Aoo`04001oogooOol30003Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l7Ool00`00Ool03`05Ool01@0?Oomoogoo00l00goo00<0
3goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l2Ool2000FOol001Aoo`800003Ool007oo01eoo`04001oogoo00l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l6Ool01000
Oomoo`0?1Goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol0
57oo000DOol200000goo001oo`0MOol200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l5Ool01@00Oomoogoo00l01Goo00D03gooOomoo`0?
00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@0
3gooOol03`9oo`0600moo`0?Ool03goo0P0?0Woo0P005Woo000DOol200000goo001oo`0MOol01000
Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
1Goo00D007ooOomoo`0?00Eoo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool0
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=o
o`03001oogoo01Aoo`0057oo00<007oo00007goo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03goo
Oomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?17oo00<007ooOol00Woo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo
00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0Woo0P005Woo000fOol01000
Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
0goo00<007ooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600mo
o`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool0
3goo0P0?0goo00<007ooOol057oo000fOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0goo00<007ooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000EOol2000>
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo00moo`09Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol001Aoo`80
0003Ool007oo00ioo`07001oogooOol007oo00000Woo00<007oo00000goo00@007ooOol03`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo
00Aoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03
001oogoo01Aoo`0057oo0P0000=oo`00Ool027oo0`000goo00L007ooOomoo`00Ool00002Ool00`00
Ool00003Ool2001800l00`0000l03`1200l2000FOol001Eoo`03001oo`0000moo`07001oogooOol0
07oo00000Woo00<007oo00000goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0
3@0?Oomoo`0?Ool03goo00moo`0?Ool03`0000Qoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`009goo00L007ooOomoo`00Ool00002
Ool00`00Ool00003Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`0
3gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00d03goo
Ool03goo00moo`0?Ool03goo00l00008Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00moo`0?Ool200l2Ool2000FOol002Ioo`8000Aoo`03001oogoo009oo`03001oogoo009o
o`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool0
3goo0009Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo
00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3
Ool00`00Oomoo`0DOol003Ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`0
3gooOol03goo00moo`0?Ool03goo0009Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol003Ioo`800003Ool03goo00Uoo`0300moogoo
00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?00003`Uoo`0300moogoo00=oo`05
00moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`9oo`8001Ioo`00=Woo00@007ooOol0
3`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?00003`Uoo`03
00moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300mo
ogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo
01Aoo`00=Woo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo001oo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?0Woo0P005Woo000fOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo001oo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000fOol01000Oomoo`0?2Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03`0000moo`0?2Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000/Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`00Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol001Aoo`@001Aoo`07001oogooOol007oo0000
0goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo001o
o`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?
Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`80
3`=oo`03001oogoo01Aoo`004goo00<007ooOol00Woo00<007ooOol02goo0`000goo00<007ooOol0
0goo00@007ooOomoo`8004403`0300003`0?04T03`8001Ioo`004Woo00<007ooOol017oo00<007oo
Ool04Goo00<007ooOol00P0017oo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03`0000moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?
Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`00:goo00<007oo00000Woo00<007ooOol0
0goo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`00Ool0
3goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?
00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?0Woo0P005Woo000[Ool30002Ool30003Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03goo
Oomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`00Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@0
3gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000EOol2000OOol01000Oomo
o`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00l0000?Ool03goo00moo`0?2Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<0
3gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007oo
Ool057oo000DOol01000Oomoo`007Woo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00l0000?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?0Woo0P005Woo000BOol00`00Ool00002Ool00`00Oomoo`0L
Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool0
3goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo001oo`0?Ool03goo
00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00mo
o`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?
0goo00<007ooOol057oo000BOol6000NOol200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol007oo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000FOol001Moo`03001oogoo01aoo`04001oogoo
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo00003goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomo
o`0DOol003Ioo`800003Ool03goo00Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomo
o`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?001oo`0?
Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0
1P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0
3goo00moo`803`9oo`8001Ioo`005Goo0P005Goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool03000Oomoo`0?Ool03goo00moo`0?Ool03`Uo
o`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`03
00moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001o
ogoo01Aoo`0057oo0P0000=oo`00Ool04Woo00<007oo00000Woo00<007oo00000goo00@007ooOol0
3`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uo
o`0300moogoo00=oo`0500moogooOol03`02Ool03000Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`03
00moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300mo
ogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo
01Aoo`0057oo0P0000=oo`00Ool03Goo0`0017oo00H007ooOol007oo0003Ool2000j00l00`0000l0
3`1@00l2000FOol001Eoo`03001oo`0001=oo`8000=oo`03001oo`0000=oo`04001oogoo00l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool0200?Oomoogoo00l007oo00l2Ool02@0?Ool03goo00moo`0?Ool03`09Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol0
02]oo`03001oogoo009oo`03001oo`0000=oo`800003Ool03goo00Uoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogoo
Ool00002Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol0
3`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`04
00moogoo00l2Ool01P0?Ool03goo00moo`803`9oo`8001Ioo`00:goo0`000goo00<007ooOol00Woo
00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`Uoo`0300moogoo00=oo`0500moogoo00003`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool0
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=o
o`03001oogoo01Aoo`005Goo0P000Woo00<007ooOol06Woo00@007ooOol03`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`05
00moogoo00003`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`0057oo00H007oo
Ool007oo000LOol200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Ool007oo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l2Ool2000FOol001Aoo`06001oogoo001oo`0077oo00@007ooOol03`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo
00=oo`0500l007ooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`03
00moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`0057oo
1@007Goo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D007ooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600mo
o`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool0
3goo0P0?0Woo0P005Woo000DOol00`00Oomoo`0OOol01000Oomoo`0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00Woo00<0000?
Ool00Woo00@03gooOol03`9oo`0900moo`0?Ool03goo00moo`0?00Uoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Aoo`00=Woo0P0000=o
o`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00Woo00<0000?Ool00Woo00@03gooOol03`9oo`0900moo`0?Ool03goo00mo
o`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool0
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`9o
o`8001Ioo`004Woo00<007ooOol017oo00<007ooOol03goo0`000goo00<007ooOol00Woo00@007oo
Ool03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0700moogooOol007oo00l00goo00@03gooOol03`9oo`0900moo`0?Ool03goo00moo`0?00Uo
o`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`03
00moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001o
ogoo01Aoo`004goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00<007oo00000goo
00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`Uoo`0400moogoo0002Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool0
3goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo
00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3
Ool00`00Oomoo`0DOol001Aoo`@000ioo`<000=oo`03001oogoo00=oo`04001oogooOol2000_00l2
001L00l2000FOol002aoo`04001oogooOol20004Ool01000Oomoo`0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?27oo0P001Goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000[Ool00`00Ool00002Ool00`00
Oomoo`03Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l7Ool00`00Ool03`05Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H0
3goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?Ool200l2Ool2000FOol002aoo`04001oogooOol30003Ool01000Oomoo`0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?1Goo0P000Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo
00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000f
Ool200000goo00moo`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l3Ool20004Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H0
3goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?Ool200l2Ool2000FOol003Ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00d03gooOol03goo00moo`0?Ool03goo00moo`020006Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol003Ioo`04001oogoo00l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00/03gooOol03goo00moo`0?Ool03goo008000Qoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo
00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Ao
o`00=Woo0P0000=oo`0?Ool02Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0800moogoo00mo
o`0?Ool03`<0000300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?
Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0
1P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0
3goo00moo`803`9oo`8001Ioo`00=Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool00`0?Oomoo`05000017oo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300mo
o`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9o
o`0600moo`0?Ool03goo0P0?0goo00<007ooOol057oo000fOol200000goo00moo`09Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l01@0000T03goo00moo`0?Ool03goo00l02Goo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol0
0Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0Woo0P005Woo000aOol00`00Oomoo`02Ool0
1000Oomoo`0?2Woo00<03goo000020000Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0DOol0
031oo`03001oo`0000=oo`03001oogoo00d000Aoo`0500moogooOol03`02Ool0300?Oomoo`0?Ool0
3goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool0
3`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00mo
o`803`=oo`03001oogoo01Aoo`00<7oo00<007oo00000goo0P0000=oo`00Ool02Goo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`002Goo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`002Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`002Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moo`0?Ool03goo00l0009oo`8001Ioo`00<7oo00<007oo0000
0gooT@005Woo000`Ool00`00Ool0002ZOol0035oo`03001oogoo0:Uoo`00gGoo003MOol00=eoo`00
gGoo000_Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000DOol00`00Oomoo`02Ool0
0`00Oomoo`05000IOol5000JOol50002Ool00`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00
Oomoo`0EOol002ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qo
o`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool0
0002Ool00`00Ool0000FOol002ioo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03
001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000FOol002ioo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo01=oo`03001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo0000
67oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol002ioo`03001oo`0000Moo`03001oo`00
00=oo`03001oogoo01=oo`03001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogoo
Ool007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol002moo`03001oogoo00Mo
o`04001oogooOol2000FOol00`00Oomoo`06Ool2000LOol2000MOol20004Ool00`00Oomoo`0FOol2
0004Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol0
0=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001;Ool2
000EOol2000EOol00`00Oomoo`0lOol00`00Oomoo`0ROol004aoo`03001oogoo01Aoo`03001oogoo
019oo`03001oogoo01=oo`03001oogoo02Qoo`03001oogoo025oo`00>Goo0`000goo0`000goo0P00
0goo0`000Woo0`000Woo0P0000=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@0
07ooOomoo`<00003Ool007oo00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=o
o`800003Ool00000009oo`03001oogoo00<000Uoo`03001oogoo021oo`00>Woo00<007ooOol00goo
00D007ooOomoo`0000Aoo`06001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004
Ool00`00Ool0000BOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03
001oogoo009oo`03001oo`00009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`00
0Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol087oo000jOol00`00Oomoo`03Ool01000
Oomoogoo0`000Woo00H007ooOol007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Ao
o`03001oo`00019oo`03001oogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`030002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00
009oo`03001oogoo00Moo`03001oogoo021oo`00>Woo0P000goo100000Aoo`00000000=oo`D00004
Ool00000Ool300000goo000000020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@0
07ooOol0009oo`8000=oo`<000Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool20000
0goo000000020003Ool30009Ool00`00Oomoo`0POol003Yoo`04001oogoo000jOol01@00Oomoogoo
00000Woo00<007ooOol01goo00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06
Ool00`00Oomoo`0QOol003Uoo`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qo
o`8000Moo`03001oogoo029oo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000/Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000DOol00`00Oomoo`02Ool00`00Oomoo`05
000IOol5000JOol50002Ool00`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0HOol0
02]oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qoo`03001oogoo
01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00
Ool0000IOol002]oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03001oo`0000Qo
o`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool0
0002Ool00`00Ool0000IOol002]oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01=oo`03
001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000IOol002]oo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo01=oo`03001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo0000
67oo00L007ooOomoo`00Ool00002Ool00`00Ool0000IOol002aoo`03001oogoo00Moo`04001oogoo
Ool2000FOol00`00Oomoo`06Ool2000LOol2000MOol20004Ool00`00Oomoo`0FOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol003=ooi4001Uoo`00:Goo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol000Yoo`03001oogoo00=oo`05001oogooOol00002Ool03000
Oomoo`00Ool007oo001oo`00Ool000Uoo`03001oogoo00=oo`05001oogooOol00002Ool03000Oomo
o`00Ool007oo001oo`00Ool000Uoo`03001oogoo00=oo`05001oogooOol00003Ool00`00Ool00002
Ool01P00Ool00000Ool000Uoo`03001oogoo00=oo`03001oogoo009oo`04001oogoo0002Ool01P00
Ool007oo001oo`8000=oo`03001oogoo01Moo`00:7oo00<007oo00000Woo00<007oo00000goo00@0
07ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03
001oogoo01Moo`008goo0`000Woo00<007oo00000Woo00<007oo00000goo0P0000=oo`0?Ool02Goo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol0
0goo00<03gooOol00Woo00@03gooOol03`9oo`0800moo`0?Ool03goo00l0009oo`8001Uoo`005Goo
1P003Woo00L007ooOomoo`00Ool00003Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moo`0?Ool03goo00003`=oo`03001oogoo01Moo`005Goo0`000Woo00<007ooOol0
2goo00<007oo00000Woo00<007oo00000goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03
Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00l000803`=oo`03001oogoo01Moo`0067oo00<007ooOol03Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?
Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool03goo001oo`803`=oo`03001oogoo01Moo`005Goo0`000Woo00<007ooOol05Woo00@0
07ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03`0000moo`803`=oo`03
001oogoo01Moo`005Goo1P0067oo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?
Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool007oo00moo`803`9oo`8001Uoo`005Goo00<007ooOol00Woo00<007ooOol05Woo00@0
07ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?00003goo00moo`803`=oo`03
001oogoo01Moo`00<goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomo
o`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02
Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
00003goo00moo`803`=oo`03001oogoo01Moo`006Goo0P0067oo00@007ooOol03`Yoo`0300moogoo
00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`05
00moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P00Ool03goo00moo`803`=oo`03001oogoo01Moo`005goo00@0
07oo000001Qoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H0
3goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0300?Oomoo`0?Ool0000?Ool03goo
00moo`803`=oo`03001oogoo01Moo`005goo00@007oo000001Qoo`04001oogoo00l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0300?Oomoo`0?Ool0000?Ool03goo00moo`803`9oo`8001Uoo`005goo100067oo00@0
07ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0<00moogoo00l007oo00moo`0?Ool03goo0P0?0goo00<0
07ooOol05goo000JOol00`00Oomoo`0FOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool0009oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000cOol01000Oomoo`0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo
00<03gooOol00Woo00@03goo00003`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000H
Ool20002Ool00`00Oomoo`0DOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300mo
o`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03`00Ool03`9o
o`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000GOol01P00Oomoo`00Ool001Ioo`04001o
ogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo
00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?001oo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000I
Ool001Moo`06001oogoo001oo`005Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`04001oogoo
00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`005goo1@005goo00@007ooOol03`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo
00=oo`0600moogooOol0000?0Woo00T03gooOol03goo00moo`0?Ool00P0?0goo00<007ooOol05goo
000GOol00`00Oomoo`0IOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00mo
ogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?
009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00H03gooOol007oo00l2Ool02@0?Oomoo`0?
Ool03goo00moo`0200l3Ool00`00Oomoo`0GOol001Moo`04001oogoo000=Ool20004Ool00`00Oomo
o`02Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool0
3goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?
00moo`0?2Goo00<03gooOol00goo00<03goo00000Woo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?0goo00<007ooOol05goo000GOol4000=Ool00`00Ool00002Ool00`00Ool00003Ool01000Oomo
o`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<0
3gooOol00goo00<03`00Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007oo
Ool05goo000GOol00`00Oomoo`09Ool30002Ool00`00Ool00002Ool00`00Ool00003Ool2001i00l0
0`0000l03`0A00l2000IOol001Moo`03001oogoo00ioo`8000=oo`03001oo`0000=oo`04001oogoo
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?
Oomoo`03Ool00`00Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomo
o`0GOol001Qoo`<000eoo`03001oogoo009oo`03001oo`0000=oo`04001oogoo00l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`02Ool00`00
00moo`03Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Yoo`03
001oogoo00aoo`8000=oo`03001oogoo009oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H03goo00l03goo00l9Ool01`0?Oomoogoo001oo`0?00Aoo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`00<goo00@007ooOol03`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo
00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0700moogooOol007oo
00l017oo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000cOol01000
Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo
00@03gooOol0009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`9oo`80
01Uoo`005goo00@007ooOol001Qoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<0
3goo00l00Woo00H03goo00l03goo00l9Ool00`0?Ool00003Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Eoo`03001oo`0000<001Qoo`04001o
ogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo
00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool0
0`0?Ool00003Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00
Oomoo`0GOol001Yoo`03001oogoo01Ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?001oo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol003=oo`04001oogoo00l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`00Oomoo`03Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Mo
o`03001oogoo01Uoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00H03goo00l03goo00l8Ool00`0000moo`04Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l2Ool2000IOol001Ioo`@001Uoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00<03goo00l00Woo00H03goo00l03goo00l7Ool00`00Ool03`05Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Moo`04001oogoo000H
Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool0
3goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00mo
o`0?1Woo00@007ooOol03`Eoo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`80
3`=oo`03001oogoo01Moo`005goo00@007ooOol001Qoo`04001oogoo00l:Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l5Ool01@00Oomoogoo00l01Goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000GOol00`00
Ool0000IOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600mo
o`0?00moo`0?17oo00<007ooOol00Woo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9o
o`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000cOol01000Oomoo`0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?0goo00<007ooOol00goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol0
5goo000GOol00`00Oomoo`0IOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300mo
o`0?009oo`0600moo`0?00moo`0?0Woo00<007ooOol017oo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0Woo0P006Goo000GOol3000IOol01000Oomoo`0?
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?0Woo00<007oo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?
0goo00<007ooOol05goo000JOol00`00Oomoo`0FOol01000Oomoo`0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03goo
Oomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0300moo`0?009oo`0800moo`0?00moo`0?Ool000Moo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`005goo00<007oo
00003goo0`000Woo00<007ooOol00Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01`0?Ool03`0?Ool03`0000Qoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`005goo10003goo00H007ooOol0
07oo0003Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600mo
o`0?00moo`002Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool0
3goo0P0?0goo00<007ooOol05goo000JOol00`00Oomoo`06Ool30002Ool4000017oo001oo`000goo
0P00I`0?00<0000?00l08`0?0P006Goo000XOol00`00Ool00002Ool00`00Ool00003Ool01000Oomo
o`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?001oo`0?2Goo00<0
3gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007oo
Ool05goo000HOol2000?Ool20002Ool00`00Ool00003Ool01000Oomoo`0?2Woo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0300moo`0?009oo`0600moo`0?001oo`0?2Goo00<03gooOol00goo00<03gooOol0
0Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000GOol01000Oomo
o`003goo00D007ooOomoo`0000Aoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<0
3goo00l00Woo00H03goo00003goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Eoo`03001oo`00009oo`03001oogoo
01Ioo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03`0000l0
3goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool2
00l3Ool00`00Oomoo`0GOol001Eoo`H001Qoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H007oo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000IOol001Yoo`03001oogoo01Ioo`04001oogoo
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H007oo00l03goo00l9Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomo
o`0GOol003=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo00moo`0000mo
o`0200l00goo00moo`08Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Qoo`8001Uoo`04001oogoo00l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03goo00l007oo00moo`0200l00goo00moo`08Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Moo`80
0003Ool007oo01Moo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo00l007oo
00moo`0200l00goo00moo`08Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H0
3goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Moo`800003Ool007oo01Moo`04001oogoo00l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00000Woo00H03goo00l03goo00l9Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000IOol001Qo
o`03001oo`0001Qoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03`0000l00Woo
00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l3Ool00`00Oomoo`0GOol003=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00<007oo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol003=oo`04001oogoo00l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00@0000?Ool03`9oo`0600moo`0?00moo`0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol0
5goo000cOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?2Goo00<03gooOol00goo00/03gooOomoo`0?Ool007oo00moo`0?009oo`0600mo
o`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool0
3goo0P0?0goo00<007ooOol05goo000cOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00H03gooOomoo`0?0002
Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`00<goo00@007ooOol03`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo
00=oo`0500moogooOol00003Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`9oo`8001Uoo`00<goo00@0
07ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?
Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`Uoo`0300moogoo00=oo`0500moogoo00003`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03
001oogoo01Moo`00<goo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomo
o`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moo`00Ool03`03Ool00`0?Ool03`02
Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
Ool03goo00moo`803`=oo`03001oogoo01Moo`00:7oo0`000goo00<007ooOol00Woo00@007ooOol0
3`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`03
00moogoo00=oo`0500moo`00Ool03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300mo
ogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo
01Moo`00:7oo00<007ooOol00Woo00<007oo00000goo00@007ooOol03`Yoo`0300moogoo00=oo`05
00moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500l007oo
Ool03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`005goo100027oo0`00
0goo00L007ooOomoo`00Ool00003Ool2001F00l00`0000l03`0d00l2000IOol001Ioo`03001oogoo
009oo`03001oogoo00]oo`07001oogooOol007oo00000goo00@007ooOol03`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`05
00moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo009oo`030000
3goo009oo`0700moogooOol03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol001Eoo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oo`00009oo`03001oo`0000=oo`04001oogoo00l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool01`0?Oomo
ogoo001oo`0?00=oo`0700moogooOol03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol0
02Uoo`03001oogoo009oo`03001oogoo009oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool01`0?Oomoogoo001oo`0?00=oo`0700mo
ogooOol03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00Oomoo`0GOol003=oo`04001oogoo00l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0100?Oomo
o`000Woo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol0
0goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo
000HOol2000IOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03goo00000goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?0Woo0P006Goo000GOol01000Oomoo`0067oo00@007ooOol03`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`05
00moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300l007oo00=oo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`005Goo00<007oo
00000Woo00<007ooOol05Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`Qoo`8000Eoo`0500moogooOol03`03Ool00`0?Ool03`02Ool0
1P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0
3goo00moo`803`=oo`03001oogoo01Moo`005Goo1P0067oo00@007ooOol03`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`0300moogoo00=oo`05
00moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Moo`03001oo`0?00Eoo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`006Woo00<007oo
Ool05Woo00@007ooOol03`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool0
3goo00moo`0?Ool03`Uoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`Ioo`04001oogoo00l5Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo
00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?
Ool200l3Ool00`00Oomoo`0GOol001Eoo`03001oogoo009oo`03001oogoo01Ioo`04001oogoo00l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l5Ool01@00
Oomoogoo00l01Goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<0
3gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007oo
Ool05goo000EOol6000HOol01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00mo
ogoo00moo`0?Ool03goo00moo`0?0goo0P0017oo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?0Woo0P006Goo000EOol00`00Ool00002Ool00`00Oomoo`0FOol0
1000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?0Woo00<007ooOol017oo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?0goo00<007ooOol05goo000EOol00`00Ool00002Ool00`00Oomoo`0FOol01000Oomo
o`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
2Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0>00moogoo00moo`0?Ool03goo00moo`0?Ool0
00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03
001oogoo01Moo`005Woo00@007oo000001Uoo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00/03gooOol03goo00moo`0?Ool03goo008000Qoo`0300moogoo00=oo`0500moogooOol0
3`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`04
00moogoo00l2Ool01P0?Ool03goo00moo`803`=oo`03001oogoo01Moo`00<goo00@007ooOol03`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`Uoo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200000`0?Oomoo`07
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3Ool00`00
Oomoo`0GOol003=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?00003goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l2Ool2000IOol001Eoo`03001oogoo00Aoo`03001oogoo01Aoo`04001oogoo00l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00H03gooOol03goo00l2000017oo00moo`0?2Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol0
5goo000FOol00`00Oomoo`02Ool00`00Oomoo`0EOol01000Oomoo`0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00D03goo
Oomoo`0?009oo`0300moo`0000<00006Ool03goo00moo`0?2Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000GOol4000COol00`00
Oomoo`02Ool01000Oomoo`0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?2Goo00<03gooOol00goo00@03gooOomoo`D0000:Ool03goo00moo`0?Ool0
3goo00l9Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo
00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l3
Ool00`00Oomoo`0GOol002eoo`03001oo`0000=oo`04001oogoo00l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?Oomoo`03Ool40000100?
Oomoo`0?0Woo00T03goo00moo`0?Ool03goo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol05goo000]Ool00`00Ool00003Ool20000
0goo0000000a00001@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l9Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l2Ool2000IOol002eo
o`03001oo`0000=oo`04001oogoo000:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo0009Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo0009Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00H03goo00l03goo0009Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
00moo`0?Ool03`000goo00<007ooOol05goo000]Ool00`00Ool00003OonA000IOol002ioo`03001o
ogoo0:aoo`00gGoo003MOol00=eoo`00gGoo003MOol002aoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00D001Aoo`03001oogoo009oo`03001oogoo00D001Uoo`D001Yoo`D0009oo`03001o
ogoo01Eoo`D0009oo`03001oogoo009oo`03001oogoo01Qoo`00:goo00<007oo00001goo00<007oo
00000goo00<007ooOol04goo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007oo
Oomoo`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`00:goo00<007oo0000
1goo00<007oo00000goo00<007ooOol04goo00<007oo000027oo00<007ooOol06goo00<007ooOol0
77oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`00:goo
00<007oo00001goo00<007oo00000goo00<007ooOol04goo00<007oo000027oo00<007ooOol06goo
00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`00
01Uoo`00:goo00<007oo00001goo00<007oo00000goo00<007ooOol04goo00<007oo000027oo00<0
07ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001oo`00009o
o`03001oo`0001Uoo`00;7oo00<007ooOol01goo00@007ooOomoo`8001Ioo`03001oogoo00Ioo`80
01aoo`8001eoo`8000Aoo`03001oogoo01Ioo`8000Aoo`03001oogoo009oo`03001oogoo01Qoo`00
gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-3.69343, -254.634, 0.0292567, 2.1031}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-3.60328, -249.392, 0.0292369, 0.946134}},
  CellTags->"5.2.1"]
}, Open  ]],

Cell[TextData[{
  "By default, ",
  StyleBox["BodePlot", "MR"],
  " tries to unwrap the phase in order to present a smooth phase curve should \
branch cuts be detected. The value ",
  StyleBox["Automatic", "MR"],
  " for the option ",
  StyleBox["PhaseRange", "MR"],
  " typically (unless the gain and phase margins are to be \
plotted\[LongDash]see below) corresponds to such behavior. ",
  StyleBox["PhaseRange", "MR"],
  " allows also to shift the graph to another phase range which must be \
specified in the form ",
  StyleBox["PhaseRange", "MR"],
  " ",
  StyleBox["->", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`{\)], "InlineFormula",
    CellTags->"S0.0.3"],
  StyleBox["min", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["max", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`}\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", with the new limits ",
  StyleBox["min", "TI"],
  " and ",
  StyleBox["max", "TI"],
  " given in degrees. Very rapid changes in phase dependence may cause errors \
in phase unwrapping. The safest (and fastest) choice is ",
  StyleBox["PhaseRange", "MR"],
  " ",
  StyleBox["->{-180,", "MR"],
  " ",
  StyleBox["180}", "MR"],
  ", in which case no additional processing of the phase is performed.    \n\
Another way to eliminate possible errors in phase unwrapping is to increase \
the number of points at which the transfer function is sampled by changing \
the option ",
  StyleBox["PlotPoints", "MR"],
  "; this is also useful if rapid changes in the magnitude or phase curve are \
not plotted satisfactorily otherwise. For some plots, you may wish to use \
linear spacing between samples instead of the default logarithmic spacing. \
This can be done by using ",
  StyleBox["PlotSampling", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["LinearSpacing", "MR"],
  ". \nThe option ",
  StyleBox["PhaseRange", "MR"],
  " is in no way a substitute for the standard ",
  StyleBox["Mathematica", "TI"],
  " plotting option ",
  StyleBox["PlotRange", "MR"],
  " and, in fact, works quite differently. If, for example, a plot does not \
have any part in the range specified in ",
  StyleBox["PlotRange", "MR"],
  ", nothing will appear in the graph. On the other hand, ",
  StyleBox["PhaseRange", "MR"],
  " will bring the graph into the specified range based on the principle that \
all ",
  Cell[BoxData[
      \(TraditionalForm\`360  \[Degree]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " intervals are physically equivalent. "
}], "Text",
  CellTags->"5.2.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["PhaseRange",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            StyleBox[\(the\ range\ for\ plotting\ the\ phase\ curve\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["PlotPoints",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["30",
                "StandardForm"],
              "Text"], 
            StyleBox[\(how\ many\ points\ of\ the\ graph\ are\ required\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["PlotSampling",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["LogSpacing",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(distribute\ points\ evenly\ on\ the\ logarithmic\ or\ linear\ 
                scale\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["Margins",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ to\ compute\ and\ show\ gain\ and\ phase\ margins\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["MarginStyle",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(a\ list\ of\ lists\ of\ graphics\ primitives\ to\ use\ for\ 
                each\ margins\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"5.2.1"],

Cell[TextData[{
  "Options specific to ",
  StyleBox["BodePlot", "MR"],
  ". "
}], "Caption",
  CellTags->"5.2.1"],

Cell[TextData[{
  StyleBox["BodePlot", "MR"],
  " also accepts options pertinent to ",
  StyleBox["ListPlot", "MR"],
  " and ",
  StyleBox["GraphicsArray", "MR"],
  ". Because a plot consists of two subplots, certain \
options\[LongDash]namely, ",
  StyleBox["AspectRatio", "MR"],
  ", ",
  StyleBox["AxesLabel", "MR"],
  ", ",
  StyleBox["AxesOrigin", "MR"],
  ", ",
  StyleBox["FrameLabel", "MR"],
  ", ",
  StyleBox["Epilog", "MR"],
  ", ",
  StyleBox["Prolog", "MR"],
  ", ",
  StyleBox["FrameTicks", "MR"],
  ", ",
  StyleBox["GridLines", "MR"],
  ", ",
  StyleBox["Ticks", "MR"],
  ", and ",
  StyleBox["PlotRange", "MR"],
  "\[LongDash]are handled in a nonstandard fashion. Given a list of two items \
as input, they will apply the first item to the magnitude plot and the second \
to the phase plot. Other options are applied equally to both plots or to ",
  StyleBox["GraphicsArray", "MR"],
  " itself. \n",
  StyleBox["BodePlot", "MR"],
  " operates on MIMO systems by grouping the graphs related to each input and \
plotting as many graphs as there are inputs. You may specify options for each \
input differently by wrapping option values into additional list. By default, \
the graphs related to different outputs in one plot are distinguished by the \
",
  StyleBox["Hue", "MR"],
  " value. This can be changed using the standard ",
  StyleBox["PlotStyle", "MR"],
  " option. "
}], "Text",
  CellTags->"5.2.1"],

Cell["\<\
Here is a single\[Hyphen]input, multiple\[Hyphen]output system, of \
which each input\[Hyphen]output pair is a second\[Hyphen]order system with a \
different value of damping ratio. \
\>", "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{

Cell["\<\
TransferFunction[s,
 Table[{1/(s^2 + 2 s zeta +1)},
 {zeta, .05, .8, .25}]]\
\>", "Input",
  CellLabel->"In[14]:=",
  CellTags->"5.2.1"],

Cell[BoxData[
    \(TransferFunction[
      s, {{1\/\(1 + 0.1`\ s + s\^2\)}, {1\/\(1 + 0.6`\ s + s\^2\)}, {
          1\/\(1 + 1.10000000000000008`\ s + s\^2\)}, {
          1\/\(1 + 1.60000000000000008`\ s + s\^2\)}}]\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->"5.2.1"]
}, Open  ]],

Cell["This is its Bode plot. ", "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{

Cell["\<\
BodePlot[%, {.1, 10},
 PlotStyle -> {
 Dashing[{.05, .01, .01, .01}],
 Dashing[{.05, .01}],
 Dashing[{.05}],
 Thickness[.001]
 },
 PlotPoints -> 200
]\
\>", "Input",
  CellLabel->"In[15]:=",
  CellTags->"5.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.605224 0.00329118 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.16716 -0.0125 -11 -12.5625 ]
[.16716 -0.0125 11 0 ]
[.35665 -0.0125 -11 -12.5625 ]
[.35665 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.64335 -0.0125 -5 -12.5625 ]
[.64335 -0.0125 5 0 ]
[.83284 -0.0125 -5 -12.5625 ]
[.83284 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .02927 -24 -4.5 ]
[-0.0125 .02927 0 4.5 ]
[-0.0125 .11155 -24 -4.5 ]
[-0.0125 .11155 0 4.5 ]
[-0.0125 .19383 -24 -4.5 ]
[-0.0125 .19383 0 4.5 ]
[-0.0125 .27611 -24 -4.5 ]
[-0.0125 .27611 0 4.5 ]
[-0.0125 .35838 -18 -4.5 ]
[-0.0125 .35838 0 4.5 ]
[-0.0125 .44066 -18 -4.5 ]
[-0.0125 .44066 0 4.5 ]
[-0.0125 .52294 -18 -4.5 ]
[-0.0125 .52294 0 4.5 ]
[-0.0125 .60522 -6 -4.5 ]
[-0.0125 .60522 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.16716 .63053 -11 0 ]
[.16716 .63053 11 12.5625 ]
[.35665 .63053 -11 0 ]
[.35665 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.64335 .63053 -5 0 ]
[.64335 .63053 5 12.5625 ]
[.83284 .63053 -5 0 ]
[.83284 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.35665 0 m
.35665 .61803 L
s
.5 0 m
.5 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.83284 0 m
.83284 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.39436 0 m
.39436 .61803 L
s
.42624 0 m
.42624 .61803 L
s
.45385 0 m
.45385 .61803 L
s
.47821 0 m
.47821 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.7867 0 m
.7867 .61803 L
s
.87055 0 m
.87055 .61803 L
s
.90243 0 m
.90243 .61803 L
s
.93004 0 m
.93004 .61803 L
s
.9544 0 m
.9544 .61803 L
s
0 .02927 m
1 .02927 L
s
0 .11155 m
1 .11155 L
s
0 .19383 m
1 .19383 L
s
0 .27611 m
1 .27611 L
s
0 .35838 m
1 .35838 L
s
0 .44066 m
1 .44066 L
s
0 .52294 m
1 .52294 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .02927 m
.00625 .02927 L
s
[(-175)] -0.0125 .02927 1 0 Mshowa
0 .11155 m
.00625 .11155 L
s
[(-150)] -0.0125 .11155 1 0 Mshowa
0 .19383 m
.00625 .19383 L
s
[(-125)] -0.0125 .19383 1 0 Mshowa
0 .27611 m
.00625 .27611 L
s
[(-100)] -0.0125 .27611 1 0 Mshowa
0 .35838 m
.00625 .35838 L
s
[(-75)] -0.0125 .35838 1 0 Mshowa
0 .44066 m
.00625 .44066 L
s
[(-50)] -0.0125 .44066 1 0 Mshowa
0 .52294 m
.00625 .52294 L
s
[(-25)] -0.0125 .52294 1 0 Mshowa
0 .60522 m
.00625 .60522 L
s
[(0)] -0.0125 .60522 1 0 Mshowa
.125 Mabswid
0 .04572 m
.00375 .04572 L
s
0 .06218 m
.00375 .06218 L
s
0 .07863 m
.00375 .07863 L
s
0 .09509 m
.00375 .09509 L
s
0 .128 m
.00375 .128 L
s
0 .14446 m
.00375 .14446 L
s
0 .16091 m
.00375 .16091 L
s
0 .17737 m
.00375 .17737 L
s
0 .21028 m
.00375 .21028 L
s
0 .22674 m
.00375 .22674 L
s
0 .24319 m
.00375 .24319 L
s
0 .25965 m
.00375 .25965 L
s
0 .29256 m
.00375 .29256 L
s
0 .30902 m
.00375 .30902 L
s
0 .32547 m
.00375 .32547 L
s
0 .34193 m
.00375 .34193 L
s
0 .37484 m
.00375 .37484 L
s
0 .3913 m
.00375 .3913 L
s
0 .40775 m
.00375 .40775 L
s
0 .42421 m
.00375 .42421 L
s
0 .45712 m
.00375 .45712 L
s
0 .47358 m
.00375 .47358 L
s
0 .49003 m
.00375 .49003 L
s
0 .50649 m
.00375 .50649 L
s
0 .5394 m
.00375 .5394 L
s
0 .55586 m
.00375 .55586 L
s
0 .57231 m
.00375 .57231 L
s
0 .58877 m
.00375 .58877 L
s
0 .01281 m
.00375 .01281 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 .61178 m
.16716 .61803 L
s
gsave
.16716 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 .61178 m
.35665 .61803 L
s
gsave
.35665 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 .61178 m
.64335 .61803 L
s
gsave
.64335 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 .61178 m
.83284 .61803 L
s
gsave
.83284 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 .61428 m
.25101 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.39436 .61428 m
.39436 .61803 L
s
.42624 .61428 m
.42624 .61803 L
s
.45385 .61428 m
.45385 .61803 L
s
.47821 .61428 m
.47821 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.7867 .61428 m
.7867 .61803 L
s
.87055 .61428 m
.87055 .61803 L
s
.90243 .61428 m
.90243 .61803 L
s
.93004 .61428 m
.93004 .61803 L
s
.9544 .61428 m
.9544 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02927 m
1 .02927 L
s
.99375 .11155 m
1 .11155 L
s
.99375 .19383 m
1 .19383 L
s
.99375 .27611 m
1 .27611 L
s
.99375 .35838 m
1 .35838 L
s
.99375 .44066 m
1 .44066 L
s
.99375 .52294 m
1 .52294 L
s
.99375 .60522 m
1 .60522 L
s
.125 Mabswid
.99625 .04572 m
1 .04572 L
s
.99625 .06218 m
1 .06218 L
s
.99625 .07863 m
1 .07863 L
s
.99625 .09509 m
1 .09509 L
s
.99625 .128 m
1 .128 L
s
.99625 .14446 m
1 .14446 L
s
.99625 .16091 m
1 .16091 L
s
.99625 .17737 m
1 .17737 L
s
.99625 .21028 m
1 .21028 L
s
.99625 .22674 m
1 .22674 L
s
.99625 .24319 m
1 .24319 L
s
.99625 .25965 m
1 .25965 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .32547 m
1 .32547 L
s
.99625 .34193 m
1 .34193 L
s
.99625 .37484 m
1 .37484 L
s
.99625 .3913 m
1 .3913 L
s
.99625 .40775 m
1 .40775 L
s
.99625 .42421 m
1 .42421 L
s
.99625 .45712 m
1 .45712 L
s
.99625 .47358 m
1 .47358 L
s
.99625 .49003 m
1 .49003 L
s
.99625 .50649 m
1 .50649 L
s
.99625 .5394 m
1 .5394 L
s
.99625 .55586 m
1 .55586 L
s
.99625 .57231 m
1 .57231 L
s
.99625 .58877 m
1 .58877 L
s
.99625 .01281 m
1 .01281 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
[ .05 .01 .01 .01 ] 0 setdash
.02381 .60332 m
.0286 .60327 L
.03338 .60323 L
.03817 .60318 L
.04295 .60313 L
.04774 .60308 L
.05252 .60303 L
.05731 .60298 L
.0621 .60292 L
.06688 .60287 L
.07167 .60281 L
.07645 .60275 L
.08124 .60269 L
.08603 .60263 L
.09081 .60257 L
.0956 .6025 L
.10038 .60243 L
.10517 .60237 L
.10995 .6023 L
.11474 .60222 L
.11953 .60215 L
.12431 .60207 L
.1291 .602 L
.13388 .60192 L
.13867 .60183 L
.14346 .60175 L
.14824 .60166 L
.15303 .60157 L
.15781 .60148 L
.1626 .60139 L
.16738 .60129 L
.17217 .60119 L
.17696 .60109 L
.18174 .60098 L
.18653 .60087 L
.19131 .60076 L
.1961 .60064 L
.20089 .60052 L
.20567 .6004 L
.21046 .60027 L
.21524 .60014 L
.22003 .60001 L
.22481 .59987 L
.2296 .59972 L
.23439 .59957 L
.23917 .59942 L
.24396 .59926 L
.24874 .59909 L
.25353 .59892 L
.25832 .59874 L
Mistroke
.2631 .59855 L
.26789 .59836 L
.27267 .59816 L
.27746 .59795 L
.28224 .59774 L
.28703 .59751 L
.29182 .59728 L
.2966 .59703 L
.30139 .59677 L
.30617 .5965 L
.31096 .59622 L
.31575 .59593 L
.32053 .59562 L
.32532 .59529 L
.3301 .59495 L
.33489 .59459 L
.33967 .59421 L
.34446 .59381 L
.34925 .59338 L
.35403 .59293 L
.35882 .59245 L
.3636 .59194 L
.36839 .59139 L
.37318 .5908 L
.37796 .59017 L
.38275 .58949 L
.38753 .58875 L
.39232 .58796 L
.3971 .58709 L
.40189 .58614 L
.40668 .5851 L
.41146 .58395 L
.41625 .58267 L
.42103 .58125 L
.42582 .57965 L
.43061 .57784 L
.43539 .57577 L
.44018 .57339 L
.44496 .5706 L
.44975 .56732 L
.45453 .56338 L
.45932 .55857 L
.46411 .55258 L
.46889 .54492 L
.47368 .53481 L
.47846 .52095 L
.48325 .50103 L
.48804 .47088 L
.49282 .42347 L
.49761 .3519 L
Mistroke
.50239 .26613 L
.50718 .19456 L
.51196 .14715 L
.51675 .11701 L
.52154 .09709 L
.52632 .08322 L
.53111 .07311 L
.53589 .06545 L
.54068 .05946 L
.54547 .05465 L
.55025 .05072 L
.55504 .04743 L
.55982 .04465 L
.56461 .04226 L
.56939 .04019 L
.57418 .03838 L
.57897 .03678 L
.58375 .03536 L
.58854 .03408 L
.59332 .03293 L
.59811 .03189 L
.6029 .03094 L
.60768 .03008 L
.61247 .02928 L
.61725 .02854 L
.62204 .02786 L
.62682 .02723 L
.63161 .02665 L
.6364 .0261 L
.64118 .02558 L
.64597 .0251 L
.65075 .02465 L
.65554 .02422 L
.66033 .02382 L
.66511 .02344 L
.6699 .02308 L
.67468 .02274 L
.67947 .02241 L
.68425 .02211 L
.68904 .02181 L
.69383 .02153 L
.69861 .02126 L
.7034 .021 L
.70818 .02076 L
.71297 .02052 L
.71776 .0203 L
.72254 .02008 L
.72733 .01987 L
.73211 .01967 L
.7369 .01948 L
Mistroke
.74168 .01929 L
.74647 .01912 L
.75126 .01894 L
.75604 .01878 L
.76083 .01862 L
.76561 .01846 L
.7704 .01831 L
.77519 .01817 L
.77997 .01803 L
.78476 .01789 L
.78954 .01776 L
.79433 .01763 L
.79911 .01751 L
.8039 .01739 L
.80869 .01727 L
.81347 .01716 L
.81826 .01705 L
.82304 .01695 L
.82783 .01684 L
.83262 .01674 L
.8374 .01665 L
.84219 .01655 L
.84697 .01646 L
.85176 .01637 L
.85654 .01628 L
.86133 .0162 L
.86612 .01612 L
.8709 .01604 L
.87569 .01596 L
.88047 .01588 L
.88526 .01581 L
.89005 .01574 L
.89483 .01567 L
.89962 .0156 L
.9044 .01553 L
.90919 .01547 L
.91397 .01541 L
.91876 .01534 L
.92355 .01528 L
.92833 .01523 L
.93312 .01517 L
.9379 .01511 L
.94269 .01506 L
.94748 .01501 L
.95226 .01495 L
.95705 .0149 L
.96183 .01486 L
.96662 .01481 L
.9714 .01476 L
.97619 .01472 L
Mistroke
Mfstroke
[ .05 .01 ] 0 setdash
.02381 .59381 m
.0286 .59354 L
.03338 .59326 L
.03817 .59297 L
.04295 .59268 L
.04774 .59238 L
.05252 .59207 L
.05731 .59176 L
.0621 .59143 L
.06688 .5911 L
.07167 .59076 L
.07645 .59041 L
.08124 .59006 L
.08603 .58969 L
.09081 .58931 L
.0956 .58893 L
.10038 .58853 L
.10517 .58813 L
.10995 .58771 L
.11474 .58728 L
.11953 .58684 L
.12431 .58639 L
.1291 .58593 L
.13388 .58546 L
.13867 .58497 L
.14346 .58447 L
.14824 .58395 L
.15303 .58342 L
.15781 .58288 L
.1626 .58232 L
.16738 .58175 L
.17217 .58116 L
.17696 .58055 L
.18174 .57992 L
.18653 .57928 L
.19131 .57862 L
.1961 .57793 L
.20089 .57723 L
.20567 .57651 L
.21046 .57576 L
.21524 .57499 L
.22003 .5742 L
.22481 .57338 L
.2296 .57253 L
.23439 .57166 L
.23917 .57076 L
.24396 .56983 L
.24874 .56887 L
.25353 .56787 L
.25832 .56684 L
Mistroke
.2631 .56577 L
.26789 .56467 L
.27267 .56352 L
.27746 .56233 L
.28224 .5611 L
.28703 .55982 L
.29182 .55849 L
.2966 .5571 L
.30139 .55566 L
.30617 .55416 L
.31096 .55259 L
.31575 .55096 L
.32053 .54925 L
.32532 .54747 L
.3301 .54561 L
.33489 .54365 L
.33967 .54161 L
.34446 .53946 L
.34925 .5372 L
.35403 .53482 L
.35882 .53232 L
.3636 .52968 L
.36839 .5269 L
.37318 .52395 L
.37796 .52083 L
.38275 .51752 L
.38753 .51401 L
.39232 .51027 L
.3971 .50629 L
.40189 .50204 L
.40668 .4975 L
.41146 .49264 L
.41625 .48744 L
.42103 .48185 L
.42582 .47586 L
.43061 .46941 L
.43539 .46247 L
.44018 .455 L
.44496 .44695 L
.44975 .4383 L
.45453 .429 L
.45932 .41901 L
.46411 .40833 L
.46889 .39694 L
.47368 .38486 L
.47846 .37213 L
.48325 .35879 L
.48804 .34496 L
.49282 .33074 L
.49761 .31629 L
Mistroke
.50239 .30175 L
.50718 .28729 L
.51196 .27307 L
.51675 .25924 L
.52154 .24591 L
.52632 .23317 L
.53111 .22109 L
.53589 .2097 L
.54068 .19902 L
.54547 .18904 L
.55025 .17973 L
.55504 .17108 L
.55982 .16304 L
.56461 .15557 L
.56939 .14863 L
.57418 .14218 L
.57897 .13618 L
.58375 .1306 L
.58854 .12539 L
.59332 .12054 L
.59811 .116 L
.6029 .11175 L
.60768 .10777 L
.61247 .10403 L
.61725 .10051 L
.62204 .0972 L
.62682 .09408 L
.63161 .09114 L
.6364 .08835 L
.64118 .08571 L
.64597 .08321 L
.65075 .08083 L
.65554 .07858 L
.66033 .07643 L
.66511 .07438 L
.6699 .07243 L
.67468 .07056 L
.67947 .06878 L
.68425 .06707 L
.68904 .06544 L
.69383 .06388 L
.69861 .06237 L
.7034 .06093 L
.70818 .05955 L
.71297 .05822 L
.71776 .05694 L
.72254 .0557 L
.72733 .05451 L
.73211 .05337 L
.7369 .05226 L
Mistroke
.74168 .05119 L
.74647 .05016 L
.75126 .04917 L
.75604 .0482 L
.76083 .04727 L
.76561 .04637 L
.7704 .0455 L
.77519 .04465 L
.77997 .04384 L
.78476 .04304 L
.78954 .04227 L
.79433 .04153 L
.79911 .0408 L
.8039 .0401 L
.80869 .03942 L
.81347 .03876 L
.81826 .03811 L
.82304 .03749 L
.82783 .03688 L
.83262 .03629 L
.8374 .03571 L
.84219 .03515 L
.84697 .03461 L
.85176 .03408 L
.85654 .03357 L
.86133 .03307 L
.86612 .03258 L
.8709 .0321 L
.87569 .03164 L
.88047 .03119 L
.88526 .03075 L
.89005 .03032 L
.89483 .02991 L
.89962 .0295 L
.9044 .02911 L
.90919 .02872 L
.91397 .02834 L
.91876 .02798 L
.92355 .02762 L
.92833 .02727 L
.93312 .02693 L
.9379 .0266 L
.94269 .02628 L
.94748 .02596 L
.95226 .02565 L
.95705 .02535 L
.96183 .02506 L
.96662 .02478 L
.9714 .0245 L
.97619 .02422 L
Mistroke
Mfstroke
[ .05 ] 0 setdash
.02381 .58436 m
.0286 .58386 L
.03338 .58336 L
.03817 .58284 L
.04295 .58231 L
.04774 .58176 L
.05252 .5812 L
.05731 .58063 L
.0621 .58005 L
.06688 .57945 L
.07167 .57883 L
.07645 .5782 L
.08124 .57756 L
.08603 .57689 L
.09081 .57622 L
.0956 .57552 L
.10038 .57481 L
.10517 .57408 L
.10995 .57333 L
.11474 .57256 L
.11953 .57177 L
.12431 .57097 L
.1291 .57014 L
.13388 .56929 L
.13867 .56842 L
.14346 .56753 L
.14824 .56661 L
.15303 .56567 L
.15781 .5647 L
.1626 .56371 L
.16738 .56269 L
.17217 .56165 L
.17696 .56058 L
.18174 .55948 L
.18653 .55835 L
.19131 .55718 L
.1961 .55599 L
.20089 .55476 L
.20567 .5535 L
.21046 .55221 L
.21524 .55087 L
.22003 .5495 L
.22481 .5481 L
.2296 .54665 L
.23439 .54515 L
.23917 .54362 L
.24396 .54204 L
.24874 .54041 L
.25353 .53873 L
.25832 .53701 L
Mistroke
.2631 .53523 L
.26789 .53339 L
.27267 .5315 L
.27746 .52955 L
.28224 .52753 L
.28703 .52546 L
.29182 .52331 L
.2966 .5211 L
.30139 .51881 L
.30617 .51644 L
.31096 .514 L
.31575 .51147 L
.32053 .50886 L
.32532 .50615 L
.3301 .50336 L
.33489 .50046 L
.33967 .49746 L
.34446 .49435 L
.34925 .49113 L
.35403 .48779 L
.35882 .48432 L
.3636 .48073 L
.36839 .47701 L
.37318 .47314 L
.37796 .46913 L
.38275 .46497 L
.38753 .46066 L
.39232 .45618 L
.3971 .45153 L
.40189 .44671 L
.40668 .44171 L
.41146 .43653 L
.41625 .43116 L
.42103 .4256 L
.42582 .41984 L
.43061 .41389 L
.43539 .40775 L
.44018 .40141 L
.44496 .39487 L
.44975 .38815 L
.45453 .38125 L
.45932 .37417 L
.46411 .36693 L
.46889 .35954 L
.47368 .35201 L
.47846 .34437 L
.48325 .33662 L
.48804 .32879 L
.49282 .3209 L
.49761 .31298 L
Mistroke
.50239 .30505 L
.50718 .29713 L
.51196 .28924 L
.51675 .28142 L
.52154 .27367 L
.52632 .26602 L
.53111 .25849 L
.53589 .2511 L
.54068 .24386 L
.54547 .23679 L
.55025 .22988 L
.55504 .22316 L
.55982 .21663 L
.56461 .21029 L
.56939 .20414 L
.57418 .19819 L
.57897 .19244 L
.58375 .18688 L
.58854 .18151 L
.59332 .17632 L
.59811 .17132 L
.6029 .1665 L
.60768 .16186 L
.61247 .15738 L
.61725 .15306 L
.62204 .1489 L
.62682 .14489 L
.63161 .14103 L
.6364 .1373 L
.64118 .13371 L
.64597 .13025 L
.65075 .12691 L
.65554 .12369 L
.66033 .12058 L
.66511 .11758 L
.6699 .11468 L
.67468 .11188 L
.67947 .10917 L
.68425 .10656 L
.68904 .10403 L
.69383 .10159 L
.69861 .09923 L
.7034 .09694 L
.70818 .09472 L
.71297 .09258 L
.71776 .0905 L
.72254 .08849 L
.72733 .08654 L
.73211 .08464 L
.7369 .08281 L
Mistroke
.74168 .08103 L
.74647 .0793 L
.75126 .07762 L
.75604 .076 L
.76083 .07442 L
.76561 .07288 L
.7704 .07139 L
.77519 .06994 L
.77997 .06853 L
.78476 .06716 L
.78954 .06583 L
.79433 .06453 L
.79911 .06327 L
.8039 .06204 L
.80869 .06085 L
.81347 .05969 L
.81826 .05856 L
.82304 .05746 L
.82783 .05638 L
.83262 .05534 L
.8374 .05432 L
.84219 .05333 L
.84697 .05237 L
.85176 .05143 L
.85654 .05051 L
.86133 .04962 L
.86612 .04874 L
.8709 .04789 L
.87569 .04707 L
.88047 .04626 L
.88526 .04547 L
.89005 .0447 L
.89483 .04396 L
.89962 .04323 L
.9044 .04251 L
.90919 .04182 L
.91397 .04114 L
.91876 .04048 L
.92355 .03983 L
.92833 .0392 L
.93312 .03859 L
.9379 .03799 L
.94269 .0374 L
.94748 .03683 L
.95226 .03627 L
.95705 .03573 L
.96183 .0352 L
.96662 .03468 L
.9714 .03417 L
.97619 .03368 L
Mistroke
Mfstroke
.001 w
[ ] 0 setdash
.02381 .57501 m
.0286 .5743 L
.03338 .57357 L
.03817 .57283 L
.04295 .57207 L
.04774 .57129 L
.05252 .57049 L
.05731 .56968 L
.0621 .56884 L
.06688 .56799 L
.07167 .56711 L
.07645 .56621 L
.08124 .5653 L
.08603 .56436 L
.09081 .56339 L
.0956 .56241 L
.10038 .5614 L
.10517 .56037 L
.10995 .55931 L
.11474 .55823 L
.11953 .55712 L
.12431 .55599 L
.1291 .55483 L
.13388 .55364 L
.13867 .55242 L
.14346 .55118 L
.14824 .5499 L
.15303 .54859 L
.15781 .54726 L
.1626 .54589 L
.16738 .54448 L
.17217 .54305 L
.17696 .54158 L
.18174 .54007 L
.18653 .53852 L
.19131 .53694 L
.1961 .53533 L
.20089 .53367 L
.20567 .53197 L
.21046 .53023 L
.21524 .52845 L
.22003 .52663 L
.22481 .52476 L
.2296 .52284 L
.23439 .52088 L
.23917 .51887 L
.24396 .51682 L
.24874 .51471 L
.25353 .51255 L
.25832 .51034 L
Mistroke
.2631 .50808 L
.26789 .50576 L
.27267 .50338 L
.27746 .50095 L
.28224 .49845 L
.28703 .4959 L
.29182 .49328 L
.2966 .4906 L
.30139 .48786 L
.30617 .48505 L
.31096 .48217 L
.31575 .47923 L
.32053 .47621 L
.32532 .47312 L
.3301 .46996 L
.33489 .46672 L
.33967 .46341 L
.34446 .46003 L
.34925 .45656 L
.35403 .45301 L
.35882 .44939 L
.3636 .44568 L
.36839 .4419 L
.37318 .43803 L
.37796 .43407 L
.38275 .43004 L
.38753 .42592 L
.39232 .42171 L
.3971 .41743 L
.40189 .41306 L
.40668 .40861 L
.41146 .40408 L
.41625 .39947 L
.42103 .39478 L
.42582 .39001 L
.43061 .38517 L
.43539 .38026 L
.44018 .37529 L
.44496 .37024 L
.44975 .36514 L
.45453 .35998 L
.45932 .35476 L
.46411 .3495 L
.46889 .34419 L
.47368 .33885 L
.47846 .33347 L
.48325 .32806 L
.48804 .32264 L
.49282 .3172 L
.49761 .31174 L
Mistroke
.50239 .30629 L
.50718 .30084 L
.51196 .2954 L
.51675 .28997 L
.52154 .28456 L
.52632 .27919 L
.53111 .27384 L
.53589 .26853 L
.54068 .26327 L
.54547 .25806 L
.55025 .25289 L
.55504 .24779 L
.55982 .24275 L
.56461 .23777 L
.56939 .23286 L
.57418 .22802 L
.57897 .22326 L
.58375 .21857 L
.58854 .21396 L
.59332 .20943 L
.59811 .20498 L
.6029 .20061 L
.60768 .19632 L
.61247 .19212 L
.61725 .188 L
.62204 .18396 L
.62682 .18001 L
.63161 .17614 L
.6364 .17235 L
.64118 .16864 L
.64597 .16502 L
.65075 .16147 L
.65554 .15801 L
.66033 .15462 L
.66511 .15131 L
.6699 .14807 L
.67468 .14491 L
.67947 .14182 L
.68425 .13881 L
.68904 .13586 L
.69383 .13298 L
.69861 .13017 L
.7034 .12743 L
.70818 .12475 L
.71297 .12214 L
.71776 .11958 L
.72254 .11709 L
.72733 .11465 L
.73211 .11228 L
.7369 .10996 L
Mistroke
.74168 .10769 L
.74647 .10548 L
.75126 .10332 L
.75604 .10122 L
.76083 .09916 L
.76561 .09715 L
.7704 .09519 L
.77519 .09328 L
.77997 .09141 L
.78476 .08958 L
.78954 .0878 L
.79433 .08606 L
.79911 .08437 L
.8039 .08271 L
.80869 .08109 L
.81347 .07951 L
.81826 .07797 L
.82304 .07646 L
.82783 .07499 L
.83262 .07355 L
.8374 .07215 L
.84219 .07078 L
.84697 .06944 L
.85176 .06813 L
.85654 .06686 L
.86133 .06561 L
.86612 .06439 L
.8709 .0632 L
.87569 .06204 L
.88047 .06091 L
.88526 .0598 L
.89005 .05872 L
.89483 .05766 L
.89962 .05663 L
.9044 .05562 L
.90919 .05464 L
.91397 .05368 L
.91876 .05274 L
.92355 .05182 L
.92833 .05092 L
.93312 .05005 L
.9379 .04919 L
.94269 .04836 L
.94748 .04754 L
.95226 .04674 L
.95705 .04597 L
.96183 .0452 L
.96662 .04446 L
.9714 .04373 L
.97619 .04303 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.408024 0.00982667 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.16716 -0.0125 -11 -12.5625 ]
[.16716 -0.0125 11 0 ]
[.35665 -0.0125 -11 -12.5625 ]
[.35665 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.64335 -0.0125 -5 -12.5625 ]
[.64335 -0.0125 5 0 ]
[.83284 -0.0125 -5 -12.5625 ]
[.83284 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01496 -18 -4.5 ]
[-0.0125 .01496 0 4.5 ]
[-0.0125 .11322 -18 -4.5 ]
[-0.0125 .11322 0 4.5 ]
[-0.0125 .21149 -18 -4.5 ]
[-0.0125 .21149 0 4.5 ]
[-0.0125 .30976 -18 -4.5 ]
[-0.0125 .30976 0 4.5 ]
[-0.0125 .40802 -6 -4.5 ]
[-0.0125 .40802 0 4.5 ]
[-0.0125 .50629 -12 -4.5 ]
[-0.0125 .50629 0 4.5 ]
[-0.0125 .60456 -12 -4.5 ]
[-0.0125 .60456 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.16716 .63053 -11 0 ]
[.16716 .63053 11 12.5625 ]
[.35665 .63053 -11 0 ]
[.35665 .63053 11 12.5625 ]
[.5 .63053 -5 0 ]
[.5 .63053 5 12.5625 ]
[.64335 .63053 -5 0 ]
[.64335 .63053 5 12.5625 ]
[.83284 .63053 -5 0 ]
[.83284 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.35665 0 m
.35665 .61803 L
s
.5 0 m
.5 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.83284 0 m
.83284 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.39436 0 m
.39436 .61803 L
s
.42624 0 m
.42624 .61803 L
s
.45385 0 m
.45385 .61803 L
s
.47821 0 m
.47821 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.7867 0 m
.7867 .61803 L
s
.87055 0 m
.87055 .61803 L
s
.90243 0 m
.90243 .61803 L
s
.93004 0 m
.93004 .61803 L
s
.9544 0 m
.9544 .61803 L
s
0 .11322 m
1 .11322 L
s
0 .21149 m
1 .21149 L
s
0 .30976 m
1 .30976 L
s
0 .40802 m
1 .40802 L
s
0 .50629 m
1 .50629 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 0 m
.16716 .00625 L
s
gsave
.16716 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 0 m
.35665 .00625 L
s
gsave
.35665 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 0 m
.64335 .00625 L
s
gsave
.64335 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 0 m
.83284 .00625 L
s
gsave
.83284 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 0 m
.25101 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.39436 0 m
.39436 .00375 L
s
.42624 0 m
.42624 .00375 L
s
.45385 0 m
.45385 .00375 L
s
.47821 0 m
.47821 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.7867 0 m
.7867 .00375 L
s
.87055 0 m
.87055 .00375 L
s
.90243 0 m
.90243 .00375 L
s
.93004 0 m
.93004 .00375 L
s
.9544 0 m
.9544 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01496 m
.00625 .01496 L
s
[(-40)] -0.0125 .01496 1 0 Mshowa
0 .11322 m
.00625 .11322 L
s
[(-30)] -0.0125 .11322 1 0 Mshowa
0 .21149 m
.00625 .21149 L
s
[(-20)] -0.0125 .21149 1 0 Mshowa
0 .30976 m
.00625 .30976 L
s
[(-10)] -0.0125 .30976 1 0 Mshowa
0 .40802 m
.00625 .40802 L
s
[(0)] -0.0125 .40802 1 0 Mshowa
0 .50629 m
.00625 .50629 L
s
[(10)] -0.0125 .50629 1 0 Mshowa
0 .60456 m
.00625 .60456 L
s
[(20)] -0.0125 .60456 1 0 Mshowa
.125 Mabswid
0 .03461 m
.00375 .03461 L
s
0 .05426 m
.00375 .05426 L
s
0 .07392 m
.00375 .07392 L
s
0 .09357 m
.00375 .09357 L
s
0 .13288 m
.00375 .13288 L
s
0 .15253 m
.00375 .15253 L
s
0 .17218 m
.00375 .17218 L
s
0 .19184 m
.00375 .19184 L
s
0 .23114 m
.00375 .23114 L
s
0 .2508 m
.00375 .2508 L
s
0 .27045 m
.00375 .27045 L
s
0 .2901 m
.00375 .2901 L
s
0 .32941 m
.00375 .32941 L
s
0 .34906 m
.00375 .34906 L
s
0 .36872 m
.00375 .36872 L
s
0 .38837 m
.00375 .38837 L
s
0 .42768 m
.00375 .42768 L
s
0 .44733 m
.00375 .44733 L
s
0 .46698 m
.00375 .46698 L
s
0 .48664 m
.00375 .48664 L
s
0 .52594 m
.00375 .52594 L
s
0 .5456 m
.00375 .5456 L
s
0 .56525 m
.00375 .56525 L
s
0 .5849 m
.00375 .5849 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.16716 .61178 m
.16716 .61803 L
s
gsave
.16716 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.2) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.35665 .61178 m
.35665 .61803 L
s
gsave
.35665 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.64335 .61178 m
.64335 .61803 L
s
gsave
.64335 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.83284 .61178 m
.83284 .61803 L
s
gsave
.83284 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.25101 .61428 m
.25101 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.39436 .61428 m
.39436 .61803 L
s
.42624 .61428 m
.42624 .61803 L
s
.45385 .61428 m
.45385 .61803 L
s
.47821 .61428 m
.47821 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.7867 .61428 m
.7867 .61803 L
s
.87055 .61428 m
.87055 .61803 L
s
.90243 .61428 m
.90243 .61803 L
s
.93004 .61428 m
.93004 .61803 L
s
.9544 .61428 m
.9544 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01496 m
1 .01496 L
s
.99375 .11322 m
1 .11322 L
s
.99375 .21149 m
1 .21149 L
s
.99375 .30976 m
1 .30976 L
s
.99375 .40802 m
1 .40802 L
s
.99375 .50629 m
1 .50629 L
s
.99375 .60456 m
1 .60456 L
s
.125 Mabswid
.99625 .03461 m
1 .03461 L
s
.99625 .05426 m
1 .05426 L
s
.99625 .07392 m
1 .07392 L
s
.99625 .09357 m
1 .09357 L
s
.99625 .13288 m
1 .13288 L
s
.99625 .15253 m
1 .15253 L
s
.99625 .17218 m
1 .17218 L
s
.99625 .19184 m
1 .19184 L
s
.99625 .23114 m
1 .23114 L
s
.99625 .2508 m
1 .2508 L
s
.99625 .27045 m
1 .27045 L
s
.99625 .2901 m
1 .2901 L
s
.99625 .32941 m
1 .32941 L
s
.99625 .34906 m
1 .34906 L
s
.99625 .36872 m
1 .36872 L
s
.99625 .38837 m
1 .38837 L
s
.99625 .42768 m
1 .42768 L
s
.99625 .44733 m
1 .44733 L
s
.99625 .46698 m
1 .46698 L
s
.99625 .48664 m
1 .48664 L
s
.99625 .52594 m
1 .52594 L
s
.99625 .5456 m
1 .5456 L
s
.99625 .56525 m
1 .56525 L
s
.99625 .5849 m
1 .5849 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
[ .05 .01 .01 .01 ] 0 setdash
.02381 .40888 m
.0286 .40892 L
.03338 .40896 L
.03817 .40901 L
.04295 .40905 L
.04774 .4091 L
.05252 .40915 L
.05731 .40921 L
.0621 .40926 L
.06688 .40932 L
.07167 .40938 L
.07645 .40945 L
.08124 .40952 L
.08603 .40959 L
.09081 .40966 L
.0956 .40974 L
.10038 .40982 L
.10517 .40991 L
.10995 .41 L
.11474 .4101 L
.11953 .41019 L
.12431 .4103 L
.1291 .41041 L
.13388 .41052 L
.13867 .41064 L
.14346 .41077 L
.14824 .4109 L
.15303 .41104 L
.15781 .41119 L
.1626 .41134 L
.16738 .4115 L
.17217 .41167 L
.17696 .41184 L
.18174 .41203 L
.18653 .41222 L
.19131 .41243 L
.1961 .41264 L
.20089 .41286 L
.20567 .4131 L
.21046 .41335 L
.21524 .41361 L
.22003 .41388 L
.22481 .41417 L
.2296 .41447 L
.23439 .41479 L
.23917 .41513 L
.24396 .41548 L
.24874 .41585 L
.25353 .41623 L
.25832 .41664 L
Mistroke
.2631 .41707 L
.26789 .41753 L
.27267 .418 L
.27746 .41851 L
.28224 .41904 L
.28703 .4196 L
.29182 .42018 L
.2966 .4208 L
.30139 .42146 L
.30617 .42215 L
.31096 .42288 L
.31575 .42365 L
.32053 .42447 L
.32532 .42533 L
.3301 .42624 L
.33489 .42721 L
.33967 .42823 L
.34446 .42932 L
.34925 .43047 L
.35403 .43169 L
.35882 .43299 L
.3636 .43437 L
.36839 .43584 L
.37318 .43741 L
.37796 .43908 L
.38275 .44087 L
.38753 .44278 L
.39232 .44483 L
.3971 .44702 L
.40189 .44939 L
.40668 .45193 L
.41146 .45468 L
.41625 .45765 L
.42103 .46087 L
.42582 .46438 L
.43061 .46821 L
.43539 .4724 L
.44018 .47701 L
.44496 .48211 L
.44975 .48778 L
.45453 .49412 L
.45932 .50125 L
.46411 .50935 L
.46889 .51863 L
.47368 .52935 L
.47846 .54185 L
.48325 .55645 L
.48804 .57321 L
.49282 .59073 L
.49761 .60332 L
Mistroke
.50239 .60134 L
.50718 .5848 L
.51196 .56333 L
.51675 .54263 L
.52154 .52407 L
.52632 .50762 L
.53111 .49295 L
.53589 .47972 L
.54068 .46767 L
.54547 .45659 L
.55025 .4463 L
.55504 .43668 L
.55982 .42763 L
.56461 .41907 L
.56939 .41093 L
.57418 .40315 L
.57897 .39569 L
.58375 .38852 L
.58854 .38159 L
.59332 .3749 L
.59811 .3684 L
.6029 .36209 L
.60768 .35594 L
.61247 .34994 L
.61725 .34408 L
.62204 .33834 L
.62682 .33272 L
.63161 .3272 L
.6364 .32178 L
.64118 .31645 L
.64597 .3112 L
.65075 .30603 L
.65554 .30093 L
.66033 .29589 L
.66511 .29092 L
.6699 .286 L
.67468 .28114 L
.67947 .27633 L
.68425 .27156 L
.68904 .26684 L
.69383 .26216 L
.69861 .25752 L
.7034 .25291 L
.70818 .24834 L
.71297 .2438 L
.71776 .23929 L
.72254 .23481 L
.72733 .23036 L
.73211 .22593 L
.7369 .22153 L
Mistroke
.74168 .21715 L
.74647 .21279 L
.75126 .20845 L
.75604 .20413 L
.76083 .19983 L
.76561 .19554 L
.7704 .19127 L
.77519 .18702 L
.77997 .18278 L
.78476 .17856 L
.78954 .17435 L
.79433 .17015 L
.79911 .16596 L
.8039 .16179 L
.80869 .15762 L
.81347 .15347 L
.81826 .14932 L
.82304 .14519 L
.82783 .14106 L
.83262 .13694 L
.8374 .13283 L
.84219 .12873 L
.84697 .12463 L
.85176 .12055 L
.85654 .11646 L
.86133 .11239 L
.86612 .10832 L
.8709 .10425 L
.87569 .10019 L
.88047 .09614 L
.88526 .09209 L
.89005 .08804 L
.89483 .084 L
.89962 .07996 L
.9044 .07593 L
.90919 .0719 L
.91397 .06788 L
.91876 .06386 L
.92355 .05984 L
.92833 .05582 L
.93312 .05181 L
.9379 .0478 L
.94269 .04379 L
.94748 .03979 L
.95226 .03579 L
.95705 .03179 L
.96183 .02779 L
.96662 .0238 L
.9714 .0198 L
.97619 .01581 L
Mistroke
Mfstroke
[ .05 .01 ] 0 setdash
.02381 .40873 m
.0286 .40876 L
.03338 .40879 L
.03817 .40883 L
.04295 .40887 L
.04774 .40891 L
.05252 .40895 L
.05731 .40899 L
.0621 .40904 L
.06688 .40909 L
.07167 .40914 L
.07645 .40919 L
.08124 .40925 L
.08603 .40931 L
.09081 .40937 L
.0956 .40943 L
.10038 .4095 L
.10517 .40957 L
.10995 .40964 L
.11474 .40972 L
.11953 .4098 L
.12431 .40988 L
.1291 .40997 L
.13388 .41007 L
.13867 .41016 L
.14346 .41027 L
.14824 .41037 L
.15303 .41048 L
.15781 .4106 L
.1626 .41072 L
.16738 .41085 L
.17217 .41099 L
.17696 .41113 L
.18174 .41128 L
.18653 .41143 L
.19131 .4116 L
.1961 .41177 L
.20089 .41195 L
.20567 .41214 L
.21046 .41233 L
.21524 .41254 L
.22003 .41276 L
.22481 .41298 L
.2296 .41322 L
.23439 .41347 L
.23917 .41373 L
.24396 .41401 L
.24874 .41429 L
.25353 .4146 L
.25832 .41491 L
Mistroke
.2631 .41525 L
.26789 .41559 L
.27267 .41596 L
.27746 .41634 L
.28224 .41675 L
.28703 .41717 L
.29182 .41761 L
.2966 .41807 L
.30139 .41856 L
.30617 .41907 L
.31096 .41961 L
.31575 .42017 L
.32053 .42076 L
.32532 .42138 L
.3301 .42203 L
.33489 .42271 L
.33967 .42342 L
.34446 .42417 L
.34925 .42496 L
.35403 .42578 L
.35882 .42664 L
.3636 .42754 L
.36839 .42848 L
.37318 .42947 L
.37796 .4305 L
.38275 .43158 L
.38753 .4327 L
.39232 .43387 L
.3971 .43509 L
.40189 .43635 L
.40668 .43766 L
.41146 .43901 L
.41625 .4404 L
.42103 .44182 L
.42582 .44327 L
.43061 .44474 L
.43539 .44622 L
.44018 .44768 L
.44496 .44912 L
.44975 .4505 L
.45453 .4518 L
.45932 .45299 L
.46411 .45401 L
.46889 .45483 L
.47368 .45539 L
.47846 .45564 L
.48325 .45553 L
.48804 .455 L
.49282 .45402 L
.49761 .45255 L
Mistroke
.50239 .45057 L
.50718 .44809 L
.51196 .44513 L
.51675 .4417 L
.52154 .43786 L
.52632 .43366 L
.53111 .42915 L
.53589 .42438 L
.54068 .41941 L
.54547 .41428 L
.55025 .40902 L
.55504 .40369 L
.55982 .3983 L
.56461 .39289 L
.56939 .38746 L
.57418 .38204 L
.57897 .37664 L
.58375 .37127 L
.58854 .36593 L
.59332 .36063 L
.59811 .35537 L
.6029 .35015 L
.60768 .34499 L
.61247 .33987 L
.61725 .33479 L
.62204 .32977 L
.62682 .32478 L
.63161 .31985 L
.6364 .31495 L
.64118 .3101 L
.64597 .30529 L
.65075 .30052 L
.65554 .29578 L
.66033 .29108 L
.66511 .28642 L
.6699 .28179 L
.67468 .27719 L
.67947 .27262 L
.68425 .26808 L
.68904 .26357 L
.69383 .25908 L
.69861 .25462 L
.7034 .25018 L
.70818 .24577 L
.71297 .24137 L
.71776 .237 L
.72254 .23265 L
.72733 .22832 L
.73211 .224 L
.7369 .2197 L
Mistroke
.74168 .21542 L
.74647 .21115 L
.75126 .2069 L
.75604 .20266 L
.76083 .19843 L
.76561 .19422 L
.7704 .19002 L
.77519 .18583 L
.77997 .18166 L
.78476 .17749 L
.78954 .17333 L
.79433 .16918 L
.79911 .16505 L
.8039 .16092 L
.80869 .1568 L
.81347 .15268 L
.81826 .14858 L
.82304 .14448 L
.82783 .14038 L
.83262 .1363 L
.8374 .13222 L
.84219 .12815 L
.84697 .12408 L
.85176 .12002 L
.85654 .11596 L
.86133 .11191 L
.86612 .10786 L
.8709 .10382 L
.87569 .09978 L
.88047 .09574 L
.88526 .09171 L
.89005 .08768 L
.89483 .08366 L
.89962 .07964 L
.9044 .07562 L
.90919 .07161 L
.91397 .0676 L
.91876 .06359 L
.92355 .05958 L
.92833 .05558 L
.93312 .05158 L
.9379 .04758 L
.94269 .04358 L
.94748 .03959 L
.95226 .03559 L
.95705 .0316 L
.96183 .02761 L
.96662 .02363 L
.9714 .01964 L
.97619 .01566 L
Mistroke
Mfstroke
[ .05 ] 0 setdash
.02381 .40836 m
.0286 .40837 L
.03338 .40839 L
.03817 .40841 L
.04295 .40843 L
.04774 .40844 L
.05252 .40846 L
.05731 .40848 L
.0621 .40851 L
.06688 .40853 L
.07167 .40855 L
.07645 .40858 L
.08124 .4086 L
.08603 .40863 L
.09081 .40866 L
.0956 .40869 L
.10038 .40872 L
.10517 .40875 L
.10995 .40878 L
.11474 .40882 L
.11953 .40886 L
.12431 .40889 L
.1291 .40893 L
.13388 .40898 L
.13867 .40902 L
.14346 .40907 L
.14824 .40911 L
.15303 .40916 L
.15781 .40922 L
.1626 .40927 L
.16738 .40933 L
.17217 .40939 L
.17696 .40945 L
.18174 .40951 L
.18653 .40958 L
.19131 .40965 L
.1961 .40972 L
.20089 .4098 L
.20567 .40988 L
.21046 .40996 L
.21524 .41005 L
.22003 .41013 L
.22481 .41023 L
.2296 .41032 L
.23439 .41042 L
.23917 .41053 L
.24396 .41064 L
.24874 .41075 L
.25353 .41086 L
.25832 .41098 L
Mistroke
.2631 .41111 L
.26789 .41124 L
.27267 .41137 L
.27746 .4115 L
.28224 .41165 L
.28703 .41179 L
.29182 .41194 L
.2966 .41209 L
.30139 .41225 L
.30617 .41241 L
.31096 .41257 L
.31575 .41274 L
.32053 .41291 L
.32532 .41308 L
.3301 .41326 L
.33489 .41343 L
.33967 .41361 L
.34446 .41378 L
.34925 .41395 L
.35403 .41412 L
.35882 .41429 L
.3636 .41445 L
.36839 .4146 L
.37318 .41474 L
.37796 .41488 L
.38275 .41499 L
.38753 .41509 L
.39232 .41517 L
.3971 .41523 L
.40189 .41526 L
.40668 .41526 L
.41146 .41522 L
.41625 .41514 L
.42103 .41501 L
.42582 .41483 L
.43061 .41459 L
.43539 .41428 L
.44018 .4139 L
.44496 .41343 L
.44975 .41288 L
.45453 .41223 L
.45932 .41148 L
.46411 .41061 L
.46889 .40963 L
.47368 .40851 L
.47846 .40727 L
.48325 .40588 L
.48804 .40436 L
.49282 .40268 L
.49761 .40086 L
Mistroke
.50239 .39888 L
.50718 .39676 L
.51196 .39448 L
.51675 .39206 L
.52154 .38949 L
.52632 .38679 L
.53111 .38395 L
.53589 .38099 L
.54068 .3779 L
.54547 .3747 L
.55025 .3714 L
.55504 .368 L
.55982 .36452 L
.56461 .36095 L
.56939 .35731 L
.57418 .3536 L
.57897 .34983 L
.58375 .34601 L
.58854 .34214 L
.59332 .33822 L
.59811 .33428 L
.6029 .3303 L
.60768 .32629 L
.61247 .32226 L
.61725 .31821 L
.62204 .31414 L
.62682 .31006 L
.63161 .30596 L
.6364 .30186 L
.64118 .29775 L
.64597 .29363 L
.65075 .28951 L
.65554 .28539 L
.66033 .28127 L
.66511 .27714 L
.6699 .27302 L
.67468 .26889 L
.67947 .26477 L
.68425 .26065 L
.68904 .25653 L
.69383 .25242 L
.69861 .24831 L
.7034 .2442 L
.70818 .2401 L
.71297 .236 L
.71776 .2319 L
.72254 .22781 L
.72733 .22372 L
.73211 .21964 L
.7369 .21556 L
Mistroke
.74168 .21149 L
.74647 .20742 L
.75126 .20335 L
.75604 .19929 L
.76083 .19523 L
.76561 .19118 L
.7704 .18712 L
.77519 .18308 L
.77997 .17904 L
.78476 .175 L
.78954 .17096 L
.79433 .16693 L
.79911 .1629 L
.8039 .15887 L
.80869 .15485 L
.81347 .15083 L
.81826 .14681 L
.82304 .14279 L
.82783 .13878 L
.83262 .13477 L
.8374 .13077 L
.84219 .12676 L
.84697 .12276 L
.85176 .11876 L
.85654 .11476 L
.86133 .11076 L
.86612 .10677 L
.8709 .10278 L
.87569 .09879 L
.88047 .0948 L
.88526 .09081 L
.89005 .08682 L
.89483 .08284 L
.89962 .07886 L
.9044 .07488 L
.90919 .0709 L
.91397 .06692 L
.91876 .06294 L
.92355 .05896 L
.92833 .05499 L
.93312 .05102 L
.9379 .04704 L
.94269 .04307 L
.94748 .0391 L
.95226 .03513 L
.95705 .03116 L
.96183 .02719 L
.96662 .02322 L
.9714 .01926 L
.97619 .01529 L
Mistroke
Mfstroke
.001 w
[ ] 0 setdash
.02381 .40778 m
.0286 .40777 L
.03338 .40776 L
.03817 .40775 L
.04295 .40773 L
.04774 .40772 L
.05252 .4077 L
.05731 .40769 L
.0621 .40767 L
.06688 .40765 L
.07167 .40764 L
.07645 .40762 L
.08124 .4076 L
.08603 .40758 L
.09081 .40755 L
.0956 .40753 L
.10038 .40751 L
.10517 .40748 L
.10995 .40746 L
.11474 .40743 L
.11953 .4074 L
.12431 .40737 L
.1291 .40734 L
.13388 .4073 L
.13867 .40727 L
.14346 .40723 L
.14824 .40719 L
.15303 .40715 L
.15781 .4071 L
.1626 .40706 L
.16738 .40701 L
.17217 .40696 L
.17696 .40691 L
.18174 .40685 L
.18653 .40679 L
.19131 .40673 L
.1961 .40666 L
.20089 .40659 L
.20567 .40652 L
.21046 .40644 L
.21524 .40636 L
.22003 .40628 L
.22481 .40619 L
.2296 .40609 L
.23439 .40599 L
.23917 .40589 L
.24396 .40577 L
.24874 .40566 L
.25353 .40553 L
.25832 .4054 L
Mistroke
.2631 .40526 L
.26789 .40511 L
.27267 .40496 L
.27746 .4048 L
.28224 .40462 L
.28703 .40444 L
.29182 .40424 L
.2966 .40404 L
.30139 .40382 L
.30617 .40359 L
.31096 .40335 L
.31575 .40309 L
.32053 .40282 L
.32532 .40253 L
.3301 .40222 L
.33489 .40189 L
.33967 .40155 L
.34446 .40119 L
.34925 .4008 L
.35403 .40039 L
.35882 .39996 L
.3636 .3995 L
.36839 .39901 L
.37318 .39849 L
.37796 .39794 L
.38275 .39737 L
.38753 .39675 L
.39232 .3961 L
.3971 .39542 L
.40189 .39469 L
.40668 .39392 L
.41146 .39311 L
.41625 .39225 L
.42103 .39135 L
.42582 .3904 L
.43061 .38939 L
.43539 .38833 L
.44018 .38722 L
.44496 .38604 L
.44975 .38481 L
.45453 .38352 L
.45932 .38216 L
.46411 .38074 L
.46889 .37925 L
.47368 .3777 L
.47846 .37608 L
.48325 .37439 L
.48804 .37262 L
.49282 .37079 L
.49761 .36889 L
Mistroke
.50239 .36691 L
.50718 .36486 L
.51196 .36275 L
.51675 .36056 L
.52154 .3583 L
.52632 .35597 L
.53111 .35358 L
.53589 .35111 L
.54068 .34858 L
.54547 .34599 L
.55025 .34333 L
.55504 .34061 L
.55982 .33783 L
.56461 .335 L
.56939 .33211 L
.57418 .32916 L
.57897 .32617 L
.58375 .32312 L
.58854 .32003 L
.59332 .31689 L
.59811 .31371 L
.6029 .31048 L
.60768 .30722 L
.61247 .30392 L
.61725 .30058 L
.62204 .29721 L
.62682 .29381 L
.63161 .29037 L
.6364 .28691 L
.64118 .28342 L
.64597 .2799 L
.65075 .27636 L
.65554 .2728 L
.66033 .26921 L
.66511 .26561 L
.6699 .26198 L
.67468 .25834 L
.67947 .25468 L
.68425 .251 L
.68904 .24731 L
.69383 .2436 L
.69861 .23988 L
.7034 .23615 L
.70818 .2324 L
.71297 .22864 L
.71776 .22488 L
.72254 .2211 L
.72733 .21731 L
.73211 .21352 L
.7369 .20972 L
Mistroke
.74168 .2059 L
.74647 .20209 L
.75126 .19826 L
.75604 .19443 L
.76083 .19059 L
.76561 .18674 L
.7704 .18289 L
.77519 .17904 L
.77997 .17518 L
.78476 .17131 L
.78954 .16744 L
.79433 .16357 L
.79911 .15969 L
.8039 .15581 L
.80869 .15193 L
.81347 .14804 L
.81826 .14415 L
.82304 .14025 L
.82783 .13636 L
.83262 .13246 L
.8374 .12855 L
.84219 .12465 L
.84697 .12074 L
.85176 .11683 L
.85654 .11292 L
.86133 .10901 L
.86612 .10509 L
.8709 .10118 L
.87569 .09726 L
.88047 .09334 L
.88526 .08942 L
.89005 .0855 L
.89483 .08157 L
.89962 .07765 L
.9044 .07372 L
.90919 .06979 L
.91397 .06587 L
.91876 .06194 L
.92355 .058 L
.92833 .05407 L
.93312 .05014 L
.9379 .04621 L
.94269 .04227 L
.94748 .03834 L
.95226 .0344 L
.95705 .03047 L
.96183 .02653 L
.96662 .02259 L
.9714 .01865 L
.97619 .01472 L
Mistroke
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001?Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0NOol0051oo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo01eoo`00?Goo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01aoo`00?Woo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol077oo000nOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01aoo`00?Woo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0LOol003ioo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0MOol003eo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo01io
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000dOol00`00Oomoo`02Ool00`00Oomo
o`050007Ool00`00Oomoo`02Ool01000Oomoogoo0`0047oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol02goo1@004Goo0`006Goo00<007ooOol03Goo1@000Woo00<007ooOol05Goo000cOol0
0`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007Ool00`00Oomoo`0?Ool00`00Ool00007Ool0
0`00Ool0000>Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Ool0000@Ool01`00Oomoogoo001o
o`0001Ioo`00<goo00<007oo000027oo00<007ooOol01Woo00<007oo000027oo00<007ooOol03Woo
00<007oo00002Goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol03Woo
00L007ooOomoo`00Ool0000FOol003=oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Qo
o`03001oogoo00ioo`03001oo`0000Moo`8000moo`03001oogoo019oo`03001oogoo01Moo`80015o
o`07001oogooOol007oo00005Woo000cOol00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007
Ool00`00Ool0000?Ool00`00Ool00007Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Ool0000H
Ool00`00Oomoo`0@Ool01`00Oomoogoo001oo`0001Ioo`00=7oo00<007ooOol01Woo0P002Goo00<0
07ooOol01goo00<007ooOol03goo00<007ooOol01Woo0`003Goo0P0057oo00<007ooOol05goo0`00
3goo0P0017oo00<007ooOol05Goo003MOol00=eoo`00gGoo000gOonA000EOol003Moo`05001oogoo
Ool0000COol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol001Aoo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool01@00Oomo
ogoo00000Woo00<007ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`009goo1@000Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`0?57oo00<03gooOol01Goo100000<03`000000300000@03`00001ooa80009oo`03001oogoo
01=oo`00:Goo00<007ooOol00Woo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l04goo00<0
3gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo00lAOol;0004Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Ool000090002Ool00`00Oomoo`0COol002=oo`<000=oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo008005803`0300003`0000<001l03`H0000300l0
0000008000P03`80000300l0000001Eoo`00:Goo00<007ooOol00goo00<007ooOol00P000goo00D0
07ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?2Goo0`0027oo00<03gooOol02Goo
00<03gooOol01Goo00<03`0000001P000goo00<03gooOol00Woo00D03`000000000?009oo`0500mo
ogooOol03`02Ool00`00Oomoo`0COol002Uoo`07001oogooOol007oo00000Woo00<007ooOol00Woo
0P000Woo00<03gooOol04Goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l7Ool2000;Ool00`0?Oomo
o`09Ool00`0?Oomoo`02000017oo000000001Woo00<03gooOol00Woo00<03`0000000`000goo00<0
3`0000001@0000=oo`0000005Goo000XOol20003Ool30002Ool30002Ool01@00Oomoogoo00l04goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00l6Ool00`00Oomoo`0;Ool00`0?Oomoo`08Ool50004Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool50002Ool01@0?Oomoogoo00l00Woo00<0
07ooOol04goo000gOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eo
o`03001oogoo00aoo`0300moogoo00Eoo`@0000300moogoo00Eoo`0300moogoo00<00003Ool03goo
00=oo`H000=oo`0400moogoo00l3Ool0100?Ool000005Goo000gOol01@00Oomoogoo00l04goo00<0
3gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo00l4Ool00`00Oomoo`0=Ool00`0?Oomoo`02Ool30004Ool00`0?
Oomoo`04Ool40004Ool00`0?Ool000030004Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009o
o`03001oogoo01=oo`00=goo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
17oo00<007ooOol03Goo00<03goo00000P001goo00<03gooOol017oo00<0000?Ool017oo0`000goo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Mo
o`80009oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo0`002Goo00<03goo
Ool01Goo00<03gooOol00`0000=oo`0?Ool00goo00<03gooOol00Woo00D03gooOomoo`0?009oo`06
00moogooOol03goo0P005Goo000COol00`00Oomoo`02Ool00`00Oomoo`0LOol01@00Oomoogoo00l0
4goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00l3Ool00`00Oomoo`0=Ool2000:Ool20007Ool30004
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03
001oogoo01=oo`004goo1P003Woo1@000Woo00<007ooOol00Woo00@007ooOomoo`80009oo`0300mo
ogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?0Woo00<007ooOol037oo00@007ooOol03`Mo
o`<00003Ool03goo00=oo`<0000300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`004goo00H007ooOol007oo000@Ool01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol03`9oo`03001oogoo00Yoo`8000=oo`0300moogoo00=oo`<000=oo`0300moogoo00<0009o
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l00Woo00<007ooOol04goo000COol01000Oomoo`0037oo0`000goo00<007ooOol00goo00H0
07ooOol007oo0002Ool2001900l00`0000l03`0900l2000:00l00`0000l03`0400l3000R00l2000E
Ool001Aoo`8001=oo`04001oogooOol20003Ool00`00Ool00002Ool01@00Oomoogoo00l04goo00<0
3gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo00l2Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`0?Oomoo`08
Ool30006Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?009oo`03001oogoo01=oo`00:Goo00D007ooOomoo`0000Aoo`03001oo`00009o
o`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`9oo`03001oogoo00Moo`80
00Ioo`0300moogoo00Ioo`<0000300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000COol00`00
Oomoo`02Ool00`00Oomoo`0=Ool20003Ool30003Ool01000Oomoogoo0P000Woo00<03gooOol04Goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00l2Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool01@00Oomoogoo00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000COol6000NOol01@00Oomoogoo00l04goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0600moogoo00moo`002Goo00<007ooOol01Goo0P001Goo0P0017oo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0500moogooOol03`02Ool00`00Oomoo`0COol001Eoo`04001oogoo000NOol20002Ool00`0?Oomo
o`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00H03gooOol03goo0008Ool00`00Oomoo`04Ool200000goo00mo
o`02Ool20006Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol001Eoo`03001oogoo01moo`05001oogoo
Ool03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOol03goo0007Ool00`00Oomoo`04Ool20002Ool0
0`0?Oomoo`020007Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`005Woo0`007Woo00D0
07ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?2Goo00<007ooOol00goo00<007oo
Ool00Woo00<03goo00002Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol001Qoo`03001o
ogoo01aoo`80009oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoo`0?Ool000Ioo`03
001oogoo00=oo`8000Aoo`8000Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`00=goo00D007ooOomo
o`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01P0?Oomoo`0?Ool000Eoo`03001oogoo00Uoo`8000]oo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000GOol2000>Ool5000017oo000000000goo00@0
07ooOomoo`80009oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1goo00<007oo
Ool01goo0P0000=oo`0?Ool02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P005Goo000EOol01000Ool00000
47oo00D007ooOomoo`0000Aoo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOol03`0000Eoo`03001oogoo00Moo`80009oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l00Woo00<007ooOol04goo000EOol01000Ool000002Woo0`000goo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol00P00A`0?00<0000?00l00`0?00<0000?00l01P0?00<0000?00l0=00?
0P005Goo000EOol4000@Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00D007ooOomoo`0?01=o
o`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoo`0?000017oo00D007ooOomoo`0000Aoo`8000Aoo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000HOol00`00Oomoo`0>Ool01`00
Oomoogoo001oo`00009oo`03001oogoo009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOol03`0000=oo`03001oogoo009oo`05001oogooOol00006Ool00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?009oo`03001oogoo01=oo`00:7oo0P0017oo00@007ooOomoo`<0009oo`80009o
o`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoo`0?00000goo00<007ooOol00Woo00@0
07ooOol000Moo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`005Goo0P0000=oo`00
Ool07Goo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoo`0?00000goo00<007oo
Ool00P000Woo00<007ooOol01Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomo
o`0COol001Eoo`800003Ool007oo01eoo`80009oo`0300moogoo015oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1@0?Oomoo`0?00000Woo00@007ooOol000=oo`03001oogoo00Moo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?
Oomoogoo00moo`8001Eoo`005Goo0P0000=oo`00Ool07Goo00D007ooOomoo`0?01=oo`0300moogoo
00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool01@0?Oomoo`0?00001Goo00@007ooOol000Yoo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l00Woo00<007ooOol04goo000EOol00`00Ool0000OOol20002Ool00`0?Oomoo`0AOol00`0?
Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00D03gooOol03`00009oo`03001oo`00009oo`8000Yoo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01P0?Oomoogoo00moo`8001Eoo`00=goo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1`0?Oomoo`0?001oo`0000Aoo`03001oogoo00Yoo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
0Woo00<007ooOol04goo000gOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0700moogoo
00l007oo00000goo00<007ooOol02goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00
Oomoo`0COol001Ioo`8000moo`D0009oo`03001oogoo009oo`04001oogooOol20002Ool00`0?Oomo
o`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00L03gooOol03`00Ool00002Ool00`00Oomoo`0<Ool00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00H03gooOomoo`0?Ool2000EOol001Eoo`800003Ool007oo00moo`07001oogooOol0
07oo00000Woo00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`0?0P000Woo00<007ooOol03Goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomo
o`0COol001Eoo`800003Ool007oo00Uoo`<000=oo`07001oogooOol007oo00000Woo00<007oo0000
0Woo0P00A`0?0P0000<03`000000@@0?0P005Goo000FOol00`00Ool0000@Ool01`00Oomoogoo001o
o`00009oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
3`<0015oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000YOol01`00
Oomoogoo001oo`00009oo`03001oo`00009oo`80009oo`0300moogoo015oo`0300moogoo00Yoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`04000AOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol002Qoo`80
00Aoo`03001oogoo009oo`05001oogooOol00003Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol00`004Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol0
03Moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00P004goo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`80009oo`0300moogoo015oo`03
00moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0057oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P00
5Goo000gOol01@00Oomoogoo00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moo`00000DOol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00=goo0P000Woo00<03gooOol04Goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moo`00000DOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2
000EOol003Moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo100057oo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`05001oogooOol03`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomo
ogoo00moo`0000l2Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03
001oogoo01=oo`00;Woo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo015oo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0900mo
ogooOol03goo00003goo008001Aoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`00
5Goo10005Goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l04goo00<03gooOol02Woo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00@03gooOomoo`800005
Ool03`00Ool0000DOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00
57oo00<007ooOol00Woo00<007ooOol037oo0`000goo00<007ooOol00goo00<007ooOol00P00@00?
00L0000?00l03`0000l0001600l2000EOol001=oo`03001oogoo00Aoo`03001oogoo019oo`03001o
ogoo008000=oo`05001oogooOol03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoo`0000l007oo0002Ool00`00Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00;Goo00<007oo00000Woo
00<007ooOol00Woo0P000Woo00<03gooOol04Goo00<03gooOol02Woo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo001oo`00009oo`04001oo`0000lDOol0
0`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol002eoo`<0009oo`<0009oo`05001oogoo
Ool03`0COol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool02`0?001oogoo001oo`0000moo`0000l057oo00<03gooOol02Goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogoo
Ool03`02Ool00`00Oomoo`0COol001Ioo`8001moo`05001oogooOol03`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool02`00Oomoo`0000mo
o`0000moo`0000l057oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol0
01Eoo`04001oogoo000NOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool02P0?Oomoogoo00003goo001oo`0?0Woo00@03goo00003aAo
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`004goo00<007oo00000Woo00<007oo
Ool077oo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0@00moogoo001oo`0?Ool007oo00moo`0000moo`0000lDOol00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`004goo1P007Woo0P000Woo00<03gooOol04Goo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo00000Woo
00/03`00Oomoo`0?001oo`0?Ool0000?01Aoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`80
01Eoo`0067oo00<007ooOol077oo00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`8000=oo`0500moogooOol00002Ool0100?Oomoo`0?57oo
00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol003Moo`80009oo`0300mo
ogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03001o
ogoo009oo`0500moogooOol00002Ool0100?Ool0000?57oo00<03gooOol02Goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogoo
Ool03goo0P005Goo000FOol2000FOol00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol0
4Goo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00P0000<03gooOol0
0Woo00D03gooOomoo`00009oo`0400moo`0000lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?
009oo`03001oogoo01=oo`005Goo0P0000=oo`00Ool04goo00<007oo00000Woo00<007oo00000Woo
00D007ooOomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00Aoo`0600moo`00
001oo`0?17oo00D03gooOol0000?009oo`0400moo`0000lDOol00`0?Oomoo`09Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03goo
Oomoo`0?009oo`03001oogoo01=oo`005Goo0P0000=oo`00Ool03Woo0`0017oo00H007ooOol007oo
0002Ool2000c00l00`0000l03`0200l00`0000l03`0400l00`0000l03`0300l00`0000l03`1500l2
000EOol001Ioo`03001oo`0001Aoo`8000=oo`03001oo`00009oo`05001oogooOol03`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool20004Ool20003Ool01@0?Ool007oo00l00Woo
00@03goo00003aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000]
Ool00`00Oomoo`02Ool00`00Ool00002Ool20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool200000`0?Oomoo`02Ool00`00Oomoo`02Ool01@0?Ool007oo00l0
0Woo00@03goo00003aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`00;Goo0`00
0goo00D007ooOomoo`0000=oo`0300moogoo015oo`0300moogoo00Yoo`0300moogoo00Eoo`0500mo
ogooOol00002Ool00`0?Oomoo`0200000`0?Oomoo`02Ool01@0?001oogoo00l00Woo00@03goo0000
3aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000FOol20002Ool0
0`00Oomoo`0JOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0100?Ool0
00000goo00H03goo000007oo00l4Ool01@00Oomoogoo00l00Woo00@03goo00003aAoo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool01P0?Oomoogoo00moo`8001Eoo`005Goo00H007ooOol007oo000LOol01@00Oomoogoo
00l04goo00<03gooOol02Woo00<03gooOol01Goo00<03`00Ool017oo00<03`00Ool00Woo00<03goo
Ool00Woo00D007ooOomoo`0?009oo`0400l007oo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomo
o`0?009oo`03001oogoo01=oo`005Goo00H007ooOol007oo000LOol01@00Oomoogoo00l04goo00<0
3gooOol02Woo00<03gooOol017oo0P001Woo00<03gooOol00Woo00<03gooOol00P0000D03gooOomo
o`0?009oo`0400l007oo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo
01=oo`005Goo1@007Goo0P000Woo00<03gooOol04Goo00<03gooOol02Woo00<03gooOol00Woo0P00
00=oo`0?Ool01Goo00<03gooOol00Woo00H03gooOol007oo00l3Ool01`0?Oomoo`0?001oo`0?01Ao
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01P0?Oomoogoo00moo`8001Eoo`005Goo00<007ooOol07goo00D007oo
Oomoo`0?01=oo`0300moogoo00Yoo`0300moogoo00<0009oo`0300moogoo00Aoo`0300moogoo009o
o`0300l007oo009oo`0500moogooOol03`02Ool0100?001oo`0?57oo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00moogooOol03`02Ool00`00Oomoo`0COol002eoo`<000=oo`04001oogooOol20002Ool00`0?Oomo
o`0AOol00`0?Oomoo`0:Ool0100?0000000017oo00<03`00000017oo00<03gooOol00Woo00<007oo
Ool00Woo00D03gooOomoo`0?009oo`0400l007oo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomo
o`0?Ool2000EOol001=oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo009oo`03001oo`00
009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool30006Ool20005Ool0100?Oomoogoo0P0017oo
00D03gooOomoo`0?009oo`04001oogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009o
o`03001oogoo01=oo`0057oo00<007ooOol00Woo00<007ooOol037oo0`000goo00<007ooOol00goo
00<007ooOol00P007`0?0`001`0?0P002P0?00<0000?00l02`0?00<0000?00l0A`0?0P005Goo000E
Ool4000EOol01000Oomoogoo0P000goo00D007ooOomoo`0?01=oo`0300moogoo00Aoo`<000=oo`04
00moogooOol20002Ool00`0?Oomoo`04Ool00`0?00000002Ool00`0?Oomoo`02Ool0200?Oomoogoo
00moo`0000l2Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001o
ogoo01=oo`00;Goo00<007oo00000Woo00<007ooOol00Woo00D007ooOomoo`0?01=oo`0400moogoo
Ool40005Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02Ool0200?
Oomoogoo00moo`0000l2Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009o
o`03001oogoo01=oo`00;Woo00@007ooOomoo`<0009oo`80009oo`0300moogoo015oo`0400l00000
0009Ool00`0?Oomoo`05Ool0100?Oomoogoo0`0000<03gooOol00Woo00<03gooOol00Woo00P03goo
Oomoo`0?Ool0000?0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0600moogooOol03goo0P00
5Goo000gOol01@00Oomoogoo00l04Goo0`001Woo10000Woo00<03gooOol01Goo00@03`00000000=o
o`0300moogoo009oo`0300moogoo009oo`0800moogooOol03goo00003`9oo`0300moogoo019oo`03
00moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo000gOol20002Ool00`0?Oomo
o`0;Ool40002Ool0100?Oomoogoo10001Goo00<03gooOol00goo00@007oo000000Eoo`0300moogoo
009oo`0300moogoo009oo`0800moogooOol03`00Ool03`9oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool01P0?Oomoogoo00moo`8001Eoo`00=goo00D007ooOomoo`0?00Qoo`D000Ioo`0400moogoo
0009Ool00`0?Ool000030002Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00000Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<0
07ooOol04goo000gOol01@00Oomoogoo00l00Woo1P001Goo0`000goo00<03gooOol01goo1@001Woo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo0000000?009oo`0400moogoo
00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?009oo`03001oogoo01=oo`00=goo0P000Woo
100017oo1P001Woo00@03gooOomoo`H000=oo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`<00005Ool03gooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00H03gooOomoo`0?Ool2000EOol003Moo`04001oogooOol2000>Ool00`00Ool000050009Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Ool000030003Ool0100?Oomoo`0?
0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`02Ool00`00Oomoo`0COol0
03=oo`04001oogooOol20002Ool00`0?Oomoo`0=0004Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool70003Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01P0?Oomoogoo00moo`8001Eoo`00<Woo00<007oo00000Woo00@007ooOomoo`@0011oo`0300mo
ogoo00Moo`T00004Ool00000Ool500000`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo
000bOol00`00Ool00002Ool20002Ool00`0?0000000A0000100?000007oo1P000goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00H03gooOomoo`0?Ool2000EOol0039oo`03001oo`00009o
o`05001oogooOol0000COol00`00Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`00Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol001Aoo`03001oogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo00000Woo00<007ooOol04goo000bOol00`00Ool00002OonA000EOol003=oo`03
001oogoo0:Moo`00gGoo003MOol00=eoo`00gGoo003MOol003Aoo`03001oogoo009oo`03001oogoo
00D000Moo`03001oogoo009oo`04001oogooOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0;Ool5000AOol3000IOol00`00Oomoo`0=Ool50002Ool00`00Oomoo`0EOol003=oo`03
001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Moo`03001oogoo00moo`03001oo`0000Moo`03
001oo`0000ioo`03001oogoo015oo`03001oogoo01Qoo`03001oo`00011oo`07001oogooOol007oo
00005Woo000cOol00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`0>Ool0
0`00Ool00009Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0>Ool0
1`00Oomoogoo001oo`0001Ioo`00<goo00<007oo000027oo00<007ooOol01Woo00<007oo000027oo
00<007ooOol03Woo00<007oo00001goo0P003goo00<007ooOol04Woo00<007ooOol05goo0P004Goo
00L007ooOomoo`00Ool0000FOol003=oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Mo
o`03001oo`0000moo`03001oo`0000Moo`03001oogoo00ioo`03001oogoo015oo`03001oo`0001Qo
o`03001oogoo011oo`07001oogooOol007oo00005Woo000dOol00`00Oomoo`06Ool20009Ool00`00
Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool3000=Ool2000DOol00`00Oomoo`0GOol3000?
Ool20004Ool00`00Oomoo`0EOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo
003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000E
Ool00`00Oomoo`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001o
ogoo01=oo`03001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo
0`000Woo0P0000=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<0
0003Ool007oo00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool0
0000009oo`03001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomo
o`0000Aoo`06001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0
000BOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009o
o`03001oo`00009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo
00000Woo00<007ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`00
0Woo00H007ooOol007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00
019oo`03001oogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`030002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001o
ogoo00Moo`03001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool3
00000goo000000020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009o
o`8000=oo`<000Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo00000002
0003Ool30009Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<0
07ooOol01goo00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomo
o`0POol003Yoo`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03
001oogoo025oo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000aOol00`00Oomoo`02
Ool00`00Oomoo`050007Ool00`00Oomoo`02Ool01000Oomoogoo0`0047oo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol02goo1@004Goo0`006Goo00<007ooOol03Goo1@000Woo00<007ooOol0
67oo000`Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00007Ool00`00Oomoo`0?Ool00`00
Ool00007Ool00`00Ool0000>Ool00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Ool0000@Ool01`00
Oomoogoo001oo`0001Uoo`00<7oo00<007oo000027oo00<007ooOol01Woo00<007oo000027oo00<0
07ooOol03Woo00<007oo00002Goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol06Goo00<0
07ooOol03Woo00L007ooOomoo`00Ool0000IOol0031oo`03001oo`0000Qoo`03001oogoo00Ioo`03
001oo`0000Qoo`03001oogoo00ioo`03001oo`0000Moo`8000moo`03001oogoo019oo`03001oogoo
01Moo`80015oo`07001oogooOol007oo00006Goo000`Ool00`00Ool00008Ool00`00Oomoo`06Ool0
0`00Ool00007Ool00`00Ool0000?Ool00`00Ool00007Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol0
0`00Ool0000HOol00`00Oomoo`0@Ool01`00Oomoogoo001oo`0001Uoo`00<Goo00<007ooOol01Woo
0P002Goo00<007ooOol01goo00<007ooOol03goo00<007ooOol01Woo0`003Goo0P0057oo00<007oo
Ool05goo0`003goo0P0017oo00<007ooOol067oo003MOol00=eoo`00gGoo000dOonA000HOol002]o
o`<0009oo`05001oogooOol00003Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0
01Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool01000Oomoo`000Woo00<007ooOol05Woo000/Ool01P00Oomoo`00
Ool0009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000UOol30002Ool4000017oo001oo`000Woo
0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00D03goo000007oo008001Qoo`005Woo1P003Woo00<007oo00000Woo00<007oo00000Woo00D0
07ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00l007oo00l2Ool00`00Oomoo`0FOol001Ioo`<0009oo`03001oogoo00eoo`80009oo`03001oo`00
009oo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`80009oo`0400moogoo000HOol001Uoo`03001oogoo011oo`05001oogooOol00003Ool0
1@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomoogoo00moo`80
000400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`<0009oo`03001oogoo01Ioo`05001oogooOol0
3`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`0200001Goo00moogoo
00l00Woo00<007ooOol05Woo000FOol6000HOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0400moogooOol20002Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000F
Ool00`00Oomoo`02Ool00`00Oomoo`0FOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Ool000020003Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000dOol01@00
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?0000000000l00goo00@0
3gooOol03`9oo`03001oogoo01Ioo`006Woo0P0067oo0P000Woo00<03gooOol04Goo00<03gooOol0
2Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool20002Ool01@0?Oomoogoo00l00Woo00@03gooOol001Qoo`0067oo
00@007oo000001Qoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`03
00moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0400moogooOol20003
Ool01@0?Oomoogoo00l00Woo00@03gooOol001Qoo`0067oo00@007oo000001Qoo`05001oogooOol0
3`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00D03gooOomoo`0?009oo`0400mo
ogoo000HOol001Qoo`@001Qoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`0?57oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03`00
000007oo00l3Ool01@0?Oomoogoo00l00Woo00@03gooOol001Qoo`006goo00<007ooOol037oo0P00
17oo00D007ooOomoo`0000=oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo
00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03`00Ool00Woo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol002aoo`06001oogoo001oo`00
0Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00@03gooOomoo`8000Aoo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00<007ooOol05Woo000IOol20002Ool00`00Oomoo`05Ool30003Ool01`00Oomoogoo
001oo`00009oo`8007T03`8001803`8001Qoo`0067oo00H007ooOol007oo000>Ool01P00Oomoo`00
Ool0009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0600l00000001oo`0?17oo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`06001oogoo001oo`0037oo00<007oo00000Woo
00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<0
3gooOol02Goo00<03gooOol01Goo00<03gooOol017oo0`000Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`D000ioo`03001oogoo009oo`04001o
ogooOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00=oo`<000=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol00`00Oomoo`0IOol01@00Oomoogoo00l04goo
00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool200000`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`03001oogoo01Ioo`0067oo00@007ooOol001Qoo`80009oo`0300moogoo015oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol01Goo00@03gooOomoo`800003Ool0
3goo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo
000HOol4000HOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?
Oomoo`09Ool00`0?Oomoo`05Ool00`0?Ool000020002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo00<007ooOol06Goo00D0
07ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03goo
Ool01Goo00@03`00000000=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000HOol00`00Oomoo`0IOol20002Ool00`0?Oomoo`0AOol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`<000Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol0
5Woo000IOol3000HOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol0
0`0?Oomoo`09Ool00`0?Oomoo`04Ool20006Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006goo00<007ooOol05Woo00D007ooOomo
o`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol02Goo00<03gooOol00Woo
0`0000<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol02Goo00@03gooOomoo`<00003Ool03goo00Eoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000ZOol3
0003Ool01@00Oomoogoo00000goo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lD
Ool00`0?Oomoo`09Ool00`0?Oomoo`030002Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo00@007ooOol0
00ioo`03001oogoo009oo`03001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Uoo`0300moo`00008000=oo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000F
Ool00`00Ool000030009Ool30003Ool01`00Oomoogoo001oo`00009oo`8006P03`<002803`8001Qo
o`006goo00<007ooOol03Goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l04goo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo00lDOol00`0?Oomoo`08Ool30006Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00
:Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?57oo00<03gooOol01goo10001Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`03001oogoo
011oo`03001oogoo009oo`04001oogooOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol03aAoo`0300moogoo00Eoo`800003Ool0000000Moo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000G
Ool4000IOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol00`0?Oomo
o`04Ool500000`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo00@007ooOol001Qoo`80009o
o`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol00goo00@007oo
0000009oo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol01000Oomoo`0067oo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo00<03gooOol00Woo10000goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`03001oo`0001Uoo`05001oogooOol03`0COol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol03aAoo`0400moogooOol50003Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
00lDOol00`0?Ool0000200000goo00000004Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00
67oo00<007ooOol06Goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?57oo
00@03`00001oo`8000Ioo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol3000IOol01@00
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00lDOol01@00Oomoogoo00001goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool00`00Oomoo`0FOol001]oo`03001oogoo01Ioo`80009oo`0300moogoo015o
o`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?4Woo0P0000<03goo00000P001goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool00`00Oomoo`0FOol001Qoo`03001oo`0000ioo`D0009oo`05001oogooOol00003Ool00`0?
Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03a5oo`06001oogoo00moo`002Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool00`00Oomoo`0FOol001Qoo`@000moo`07001oogooOol007oo00000Woo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?3goo0P0000=oo`0000000`002Goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool00`00Oomoo`0FOol001]oo`03001oogoo00Moo`<000=oo`07001oogooOol0
07oo00000Woo0P00E00?0`0000D03`0000l03`0003403`8001Qoo`00:goo00L007ooOomoo`00Ool0
0002Ool01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l<Ool20002Ool5000;
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`006Goo0P0047oo00L007ooOomoo`00Ool00002
Ool01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l;Ool01P00Oomoogoo001o
o`<0000300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000HOol01000Oomoo`00
3Woo0P0017oo00@007ooOomoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`0?2Goo0P000Woo0P000Woo0P0000=oo`0?Ool02Woo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0F
Ool001Ioo`03001oo`00009oo`03001oogoo01Ioo`05001oogooOol03`0COol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03`Moo`<000=oo`03001oo`000080009oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol05Woo000FOol6000HOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo00l5Ool20008Ool20003Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001o
ogoo01Ioo`006goo00<007ooOol05Woo0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00l4Ool00`00Oomoo`07Ool20004Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03
001oogoo01Ioo`00=7oo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?0Woo
0P002Goo0`0017oo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Uoo`80
01Uoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`030005Ool20003Ool2
0006Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo0P0000=oo`00
Ool05goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool300000`0?Oomoo`04Ool00`00Oomo
o`02Ool00`00Ool00006Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00
67oo0P0000=oo`00Ool05goo00D007ooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0400moogooOol30000100?Oomoo`0?17oo
0P0017oo0`001goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Uoo`03
001oo`0001Qoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`D0009oo`0400moogoo00l2Ool30004Ool00`00Ool0
0008Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00<7oo00D007ooOomo
o`0000=oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0400mo
ogooOol70003Ool0100?Oomoo`0?0Woo00@03gooOol000Eoo`800003Ool007oo00Moo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000_Ool00`00Ool00002Ool01@00Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol00goo3P0000=oo`0?Ool00goo00D03gooOomoo`0?009o
o`0400moo`000007Ool01000Oomoo`002Goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00
Oomoo`0FOol002moo`03001oo`00009oo`8000803bL001/03`8000L03`0400003`0?000l00l2000H
Ool002moo`03001oo`00009oo`05001oogooOol03`0BOol00`0000l0000G0003Ool00`0?Oomoo`08
0003Ool0100?Oomoo`0?0Woo00<03gooOol017oo00@007ooOol000Yoo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000_Ool00`00Ool00002Ool01@00Oomoogoo00l04goo00<0
3gooOol02Goo00@03gooOomoo``0000300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`0?17oo0P000goo00<007ooOol027oo00<03gooOol02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool00`00Oomoo`0FOol0031oo`04001oogooOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Ool00006000017oo001oo`0?17oo00D03gooOomoo`0?009oo`0400moogoo
00l4Ool01@00Oomoogoo00002goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0F
Ool003Aoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool3
00000goo0000000300000goo00moo`02Ool0100?Oomoo`0?0Woo00<03gooOol00P000goo00<007oo
Ool02Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogoo
Ool03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0100?Oomoogoo0P000Woo
0`000goo00@03gooOol03`9oo`0400moo`000003Ool00`00Oomoo`0;Ool00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol04Goo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03`0000000Woo00<03`0000000P00
0Woo00<03gooOol00P001Goo00<007ooOol02goo00<03gooOol02Goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
0`00Oomoo`0FOol001Qoo`@001Qoo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool03`=oo`0300l0000000<0000300mo
ogoo00Aoo`03001oogoo00]oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo
000GOol00`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00@03gooOomoo`8000=oo`0400moogoo00l2
Ool00`0?Oomoo`03Ool00`00Oomoo`0<Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001o
ogoo01Ioo`005Woo00<007ooOol017oo00<007ooOol057oo0P000Woo00<03gooOol04Goo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo0P000Woo
00@03gooOol03`9oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007oo
Ool05Woo000dOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03goo001oo`0?009oo`0400moogoo00l4Ool2000>
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`00=7oo0P000Woo00<03goo
Ool04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOol0000?009oo`0400moogoo00l4Ool00`00Oomoo`0=Ool00`0?Oomoo`09Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`03001oogoo01Ioo`006Goo0P003Woo1@000Woo00D007ooOomoo`0000=o
o`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol00002Ool0100?Oomoo`0?17oo00<007ooOol03Goo00<03goo
Ool02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Qoo`04001oogoo000?Ool01`00Oomo
ogoo001oo`00009oo`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000Woo00@03gooOol03`=oo`03
001oogoo00ioo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00
Ool00002Ool00`00Oomoo`0=Ool01`00Oomoogoo001oo`00009oo`8004403`0300003`0?00H03`03
00003`0?04003`8001Qoo`005Woo1P003goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l0
4goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00P03gooOomoo`0?001oo`0?0Woo00@03gooOol0015oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol05Woo000KOol00`00Oomoo`0=Ool01`00Oomoogoo001oo`00009oo`05001o
ogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0200?Oomoogoo00moo`0000l2Ool0100?Oomoo`004Goo00<03gooOol02Goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`03001oogoo009oo`03001oogoo00aoo`8000Ao
o`04001oogooOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000l2Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`005Woo1P0067oo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01000Oomoo`0?0Woo00<007ooOol03goo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol001Ioo`03001oo`00009oo`03001oogoo01Io
o`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@007ooOol03`9oo`03001oogoo00moo`03
00moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00Ool00002Ool00`00
Oomoo`0FOol20002Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@007ooOol03aAoo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000GOol01000Ool000006Goo00D007oo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01P0?Oomoo`0?Ool0019oo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0600l007oo00moo`004Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol0
03Aoo`80009oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?001oo`0?Ool0019oo`0300mo
ogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol05Woo000FOol00`00Oomoo`04Ool00`00Oomo
o`0DOol01@00Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moo`0000l0000COol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`005goo00<007ooOol00Woo00<007ooOol0
5Goo0P000Woo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moo`0000l0000COol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`03001oogoo01Ioo`0067oo10003Woo0`000goo00D007ooOomo
o`0000=oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Ool0000?00004goo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol002Yoo`03001oogoo009oo`03001oo`00009o
o`05001oogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00P004goo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool00`00Oomoo`0FOol002]oo`07001oogooOol007oo00000Woo0P000Woo
00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo008001=oo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
1@0?Oomoo`0?Ool00P0067oo000[Ool01`00Oomoogoo001oo`00009oo`05001oogooOol0000COol0
0`00Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol001Aoo`03001oogoo00Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`000Woo00<0
07ooOol05Woo000ZOol00`00Ool00002Ool00`00Ool00002OonA000HOol002]oo`03001oogoo009o
o`03001oogoo0:Yoo`00gGoo003MOol00=eoo`00gGoo003MOol0035oo`03001oogoo009oo`03001o
ogoo00D000Moo`03001oogoo009oo`04001oogooOol3000@Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0;Ool5000AOol3000IOol00`00Oomoo`0=Ool50002Ool00`00Oomoo`0HOol0031o
o`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`0000Moo`03001oogoo00moo`03001oo`0000Mo
o`03001oo`0000ioo`03001oogoo015oo`03001oogoo01Qoo`03001oo`00011oo`07001oogooOol0
07oo00006Goo000`Ool00`00Ool00008Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`0>
Ool00`00Ool00009Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0>
Ool01`00Oomoogoo001oo`0001Uoo`00<7oo00<007oo000027oo00<007ooOol01Woo00<007oo0000
27oo00<007ooOol03Woo00<007oo00001goo0P003goo00<007ooOol04Woo00<007ooOol05goo0P00
4Goo00L007ooOomoo`00Ool0000IOol0031oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oo`00
00Moo`03001oo`0000moo`03001oo`0000Moo`03001oogoo00ioo`03001oogoo015oo`03001oo`00
01Qoo`03001oogoo011oo`07001oogooOol007oo00006Goo000aOol00`00Oomoo`06Ool20009Ool0
0`00Oomoo`07Ool00`00Oomoo`0?Ool00`00Oomoo`06Ool3000=Ool2000DOol00`00Oomoo`0GOol3
000?Ool20004Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00
gGoo003MOol00001\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-1.86866, -255.685, 0.0146283, 2.11653}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-1.82357, -166.852, 0.0146184, 0.708394}},
  CellTags->"5.2.1"]
}, Open  ]],

Cell[TextData[{
  "Of course, you can always supplement the results from ",
  StyleBox["BodePlot", "MR"],
  " with diagrams obtained using the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " functions. This plots the gain versus frequency and damping ratio for the \
generic second\[Hyphen]order system. To make a more attractive graphic, we \
picked up some coefficients for the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " axes. "
}], "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{

Cell["\<\
ParametricPlot3D[
 Evaluate[{ 
 10 Log[10, w],
 zeta 50,
 20 Log[10, Abs[
 s2[1, zeta][I w][[1, 1]]
 ] ]
 }], {w, .005, 5}, {zeta, 0, 1.5},
 PlotPoints -> {40,20},
 AxesLabel -> {\"10 Log[10, w]\",
 \"zeta x 50\", \"Gain (dB)\"},
 Boxed -> False
]\
\>", "Input",
  CellLabel->"In[16]:=",
  CellTags->"5.2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.59056 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.290652 1.67909 0 1.67909 [
[.06802 .09374 -16.8071 -9 ]
[.06802 .09374 1.1929 0 ]
[.14408 .06268 -11.0564 -9 ]
[.14408 .06268 .94357 0 ]
[.22129 .03115 -5.45406 -9 ]
[.22129 .03115 .54594 0 ]
[.29968 -0.00086 -5.3799 -9 ]
[.29968 -0.00086 .6201 0 ]
[.12858 -0.03919 -74.8766 -12.5625 ]
[.12858 -0.03919 7.12342 0 ]
[.00148 .96249 -6 -3.03587 ]
[.00148 .96249 0 5.96413 ]
[.21529 1.15476 -12 -3.15075 ]
[.21529 1.15476 0 5.84925 ]
[.40534 1.32565 -12 -3.24891 ]
[.40534 1.32565 0 5.75109 ]
[.57538 1.47854 -12 -3.33376 ]
[.57538 1.47854 0 5.66624 ]
[.28171 1.33368 -58 -4.51891 ]
[.28171 1.33368 0 8.04359 ]
[.03927 .25762 -18 -2.72668 ]
[.03927 .25762 0 6.27332 ]
[.01502 .53835 -6 -2.84803 ]
[.01502 .53835 0 6.15197 ]
[-0.01173 .84805 -12 -2.98259 ]
[-0.01173 .84805 0 6.01741 ]
[-0.08047 .54101 -58 -3.95494 ]
[-0.08047 .54101 0 8.60756 ]
[ 0 0 0 0 ]
[ 1 1.59056 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.07041 .11422 m
.35102 0 L
s
.08177 .1096 m
.08865 .11752 L
s
[(-10)] .06802 .09374 .86746 1 Mshowa
.1576 .07873 m
.16437 .08675 L
s
[(-5)] .14408 .06268 .84274 1 Mshowa
.23458 .0474 m
.24122 .05552 L
s
[(0)] .22129 .03115 .81802 1 Mshowa
.31273 .01559 m
.31925 .02381 L
s
[(5)] .29968 -0.00086 .7933 1 Mshowa
.125 Mabswid
.09685 .10346 m
.10096 .10823 L
s
.11197 .0973 m
.11607 .10208 L
s
.12713 .09113 m
.13122 .09592 L
s
.14235 .08494 m
.14642 .08974 L
s
.17291 .0725 m
.17695 .07733 L
s
.18826 .06625 m
.19228 .07109 L
s
.20365 .05999 m
.20767 .06484 L
s
.21909 .0537 m
.22309 .05856 L
s
.25012 .04107 m
.25409 .04596 L
s
.2657 .03473 m
.26966 .03963 L
s
.28133 .02837 m
.28527 .03328 L
s
.297 .02199 m
.30093 .02691 L
s
.3285 .00917 m
.3324 .01411 L
s
.34432 .00273 m
.3482 .00768 L
s
gsave
.12858 -0.03919 -135.877 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
81.000000 12.812500 moveto
(Log) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(@) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
135.000000 12.812500 moveto
(D) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
0 .93669 m
.7259 1.59056 L
s
.02144 .956 m
.03142 .95275 L
s
[(0)] .00148 .96249 1 -0.32536 Mshowa
.2354 1.14873 m
.24545 1.14571 L
s
[(20)] .21529 1.15476 1 -0.29983 Mshowa
.42556 1.32003 m
.43567 1.31721 L
s
[(40)] .40534 1.32565 1 -0.27802 Mshowa
.5957 1.47328 m
.60586 1.47065 L
s
[(60)] .57538 1.47854 1 -0.25916 Mshowa
.125 Mabswid
.0774 1.00641 m
.0834 1.0045 L
s
.13166 1.05529 m
.13767 1.05341 L
s
.1843 1.10271 m
.19032 1.10086 L
s
.28501 1.19342 m
.29105 1.19164 L
s
.3332 1.23683 m
.33925 1.23508 L
s
.38003 1.27901 m
.38609 1.2773 L
s
.46984 1.35991 m
.47592 1.35826 L
s
.51293 1.39872 m
.51901 1.39709 L
s
.55487 1.4365 m
.56095 1.43489 L
s
.63547 1.5091 m
.64157 1.50755 L
s
.67422 1.54401 m
.68032 1.54248 L
s
.71198 1.57803 m
.7181 1.57652 L
s
gsave
.28171 1.33368 -119 -8.51891 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(zeta) show
93.000000 12.812500 moveto
(x) show
105.000000 12.812500 moveto
(50) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.25 Mabswid
.07041 .11422 m
0 .93669 L
s
.05879 .24993 m
.06856 .24608 L
s
[(-20)] .03927 .25762 1 -0.39407 Mshowa
.03472 .53111 m
.04457 .5275 L
s
[(0)] .01502 .53835 1 -0.3671 Mshowa
.00816 .84134 m
.01811 .83799 L
s
[(20)] -0.01173 .84805 1 -0.3372 Mshowa
.125 Mabswid
.05299 .31773 m
.05886 .31545 L
s
.04705 .38715 m
.05293 .38491 L
s
.04096 .45826 m
.04686 .45605 L
s
.02833 .60578 m
.03425 .60365 L
s
.02178 .68232 m
.02771 .68023 L
s
.01506 .76082 m
.02101 .75877 L
s
.06446 .1837 m
.07031 .18136 L
s
.07 .11898 m
.07584 .11661 L
s
.00109 .92398 m
.00707 .92201 L
s
gsave
-0.08047 .54101 -119 -7.95494 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gain) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
111.000000 12.812500 moveto
(L) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 1.59056 L
0 1.59056 L
closepath
clip
newpath
.5 Mabswid
.93462 .77128 m .93336 .77661 L .90826 .74626 L p .945 .757 .617 r
F P
0 g
s
.90826 .74626 m .90954 .74084 L .93462 .77128 L p .945 .757 .617 r
F P
0 g
s
.93336 .77661 m .93206 .78205 L .90694 .7518 L p .945 .757 .618 r
F P
0 g
s
.90694 .7518 m .90826 .74626 L .93336 .77661 L p .945 .757 .618 r
F P
0 g
s
.93206 .78205 m .93073 .78763 L .90558 .75749 L p .945 .757 .618 r
F P
0 g
s
.90558 .75749 m .90694 .7518 L .93206 .78205 L p .945 .757 .618 r
F P
0 g
s
.93073 .78763 m .92936 .79334 L .90418 .76331 L p .945 .758 .619 r
F P
0 g
s
.90418 .76331 m .90558 .75749 L .93073 .78763 L p .945 .758 .619 r
F P
0 g
s
.92936 .79334 m .92794 .79919 L .90273 .76927 L p .945 .758 .62 r
F P
0 g
s
.90273 .76927 m .90418 .76331 L .92936 .79334 L p .945 .758 .62 r
F P
0 g
s
.92794 .79919 m .92647 .80518 L .90124 .77538 L p .944 .758 .621 r
F P
0 g
s
.90124 .77538 m .90273 .76927 L .92794 .79919 L p .944 .758 .621 r
F P
0 g
s
.92647 .80518 m .92496 .81132 L .8997 .78166 L p .944 .759 .621 r
F P
0 g
s
.8997 .78166 m .90124 .77538 L .92647 .80518 L p .944 .759 .621 r
F P
0 g
s
.92496 .81132 m .92339 .81763 L .8981 .7881 L p .944 .759 .622 r
F P
0 g
s
.8981 .7881 m .8997 .78166 L .92496 .81132 L p .944 .759 .622 r
F P
0 g
s
.92339 .81763 m .92177 .8241 L .89645 .79471 L p .944 .76 .623 r
F P
0 g
s
.89645 .79471 m .8981 .7881 L .92339 .81763 L p .944 .76 .623 r
F P
0 g
s
.92177 .8241 m .92008 .83075 L .89474 .80151 L p .944 .76 .624 r
F P
0 g
s
.89474 .80151 m .89645 .79471 L .92177 .8241 L p .944 .76 .624 r
F P
0 g
s
.92008 .83075 m .91833 .83757 L .89295 .8085 L p .944 .761 .625 r
F P
0 g
s
.89295 .8085 m .89474 .80151 L .92008 .83075 L p .944 .761 .625 r
F P
0 g
s
.91833 .83757 m .91651 .8446 L .8911 .81569 L p .943 .761 .627 r
F P
0 g
s
.8911 .81569 m .89295 .8085 L .91833 .83757 L p .943 .761 .627 r
F P
0 g
s
.91651 .8446 m .91461 .85182 L .88917 .82309 L p .943 .762 .628 r
F P
0 g
s
.88917 .82309 m .8911 .81569 L .91651 .8446 L p .943 .762 .628 r
F P
0 g
s
.91461 .85182 m .91263 .85927 L .88716 .83072 L p .943 .763 .629 r
F P
0 g
s
.88716 .83072 m .88917 .82309 L .91461 .85182 L p .943 .763 .629 r
F P
0 g
s
.90954 .74084 m .90826 .74626 L .88267 .71528 L p .945 .756 .616 r
F P
0 g
s
.88267 .71528 m .88398 .70977 L .90954 .74084 L p .945 .756 .616 r
F P
0 g
s
.90826 .74626 m .90694 .7518 L .88133 .72093 L p .945 .756 .616 r
F P
0 g
s
.88133 .72093 m .88267 .71528 L .90826 .74626 L p .945 .756 .616 r
F P
0 g
s
.91263 .85927 m .91057 .86694 L .88506 .83858 L p .943 .764 .631 r
F P
0 g
s
.88506 .83858 m .88716 .83072 L .91263 .85927 L p .943 .764 .631 r
F P
0 g
s
.90694 .7518 m .90558 .75749 L .87994 .72672 L p .945 .757 .617 r
F P
0 g
s
.87994 .72672 m .88133 .72093 L .90694 .7518 L p .945 .757 .617 r
F P
0 g
s
.91057 .86694 m .9084 .87485 L .88286 .8467 L p .942 .765 .633 r
F P
0 g
s
.88286 .8467 m .88506 .83858 L .91057 .86694 L p .942 .765 .633 r
F P
0 g
s
.90558 .75749 m .90418 .76331 L .87851 .73265 L p .945 .757 .617 r
F P
0 g
s
.87851 .73265 m .87994 .72672 L .90558 .75749 L p .945 .757 .617 r
F P
0 g
s
.9084 .87485 m .90613 .88301 L .88055 .85509 L p .942 .765 .634 r
F P
0 g
s
.88055 .85509 m .88286 .8467 L .9084 .87485 L p .942 .765 .634 r
F P
0 g
s
.90418 .76331 m .90273 .76927 L .87704 .73873 L p .945 .757 .618 r
F P
0 g
s
.87704 .73873 m .87851 .73265 L .90418 .76331 L p .945 .757 .618 r
F P
0 g
s
.90273 .76927 m .90124 .77538 L .87552 .74497 L p .945 .758 .619 r
F P
0 g
s
.87552 .74497 m .87704 .73873 L .90273 .76927 L p .945 .758 .619 r
F P
0 g
s
.90613 .88301 m .90374 .89146 L .87812 .86376 L p .942 .767 .636 r
F P
0 g
s
.87812 .86376 m .88055 .85509 L .90613 .88301 L p .942 .767 .636 r
F P
0 g
s
.90124 .77538 m .8997 .78166 L .87395 .75138 L p .945 .758 .619 r
F P
0 g
s
.87395 .75138 m .87552 .74497 L .90124 .77538 L p .945 .758 .619 r
F P
0 g
s
.90374 .89146 m .90122 .90019 L .87556 .87273 L p .941 .768 .639 r
F P
0 g
s
.87556 .87273 m .87812 .86376 L .90374 .89146 L p .941 .768 .639 r
F P
0 g
s
.8997 .78166 m .8981 .7881 L .87232 .75796 L p .945 .759 .62 r
F P
0 g
s
.87232 .75796 m .87395 .75138 L .8997 .78166 L p .945 .759 .62 r
F P
0 g
s
.90122 .90019 m .89856 .90924 L .87286 .88203 L p .941 .769 .641 r
F P
0 g
s
.87286 .88203 m .87556 .87273 L .90122 .90019 L p .941 .769 .641 r
F P
0 g
s
.8981 .7881 m .89645 .79471 L .87064 .76472 L p .945 .759 .621 r
F P
0 g
s
.87064 .76472 m .87232 .75796 L .8981 .7881 L p .945 .759 .621 r
F P
0 g
s
.89856 .90924 m .89575 .91862 L .87 .89168 L p .94 .77 .644 r
F P
0 g
s
.87 .89168 m .87286 .88203 L .89856 .90924 L p .94 .77 .644 r
F P
0 g
s
.89645 .79471 m .89474 .80151 L .86889 .77167 L p .944 .76 .622 r
F P
0 g
s
.86889 .77167 m .87064 .76472 L .89645 .79471 L p .944 .76 .622 r
F P
0 g
s
.89474 .80151 m .89295 .8085 L .86708 .77882 L p .944 .76 .623 r
F P
0 g
s
.86708 .77882 m .86889 .77167 L .89474 .80151 L p .944 .76 .623 r
F P
0 g
s
.89575 .91862 m .89275 .92838 L .86695 .90171 L p .939 .771 .646 r
F P
0 g
s
.86695 .90171 m .87 .89168 L .89575 .91862 L p .939 .771 .646 r
F P
0 g
s
.89295 .8085 m .8911 .81569 L .86519 .78619 L p .944 .761 .624 r
F P
0 g
s
.86519 .78619 m .86708 .77882 L .89295 .8085 L p .944 .761 .624 r
F P
0 g
s
.89275 .92838 m .88956 .93853 L .86371 .91214 L p .939 .773 .65 r
F P
0 g
s
.86371 .91214 m .86695 .90171 L .89275 .92838 L p .939 .773 .65 r
F P
0 g
s
.8911 .81569 m .88917 .82309 L .86323 .79378 L p .944 .761 .625 r
F P
0 g
s
.86323 .79378 m .86519 .78619 L .8911 .81569 L p .944 .761 .625 r
F P
0 g
s
.88956 .93853 m .88614 .94913 L .86024 .92303 L p .938 .775 .653 r
F P
0 g
s
.86024 .92303 m .86371 .91214 L .88956 .93853 L p .938 .775 .653 r
F P
0 g
s
.88398 .70977 m .88267 .71528 L .85659 .68366 L p .946 .755 .614 r
F P
0 g
s
.85659 .68366 m .85792 .67805 L .88398 .70977 L p .946 .755 .614 r
F P
0 g
s
.88917 .82309 m .88716 .83072 L .86118 .8016 L p .944 .762 .627 r
F P
0 g
s
.86118 .8016 m .86323 .79378 L .88917 .82309 L p .944 .762 .627 r
F P
0 g
s
.88267 .71528 m .88133 .72093 L .85522 .68942 L p .946 .756 .614 r
F P
0 g
s
.85522 .68942 m .85659 .68366 L .88267 .71528 L p .946 .756 .614 r
F P
0 g
s
.88716 .83072 m .88506 .83858 L .85904 .80967 L p .943 .763 .628 r
F P
0 g
s
.85904 .80967 m .86118 .8016 L .88716 .83072 L p .943 .763 .628 r
F P
0 g
s
.88614 .94913 m .88246 .96022 L .8565 .93441 L p .937 .776 .657 r
F P
0 g
s
.8565 .93441 m .86024 .92303 L .88614 .94913 L p .937 .776 .657 r
F P
0 g
s
.88133 .72093 m .87994 .72672 L .8538 .69531 L p .946 .756 .615 r
F P
0 g
s
.8538 .69531 m .85522 .68942 L .88133 .72093 L p .946 .756 .615 r
F P
0 g
s
.88506 .83858 m .88286 .8467 L .8568 .81801 L p .943 .764 .63 r
F P
0 g
s
.8568 .81801 m .85904 .80967 L .88506 .83858 L p .943 .764 .63 r
F P
0 g
s
.87994 .72672 m .87851 .73265 L .85235 .70136 L p .946 .756 .615 r
F P
0 g
s
.85235 .70136 m .8538 .69531 L .87994 .72672 L p .946 .756 .615 r
F P
0 g
s
.88246 .96022 m .87849 .97185 L .85247 .94634 L p .936 .778 .661 r
F P
0 g
s
.85247 .94634 m .8565 .93441 L .88246 .96022 L p .936 .778 .661 r
F P
0 g
s
.87851 .73265 m .87704 .73873 L .85084 .70756 L p .946 .757 .616 r
F P
0 g
s
.85084 .70756 m .85235 .70136 L .87851 .73265 L p .946 .757 .616 r
F P
0 g
s
.88286 .8467 m .88055 .85509 L .85445 .82663 L p .943 .765 .631 r
F P
0 g
s
.85445 .82663 m .8568 .81801 L .88286 .8467 L p .943 .765 .631 r
F P
0 g
s
.87849 .97185 m .87417 .98409 L .84808 .95888 L p .935 .78 .665 r
F P
0 g
s
.84808 .95888 m .85247 .94634 L .87849 .97185 L p .935 .78 .665 r
F P
0 g
s
.87704 .73873 m .87552 .74497 L .84929 .71393 L p .946 .757 .617 r
F P
0 g
s
.84929 .71393 m .85084 .70756 L .87704 .73873 L p .946 .757 .617 r
F P
0 g
s
.88055 .85509 m .87812 .86376 L .85198 .83554 L p .943 .766 .633 r
F P
0 g
s
.85198 .83554 m .85445 .82663 L .88055 .85509 L p .943 .766 .633 r
F P
0 g
s
.87552 .74497 m .87395 .75138 L .84769 .72047 L p .945 .757 .617 r
F P
0 g
s
.84769 .72047 m .84929 .71393 L .87552 .74497 L p .945 .757 .617 r
F P
0 g
s
.87417 .98409 m .86944 .99704 L .84328 .97211 L p .933 .783 .671 r
F P
0 g
s
.84328 .97211 m .84808 .95888 L .87417 .98409 L p .933 .783 .671 r
F P
0 g
s
.87812 .86376 m .87556 .87273 L .84938 .84477 L p .942 .767 .635 r
F P
0 g
s
.84938 .84477 m .85198 .83554 L .87812 .86376 L p .942 .767 .635 r
F P
0 g
s
.87395 .75138 m .87232 .75796 L .84603 .72719 L p .945 .758 .618 r
F P
0 g
s
.84603 .72719 m .84769 .72047 L .87395 .75138 L p .945 .758 .618 r
F P
0 g
s
.87556 .87273 m .87286 .88203 L .84664 .85434 L p .942 .768 .638 r
F P
0 g
s
.84664 .85434 m .84938 .84477 L .87556 .87273 L p .942 .768 .638 r
F P
0 g
s
.87232 .75796 m .87064 .76472 L .84432 .7341 L p .945 .758 .619 r
F P
0 g
s
.84432 .7341 m .84603 .72719 L .87232 .75796 L p .945 .758 .619 r
F P
0 g
s
.86944 .99704 m .86423 1.01079 L .83798 .98613 L p .931 .785 .676 r
F P
0 g
s
.83798 .98613 m .84328 .97211 L .86944 .99704 L p .931 .785 .676 r
F P
0 g
s
.87064 .76472 m .86889 .77167 L .84254 .74121 L p .945 .759 .62 r
F P
0 g
s
.84254 .74121 m .84432 .7341 L .87064 .76472 L p .945 .759 .62 r
F P
0 g
s
.87286 .88203 m .87 .89168 L .84373 .86428 L p .941 .769 .64 r
F P
0 g
s
.84373 .86428 m .84664 .85434 L .87286 .88203 L p .941 .769 .64 r
F P
0 g
s
.86423 1.01079 m .85843 1.02549 L .83209 1.00107 L p .929 .787 .683 r
F P
0 g
s
.83209 1.00107 m .83798 .98613 L .86423 1.01079 L p .929 .787 .683 r
F P
0 g
s
.86889 .77167 m .86708 .77882 L .84069 .74853 L p .945 .759 .621 r
F P
0 g
s
.84069 .74853 m .84254 .74121 L .86889 .77167 L p .945 .759 .621 r
F P
0 g
s
.87 .89168 m .86695 .90171 L .84064 .8746 L p .941 .771 .643 r
F P
0 g
s
.84064 .8746 m .84373 .86428 L .87 .89168 L p .941 .771 .643 r
F P
0 g
s
.86708 .77882 m .86519 .78619 L .83877 .75608 L p .945 .76 .622 r
F P
0 g
s
.83877 .75608 m .84069 .74853 L .86708 .77882 L p .945 .76 .622 r
F P
0 g
s
.85843 1.02549 m .8519 1.0413 L .82546 1.01707 L p .927 .79 .69 r
F P
0 g
s
.82546 1.01707 m .83209 1.00107 L .85843 1.02549 L p .927 .79 .69 r
F P
0 g
s
.86695 .90171 m .86371 .91214 L .83734 .88535 L p .94 .772 .646 r
F P
0 g
s
.83734 .88535 m .84064 .8746 L .86695 .90171 L p .94 .772 .646 r
F P
0 g
s
.86519 .78619 m .86323 .79378 L .83677 .76386 L p .945 .76 .623 r
F P
0 g
s
.83677 .76386 m .83877 .75608 L .86519 .78619 L p .945 .76 .623 r
F P
0 g
s
.85792 .67805 m .85659 .68366 L .82999 .65137 L p .946 .755 .612 r
F P
0 g
s
.82999 .65137 m .83135 .64566 L .85792 .67805 L p .946 .755 .612 r
F P
0 g
s
.86323 .79378 m .86118 .8016 L .83468 .77189 L p .945 .761 .624 r
F P
0 g
s
.83468 .77189 m .83677 .76386 L .86323 .79378 L p .945 .761 .624 r
F P
0 g
s
.8519 1.0413 m .84444 1.05843 L .81788 1.03431 L p .923 .793 .699 r
F P
0 g
s
.81788 1.03431 m .82546 1.01707 L .8519 1.0413 L p .923 .793 .699 r
F P
0 g
s
.86371 .91214 m .86024 .92303 L .83381 .89656 L p .939 .774 .65 r
F P
0 g
s
.83381 .89656 m .83734 .88535 L .86371 .91214 L p .939 .774 .65 r
F P
0 g
s
.85659 .68366 m .85522 .68942 L .82859 .65723 L p .946 .755 .613 r
F P
0 g
s
.82859 .65723 m .82999 .65137 L .85659 .68366 L p .946 .755 .613 r
F P
0 g
s
.86118 .8016 m .85904 .80967 L .8325 .78018 L p .944 .762 .625 r
F P
0 g
s
.8325 .78018 m .83468 .77189 L .86118 .8016 L p .944 .762 .625 r
F P
0 g
s
.85522 .68942 m .8538 .69531 L .82715 .66323 L p .946 .755 .613 r
F P
0 g
s
.82715 .66323 m .82859 .65723 L .85522 .68942 L p .946 .755 .613 r
F P
0 g
s
.86024 .92303 m .8565 .93441 L .83001 .90827 L p .938 .776 .653 r
F P
0 g
s
.83001 .90827 m .83381 .89656 L .86024 .92303 L p .938 .776 .653 r
F P
0 g
s
.84444 1.05843 m .83575 1.07714 L .80905 1.05302 L p .918 .796 .71 r
F P
0 g
s
.80905 1.05302 m .81788 1.03431 L .84444 1.05843 L p .918 .796 .71 r
F P
0 g
s
.8538 .69531 m .85235 .70136 L .82566 .66939 L p .946 .756 .614 r
F P
0 g
s
.82566 .66939 m .82715 .66323 L .8538 .69531 L p .946 .756 .614 r
F P
0 g
s
.85904 .80967 m .8568 .81801 L .83022 .78875 L p .944 .763 .627 r
F P
0 g
s
.83022 .78875 m .8325 .78018 L .85904 .80967 L p .944 .763 .627 r
F P
0 g
s
.8565 .93441 m .85247 .94634 L .82591 .92052 L p .937 .778 .658 r
F P
0 g
s
.82591 .92052 m .83001 .90827 L .8565 .93441 L p .937 .778 .658 r
F P
0 g
s
.85235 .70136 m .85084 .70756 L .82413 .67572 L p .946 .756 .614 r
F P
0 g
s
.82413 .67572 m .82566 .66939 L .85235 .70136 L p .946 .756 .614 r
F P
0 g
s
.8568 .81801 m .85445 .82663 L .82783 .79761 L p .944 .764 .628 r
F P
0 g
s
.82783 .79761 m .83022 .78875 L .8568 .81801 L p .944 .764 .628 r
F P
0 g
s
.83575 1.07714 m .82539 1.09771 L .79853 1.07341 L p .911 .8 .724 r
F P
0 g
s
.79853 1.07341 m .80905 1.05302 L .83575 1.07714 L p .911 .8 .724 r
F P
0 g
s
.85084 .70756 m .84929 .71393 L .82254 .68221 L p .946 .756 .615 r
F P
0 g
s
.82254 .68221 m .82413 .67572 L .85084 .70756 L p .946 .756 .615 r
F P
0 g
s
.85247 .94634 m .84808 .95888 L .82146 .93339 L p .936 .78 .663 r
F P
0 g
s
.82146 .93339 m .82591 .92052 L .85247 .94634 L p .936 .78 .663 r
F P
0 g
s
.85445 .82663 m .85198 .83554 L .82532 .80678 L p .944 .765 .63 r
F P
0 g
s
.82532 .80678 m .82783 .79761 L .85445 .82663 L p .944 .765 .63 r
F P
0 g
s
.84929 .71393 m .84769 .72047 L .82091 .68889 L p .946 .757 .615 r
F P
0 g
s
.82091 .68889 m .82254 .68221 L .84929 .71393 L p .946 .757 .615 r
F P
0 g
s
.73138 1.19962 m .70344 1.20843 L .69951 1.20442 L p .666 .762 .922 r
F P
0 g
s
.82539 1.09771 m .81258 1.12041 L .78552 1.09566 L p .9 .803 .744 r
F P
0 g
s
.78552 1.09566 m .79853 1.07341 L .82539 1.09771 L p .9 .803 .744 r
F P
0 g
s
.84769 .72047 m .84603 .72719 L .81922 .69575 L p .946 .757 .616 r
F P
0 g
s
.81922 .69575 m .82091 .68889 L .84769 .72047 L p .946 .757 .616 r
F P
0 g
s
.85198 .83554 m .84938 .84477 L .82267 .81629 L p .943 .766 .632 r
F P
0 g
s
.82267 .81629 m .82532 .80678 L .85198 .83554 L p .943 .766 .632 r
F P
0 g
s
.84808 .95888 m .84328 .97211 L .81658 .94695 L p .935 .783 .668 r
F P
0 g
s
.81658 .94695 m .82146 .93339 L .84808 .95888 L p .935 .783 .668 r
F P
0 g
s
.84603 .72719 m .84432 .7341 L .81747 .70282 L p .946 .757 .617 r
F P
0 g
s
.81747 .70282 m .81922 .69575 L .84603 .72719 L p .946 .757 .617 r
F P
0 g
s
.84938 .84477 m .84664 .85434 L .81988 .82616 L p .943 .767 .634 r
F P
0 g
s
.81988 .82616 m .82267 .81629 L .84938 .84477 L p .943 .767 .634 r
F P
0 g
s
.69951 1.20442 m .67521 1.18026 L p .73138 1.19962 L .666 .762 .922 r
F P
0 g
s
.84328 .97211 m .83798 .98613 L .8112 .96127 L p .933 .785 .674 r
F P
0 g
s
.8112 .96127 m .81658 .94695 L .84328 .97211 L p .933 .785 .674 r
F P
0 g
s
.81258 1.12041 m .79589 1.14531 L .76858 1.11973 L p .88 .807 .773 r
F P
0 g
s
.76858 1.11973 m .78552 1.09566 L .81258 1.12041 L p .88 .807 .773 r
F P
0 g
s
.84432 .7341 m .84254 .74121 L .81565 .7101 L p .946 .758 .617 r
F P
0 g
s
.81565 .7101 m .81747 .70282 L .84432 .7341 L p .946 .758 .617 r
F P
0 g
s
.84664 .85434 m .84373 .86428 L .81692 .8364 L p .943 .768 .637 r
F P
0 g
s
.81692 .8364 m .81988 .82616 L .84664 .85434 L p .943 .768 .637 r
F P
0 g
s
.77211 1.17195 m .73138 1.19962 L .70335 1.17141 L p .767 .796 .876 r
F P
0 g
s
.67521 1.18026 m .70335 1.17141 L .73138 1.19962 L p .666 .762 .922 r
F P
0 g
s
.84254 .74121 m .84069 .74853 L .81377 .71759 L p .946 .758 .618 r
F P
0 g
s
.81377 .71759 m .81565 .7101 L .84254 .74121 L p .946 .758 .618 r
F P
0 g
s
.83798 .98613 m .83209 1.00107 L .80521 .97647 L p .931 .788 .681 r
F P
0 g
s
.80521 .97647 m .8112 .96127 L .83798 .98613 L p .931 .788 .681 r
F P
0 g
s
.79589 1.14531 m .77211 1.17195 L .74449 1.14511 L p .842 .808 .817 r
F P
0 g
s
.74449 1.14511 m .76858 1.11973 L .79589 1.14531 L p .842 .808 .817 r
F P
0 g
s
.84373 .86428 m .84064 .8746 L .81378 .84705 L p .942 .77 .639 r
F P
0 g
s
.81378 .84705 m .81692 .8364 L .84373 .86428 L p .942 .77 .639 r
F P
0 g
s
.84069 .74853 m .83877 .75608 L .81181 .72533 L p .946 .759 .619 r
F P
0 g
s
.81181 .72533 m .81377 .71759 L .84069 .74853 L p .946 .759 .619 r
F P
0 g
s
.70335 1.17141 m .74449 1.14511 L .77211 1.17195 L p .767 .796 .876 r
F P
0 g
s
.83209 1.00107 m .82546 1.01707 L .79847 .99267 L p .928 .791 .689 r
F P
0 g
s
.79847 .99267 m .80521 .97647 L .83209 1.00107 L p .928 .791 .689 r
F P
0 g
s
.83877 .75608 m .83677 .76386 L .80977 .73331 L p .945 .76 .62 r
F P
0 g
s
.80977 .73331 m .81181 .72533 L .83877 .75608 L p .945 .76 .62 r
F P
0 g
s
.84064 .8746 m .83734 .88535 L .81042 .85814 L p .941 .771 .642 r
F P
0 g
s
.81042 .85814 m .81378 .84705 L .84064 .8746 L p .941 .771 .642 r
F P
0 g
s
.83135 .64566 m .82999 .65137 L .80287 .61839 L p .947 .754 .611 r
F P
0 g
s
.80287 .61839 m .80426 .61258 L .83135 .64566 L p .947 .754 .611 r
F P
0 g
s
.83677 .76386 m .83468 .77189 L .80764 .74155 L p .945 .76 .621 r
F P
0 g
s
.80764 .74155 m .80977 .73331 L .83677 .76386 L p .945 .76 .621 r
F P
0 g
s
.82999 .65137 m .82859 .65723 L .80144 .62435 L p .947 .755 .611 r
F P
0 g
s
.80144 .62435 m .80287 .61839 L .82999 .65137 L p .947 .755 .611 r
F P
0 g
s
.83734 .88535 m .83381 .89656 L .80684 .86971 L p .941 .773 .646 r
F P
0 g
s
.80684 .86971 m .81042 .85814 L .83734 .88535 L p .941 .773 .646 r
F P
0 g
s
.82546 1.01707 m .81788 1.03431 L .79077 1.01003 L p .924 .794 .699 r
F P
0 g
s
.79077 1.01003 m .79847 .99267 L .82546 1.01707 L p .924 .794 .699 r
F P
0 g
s
.82859 .65723 m .82715 .66323 L .79996 .63046 L p .947 .755 .611 r
F P
0 g
s
.79996 .63046 m .80144 .62435 L .82859 .65723 L p .947 .755 .611 r
F P
0 g
s
.83468 .77189 m .8325 .78018 L .80542 .75006 L p .945 .761 .622 r
F P
0 g
s
.80542 .75006 m .80764 .74155 L .83468 .77189 L p .945 .761 .622 r
F P
0 g
s
.83381 .89656 m .83001 .90827 L .80298 .88178 L p .94 .775 .65 r
F P
0 g
s
.80298 .88178 m .80684 .86971 L .83381 .89656 L p .94 .775 .65 r
F P
0 g
s
.82715 .66323 m .82566 .66939 L .79844 .63673 L p .947 .755 .612 r
F P
0 g
s
.79844 .63673 m .79996 .63046 L .82715 .66323 L p .947 .755 .612 r
F P
0 g
s
.8325 .78018 m .83022 .78875 L .8031 .75888 L p .945 .762 .624 r
F P
0 g
s
.8031 .75888 m .80542 .75006 L .8325 .78018 L p .945 .762 .624 r
F P
0 g
s
.81788 1.03431 m .80905 1.05302 L .7818 1.0287 L p .918 .798 .712 r
F P
0 g
s
.7818 1.0287 m .79077 1.01003 L .81788 1.03431 L p .918 .798 .712 r
F P
0 g
s
.82566 .66939 m .82413 .67572 L .79688 .64318 L p .947 .755 .612 r
F P
0 g
s
.79688 .64318 m .79844 .63673 L .82566 .66939 L p .947 .755 .612 r
F P
0 g
s
.83001 .90827 m .82591 .92052 L .79881 .89441 L p .939 .777 .654 r
F P
0 g
s
.79881 .89441 m .80298 .88178 L .83001 .90827 L p .939 .777 .654 r
F P
0 g
s
.83022 .78875 m .82783 .79761 L .80067 .768 L p .945 .763 .625 r
F P
0 g
s
.80067 .768 m .8031 .75888 L .83022 .78875 L p .945 .763 .625 r
F P
0 g
s
.82413 .67572 m .82254 .68221 L .79526 .6498 L p .947 .756 .613 r
F P
0 g
s
.79526 .6498 m .79688 .64318 L .82413 .67572 L p .947 .756 .613 r
F P
0 g
s
.80905 1.05302 m .79853 1.07341 L .7711 1.04886 L p .91 .802 .728 r
F P
0 g
s
.7711 1.04886 m .7818 1.0287 L .80905 1.05302 L p .91 .802 .728 r
F P
0 g
s
.82254 .68221 m .82091 .68889 L .79359 .65662 L p .947 .756 .613 r
F P
0 g
s
.79359 .65662 m .79526 .6498 L .82254 .68221 L p .947 .756 .613 r
F P
0 g
s
.82783 .79761 m .82532 .80678 L .79811 .77746 L p .945 .764 .627 r
F P
0 g
s
.79811 .77746 m .80067 .768 L .82783 .79761 L p .945 .764 .627 r
F P
0 g
s
.82591 .92052 m .82146 .93339 L .79428 .90765 L p .938 .78 .659 r
F P
0 g
s
.79428 .90765 m .79881 .89441 L .82591 .92052 L p .938 .78 .659 r
F P
0 g
s
.70335 1.17141 m .67521 1.18026 L .67121 1.17617 L p .665 .761 .922 r
F P
0 g
s
.82091 .68889 m .81922 .69575 L .79186 .66363 L p .946 .756 .614 r
F P
0 g
s
.79186 .66363 m .79359 .65662 L .82091 .68889 L p .946 .756 .614 r
F P
0 g
s
.82532 .80678 m .82267 .81629 L .79541 .78726 L p .944 .765 .629 r
F P
0 g
s
.79541 .78726 m .79811 .77746 L .82532 .80678 L p .944 .765 .629 r
F P
0 g
s
.79853 1.07341 m .78552 1.09566 L .75789 1.07057 L p .897 .806 .75 r
F P
0 g
s
.75789 1.07057 m .7711 1.04886 L .79853 1.07341 L p .897 .806 .75 r
F P
0 g
s
.82146 .93339 m .81658 .94695 L .78932 .92157 L p .936 .782 .665 r
F P
0 g
s
.78932 .92157 m .79428 .90765 L .82146 .93339 L p .936 .782 .665 r
F P
0 g
s
.81922 .69575 m .81747 .70282 L .79007 .67085 L p .946 .757 .614 r
F P
0 g
s
.79007 .67085 m .79186 .66363 L .81922 .69575 L p .946 .757 .614 r
F P
0 g
s
.67121 1.17617 m .64642 1.15151 L p .70335 1.17141 L .665 .761 .922 r
F P
0 g
s
.82267 .81629 m .81988 .82616 L .79257 .79744 L p .944 .766 .631 r
F P
0 g
s
.79257 .79744 m .79541 .78726 L .82267 .81629 L p .944 .766 .631 r
F P
0 g
s
.81747 .70282 m .81565 .7101 L .78822 .6783 L p .946 .757 .615 r
F P
0 g
s
.78822 .6783 m .79007 .67085 L .81747 .70282 L p .946 .757 .615 r
F P
0 g
s
.78552 1.09566 m .76858 1.11973 L .7407 1.09369 L p .875 .809 .781 r
F P
0 g
s
.7407 1.09369 m .75789 1.07057 L .78552 1.09566 L p .875 .809 .781 r
F P
0 g
s
.81658 .94695 m .8112 .96127 L .78386 .93623 L p .934 .785 .672 r
F P
0 g
s
.78386 .93623 m .78932 .92157 L .81658 .94695 L p .934 .785 .672 r
F P
0 g
s
.74449 1.14511 m .70335 1.17141 L .67477 1.14262 L p .757 .794 .883 r
F P
0 g
s
.64642 1.15151 m .67477 1.14262 L .70335 1.17141 L p .665 .761 .922 r
F P
0 g
s
.81988 .82616 m .81692 .8364 L .78956 .80803 L p .944 .767 .633 r
F P
0 g
s
.78956 .80803 m .79257 .79744 L .81988 .82616 L p .944 .767 .633 r
F P
0 g
s
.81565 .7101 m .81377 .71759 L .7863 .68597 L p .946 .758 .616 r
F P
0 g
s
.7863 .68597 m .78822 .6783 L .81565 .7101 L p .946 .758 .616 r
F P
0 g
s
.76858 1.11973 m .74449 1.14511 L .71631 1.1177 L p .833 .809 .827 r
F P
0 g
s
.71631 1.1177 m .7407 1.09369 L .76858 1.11973 L p .833 .809 .827 r
F P
0 g
s
.81377 .71759 m .81181 .72533 L .7843 .6939 L p .946 .758 .616 r
F P
0 g
s
.7843 .6939 m .7863 .68597 L .81377 .71759 L p .946 .758 .616 r
F P
0 g
s
.8112 .96127 m .80521 .97647 L .77777 .95172 L p .932 .789 .679 r
F P
0 g
s
.77777 .95172 m .78386 .93623 L .8112 .96127 L p .932 .789 .679 r
F P
0 g
s
.81692 .8364 m .81378 .84705 L .78636 .81904 L p .943 .769 .636 r
F P
0 g
s
.78636 .81904 m .78956 .80803 L .81692 .8364 L p .943 .769 .636 r
F P
0 g
s
.67477 1.14262 m .71631 1.1177 L .74449 1.14511 L p .757 .794 .883 r
F P
0 g
s
.81181 .72533 m .80977 .73331 L .78222 .70209 L p .946 .759 .617 r
F P
0 g
s
.78222 .70209 m .7843 .6939 L .81181 .72533 L p .946 .759 .617 r
F P
0 g
s
.80426 .61258 m .80287 .61839 L .7752 .58468 L p .947 .754 .609 r
F P
0 g
s
.7752 .58468 m .77663 .57878 L .80426 .61258 L p .947 .754 .609 r
F P
0 g
s
.81378 .84705 m .81042 .85814 L .78295 .8305 L p .943 .77 .639 r
F P
0 g
s
.78295 .8305 m .78636 .81904 L .81378 .84705 L p .943 .77 .639 r
F P
0 g
s
.80521 .97647 m .79847 .99267 L .77092 .96814 L p .929 .792 .689 r
F P
0 g
s
.77092 .96814 m .77777 .95172 L .80521 .97647 L p .929 .792 .689 r
F P
0 g
s
.80287 .61839 m .80144 .62435 L .77374 .59074 L p .947 .754 .61 r
F P
0 g
s
.77374 .59074 m .7752 .58468 L .80287 .61839 L p .947 .754 .61 r
F P
0 g
s
.80977 .73331 m .80764 .74155 L .78005 .71055 L p .946 .759 .618 r
F P
0 g
s
.78005 .71055 m .78222 .70209 L .80977 .73331 L p .946 .759 .618 r
F P
0 g
s
.80144 .62435 m .79996 .63046 L .77223 .59696 L p .947 .754 .61 r
F P
0 g
s
.77223 .59696 m .77374 .59074 L .80144 .62435 L p .947 .754 .61 r
F P
0 g
s
.81042 .85814 m .80684 .86971 L .7793 .84246 L p .942 .772 .642 r
F P
0 g
s
.7793 .84246 m .78295 .8305 L .81042 .85814 L p .942 .772 .642 r
F P
0 g
s
.80764 .74155 m .80542 .75006 L .77779 .7193 L p .946 .76 .619 r
F P
0 g
s
.77779 .7193 m .78005 .71055 L .80764 .74155 L p .946 .76 .619 r
F P
0 g
s
.79847 .99267 m .79077 1.01003 L .76308 .98561 L p .924 .796 .7 r
F P
0 g
s
.76308 .98561 m .77092 .96814 L .79847 .99267 L p .924 .796 .7 r
F P
0 g
s
.79996 .63046 m .79844 .63673 L .77068 .60335 L p .947 .754 .61 r
F P
0 g
s
.77068 .60335 m .77223 .59696 L .79996 .63046 L p .947 .754 .61 r
F P
0 g
s
.80684 .86971 m .80298 .88178 L .77538 .85495 L p .942 .774 .646 r
F P
0 g
s
.77538 .85495 m .7793 .84246 L .80684 .86971 L p .942 .774 .646 r
F P
0 g
s
.80542 .75006 m .8031 .75888 L .77542 .72837 L p .946 .761 .62 r
F P
0 g
s
.77542 .72837 m .77779 .7193 L .80542 .75006 L p .946 .761 .62 r
F P
0 g
s
.79844 .63673 m .79688 .64318 L .76908 .60992 L p .947 .755 .611 r
F P
0 g
s
.76908 .60992 m .77068 .60335 L .79844 .63673 L p .947 .755 .611 r
F P
0 g
s
.79077 1.01003 m .7818 1.0287 L .75397 1.00423 L p .918 .8 .714 r
F P
0 g
s
.75397 1.00423 m .76308 .98561 L .79077 1.01003 L p .918 .8 .714 r
F P
0 g
s
.79688 .64318 m .79526 .6498 L .76742 .61668 L p .947 .755 .611 r
F P
0 g
s
.76742 .61668 m .76908 .60992 L .79688 .64318 L p .947 .755 .611 r
F P
0 g
s
.8031 .75888 m .80067 .768 L .77294 .73777 L p .946 .762 .622 r
F P
0 g
s
.77294 .73777 m .77542 .72837 L .8031 .75888 L p .946 .762 .622 r
F P
0 g
s
.80298 .88178 m .79881 .89441 L .77114 .868 L p .941 .777 .65 r
F P
0 g
s
.77114 .868 m .77538 .85495 L .80298 .88178 L p .941 .777 .65 r
F P
0 g
s
.79526 .6498 m .79359 .65662 L .76572 .62363 L p .947 .755 .611 r
F P
0 g
s
.76572 .62363 m .76742 .61668 L .79526 .6498 L p .947 .755 .611 r
F P
0 g
s
.67477 1.14262 m .64642 1.15151 L .64235 1.14734 L p .663 .761 .923 r
F P
0 g
s
.80067 .768 m .79811 .77746 L .77033 .74752 L p .946 .762 .623 r
F P
0 g
s
.77033 .74752 m .77294 .73777 L .80067 .768 L p .946 .762 .623 r
F P
0 g
s
.7818 1.0287 m .7711 1.04886 L .7431 1.02407 L p .909 .805 .732 r
F P
0 g
s
.7431 1.02407 m .75397 1.00423 L .7818 1.0287 L p .909 .805 .732 r
F P
0 g
s
.79881 .89441 m .79428 .90765 L .76653 .88167 L p .94 .779 .655 r
F P
0 g
s
.76653 .88167 m .77114 .868 L .79881 .89441 L p .94 .779 .655 r
F P
0 g
s
.79359 .65662 m .79186 .66363 L .76395 .63079 L p .947 .756 .612 r
F P
0 g
s
.76395 .63079 m .76572 .62363 L .79359 .65662 L p .947 .756 .612 r
F P
0 g
s
.79811 .77746 m .79541 .78726 L .76759 .75765 L p .946 .763 .625 r
F P
0 g
s
.76759 .75765 m .77033 .74752 L .79811 .77746 L p .946 .763 .625 r
F P
0 g
s
.64235 1.14734 m .61707 1.12216 L p .67477 1.14262 L .663 .761 .923 r
F P
0 g
s
.79186 .66363 m .79007 .67085 L .76213 .63817 L p .947 .756 .612 r
F P
0 g
s
.76213 .63817 m .76395 .63079 L .79186 .66363 L p .947 .756 .612 r
F P
0 g
s
.7711 1.04886 m .75789 1.07057 L .72968 1.04513 L p .894 .809 .757 r
F P
0 g
s
.72968 1.04513 m .7431 1.02407 L .7711 1.04886 L p .894 .809 .757 r
F P
0 g
s
.79428 .90765 m .78932 .92157 L .76149 .896 L p .938 .782 .661 r
F P
0 g
s
.76149 .896 m .76653 .88167 L .79428 .90765 L p .938 .782 .661 r
F P
0 g
s
.79541 .78726 m .79257 .79744 L .76469 .76817 L p .945 .765 .627 r
F P
0 g
s
.76469 .76817 m .76759 .75765 L .79541 .78726 L p .945 .765 .627 r
F P
0 g
s
.79007 .67085 m .78822 .6783 L .76023 .64578 L p .947 .756 .613 r
F P
0 g
s
.76023 .64578 m .76213 .63817 L .79007 .67085 L p .947 .756 .613 r
F P
0 g
s
.71631 1.1177 m .67477 1.14262 L .64563 1.11322 L p .746 .792 .889 r
F P
0 g
s
.61707 1.12216 m .64563 1.11322 L .67477 1.14262 L p .663 .761 .923 r
F P
0 g
s
.75789 1.07057 m .7407 1.09369 L .71224 1.06715 L p .869 .812 .791 r
F P
0 g
s
.71224 1.06715 m .72968 1.04513 L .75789 1.07057 L p .869 .812 .791 r
F P
0 g
s
.78822 .6783 m .7863 .68597 L .75827 .65365 L p .947 .757 .613 r
F P
0 g
s
.75827 .65365 m .76023 .64578 L .78822 .6783 L p .947 .757 .613 r
F P
0 g
s
.78932 .92157 m .78386 .93623 L .75593 .91104 L p .936 .785 .669 r
F P
0 g
s
.75593 .91104 m .76149 .896 L .78932 .92157 L p .936 .785 .669 r
F P
0 g
s
.79257 .79744 m .78956 .80803 L .76162 .77912 L p .945 .766 .629 r
F P
0 g
s
.76162 .77912 m .76469 .76817 L .79257 .79744 L p .945 .766 .629 r
F P
0 g
s
.7863 .68597 m .7843 .6939 L .75623 .66177 L p .947 .757 .614 r
F P
0 g
s
.75623 .66177 m .75827 .65365 L .7863 .68597 L p .947 .757 .614 r
F P
0 g
s
.7407 1.09369 m .71631 1.1177 L .68755 1.08969 L p .823 .809 .838 r
F P
0 g
s
.68755 1.08969 m .71224 1.06715 L .7407 1.09369 L p .823 .809 .838 r
F P
0 g
s
.64563 1.11322 m .68755 1.08969 L .71631 1.1177 L p .746 .792 .889 r
F P
0 g
s
.78956 .80803 m .78636 .81904 L .75836 .79053 L p .945 .767 .631 r
F P
0 g
s
.75836 .79053 m .76162 .77912 L .78956 .80803 L p .945 .767 .631 r
F P
0 g
s
.78386 .93623 m .77777 .95172 L .74974 .92687 L p .934 .789 .677 r
F P
0 g
s
.74974 .92687 m .75593 .91104 L .78386 .93623 L p .934 .789 .677 r
F P
0 g
s
.77663 .57878 m .7752 .58468 L .74698 .55023 L p .947 .753 .608 r
F P
0 g
s
.74698 .55023 m .74844 .54423 L .77663 .57878 L p .947 .753 .608 r
F P
0 g
s
.7843 .6939 m .78222 .70209 L .7541 .67016 L p .947 .758 .615 r
F P
0 g
s
.7541 .67016 m .75623 .66177 L .7843 .6939 L p .947 .758 .615 r
F P
0 g
s
.7752 .58468 m .77374 .59074 L .74548 .55639 L p .947 .753 .608 r
F P
0 g
s
.74548 .55639 m .74698 .55023 L .7752 .58468 L p .947 .753 .608 r
F P
0 g
s
.78636 .81904 m .78295 .8305 L .75489 .80241 L p .944 .769 .634 r
F P
0 g
s
.75489 .80241 m .75836 .79053 L .78636 .81904 L p .944 .769 .634 r
F P
0 g
s
.78222 .70209 m .78005 .71055 L .75189 .67885 L p .947 .758 .615 r
F P
0 g
s
.75189 .67885 m .7541 .67016 L .78222 .70209 L p .947 .758 .615 r
F P
0 g
s
.77777 .95172 m .77092 .96814 L .74277 .94354 L p .93 .793 .688 r
F P
0 g
s
.74277 .94354 m .74974 .92687 L .77777 .95172 L p .93 .793 .688 r
F P
0 g
s
.77374 .59074 m .77223 .59696 L .74394 .56272 L p .947 .754 .608 r
F P
0 g
s
.74394 .56272 m .74548 .55639 L .77374 .59074 L p .947 .754 .608 r
F P
0 g
s
.78005 .71055 m .77779 .7193 L .74958 .68786 L p .947 .759 .616 r
F P
0 g
s
.74958 .68786 m .75189 .67885 L .78005 .71055 L p .947 .759 .616 r
F P
0 g
s
.78295 .8305 m .7793 .84246 L .75118 .81481 L p .944 .771 .637 r
F P
0 g
s
.75118 .81481 m .75489 .80241 L .78295 .8305 L p .944 .771 .637 r
F P
0 g
s
.77223 .59696 m .77068 .60335 L .74235 .56922 L p .947 .754 .609 r
F P
0 g
s
.74235 .56922 m .74394 .56272 L .77223 .59696 L p .947 .754 .609 r
F P
0 g
s
.77092 .96814 m .76308 .98561 L .73481 .96111 L p .925 .798 .7 r
F P
0 g
s
.73481 .96111 m .74277 .94354 L .77092 .96814 L p .925 .798 .7 r
F P
0 g
s
.77068 .60335 m .76908 .60992 L .74071 .57591 L p .947 .754 .609 r
F P
0 g
s
.74071 .57591 m .74235 .56922 L .77068 .60335 L p .947 .754 .609 r
F P
0 g
s
.77779 .7193 m .77542 .72837 L .74716 .69719 L p .947 .76 .617 r
F P
0 g
s
.74716 .69719 m .74958 .68786 L .77779 .7193 L p .947 .76 .617 r
F P
0 g
s
.7793 .84246 m .77538 .85495 L .74719 .82776 L p .943 .773 .641 r
F P
0 g
s
.74719 .82776 m .75118 .81481 L .7793 .84246 L p .943 .773 .641 r
F P
0 g
s
.76908 .60992 m .76742 .61668 L .73902 .5828 L p .947 .754 .609 r
F P
0 g
s
.73902 .5828 m .74071 .57591 L .76908 .60992 L p .947 .754 .609 r
F P
0 g
s
.77542 .72837 m .77294 .73777 L .74463 .70688 L p .947 .76 .618 r
F P
0 g
s
.74463 .70688 m .74716 .69719 L .77542 .72837 L p .947 .76 .618 r
F P
0 g
s
.76308 .98561 m .75397 1.00423 L .72554 .97962 L p .918 .803 .717 r
F P
0 g
s
.72554 .97962 m .73481 .96111 L .76308 .98561 L p .918 .803 .717 r
F P
0 g
s
.76742 .61668 m .76572 .62363 L .73728 .58989 L p .947 .755 .609 r
F P
0 g
s
.73728 .58989 m .73902 .5828 L .76742 .61668 L p .947 .755 .609 r
F P
0 g
s
.64563 1.11322 m .61707 1.12216 L .61291 1.11791 L p .662 .76 .923 r
F P
0 g
s
.77538 .85495 m .77114 .868 L .74287 .8413 L p .942 .776 .646 r
F P
0 g
s
.74287 .8413 m .74719 .82776 L .77538 .85495 L p .942 .776 .646 r
F P
0 g
s
.77294 .73777 m .77033 .74752 L .74197 .71695 L p .947 .761 .62 r
F P
0 g
s
.74197 .71695 m .74463 .70688 L .77294 .73777 L p .947 .761 .62 r
F P
0 g
s
.76572 .62363 m .76395 .63079 L .73547 .5972 L p .947 .755 .61 r
F P
0 g
s
.73547 .5972 m .73728 .58989 L .76572 .62363 L p .947 .755 .61 r
F P
0 g
s
.75397 1.00423 m .7431 1.02407 L .71449 .99906 L p .907 .808 .738 r
F P
0 g
s
.71449 .99906 m .72554 .97962 L .75397 1.00423 L p .907 .808 .738 r
F P
0 g
s
.61291 1.11791 m .58714 1.0922 L p .64563 1.11322 L .662 .76 .923 r
F P
0 g
s
.77114 .868 m .76653 .88167 L .73819 .85545 L p .941 .778 .651 r
F P
0 g
s
.73819 .85545 m .74287 .8413 L .77114 .868 L p .941 .778 .651 r
F P
0 g
s
.77033 .74752 m .76759 .75765 L .73917 .72741 L p .947 .762 .621 r
F P
0 g
s
.73917 .72741 m .74197 .71695 L .77033 .74752 L p .947 .762 .621 r
F P
0 g
s
.76395 .63079 m .76213 .63817 L .7336 .60474 L p .948 .755 .61 r
F P
0 g
s
.7336 .60474 m .73547 .5972 L .76395 .63079 L p .948 .755 .61 r
F P
0 g
s
.68755 1.08969 m .64563 1.11322 L .6159 1.08319 L p .735 .789 .896 r
F P
0 g
s
.58714 1.0922 m .6159 1.08319 L .64563 1.11322 L p .662 .76 .923 r
F P
0 g
s
.76213 .63817 m .76023 .64578 L .73167 .61252 L p .948 .755 .61 r
F P
0 g
s
.73167 .61252 m .7336 .60474 L .76213 .63817 L p .948 .755 .61 r
F P
0 g
s
.7431 1.02407 m .72968 1.04513 L .70087 1.01932 L p .89 .812 .766 r
F P
0 g
s
.70087 1.01932 m .71449 .99906 L .7431 1.02407 L p .89 .812 .766 r
F P
0 g
s
.76759 .75765 m .76469 .76817 L .73622 .73831 L p .946 .763 .623 r
F P
0 g
s
.73622 .73831 m .73917 .72741 L .76759 .75765 L p .946 .763 .623 r
F P
0 g
s
.76653 .88167 m .76149 .896 L .73306 .87026 L p .94 .782 .658 r
F P
0 g
s
.73306 .87026 m .73819 .85545 L .76653 .88167 L p .94 .782 .658 r
F P
0 g
s
.76023 .64578 m .75827 .65365 L .72966 .62057 L p .948 .756 .611 r
F P
0 g
s
.72966 .62057 m .73167 .61252 L .76023 .64578 L p .948 .756 .611 r
F P
0 g
s
.72968 1.04513 m .71224 1.06715 L .68319 1.0401 L p .86 .815 .803 r
F P
0 g
s
.68319 1.0401 m .70087 1.01932 L .72968 1.04513 L p .86 .815 .803 r
F P
0 g
s
.76469 .76817 m .76162 .77912 L .73309 .74966 L p .946 .765 .625 r
F P
0 g
s
.73309 .74966 m .73622 .73831 L .76469 .76817 L p .946 .765 .625 r
F P
0 g
s
.76149 .896 m .75593 .91104 L .7274 .88575 L p .938 .785 .665 r
F P
0 g
s
.7274 .88575 m .73306 .87026 L .76149 .896 L p .938 .785 .665 r
F P
0 g
s
.75827 .65365 m .75623 .66177 L .72757 .62889 L p .948 .756 .611 r
F P
0 g
s
.72757 .62889 m .72966 .62057 L .75827 .65365 L p .948 .756 .611 r
F P
0 g
s
.71224 1.06715 m .68755 1.08969 L .65821 1.06105 L p .81 .809 .85 r
F P
0 g
s
.6159 1.08319 m .65821 1.06105 L .68755 1.08969 L p .735 .789 .896 r
F P
0 g
s
.65821 1.06105 m .68319 1.0401 L .71224 1.06715 L p .81 .809 .85 r
F P
0 g
s
.74844 .54423 m .74698 .55023 L .71818 .515 L p .948 .753 .607 r
F P
0 g
s
.71818 .515 m .71967 .50891 L .74844 .54423 L p .948 .753 .607 r
F P
0 g
s
.76162 .77912 m .75836 .79053 L .72977 .76149 L p .946 .766 .627 r
F P
0 g
s
.72977 .76149 m .73309 .74966 L .76162 .77912 L p .946 .766 .627 r
F P
0 g
s
.75623 .66177 m .7541 .67016 L .7254 .6375 L p .948 .757 .612 r
F P
0 g
s
.7254 .6375 m .72757 .62889 L .75623 .66177 L p .948 .757 .612 r
F P
0 g
s
.75593 .91104 m .74974 .92687 L .72111 .90196 L p .935 .789 .675 r
F P
0 g
s
.72111 .90196 m .7274 .88575 L .75593 .91104 L p .935 .789 .675 r
F P
0 g
s
.74698 .55023 m .74548 .55639 L .71665 .52126 L p .948 .753 .607 r
F P
0 g
s
.71665 .52126 m .71818 .515 L .74698 .55023 L p .948 .753 .607 r
F P
0 g
s
.7541 .67016 m .75189 .67885 L .72314 .64643 L p .948 .757 .613 r
F P
0 g
s
.72314 .64643 m .7254 .6375 L .7541 .67016 L p .948 .757 .613 r
F P
0 g
s
.75836 .79053 m .75489 .80241 L .72623 .77384 L p .946 .768 .63 r
F P
0 g
s
.72623 .77384 m .72977 .76149 L .75836 .79053 L p .946 .768 .63 r
F P
0 g
s
.74548 .55639 m .74394 .56272 L .71507 .52769 L p .948 .753 .607 r
F P
0 g
s
.71507 .52769 m .71665 .52126 L .74548 .55639 L p .948 .753 .607 r
F P
0 g
s
.74974 .92687 m .74277 .94354 L .71402 .9189 L p .932 .794 .686 r
F P
0 g
s
.71402 .9189 m .72111 .90196 L .74974 .92687 L p .932 .794 .686 r
F P
0 g
s
.74394 .56272 m .74235 .56922 L .71344 .53431 L p .948 .753 .607 r
F P
0 g
s
.71344 .53431 m .71507 .52769 L .74394 .56272 L p .948 .753 .607 r
F P
0 g
s
.75189 .67885 m .74958 .68786 L .72078 .65569 L p .948 .758 .613 r
F P
0 g
s
.72078 .65569 m .72314 .64643 L .75189 .67885 L p .948 .758 .613 r
F P
0 g
s
.75489 .80241 m .75118 .81481 L .72245 .78674 L p .945 .77 .633 r
F P
0 g
s
.72245 .78674 m .72623 .77384 L .75489 .80241 L p .945 .77 .633 r
F P
0 g
s
.74235 .56922 m .74071 .57591 L .71176 .54112 L p .948 .753 .607 r
F P
0 g
s
.71176 .54112 m .71344 .53431 L .74235 .56922 L p .948 .753 .607 r
F P
0 g
s
.74958 .68786 m .74716 .69719 L .71831 .6653 L p .948 .758 .614 r
F P
0 g
s
.71831 .6653 m .72078 .65569 L .74958 .68786 L p .948 .758 .614 r
F P
0 g
s
.74277 .94354 m .73481 .96111 L .70592 .93657 L p .926 .8 .701 r
F P
0 g
s
.70592 .93657 m .71402 .9189 L .74277 .94354 L p .926 .8 .701 r
F P
0 g
s
.74071 .57591 m .73902 .5828 L .71003 .54813 L p .948 .754 .607 r
F P
0 g
s
.71003 .54813 m .71176 .54112 L .74071 .57591 L p .948 .754 .607 r
F P
0 g
s
.75118 .81481 m .74719 .82776 L .71838 .80021 L p .945 .772 .636 r
F P
0 g
s
.71838 .80021 m .72245 .78674 L .75118 .81481 L p .945 .772 .636 r
F P
0 g
s
.74716 .69719 m .74463 .70688 L .71572 .67529 L p .948 .759 .615 r
F P
0 g
s
.71572 .67529 m .71831 .6653 L .74716 .69719 L p .948 .759 .615 r
F P
0 g
s
.6159 1.08319 m .58714 1.0922 L .58289 1.08786 L p .66 .759 .923 r
F P
0 g
s
.73902 .5828 m .73728 .58989 L .70825 .55536 L p .948 .754 .608 r
F P
0 g
s
.70825 .55536 m .71003 .54813 L .73902 .5828 L p .948 .754 .608 r
F P
0 g
s
.73481 .96111 m .72554 .97962 L .69649 .95492 L p .918 .805 .72 r
F P
0 g
s
.69649 .95492 m .70592 .93657 L .73481 .96111 L p .918 .805 .72 r
F P
0 g
s
.74719 .82776 m .74287 .8413 L .71399 .8143 L p .944 .774 .641 r
F P
0 g
s
.71399 .8143 m .71838 .80021 L .74719 .82776 L p .944 .774 .641 r
F P
0 g
s
.74463 .70688 m .74197 .71695 L .71301 .68569 L p .948 .76 .616 r
F P
0 g
s
.71301 .68569 m .71572 .67529 L .74463 .70688 L p .948 .76 .616 r
F P
0 g
s
.73728 .58989 m .73547 .5972 L .7064 .56282 L p .948 .754 .608 r
F P
0 g
s
.7064 .56282 m .70825 .55536 L .73728 .58989 L p .948 .754 .608 r
F P
0 g
s
.58289 1.08786 m .5566 1.06159 L p .6159 1.08319 L .66 .759 .923 r
F P
0 g
s
.73547 .5972 m .7336 .60474 L .70449 .57052 L p .948 .754 .608 r
F P
0 g
s
.70449 .57052 m .7064 .56282 L .73547 .5972 L p .948 .754 .608 r
F P
0 g
s
.72554 .97962 m .71449 .99906 L .68527 .97385 L p .905 .811 .744 r
F P
0 g
s
.68527 .97385 m .69649 .95492 L .72554 .97962 L p .905 .811 .744 r
F P
0 g
s
.74197 .71695 m .73917 .72741 L .71015 .69651 L p .948 .761 .617 r
F P
0 g
s
.71015 .69651 m .71301 .68569 L .74197 .71695 L p .948 .761 .617 r
F P
0 g
s
.74287 .8413 m .73819 .85545 L .70922 .82901 L p .943 .777 .646 r
F P
0 g
s
.70922 .82901 m .71399 .8143 L .74287 .8413 L p .943 .777 .646 r
F P
0 g
s
.65821 1.06105 m .6159 1.08319 L .58557 1.05251 L p .723 .786 .903 r
F P
0 g
s
.5566 1.06159 m .58557 1.05251 L .6159 1.08319 L p .66 .759 .923 r
F P
0 g
s
.7336 .60474 m .73167 .61252 L .70251 .57848 L p .948 .755 .608 r
F P
0 g
s
.70251 .57848 m .70449 .57052 L .7336 .60474 L p .948 .755 .608 r
F P
0 g
s
.73917 .72741 m .73622 .73831 L .70714 .7078 L p .948 .762 .619 r
F P
0 g
s
.70714 .7078 m .71015 .69651 L .73917 .72741 L p .948 .762 .619 r
F P
0 g
s
.71449 .99906 m .70087 1.01932 L .67143 .99313 L p .884 .816 .776 r
F P
0 g
s
.67143 .99313 m .68527 .97385 L .71449 .99906 L p .884 .816 .776 r
F P
0 g
s
.73167 .61252 m .72966 .62057 L .70045 .58671 L p .948 .755 .609 r
F P
0 g
s
.70045 .58671 m .70251 .57848 L .73167 .61252 L p .948 .755 .609 r
F P
0 g
s
.73819 .85545 m .73306 .87026 L .704 .84438 L p .942 .781 .653 r
F P
0 g
s
.704 .84438 m .70922 .82901 L .73819 .85545 L p .942 .781 .653 r
F P
0 g
s
.73622 .73831 m .73309 .74966 L .70395 .71959 L p .948 .763 .62 r
F P
0 g
s
.70395 .71959 m .70714 .7078 L .73622 .73831 L p .948 .763 .62 r
F P
0 g
s
.70087 1.01932 m .68319 1.0401 L .65351 1.01248 L p .85 .817 .817 r
F P
0 g
s
.65351 1.01248 m .67143 .99313 L .70087 1.01932 L p .85 .817 .817 r
F P
0 g
s
.72966 .62057 m .72757 .62889 L .69832 .59523 L p .948 .755 .609 r
F P
0 g
s
.69832 .59523 m .70045 .58671 L .72966 .62057 L p .948 .755 .609 r
F P
0 g
s
.68319 1.0401 m .65821 1.06105 L .62825 1.03175 L p .796 .809 .862 r
F P
0 g
s
.58557 1.05251 m .62825 1.03175 L .65821 1.06105 L p .723 .786 .903 r
F P
0 g
s
.71967 .50891 m .71818 .515 L .68879 .47897 L p .948 .752 .605 r
F P
0 g
s
.68879 .47897 m .69032 .47279 L .71967 .50891 L p .948 .752 .605 r
F P
0 g
s
.62825 1.03175 m .65351 1.01248 L .68319 1.0401 L p .796 .809 .862 r
F P
0 g
s
.73306 .87026 m .7274 .88575 L .69825 .8604 L p .94 .785 .661 r
F P
0 g
s
.69825 .8604 m .704 .84438 L .73306 .87026 L p .94 .785 .661 r
F P
0 g
s
.72757 .62889 m .7254 .6375 L .6961 .60406 L p .948 .756 .609 r
F P
0 g
s
.6961 .60406 m .69832 .59523 L .72757 .62889 L p .948 .756 .609 r
F P
0 g
s
.73309 .74966 m .72977 .76149 L .70056 .73189 L p .947 .765 .622 r
F P
0 g
s
.70056 .73189 m .70395 .71959 L .73309 .74966 L p .947 .765 .622 r
F P
0 g
s
.71818 .515 m .71665 .52126 L .68722 .48533 L p .948 .752 .605 r
F P
0 g
s
.68722 .48533 m .68879 .47897 L .71818 .515 L p .948 .752 .605 r
F P
0 g
s
.7254 .6375 m .72314 .64643 L .69378 .61323 L p .948 .756 .61 r
F P
0 g
s
.69378 .61323 m .6961 .60406 L .7254 .6375 L p .948 .756 .61 r
F P
0 g
s
.71665 .52126 m .71507 .52769 L .6856 .49186 L p .948 .752 .606 r
F P
0 g
s
.6856 .49186 m .68722 .48533 L .71665 .52126 L p .948 .752 .606 r
F P
0 g
s
.7274 .88575 m .72111 .90196 L .69184 .87705 L p .937 .79 .672 r
F P
0 g
s
.69184 .87705 m .69825 .8604 L .7274 .88575 L p .937 .79 .672 r
F P
0 g
s
.72977 .76149 m .72623 .77384 L .69695 .74476 L p .947 .766 .625 r
F P
0 g
s
.69695 .74476 m .70056 .73189 L .72977 .76149 L p .947 .766 .625 r
F P
0 g
s
.71507 .52769 m .71344 .53431 L .68393 .49859 L p .948 .753 .606 r
F P
0 g
s
.68393 .49859 m .6856 .49186 L .71507 .52769 L p .948 .753 .606 r
F P
0 g
s
.72314 .64643 m .72078 .65569 L .69137 .62275 L p .948 .757 .61 r
F P
0 g
s
.69137 .62275 m .69378 .61323 L .72314 .64643 L p .948 .757 .61 r
F P
0 g
s
.71344 .53431 m .71176 .54112 L .68222 .50552 L p .948 .753 .606 r
F P
0 g
s
.68222 .50552 m .68393 .49859 L .71344 .53431 L p .948 .753 .606 r
F P
0 g
s
.72111 .90196 m .71402 .9189 L .68462 .89431 L p .933 .795 .685 r
F P
0 g
s
.68462 .89431 m .69184 .87705 L .72111 .90196 L p .933 .795 .685 r
F P
0 g
s
.72623 .77384 m .72245 .78674 L .69309 .75821 L p .947 .768 .628 r
F P
0 g
s
.69309 .75821 m .69695 .74476 L .72623 .77384 L p .947 .768 .628 r
F P
0 g
s
.72078 .65569 m .71831 .6653 L .68884 .63265 L p .948 .757 .611 r
F P
0 g
s
.68884 .63265 m .69137 .62275 L .72078 .65569 L p .948 .757 .611 r
F P
0 g
s
.71176 .54112 m .71003 .54813 L .68044 .51266 L p .948 .753 .606 r
F P
0 g
s
.68044 .51266 m .68222 .50552 L .71176 .54112 L p .948 .753 .606 r
F P
0 g
s
.58557 1.05251 m .5566 1.06159 L .55227 1.05717 L p .659 .759 .924 r
F P
0 g
s
.71402 .9189 m .70592 .93657 L .67638 .91206 L p .927 .802 .702 r
F P
0 g
s
.67638 .91206 m .68462 .89431 L .71402 .9189 L p .927 .802 .702 r
F P
0 g
s
.71831 .6653 m .71572 .67529 L .6862 .64295 L p .949 .758 .612 r
F P
0 g
s
.6862 .64295 m .68884 .63265 L .71831 .6653 L p .949 .758 .612 r
F P
0 g
s
.71003 .54813 m .70825 .55536 L .67861 .52002 L p .948 .753 .606 r
F P
0 g
s
.67861 .52002 m .68044 .51266 L .71003 .54813 L p .948 .753 .606 r
F P
0 g
s
.72245 .78674 m .71838 .80021 L .68895 .77229 L p .947 .77 .631 r
F P
0 g
s
.68895 .77229 m .69309 .75821 L .72245 .78674 L p .947 .77 .631 r
F P
0 g
s
.70825 .55536 m .7064 .56282 L .67672 .52762 L p .948 .753 .606 r
F P
0 g
s
.67672 .52762 m .67861 .52002 L .70825 .55536 L p .948 .753 .606 r
F P
0 g
s
.55227 1.05717 m .52544 1.03033 L p .58557 1.05251 L .659 .759 .924 r
F P
0 g
s
.71572 .67529 m .71301 .68569 L .68343 .65369 L p .949 .759 .612 r
F P
0 g
s
.68343 .65369 m .6862 .64295 L .71572 .67529 L p .949 .759 .612 r
F P
0 g
s
.70592 .93657 m .69649 .95492 L .6668 .93018 L p .917 .809 .724 r
F P
0 g
s
.6668 .93018 m .67638 .91206 L .70592 .93657 L p .917 .809 .724 r
F P
0 g
s
.71838 .80021 m .71399 .8143 L .68447 .787 L p .946 .773 .635 r
F P
0 g
s
.68447 .787 m .68895 .77229 L .71838 .80021 L p .946 .773 .635 r
F P
0 g
s
.7064 .56282 m .70449 .57052 L .67476 .53548 L p .948 .754 .606 r
F P
0 g
s
.67476 .53548 m .67672 .52762 L .7064 .56282 L p .948 .754 .606 r
F P
0 g
s
.62825 1.03175 m .58557 1.05251 L .55462 1.02117 L p .71 .783 .909 r
F P
0 g
s
.52544 1.03033 m .55462 1.02117 L .58557 1.05251 L p .659 .759 .924 r
F P
0 g
s
.71301 .68569 m .71015 .69651 L .6805 .6649 L p .949 .759 .613 r
F P
0 g
s
.6805 .6649 m .68343 .65369 L .71301 .68569 L p .949 .759 .613 r
F P
0 g
s
.70449 .57052 m .70251 .57848 L .67274 .54361 L p .949 .754 .606 r
F P
0 g
s
.67274 .54361 m .67476 .53548 L .70449 .57052 L p .949 .754 .606 r
F P
0 g
s
.69649 .95492 m .68527 .97385 L .65539 .94843 L p .902 .816 .753 r
F P
0 g
s
.65539 .94843 m .6668 .93018 L .69649 .95492 L p .902 .816 .753 r
F P
0 g
s
.71399 .8143 m .70922 .82901 L .67961 .80238 L p .945 .776 .641 r
F P
0 g
s
.67961 .80238 m .68447 .787 L .71399 .8143 L p .945 .776 .641 r
F P
0 g
s
.71015 .69651 m .70714 .7078 L .67742 .67661 L p .949 .76 .615 r
F P
0 g
s
.67742 .67661 m .6805 .6649 L .71015 .69651 L p .949 .76 .615 r
F P
0 g
s
.70251 .57848 m .70045 .58671 L .67063 .55203 L p .949 .754 .606 r
F P
0 g
s
.67063 .55203 m .67274 .54361 L .70251 .57848 L p .949 .754 .606 r
F P
0 g
s
.68527 .97385 m .67143 .99313 L .64135 .96655 L p .877 .821 .789 r
F P
0 g
s
.64135 .96655 m .65539 .94843 L .68527 .97385 L p .877 .821 .789 r
F P
0 g
s
.70922 .82901 m .704 .84438 L .67429 .8184 L p .944 .78 .648 r
F P
0 g
s
.67429 .8184 m .67961 .80238 L .70922 .82901 L p .944 .78 .648 r
F P
0 g
s
.70045 .58671 m .69832 .59523 L .66845 .56075 L p .949 .754 .607 r
F P
0 g
s
.66845 .56075 m .67063 .55203 L .70045 .58671 L p .949 .754 .607 r
F P
0 g
s
.70714 .7078 m .70395 .71959 L .67416 .68886 L p .949 .762 .616 r
F P
0 g
s
.67416 .68886 m .67742 .67661 L .70714 .7078 L p .949 .762 .616 r
F P
0 g
s
.65351 1.01248 m .62825 1.03175 L .59766 1.00176 L p .779 .807 .876 r
F P
0 g
s
.55462 1.02117 m .59766 1.00176 L .62825 1.03175 L p .71 .783 .909 r
F P
0 g
s
.69032 .47279 m .68879 .47897 L .65879 .44211 L p .948 .752 .604 r
F P
0 g
s
.65879 .44211 m .66036 .43583 L .69032 .47279 L p .948 .752 .604 r
F P
0 g
s
.67143 .99313 m .65351 1.01248 L .62319 .98428 L p .837 .82 .832 r
F P
0 g
s
.62319 .98428 m .64135 .96655 L .67143 .99313 L p .837 .82 .832 r
F P
0 g
s
.59766 1.00176 m .62319 .98428 L .65351 1.01248 L p .779 .807 .876 r
F P
0 g
s
.69832 .59523 m .6961 .60406 L .66617 .5698 L p .949 .755 .607 r
F P
0 g
s
.66617 .5698 m .66845 .56075 L .69832 .59523 L p .949 .755 .607 r
F P
0 g
s
.68879 .47897 m .68722 .48533 L .65718 .44856 L p .948 .752 .604 r
F P
0 g
s
.65718 .44856 m .65879 .44211 L .68879 .47897 L p .948 .752 .604 r
F P
0 g
s
.704 .84438 m .69825 .8604 L .66843 .83504 L p .942 .785 .656 r
F P
0 g
s
.66843 .83504 m .67429 .8184 L .704 .84438 L p .942 .785 .656 r
F P
0 g
s
.70395 .71959 m .70056 .73189 L .67071 .70168 L p .949 .763 .618 r
F P
0 g
s
.67071 .70168 m .67416 .68886 L .70395 .71959 L p .949 .763 .618 r
F P
0 g
s
.68722 .48533 m .6856 .49186 L .65552 .45519 L p .948 .752 .604 r
F P
0 g
s
.65552 .45519 m .65718 .44856 L .68722 .48533 L p .948 .752 .604 r
F P
0 g
s
.6961 .60406 m .69378 .61323 L .6638 .57921 L p .949 .755 .607 r
F P
0 g
s
.6638 .57921 m .66617 .5698 L .6961 .60406 L p .949 .755 .607 r
F P
0 g
s
.6856 .49186 m .68393 .49859 L .65381 .46202 L p .948 .752 .604 r
F P
0 g
s
.65381 .46202 m .65552 .45519 L .6856 .49186 L p .948 .752 .604 r
F P
0 g
s
.70056 .73189 m .69695 .74476 L .66702 .71512 L p .949 .764 .62 r
F P
0 g
s
.66702 .71512 m .67071 .70168 L .70056 .73189 L p .949 .764 .62 r
F P
0 g
s
.69825 .8604 m .69184 .87705 L .6619 .85223 L p .94 .79 .668 r
F P
0 g
s
.6619 .85223 m .66843 .83504 L .69825 .8604 L p .94 .79 .668 r
F P
0 g
s
.69378 .61323 m .69137 .62275 L .66133 .58899 L p .949 .756 .608 r
F P
0 g
s
.66133 .58899 m .6638 .57921 L .69378 .61323 L p .949 .756 .608 r
F P
0 g
s
.68393 .49859 m .68222 .50552 L .65205 .46907 L p .948 .752 .604 r
F P
0 g
s
.65205 .46907 m .65381 .46202 L .68393 .49859 L p .948 .752 .604 r
F P
0 g
s
.69137 .62275 m .68884 .63265 L .65875 .59918 L p .949 .756 .608 r
F P
0 g
s
.65875 .59918 m .66133 .58899 L .69137 .62275 L p .949 .756 .608 r
F P
0 g
s
.68222 .50552 m .68044 .51266 L .65024 .47633 L p .949 .752 .604 r
F P
0 g
s
.65024 .47633 m .65205 .46907 L .68222 .50552 L p .949 .752 .604 r
F P
0 g
s
.69695 .74476 m .69309 .75821 L .66308 .7292 L p .949 .766 .622 r
F P
0 g
s
.66308 .7292 m .66702 .71512 L .69695 .74476 L p .949 .766 .622 r
F P
0 g
s
.69184 .87705 m .68462 .89431 L .65456 .86984 L p .935 .797 .683 r
F P
0 g
s
.65456 .86984 m .6619 .85223 L .69184 .87705 L p .935 .797 .683 r
F P
0 g
s
.55462 1.02117 m .52544 1.03033 L .52102 1.02582 L p .658 .758 .924 r
F P
0 g
s
.68044 .51266 m .67861 .52002 L .64836 .48383 L p .949 .752 .604 r
F P
0 g
s
.64836 .48383 m .65024 .47633 L .68044 .51266 L p .949 .752 .604 r
F P
0 g
s
.68884 .63265 m .6862 .64295 L .65604 .60981 L p .949 .757 .608 r
F P
0 g
s
.65604 .60981 m .65875 .59918 L .68884 .63265 L p .949 .757 .608 r
F P
0 g
s
.69309 .75821 m .68895 .77229 L .65885 .74395 L p .949 .769 .625 r
F P
0 g
s
.65885 .74395 m .66308 .7292 L .69309 .75821 L p .949 .769 .625 r
F P
0 g
s
.52102 1.02582 m .49364 .99839 L p .55462 1.02117 L .658 .758 .924 r
F P
0 g
s
.67861 .52002 m .67672 .52762 L .64642 .49157 L p .949 .753 .604 r
F P
0 g
s
.64642 .49157 m .64836 .48383 L .67861 .52002 L p .949 .753 .604 r
F P
0 g
s
.68462 .89431 m .67638 .91206 L .64617 .88767 L p .928 .804 .703 r
F P
0 g
s
.64617 .88767 m .65456 .86984 L .68462 .89431 L p .928 .804 .703 r
F P
0 g
s
.6862 .64295 m .68343 .65369 L .6532 .62091 L p .949 .757 .609 r
F P
0 g
s
.6532 .62091 m .65604 .60981 L .6862 .64295 L p .949 .757 .609 r
F P
0 g
s
.67672 .52762 m .67476 .53548 L .64441 .49958 L p .949 .753 .604 r
F P
0 g
s
.64441 .49958 m .64642 .49157 L .67672 .52762 L p .949 .753 .604 r
F P
0 g
s
.59766 1.00176 m .55462 1.02117 L .52304 .98914 L p .697 .779 .915 r
F P
0 g
s
.49364 .99839 m .52304 .98914 L .55462 1.02117 L p .658 .758 .924 r
F P
0 g
s
.68895 .77229 m .68447 .787 L .65429 .7594 L p .948 .771 .629 r
F P
0 g
s
.65429 .7594 m .65885 .74395 L .68895 .77229 L p .948 .771 .629 r
F P
0 g
s
.67638 .91206 m .6668 .93018 L .63643 .90545 L p .916 .813 .73 r
F P
0 g
s
.63643 .90545 m .64617 .88767 L .67638 .91206 L p .916 .813 .73 r
F P
0 g
s
.68343 .65369 m .6805 .6649 L .65021 .63252 L p .95 .758 .61 r
F P
0 g
s
.65021 .63252 m .6532 .62091 L .68343 .65369 L p .95 .758 .61 r
F P
0 g
s
.67476 .53548 m .67274 .54361 L .64233 .50788 L p .949 .753 .604 r
F P
0 g
s
.64233 .50788 m .64441 .49958 L .67476 .53548 L p .949 .753 .604 r
F P
0 g
s
.67274 .54361 m .67063 .55203 L .64018 .51648 L p .949 .753 .604 r
F P
0 g
s
.64018 .51648 m .64233 .50788 L .67274 .54361 L p .949 .753 .604 r
F P
0 g
s
.68447 .787 m .67961 .80238 L .64933 .77555 L p .948 .775 .634 r
F P
0 g
s
.64933 .77555 m .65429 .7594 L .68447 .787 L p .948 .775 .634 r
F P
0 g
s
.6668 .93018 m .65539 .94843 L .62483 .92284 L p .897 .821 .764 r
F P
0 g
s
.62483 .92284 m .63643 .90545 L .6668 .93018 L p .897 .821 .764 r
F P
0 g
s
.6805 .6649 m .67742 .67661 L .64706 .64468 L p .95 .759 .61 r
F P
0 g
s
.64706 .64468 m .65021 .63252 L .6805 .6649 L p .95 .759 .61 r
F P
0 g
s
.67063 .55203 m .66845 .56075 L .63794 .5254 L p .949 .753 .604 r
F P
0 g
s
.63794 .5254 m .64018 .51648 L .67063 .55203 L p .949 .753 .604 r
F P
0 g
s
.66036 .43583 m .65879 .44211 L .62817 .40438 L p .948 .751 .603 r
F P
0 g
s
.62817 .40438 m .62978 .39802 L .66036 .43583 L p .948 .751 .603 r
F P
0 g
s
.65539 .94843 m .64135 .96655 L .61059 .93954 L p .866 .826 .806 r
F P
0 g
s
.61059 .93954 m .62483 .92284 L .65539 .94843 L p .866 .826 .806 r
F P
0 g
s
.62319 .98428 m .59766 1.00176 L .56643 .97105 L p .758 .805 .89 r
F P
0 g
s
.52304 .98914 m .56643 .97105 L .59766 1.00176 L p .697 .779 .915 r
F P
0 g
s
.67742 .67661 m .67416 .68886 L .64373 .65743 L p .95 .76 .611 r
F P
0 g
s
.64373 .65743 m .64706 .64468 L .67742 .67661 L p .95 .76 .611 r
F P
0 g
s
.67961 .80238 m .67429 .8184 L .6439 .79236 L p .947 .779 .641 r
F P
0 g
s
.6439 .79236 m .64933 .77555 L .67961 .80238 L p .947 .779 .641 r
F P
0 g
s
.65879 .44211 m .65718 .44856 L .62652 .41092 L p .948 .751 .603 r
F P
0 g
s
.62652 .41092 m .62817 .40438 L .65879 .44211 L p .948 .751 .603 r
F P
0 g
s
.64135 .96655 m .62319 .98428 L .59222 .95544 L p .819 .821 .851 r
F P
0 g
s
.59222 .95544 m .61059 .93954 L .64135 .96655 L p .819 .821 .851 r
F P
0 g
s
.66845 .56075 m .66617 .5698 L .63561 .53467 L p .949 .754 .605 r
F P
0 g
s
.63561 .53467 m .63794 .5254 L .66845 .56075 L p .949 .754 .605 r
F P
0 g
s
.56643 .97105 m .59222 .95544 L .62319 .98428 L p .758 .805 .89 r
F P
0 g
s
.65718 .44856 m .65552 .45519 L .62482 .41765 L p .949 .751 .603 r
F P
0 g
s
.62482 .41765 m .62652 .41092 L .65718 .44856 L p .949 .751 .603 r
F P
0 g
s
.67416 .68886 m .67071 .70168 L .64019 .67081 L p .95 .761 .613 r
F P
0 g
s
.64019 .67081 m .64373 .65743 L .67416 .68886 L p .95 .761 .613 r
F P
0 g
s
.66617 .5698 m .6638 .57921 L .63318 .54432 L p .949 .754 .605 r
F P
0 g
s
.63318 .54432 m .63561 .53467 L .66617 .5698 L p .949 .754 .605 r
F P
0 g
s
.67429 .8184 m .66843 .83504 L .63793 .80976 L p .945 .784 .65 r
F P
0 g
s
.63793 .80976 m .6439 .79236 L .67429 .8184 L p .945 .784 .65 r
F P
0 g
s
.65552 .45519 m .65381 .46202 L .62306 .42459 L p .949 .751 .603 r
F P
0 g
s
.62306 .42459 m .62482 .41765 L .65552 .45519 L p .949 .751 .603 r
F P
0 g
s
.6638 .57921 m .66133 .58899 L .63065 .55437 L p .95 .754 .605 r
F P
0 g
s
.63065 .55437 m .63318 .54432 L .6638 .57921 L p .95 .754 .605 r
F P
0 g
s
.65381 .46202 m .65205 .46907 L .62126 .43174 L p .949 .752 .603 r
F P
0 g
s
.62126 .43174 m .62306 .42459 L .65381 .46202 L p .949 .752 .603 r
F P
0 g
s
.67071 .70168 m .66702 .71512 L .63642 .68486 L p .95 .763 .614 r
F P
0 g
s
.63642 .68486 m .64019 .67081 L .67071 .70168 L p .95 .763 .614 r
F P
0 g
s
.66843 .83504 m .6619 .85223 L .63128 .8276 L p .942 .79 .663 r
F P
0 g
s
.63128 .8276 m .63793 .80976 L .66843 .83504 L p .942 .79 .663 r
F P
0 g
s
.65205 .46907 m .65024 .47633 L .61939 .43912 L p .949 .752 .603 r
F P
0 g
s
.61939 .43912 m .62126 .43174 L .65205 .46907 L p .949 .752 .603 r
F P
0 g
s
.66133 .58899 m .65875 .59918 L .628 .56486 L p .95 .755 .605 r
F P
0 g
s
.628 .56486 m .63065 .55437 L .66133 .58899 L p .95 .755 .605 r
F P
0 g
s
.52304 .98914 m .49364 .99839 L .48914 .99379 L p .656 .757 .924 r
F P
0 g
s
.66702 .71512 m .66308 .7292 L .6324 .69964 L p .95 .764 .616 r
F P
0 g
s
.6324 .69964 m .63642 .68486 L .66702 .71512 L p .95 .764 .616 r
F P
0 g
s
.65024 .47633 m .64836 .48383 L .61747 .44674 L p .949 .752 .603 r
F P
0 g
s
.61747 .44674 m .61939 .43912 L .65024 .47633 L p .949 .752 .603 r
F P
0 g
s
.65875 .59918 m .65604 .60981 L .62522 .57582 L p .95 .755 .605 r
F P
0 g
s
.62522 .57582 m .628 .56486 L .65875 .59918 L p .95 .755 .605 r
F P
0 g
s
.6619 .85223 m .65456 .86984 L .62379 .84563 L p .937 .798 .68 r
F P
0 g
s
.62379 .84563 m .63128 .8276 L .6619 .85223 L p .937 .798 .68 r
F P
0 g
s
.48914 .99379 m .46119 .96576 L p .52304 .98914 L .656 .757 .924 r
F P
0 g
s
.64836 .48383 m .64642 .49157 L .61548 .45463 L p .949 .752 .603 r
F P
0 g
s
.61548 .45463 m .61747 .44674 L .64836 .48383 L p .949 .752 .603 r
F P
0 g
s
.66308 .7292 m .65885 .74395 L .62807 .71518 L p .95 .766 .619 r
F P
0 g
s
.62807 .71518 m .6324 .69964 L .66308 .7292 L p .95 .766 .619 r
F P
0 g
s
.65604 .60981 m .6532 .62091 L .62231 .58728 L p .95 .756 .605 r
F P
0 g
s
.62231 .58728 m .62522 .57582 L .65604 .60981 L p .95 .756 .605 r
F P
0 g
s
.64642 .49157 m .64441 .49958 L .61342 .46279 L p .949 .752 .603 r
F P
0 g
s
.61342 .46279 m .61548 .45463 L .64642 .49157 L p .949 .752 .603 r
F P
0 g
s
.56643 .97105 m .52304 .98914 L .4908 .9564 L p .684 .775 .92 r
F P
0 g
s
.46119 .96576 m .4908 .9564 L .52304 .98914 L p .656 .757 .924 r
F P
0 g
s
.65456 .86984 m .64617 .88767 L .61526 .86351 L p .929 .808 .704 r
F P
0 g
s
.61526 .86351 m .62379 .84563 L .65456 .86984 L p .929 .808 .704 r
F P
0 g
s
.64441 .49958 m .64233 .50788 L .61129 .47125 L p .949 .752 .603 r
F P
0 g
s
.61129 .47125 m .61342 .46279 L .64441 .49958 L p .949 .752 .603 r
F P
0 g
s
.6532 .62091 m .65021 .63252 L .61925 .59931 L p .95 .756 .606 r
F P
0 g
s
.61925 .59931 m .62231 .58728 L .6532 .62091 L p .95 .756 .606 r
F P
0 g
s
.65885 .74395 m .65429 .7594 L .62341 .73148 L p .95 .769 .622 r
F P
0 g
s
.62341 .73148 m .62807 .71518 L .65885 .74395 L p .95 .769 .622 r
F P
0 g
s
.64617 .88767 m .63643 .90545 L .60535 .88081 L p .915 .818 .737 r
F P
0 g
s
.60535 .88081 m .61526 .86351 L .64617 .88767 L p .915 .818 .737 r
F P
0 g
s
.64233 .50788 m .64018 .51648 L .60907 .48002 L p .949 .752 .603 r
F P
0 g
s
.60907 .48002 m .61129 .47125 L .64233 .50788 L p .949 .752 .603 r
F P
0 g
s
.65021 .63252 m .64706 .64468 L .61602 .61193 L p .951 .757 .606 r
F P
0 g
s
.61602 .61193 m .61925 .59931 L .65021 .63252 L p .951 .757 .606 r
F P
0 g
s
.65429 .7594 m .64933 .77555 L .61834 .74855 L p .95 .772 .627 r
F P
0 g
s
.61834 .74855 m .62341 .73148 L .65429 .7594 L p .95 .772 .627 r
F P
0 g
s
.64018 .51648 m .63794 .5254 L .60677 .48914 L p .95 .753 .602 r
F P
0 g
s
.60677 .48914 m .60907 .48002 L .64018 .51648 L p .95 .753 .602 r
F P
0 g
s
.62978 .39802 m .62817 .40438 L .5969 .36576 L p .949 .751 .602 r
F P
0 g
s
.5969 .36576 m .59855 .35932 L .62978 .39802 L p .949 .751 .602 r
F P
0 g
s
.63643 .90545 m .62483 .92284 L .59357 .89708 L p .89 .828 .779 r
F P
0 g
s
.59357 .89708 m .60535 .88081 L .63643 .90545 L p .89 .828 .779 r
F P
0 g
s
.59222 .95544 m .56643 .97105 L .53453 .93957 L p .734 .8 .905 r
F P
0 g
s
.4908 .9564 m .53453 .93957 L .56643 .97105 L p .684 .775 .92 r
F P
0 g
s
.62817 .40438 m .62652 .41092 L .59521 .37238 L p .949 .751 .602 r
F P
0 g
s
.59521 .37238 m .5969 .36576 L .62817 .40438 L p .949 .751 .602 r
F P
0 g
s
.64706 .64468 m .64373 .65743 L .61261 .6252 L p .951 .758 .607 r
F P
0 g
s
.61261 .6252 m .61602 .61193 L .64706 .64468 L p .951 .758 .607 r
F P
0 g
s
.63794 .5254 m .63561 .53467 L .60438 .49863 L p .95 .753 .602 r
F P
0 g
s
.60438 .49863 m .60677 .48914 L .63794 .5254 L p .95 .753 .602 r
F P
0 g
s
.62483 .92284 m .61059 .93954 L .57914 .91207 L p .851 .831 .827 r
F P
0 g
s
.57914 .91207 m .59357 .89708 L .62483 .92284 L p .851 .831 .827 r
F P
0 g
s
.61059 .93954 m .59222 .95544 L .56055 .92591 L p .795 .822 .873 r
F P
0 g
s
.53453 .93957 m .56055 .92591 L .59222 .95544 L p .734 .8 .905 r
F P
0 g
s
.62652 .41092 m .62482 .41765 L .59346 .3792 L p .949 .751 .602 r
F P
0 g
s
.59346 .3792 m .59521 .37238 L .62652 .41092 L p .949 .751 .602 r
F P
0 g
s
.64933 .77555 m .6439 .79236 L .6128 .76632 L p .949 .777 .634 r
F P
0 g
s
.6128 .76632 m .61834 .74855 L .64933 .77555 L p .949 .777 .634 r
F P
0 g
s
.56055 .92591 m .57914 .91207 L .61059 .93954 L p .795 .822 .873 r
F P
0 g
s
.63561 .53467 m .63318 .54432 L .60189 .50851 L p .95 .753 .602 r
F P
0 g
s
.60189 .50851 m .60438 .49863 L .63561 .53467 L p .95 .753 .602 r
F P
0 g
s
.62482 .41765 m .62306 .42459 L .59166 .38624 L p .949 .751 .602 r
F P
0 g
s
.59166 .38624 m .59346 .3792 L .62482 .41765 L p .949 .751 .602 r
F P
0 g
s
.64373 .65743 m .64019 .67081 L .60898 .63919 L p .951 .759 .608 r
F P
0 g
s
.60898 .63919 m .61261 .6252 L .64373 .65743 L p .951 .759 .608 r
F P
0 g
s
.62306 .42459 m .62126 .43174 L .58981 .39349 L p .949 .751 .602 r
F P
0 g
s
.58981 .39349 m .59166 .38624 L .62306 .42459 L p .949 .751 .602 r
F P
0 g
s
.63318 .54432 m .63065 .55437 L .59929 .51883 L p .95 .753 .602 r
F P
0 g
s
.59929 .51883 m .60189 .50851 L .63318 .54432 L p .95 .753 .602 r
F P
0 g
s
.6439 .79236 m .63793 .80976 L .6067 .78465 L p .948 .782 .644 r
F P
0 g
s
.6067 .78465 m .6128 .76632 L .6439 .79236 L p .948 .782 .644 r
F P
0 g
s
.64019 .67081 m .63642 .68486 L .60513 .65393 L p .952 .76 .609 r
F P
0 g
s
.60513 .65393 m .60898 .63919 L .64019 .67081 L p .952 .76 .609 r
F P
0 g
s
.62126 .43174 m .61939 .43912 L .58789 .40099 L p .949 .751 .602 r
F P
0 g
s
.58789 .40099 m .58981 .39349 L .62126 .43174 L p .949 .751 .602 r
F P
0 g
s
.4908 .9564 m .46119 .96576 L .45659 .96106 L p .655 .757 .924 r
F P
0 g
s
.63065 .55437 m .628 .56486 L .59658 .52961 L p .95 .754 .602 r
F P
0 g
s
.59658 .52961 m .59929 .51883 L .63065 .55437 L p .95 .754 .602 r
F P
0 g
s
.61939 .43912 m .61747 .44674 L .58592 .40873 L p .949 .751 .601 r
F P
0 g
s
.58592 .40873 m .58789 .40099 L .61939 .43912 L p .949 .751 .601 r
F P
0 g
s
.63793 .80976 m .63128 .8276 L .59992 .80329 L p .945 .79 .657 r
F P
0 g
s
.59992 .80329 m .6067 .78465 L .63793 .80976 L p .945 .79 .657 r
F P
0 g
s
.63642 .68486 m .6324 .69964 L .601 .66949 L p .952 .762 .61 r
F P
0 g
s
.601 .66949 m .60513 .65393 L .63642 .68486 L p .952 .762 .61 r
F P
0 g
s
.45659 .96106 m .42806 .93239 L p .4908 .9564 L .655 .757 .924 r
F P
0 g
s
.628 .56486 m .62522 .57582 L .59373 .5409 L p .951 .754 .602 r
F P
0 g
s
.59373 .5409 m .59658 .52961 L .628 .56486 L p .951 .754 .602 r
F P
0 g
s
.61747 .44674 m .61548 .45463 L .58388 .41675 L p .949 .751 .601 r
F P
0 g
s
.58388 .41675 m .58592 .40873 L .61747 .44674 L p .949 .751 .601 r
F P
0 g
s
.63128 .8276 m .62379 .84563 L .59229 .82183 L p .94 .799 .677 r
F P
0 g
s
.59229 .82183 m .59992 .80329 L .63128 .8276 L p .94 .799 .677 r
F P
0 g
s
.61548 .45463 m .61342 .46279 L .58176 .42505 L p .949 .751 .601 r
F P
0 g
s
.58176 .42505 m .58388 .41675 L .61548 .45463 L p .949 .751 .601 r
F P
0 g
s
.53453 .93957 m .4908 .9564 L .45788 .92292 L p .67 .771 .925 r
F P
0 g
s
.42806 .93239 m .45788 .92292 L .4908 .9564 L p .655 .757 .924 r
F P
0 g
s
.62522 .57582 m .62231 .58728 L .59075 .55274 L p .951 .754 .602 r
F P
0 g
s
.59075 .55274 m .59373 .5409 L .62522 .57582 L p .951 .754 .602 r
F P
0 g
s
.6324 .69964 m .62807 .71518 L .59658 .6859 L p .952 .764 .612 r
F P
0 g
s
.59658 .6859 m .601 .66949 L .6324 .69964 L p .952 .764 .612 r
F P
0 g
s
.61342 .46279 m .61129 .47125 L .57957 .43367 L p .95 .751 .601 r
F P
0 g
s
.57957 .43367 m .58176 .42505 L .61342 .46279 L p .95 .751 .601 r
F P
0 g
s
.62231 .58728 m .61925 .59931 L .58761 .56518 L p .951 .755 .602 r
F P
0 g
s
.58761 .56518 m .59075 .55274 L .62231 .58728 L p .951 .755 .602 r
F P
0 g
s
.62379 .84563 m .61526 .86351 L .5836 .83973 L p .931 .811 .706 r
F P
0 g
s
.5836 .83973 m .59229 .82183 L .62379 .84563 L p .931 .811 .706 r
F P
0 g
s
.61129 .47125 m .60907 .48002 L .5773 .44262 L p .95 .752 .601 r
F P
0 g
s
.5773 .44262 m .57957 .43367 L .61129 .47125 L p .95 .752 .601 r
F P
0 g
s
.62807 .71518 m .62341 .73148 L .5918 .7032 L p .952 .767 .615 r
F P
0 g
s
.5918 .7032 m .59658 .6859 L .62807 .71518 L p .952 .767 .615 r
F P
0 g
s
.61925 .59931 m .61602 .61193 L .58429 .57829 L p .952 .756 .602 r
F P
0 g
s
.58429 .57829 m .58761 .56518 L .61925 .59931 L p .952 .756 .602 r
F P
0 g
s
.59855 .35932 m .5969 .36576 L .56497 .32621 L p .949 .75 .601 r
F P
0 g
s
.56497 .32621 m .56667 .31969 L .59855 .35932 L p .949 .75 .601 r
F P
0 g
s
.60907 .48002 m .60677 .48914 L .57494 .45192 L p .95 .752 .601 r
F P
0 g
s
.57494 .45192 m .5773 .44262 L .60907 .48002 L p .95 .752 .601 r
F P
0 g
s
.61526 .86351 m .60535 .88081 L .57352 .85634 L p .912 .825 .747 r
F P
0 g
s
.57352 .85634 m .5836 .83973 L .61526 .86351 L p .912 .825 .747 r
F P
0 g
s
.56055 .92591 m .53453 .93957 L .50194 .9073 L p .705 .794 .92 r
F P
0 g
s
.45788 .92292 m .50194 .9073 L .53453 .93957 L p .67 .771 .925 r
F P
0 g
s
.5969 .36576 m .59521 .37238 L .56323 .33291 L p .949 .75 .601 r
F P
0 g
s
.56323 .33291 m .56497 .32621 L .5969 .36576 L p .949 .75 .601 r
F P
0 g
s
.62341 .73148 m .61834 .74855 L .58662 .72136 L p .952 .77 .619 r
F P
0 g
s
.58662 .72136 m .5918 .7032 L .62341 .73148 L p .952 .77 .619 r
F P
0 g
s
.60677 .48914 m .60438 .49863 L .57248 .46162 L p .95 .752 .6 r
F P
0 g
s
.57248 .46162 m .57494 .45192 L .60677 .48914 L p .95 .752 .6 r
F P
0 g
s
.60535 .88081 m .59357 .89708 L .56158 .87117 L p .879 .836 .799 r
F P
0 g
s
.56158 .87117 m .57352 .85634 L .60535 .88081 L p .879 .836 .799 r
F P
0 g
s
.61602 .61193 m .61261 .6252 L .58079 .59212 L p .952 .756 .602 r
F P
0 g
s
.58079 .59212 m .58429 .57829 L .61602 .61193 L p .952 .756 .602 r
F P
0 g
s
.59521 .37238 m .59346 .3792 L .56144 .33982 L p .949 .75 .601 r
F P
0 g
s
.56144 .33982 m .56323 .33291 L .59521 .37238 L p .949 .75 .601 r
F P
0 g
s
.57914 .91207 m .56055 .92591 L .52819 .89564 L p .762 .82 .898 r
F P
0 g
s
.50194 .9073 m .52819 .89564 L .56055 .92591 L p .705 .794 .92 r
F P
0 g
s
.59357 .89708 m .57914 .91207 L .54696 .88409 L p .827 .836 .855 r
F P
0 g
s
.54696 .88409 m .56158 .87117 L .59357 .89708 L p .827 .836 .855 r
F P
0 g
s
.60438 .49863 m .60189 .50851 L .56993 .47173 L p .95 .752 .6 r
F P
0 g
s
.56993 .47173 m .57248 .46162 L .60438 .49863 L p .95 .752 .6 r
F P
0 g
s
.59346 .3792 m .59166 .38624 L .55959 .34695 L p .949 .75 .601 r
F P
0 g
s
.55959 .34695 m .56144 .33982 L .59346 .3792 L p .949 .75 .601 r
F P
0 g
s
.52819 .89564 m .54696 .88409 L .57914 .91207 L p .762 .82 .898 r
F P
0 g
s
.61834 .74855 m .6128 .76632 L .58096 .7403 L p .952 .774 .626 r
F P
0 g
s
.58096 .7403 m .58662 .72136 L .61834 .74855 L p .952 .774 .626 r
F P
0 g
s
.61261 .6252 m .60898 .63919 L .57707 .60673 L p .952 .757 .603 r
F P
0 g
s
.57707 .60673 m .58079 .59212 L .61261 .6252 L p .952 .757 .603 r
F P
0 g
s
.59166 .38624 m .58981 .39349 L .55769 .3543 L p .949 .75 .601 r
F P
0 g
s
.55769 .3543 m .55959 .34695 L .59166 .38624 L p .949 .75 .601 r
F P
0 g
s
.60189 .50851 m .59929 .51883 L .56726 .4823 L p .951 .752 .6 r
F P
0 g
s
.56726 .4823 m .56993 .47173 L .60189 .50851 L p .951 .752 .6 r
F P
0 g
s
.58981 .39349 m .58789 .40099 L .55572 .3619 L p .949 .751 .601 r
F P
0 g
s
.55572 .3619 m .55769 .3543 L .58981 .39349 L p .949 .751 .601 r
F P
0 g
s
.45788 .92292 m .42806 .93239 L .42336 .9276 L p .654 .756 .925 r
F P
0 g
s
.60898 .63919 m .60513 .65393 L .57311 .62222 L p .953 .758 .603 r
F P
0 g
s
.57311 .62222 m .57707 .60673 L .60898 .63919 L p .953 .758 .603 r
F P
0 g
s
.6128 .76632 m .6067 .78465 L .57472 .7598 L p .951 .781 .635 r
F P
0 g
s
.57472 .7598 m .58096 .7403 L .6128 .76632 L p .951 .781 .635 r
F P
0 g
s
.59929 .51883 m .59658 .52961 L .56447 .49337 L p .951 .752 .6 r
F P
0 g
s
.56447 .49337 m .56726 .4823 L .59929 .51883 L p .951 .752 .6 r
F P
0 g
s
.58789 .40099 m .58592 .40873 L .55369 .36976 L p .949 .751 .6 r
F P
0 g
s
.55369 .36976 m .55572 .3619 L .58789 .40099 L p .949 .751 .6 r
F P
0 g
s
.42336 .9276 m .39423 .89828 L p .45788 .92292 L .654 .756 .925 r
F P
0 g
s
.58592 .40873 m .58388 .41675 L .55159 .3779 L p .949 .751 .6 r
F P
0 g
s
.55159 .3779 m .55369 .36976 L .58592 .40873 L p .949 .751 .6 r
F P
0 g
s
.59658 .52961 m .59373 .5409 L .56154 .50499 L p .951 .753 .599 r
F P
0 g
s
.56154 .50499 m .56447 .49337 L .59658 .52961 L p .951 .753 .599 r
F P
0 g
s
.60513 .65393 m .601 .66949 L .56888 .63863 L p .953 .76 .604 r
F P
0 g
s
.56888 .63863 m .57311 .62222 L .60513 .65393 L p .953 .76 .604 r
F P
0 g
s
.6067 .78465 m .59992 .80329 L .56779 .77947 L p .948 .789 .65 r
F P
0 g
s
.56779 .77947 m .57472 .7598 L .6067 .78465 L p .948 .789 .65 r
F P
0 g
s
.50194 .9073 m .45788 .92292 L .42427 .88869 L p .657 .766 .93 r
F P
0 g
s
.39423 .89828 m .42427 .88869 L .45788 .92292 L p .654 .756 .925 r
F P
0 g
s
.58388 .41675 m .58176 .42505 L .54942 .38634 L p .95 .751 .6 r
F P
0 g
s
.54942 .38634 m .55159 .3779 L .58388 .41675 L p .95 .751 .6 r
F P
0 g
s
.59373 .5409 m .59075 .55274 L .55848 .5172 L p .951 .753 .599 r
F P
0 g
s
.55848 .5172 m .56154 .50499 L .59373 .5409 L p .951 .753 .599 r
F P
0 g
s
.58176 .42505 m .57957 .43367 L .54717 .39511 L p .95 .751 .6 r
F P
0 g
s
.54717 .39511 m .54942 .38634 L .58176 .42505 L p .95 .751 .6 r
F P
0 g
s
.601 .66949 m .59658 .6859 L .56434 .65605 L p .954 .761 .605 r
F P
0 g
s
.56434 .65605 m .56888 .63863 L .601 .66949 L p .954 .761 .605 r
F P
0 g
s
.59992 .80329 m .59229 .82183 L .56001 .79866 L p .943 .801 .673 r
F P
0 g
s
.56001 .79866 m .56779 .77947 L .59992 .80329 L p .943 .801 .673 r
F P
0 g
s
.59075 .55274 m .58761 .56518 L .55525 .53007 L p .952 .753 .599 r
F P
0 g
s
.55525 .53007 m .55848 .5172 L .59075 .55274 L p .952 .753 .599 r
F P
0 g
s
.57957 .43367 m .5773 .44262 L .54484 .40421 L p .95 .751 .599 r
F P
0 g
s
.54484 .40421 m .54717 .39511 L .57957 .43367 L p .95 .751 .599 r
F P
0 g
s
.56667 .31969 m .56497 .32621 L .53236 .2857 L p .949 .75 .601 r
F P
0 g
s
.53236 .2857 m .5341 .27912 L .56667 .31969 L p .949 .75 .601 r
F P
0 g
s
.59658 .6859 m .5918 .7032 L .55945 .6745 L p .954 .764 .607 r
F P
0 g
s
.55945 .6745 m .56434 .65605 L .59658 .6859 L p .954 .764 .607 r
F P
0 g
s
.5773 .44262 m .57494 .45192 L .54241 .4137 L p .95 .751 .599 r
F P
0 g
s
.54241 .4137 m .54484 .40421 L .5773 .44262 L p .95 .751 .599 r
F P
0 g
s
.59229 .82183 m .5836 .83973 L .55116 .81652 L p .932 .816 .709 r
F P
0 g
s
.55116 .81652 m .56001 .79866 L .59229 .82183 L p .932 .816 .709 r
F P
0 g
s
.58761 .56518 m .58429 .57829 L .55185 .54366 L p .952 .754 .598 r
F P
0 g
s
.55185 .54366 m .55525 .53007 L .58761 .56518 L p .952 .754 .598 r
F P
0 g
s
.52819 .89564 m .50194 .9073 L .46864 .8742 L p .672 .784 .933 r
F P
0 g
s
.42427 .88869 m .46864 .8742 L .50194 .9073 L p .657 .766 .93 r
F P
0 g
s
.56497 .32621 m .56323 .33291 L .53057 .29248 L p .949 .75 .6 r
F P
0 g
s
.53057 .29248 m .53236 .2857 L .56497 .32621 L p .949 .75 .6 r
F P
0 g
s
.57494 .45192 m .57248 .46162 L .53989 .42359 L p .95 .751 .598 r
F P
0 g
s
.53989 .42359 m .54241 .4137 L .57494 .45192 L p .95 .751 .598 r
F P
0 g
s
.56323 .33291 m .56144 .33982 L .52873 .29947 L p .949 .75 .6 r
F P
0 g
s
.52873 .29947 m .53057 .29248 L .56323 .33291 L p .949 .75 .6 r
F P
0 g
s
.5836 .83973 m .57352 .85634 L .54092 .83217 L p .908 .834 .761 r
F P
0 g
s
.54092 .83217 m .55116 .81652 L .5836 .83973 L p .908 .834 .761 r
F P
0 g
s
.58429 .57829 m .58079 .59212 L .54825 .55806 L p .953 .754 .598 r
F P
0 g
s
.54825 .55806 m .55185 .54366 L .58429 .57829 L p .953 .754 .598 r
F P
0 g
s
.5918 .7032 m .58662 .72136 L .55413 .69398 L p .955 .767 .611 r
F P
0 g
s
.55413 .69398 m .55945 .6745 L .5918 .7032 L p .955 .767 .611 r
F P
0 g
s
.56144 .33982 m .55959 .34695 L .52683 .30668 L p .949 .75 .6 r
F P
0 g
s
.52683 .30668 m .52873 .29947 L .56144 .33982 L p .949 .75 .6 r
F P
0 g
s
.54696 .88409 m .52819 .89564 L .49509 .86455 L p .717 .812 .925 r
F P
0 g
s
.46864 .8742 m .49509 .86455 L .52819 .89564 L p .672 .784 .933 r
F P
0 g
s
.57248 .46162 m .56993 .47173 L .53726 .43392 L p .951 .751 .598 r
F P
0 g
s
.53726 .43392 m .53989 .42359 L .57248 .46162 L p .951 .751 .598 r
F P
0 g
s
.57352 .85634 m .56158 .87117 L .52881 .8451 L p .861 .846 .828 r
F P
0 g
s
.52881 .8451 m .54092 .83217 L .57352 .85634 L p .861 .846 .828 r
F P
0 g
s
.56158 .87117 m .54696 .88409 L .51403 .85553 L p .789 .839 .89 r
F P
0 g
s
.49509 .86455 m .51403 .85553 L .54696 .88409 L p .717 .812 .925 r
F P
0 g
s
.55959 .34695 m .55769 .3543 L .52487 .31413 L p .949 .75 .6 r
F P
0 g
s
.52487 .31413 m .52683 .30668 L .55959 .34695 L p .949 .75 .6 r
F P
0 g
s
.51403 .85553 m .52881 .8451 L .56158 .87117 L p .789 .839 .89 r
F P
0 g
s
.58079 .59212 m .57707 .60673 L .54443 .57334 L p .953 .755 .598 r
F P
0 g
s
.54443 .57334 m .54825 .55806 L .58079 .59212 L p .953 .755 .598 r
F P
0 g
s
.56993 .47173 m .56726 .4823 L .53452 .44474 L p .951 .751 .598 r
F P
0 g
s
.53452 .44474 m .53726 .43392 L .56993 .47173 L p .951 .751 .598 r
F P
0 g
s
.58662 .72136 m .58096 .7403 L .54833 .71437 L p .955 .771 .616 r
F P
0 g
s
.54833 .71437 m .55413 .69398 L .58662 .72136 L p .955 .771 .616 r
F P
0 g
s
.42427 .88869 m .39423 .89828 L .38943 .89339 L p .653 .756 .925 r
F P
0 g
s
.55769 .3543 m .55572 .3619 L .52285 .32183 L p .949 .75 .6 r
F P
0 g
s
.52285 .32183 m .52487 .31413 L .55769 .3543 L p .949 .75 .6 r
F P
0 g
s
.56726 .4823 m .56447 .49337 L .53165 .45609 L p .951 .751 .597 r
F P
0 g
s
.53165 .45609 m .53452 .44474 L .56726 .4823 L p .951 .751 .597 r
F P
0 g
s
.55572 .3619 m .55369 .36976 L .52077 .32979 L p .949 .75 .599 r
F P
0 g
s
.52077 .32979 m .52285 .32183 L .55572 .3619 L p .949 .75 .599 r
F P
0 g
s
.57707 .60673 m .57311 .62222 L .54036 .58961 L p .954 .756 .598 r
F P
0 g
s
.54036 .58961 m .54443 .57334 L .57707 .60673 L p .954 .756 .598 r
F P
0 g
s
.38943 .89339 m .35968 .86341 L p .42427 .88869 L .653 .756 .925 r
F P
0 g
s
.55369 .36976 m .55159 .3779 L .51861 .33805 L p .95 .75 .599 r
F P
0 g
s
.51861 .33805 m .52077 .32979 L .55369 .36976 L p .95 .75 .599 r
F P
0 g
s
.58096 .7403 m .57472 .7598 L .54194 .73537 L p .954 .778 .625 r
F P
0 g
s
.54194 .73537 m .54833 .71437 L .58096 .7403 L p .954 .778 .625 r
F P
0 g
s
.56447 .49337 m .56154 .50499 L .52864 .46801 L p .952 .751 .597 r
F P
0 g
s
.52864 .46801 m .53165 .45609 L .56447 .49337 L p .952 .751 .597 r
F P
0 g
s
.46864 .8742 m .42427 .88869 L .38994 .85367 L p .644 .761 .934 r
F P
0 g
s
.35968 .86341 m .38994 .85367 L .42427 .88869 L p .653 .756 .925 r
F P
0 g
s
.55159 .3779 m .54942 .38634 L .51638 .34661 L p .95 .75 .599 r
F P
0 g
s
.51638 .34661 m .51861 .33805 L .55159 .3779 L p .95 .75 .599 r
F P
0 g
s
.57311 .62222 m .56888 .63863 L .53601 .60696 L p .955 .757 .598 r
F P
0 g
s
.53601 .60696 m .54036 .58961 L .57311 .62222 L p .955 .757 .598 r
F P
0 g
s
.56154 .50499 m .55848 .5172 L .52549 .48059 L p .952 .752 .596 r
F P
0 g
s
.52549 .48059 m .52864 .46801 L .56154 .50499 L p .952 .752 .596 r
F P
0 g
s
.54942 .38634 m .54717 .39511 L .51407 .35551 L p .95 .75 .598 r
F P
0 g
s
.51407 .35551 m .51638 .34661 L .54942 .38634 L p .95 .75 .598 r
F P
0 g
s
.57472 .7598 m .56779 .77947 L .53485 .75638 L p .952 .787 .641 r
F P
0 g
s
.53485 .75638 m .54194 .73537 L .57472 .7598 L p .952 .787 .641 r
F P
0 g
s
.56888 .63863 m .56434 .65605 L .53134 .62549 L p .955 .758 .598 r
F P
0 g
s
.53134 .62549 m .53601 .60696 L .56888 .63863 L p .955 .758 .598 r
F P
0 g
s
.54717 .39511 m .54484 .40421 L .51167 .36477 L p .95 .75 .598 r
F P
0 g
s
.51167 .36477 m .51407 .35551 L .54717 .39511 L p .95 .75 .598 r
F P
0 g
s
.55848 .5172 m .55525 .53007 L .52217 .49387 L p .952 .752 .595 r
F P
0 g
s
.52217 .49387 m .52549 .48059 L .55848 .5172 L p .952 .752 .595 r
F P
0 g
s
.5341 .27912 m .53236 .2857 L .49905 .2442 L p .949 .75 .6 r
F P
0 g
s
.49905 .2442 m .50084 .23755 L .5341 .27912 L p .949 .75 .6 r
F P
0 g
s
.56779 .77947 m .56001 .79866 L .5269 .77641 L p .947 .802 .667 r
F P
0 g
s
.5269 .77641 m .53485 .75638 L .56779 .77947 L p .947 .802 .667 r
F P
0 g
s
.54484 .40421 m .54241 .4137 L .50917 .37442 L p .95 .75 .597 r
F P
0 g
s
.50917 .37442 m .51167 .36477 L .54484 .40421 L p .95 .75 .597 r
F P
0 g
s
.53236 .2857 m .53057 .29248 L .49721 .25105 L p .949 .75 .6 r
F P
0 g
s
.49721 .25105 m .49905 .2442 L .53236 .2857 L p .949 .75 .6 r
F P
0 g
s
.49509 .86455 m .46864 .8742 L .43462 .84021 L p .635 .772 .946 r
F P
0 g
s
.38994 .85367 m .43462 .84021 L .46864 .8742 L p .644 .761 .934 r
F P
0 g
s
.55525 .53007 m .55185 .54366 L .51867 .50795 L p .953 .752 .595 r
F P
0 g
s
.51867 .50795 m .52217 .49387 L .55525 .53007 L p .953 .752 .595 r
F P
0 g
s
.56434 .65605 m .55945 .6745 L .5263 .64528 L p .956 .76 .599 r
F P
0 g
s
.5263 .64528 m .53134 .62549 L .56434 .65605 L p .956 .76 .599 r
F P
0 g
s
.54241 .4137 m .53989 .42359 L .50658 .38449 L p .951 .75 .597 r
F P
0 g
s
.50658 .38449 m .50917 .37442 L .54241 .4137 L p .951 .75 .597 r
F P
0 g
s
.53057 .29248 m .52873 .29947 L .49531 .25811 L p .949 .75 .6 r
F P
0 g
s
.49531 .25811 m .49721 .25105 L .53057 .29248 L p .949 .75 .6 r
F P
0 g
s
.56001 .79866 m .55116 .81652 L .51788 .79415 L p .934 .822 .712 r
F P
0 g
s
.51788 .79415 m .5269 .77641 L .56001 .79866 L p .934 .822 .712 r
F P
0 g
s
.52873 .29947 m .52683 .30668 L .49336 .2654 L p .949 .75 .599 r
F P
0 g
s
.49336 .2654 m .49531 .25811 L .52873 .29947 L p .949 .75 .599 r
F P
0 g
s
.55185 .54366 m .54825 .55806 L .51496 .52292 L p .953 .752 .594 r
F P
0 g
s
.51496 .52292 m .51867 .50795 L .55185 .54366 L p .953 .752 .594 r
F P
0 g
s
.53989 .42359 m .53726 .43392 L .50387 .39503 L p .951 .75 .596 r
F P
0 g
s
.50387 .39503 m .50658 .38449 L .53989 .42359 L p .951 .75 .596 r
F P
0 g
s
.51403 .85553 m .49509 .86455 L .46125 .83257 L p .652 .796 .951 r
F P
0 g
s
.43462 .84021 m .46125 .83257 L .49509 .86455 L p .635 .772 .946 r
F P
0 g
s
.55945 .6745 m .55413 .69398 L .52084 .66633 L p .957 .763 .601 r
F P
0 g
s
.52084 .66633 m .5263 .64528 L .55945 .6745 L p .957 .763 .601 r
F P
0 g
s
.52683 .30668 m .52487 .31413 L .49135 .27293 L p .949 .75 .599 r
F P
0 g
s
.49135 .27293 m .49336 .2654 L .52683 .30668 L p .949 .75 .599 r
F P
0 g
s
.55116 .81652 m .54092 .83217 L .50748 .80843 L p .9 .847 .783 r
F P
0 g
s
.50748 .80843 m .51788 .79415 L .55116 .81652 L p .9 .847 .783 r
F P
0 g
s
.53726 .43392 m .53452 .44474 L .50105 .40608 L p .951 .75 .596 r
F P
0 g
s
.50105 .40608 m .50387 .39503 L .53726 .43392 L p .951 .75 .596 r
F P
0 g
s
.38994 .85367 m .35968 .86341 L .35478 .8584 L p .653 .755 .925 r
F P
0 g
s
.54825 .55806 m .54443 .57334 L .51103 .53888 L p .954 .753 .593 r
F P
0 g
s
.51103 .53888 m .51496 .52292 L .54825 .55806 L p .954 .753 .593 r
F P
0 g
s
.52881 .8451 m .51403 .85553 L .48033 .82629 L p .724 .834 .933 r
F P
0 g
s
.46125 .83257 m .48033 .82629 L .51403 .85553 L p .652 .796 .951 r
F P
0 g
s
.52487 .31413 m .52285 .32183 L .48927 .28072 L p .949 .75 .599 r
F P
0 g
s
.48927 .28072 m .49135 .27293 L .52487 .31413 L p .949 .75 .599 r
F P
0 g
s
.54092 .83217 m .52881 .8451 L .49523 .81885 L p .827 .858 .869 r
F P
0 g
s
.49523 .81885 m .50748 .80843 L .54092 .83217 L p .827 .858 .869 r
F P
0 g
s
.48033 .82629 m .49523 .81885 L .52881 .8451 L p .724 .834 .933 r
F P
0 g
s
.52285 .32183 m .52077 .32979 L .48713 .28878 L p .95 .75 .598 r
F P
0 g
s
.48713 .28878 m .48927 .28072 L .52285 .32183 L p .95 .75 .598 r
F P
0 g
s
.53452 .44474 m .53165 .45609 L .4981 .41768 L p .952 .75 .595 r
F P
0 g
s
.4981 .41768 m .50105 .40608 L .53452 .44474 L p .952 .75 .595 r
F P
0 g
s
.55413 .69398 m .54833 .71437 L .51487 .68854 L p .957 .768 .605 r
F P
0 g
s
.51487 .68854 m .52084 .66633 L .55413 .69398 L p .957 .768 .605 r
F P
0 g
s
.35478 .8584 m .32439 .82773 L p .38994 .85367 L .653 .755 .925 r
F P
0 g
s
.54443 .57334 m .54036 .58961 L .50684 .55597 L p .955 .753 .592 r
F P
0 g
s
.50684 .55597 m .51103 .53888 L .54443 .57334 L p .955 .753 .592 r
F P
0 g
s
.52077 .32979 m .51861 .33805 L .48491 .29714 L p .95 .749 .598 r
F P
0 g
s
.48491 .29714 m .48713 .28878 L .52077 .32979 L p .95 .749 .598 r
F P
0 g
s
.53165 .45609 m .52864 .46801 L .495 .42991 L p .952 .75 .594 r
F P
0 g
s
.495 .42991 m .4981 .41768 L .53165 .45609 L p .952 .75 .594 r
F P
0 g
s
.43462 .84021 m .38994 .85367 L .35487 .81784 L p .631 .756 .937 r
F P
0 g
s
.32439 .82773 m .35487 .81784 L .38994 .85367 L p .653 .755 .925 r
F P
0 g
s
.51861 .33805 m .51638 .34661 L .48262 .30582 L p .95 .749 .598 r
F P
0 g
s
.48262 .30582 m .48491 .29714 L .51861 .33805 L p .95 .749 .598 r
F P
0 g
s
.54833 .71437 m .54194 .73537 L .50831 .71149 L p .957 .774 .613 r
F P
0 g
s
.50831 .71149 m .51487 .68854 L .54833 .71437 L p .957 .774 .613 r
F P
0 g
s
.54036 .58961 m .53601 .60696 L .50236 .57432 L p .956 .754 .591 r
F P
0 g
s
.50236 .57432 m .50684 .55597 L .54036 .58961 L p .956 .754 .591 r
F P
0 g
s
.52864 .46801 m .52549 .48059 L .49176 .44282 L p .952 .75 .593 r
F P
0 g
s
.49176 .44282 m .495 .42991 L .52864 .46801 L p .952 .75 .593 r
F P
0 g
s
.51638 .34661 m .51407 .35551 L .48024 .31484 L p .95 .749 .597 r
F P
0 g
s
.48024 .31484 m .48262 .30582 L .51638 .34661 L p .95 .749 .597 r
F P
0 g
s
.51407 .35551 m .51167 .36477 L .47777 .32423 L p .95 .749 .597 r
F P
0 g
s
.47777 .32423 m .48024 .31484 L .51407 .35551 L p .95 .749 .597 r
F P
0 g
s
.52549 .48059 m .52217 .49387 L .48834 .4565 L p .953 .75 .592 r
F P
0 g
s
.48834 .4565 m .49176 .44282 L .52549 .48059 L p .953 .75 .592 r
F P
0 g
s
.50084 .23755 m .49905 .2442 L .46501 .20168 L p .949 .749 .6 r
F P
0 g
s
.46501 .20168 m .46685 .19497 L .50084 .23755 L p .949 .749 .6 r
F P
0 g
s
.53601 .60696 m .53134 .62549 L .49754 .59407 L p .957 .755 .591 r
F P
0 g
s
.49754 .59407 m .50236 .57432 L .53601 .60696 L p .957 .755 .591 r
F P
0 g
s
.54194 .73537 m .53485 .75638 L .50103 .73433 L p .956 .785 .629 r
F P
0 g
s
.50103 .73433 m .50831 .71149 L .54194 .73537 L p .956 .785 .629 r
F P
0 g
s
.51167 .36477 m .50917 .37442 L .4752 .33403 L p .95 .749 .596 r
F P
0 g
s
.4752 .33403 m .47777 .32423 L .51167 .36477 L p .95 .749 .596 r
F P
0 g
s
.49905 .2442 m .49721 .25105 L .46312 .20859 L p .949 .749 .599 r
F P
0 g
s
.46312 .20859 m .46501 .20168 L .49905 .2442 L p .949 .749 .599 r
F P
0 g
s
.46125 .83257 m .43462 .84021 L .39985 .8053 L p .594 .756 .956 r
F P
0 g
s
.35487 .81784 m .39985 .8053 L .43462 .84021 L p .631 .756 .937 r
F P
0 g
s
.52217 .49387 m .51867 .50795 L .48473 .47105 L p .953 .75 .591 r
F P
0 g
s
.48473 .47105 m .48834 .4565 L .52217 .49387 L p .953 .75 .591 r
F P
0 g
s
.49721 .25105 m .49531 .25811 L .46117 .21572 L p .949 .749 .599 r
F P
0 g
s
.46117 .21572 m .46312 .20859 L .49721 .25105 L p .949 .749 .599 r
F P
0 g
s
.50917 .37442 m .50658 .38449 L .47253 .34427 L p .951 .749 .596 r
F P
0 g
s
.47253 .34427 m .4752 .33403 L .50917 .37442 L p .951 .749 .596 r
F P
0 g
s
.53134 .62549 m .5263 .64528 L .49235 .61537 L p .958 .757 .591 r
F P
0 g
s
.49235 .61537 m .49754 .59407 L .53134 .62549 L p .958 .757 .591 r
F P
0 g
s
.53485 .75638 m .5269 .77641 L .4929 .75551 L p .951 .802 .659 r
F P
0 g
s
.4929 .75551 m .50103 .73433 L .53485 .75638 L p .951 .802 .659 r
F P
0 g
s
.49531 .25811 m .49336 .2654 L .45916 .22308 L p .949 .749 .599 r
F P
0 g
s
.45916 .22308 m .46117 .21572 L .49531 .25811 L p .949 .749 .599 r
F P
0 g
s
.50658 .38449 m .50387 .39503 L .46975 .355 L p .951 .749 .595 r
F P
0 g
s
.46975 .355 m .47253 .34427 L .50658 .38449 L p .951 .749 .595 r
F P
0 g
s
.51867 .50795 m .51496 .52292 L .48091 .48657 L p .954 .751 .59 r
F P
0 g
s
.48091 .48657 m .48473 .47105 L .51867 .50795 L p .954 .751 .59 r
F P
0 g
s
.49336 .2654 m .49135 .27293 L .45709 .23068 L p .949 .749 .599 r
F P
0 g
s
.45709 .23068 m .45916 .22308 L .49336 .2654 L p .949 .749 .599 r
F P
0 g
s
.48033 .82629 m .46125 .83257 L .42663 .79962 L p .563 .765 .973 r
F P
0 g
s
.39985 .8053 m .42663 .79962 L .46125 .83257 L p .594 .756 .956 r
F P
0 g
s
.5269 .77641 m .51788 .79415 L .48371 .773 L p .935 .831 .717 r
F P
0 g
s
.48371 .773 m .4929 .75551 L .5269 .77641 L p .935 .831 .717 r
F P
0 g
s
.35487 .81784 m .32439 .82773 L .31939 .82262 L p .652 .754 .925 r
F P
0 g
s
.50387 .39503 m .50105 .40608 L .46684 .36625 L p .951 .749 .594 r
F P
0 g
s
.46684 .36625 m .46975 .355 L .50387 .39503 L p .951 .749 .594 r
F P
0 g
s
.49135 .27293 m .48927 .28072 L .45496 .23855 L p .949 .749 .598 r
F P
0 g
s
.45496 .23855 m .45709 .23068 L .49135 .27293 L p .949 .749 .598 r
F P
0 g
s
.5263 .64528 m .52084 .66633 L .48671 .6383 L p .959 .759 .591 r
F P
0 g
s
.48671 .6383 m .49235 .61537 L .5263 .64528 L p .959 .759 .591 r
F P
0 g
s
.51496 .52292 m .51103 .53888 L .47685 .50321 L p .955 .751 .589 r
F P
0 g
s
.47685 .50321 m .48091 .48657 L .51496 .52292 L p .955 .751 .589 r
F P
0 g
s
.49523 .81885 m .48033 .82629 L .44582 .79625 L p .605 .805 .977 r
F P
0 g
s
.42663 .79962 m .44582 .79625 L .48033 .82629 L p .563 .765 .973 r
F P
0 g
s
.48927 .28072 m .48713 .28878 L .45275 .2467 L p .95 .749 .598 r
F P
0 g
s
.45275 .2467 m .45496 .23855 L .48927 .28072 L p .95 .749 .598 r
F P
0 g
s
.31939 .82262 m .28833 .79123 L p .35487 .81784 L .652 .754 .925 r
F P
0 g
s
.51788 .79415 m .50748 .80843 L .47317 .78525 L p .882 .865 .818 r
F P
0 g
s
.47317 .78525 m .48371 .773 L .51788 .79415 L p .882 .865 .818 r
F P
0 g
s
.50105 .40608 m .4981 .41768 L .4638 .37809 L p .952 .749 .593 r
F P
0 g
s
.4638 .37809 m .46684 .36625 L .50105 .40608 L p .952 .749 .593 r
F P
0 g
s
.50748 .80843 m .49523 .81885 L .46082 .79236 L p .752 .863 .93 r
F P
0 g
s
.44582 .79625 m .46082 .79236 L .49523 .81885 L p .605 .805 .977 r
F P
0 g
s
.46082 .79236 m .47317 .78525 L .50748 .80843 L p .752 .863 .93 r
F P
0 g
s
.48713 .28878 m .48491 .29714 L .45047 .25515 L p .95 .749 .597 r
F P
0 g
s
.45047 .25515 m .45275 .2467 L .48713 .28878 L p .95 .749 .597 r
F P
0 g
s
.51103 .53888 m .50684 .55597 L .47253 .52112 L p .956 .751 .587 r
F P
0 g
s
.47253 .52112 m .47685 .50321 L .51103 .53888 L p .956 .751 .587 r
F P
0 g
s
.39985 .8053 m .35487 .81784 L .31903 .78118 L p .62 .75 .94 r
F P
0 g
s
.28833 .79123 m .31903 .78118 L .35487 .81784 L p .652 .754 .925 r
F P
0 g
s
.52084 .66633 m .51487 .68854 L .48054 .66278 L p .96 .763 .594 r
F P
0 g
s
.48054 .66278 m .48671 .6383 L .52084 .66633 L p .96 .763 .594 r
F P
0 g
s
.4981 .41768 m .495 .42991 L .46061 .39059 L p .952 .749 .592 r
F P
0 g
s
.46061 .39059 m .4638 .37809 L .4981 .41768 L p .952 .749 .592 r
F P
0 g
s
.48491 .29714 m .48262 .30582 L .44811 .26392 L p .95 .749 .597 r
F P
0 g
s
.44811 .26392 m .45047 .25515 L .48491 .29714 L p .95 .749 .597 r
F P
0 g
s
.48262 .30582 m .48024 .31484 L .44566 .27305 L p .95 .749 .596 r
F P
0 g
s
.44566 .27305 m .44811 .26392 L .48262 .30582 L p .95 .749 .596 r
F P
0 g
s
.495 .42991 m .49176 .44282 L .45727 .40381 L p .953 .749 .591 r
F P
0 g
s
.45727 .40381 m .46061 .39059 L .495 .42991 L p .953 .749 .591 r
F P
0 g
s
.50684 .55597 m .50236 .57432 L .4679 .54049 L p .956 .751 .586 r
F P
0 g
s
.4679 .54049 m .47253 .52112 L .50684 .55597 L p .956 .751 .586 r
F P
0 g
s
.48024 .31484 m .47777 .32423 L .44312 .28257 L p .95 .749 .596 r
F P
0 g
s
.44312 .28257 m .44566 .27305 L .48024 .31484 L p .95 .749 .596 r
F P
0 g
s
.51487 .68854 m .50831 .71149 L .47377 .68834 L p .961 .769 .6 r
F P
0 g
s
.47377 .68834 m .48054 .66278 L .51487 .68854 L p .961 .769 .6 r
F P
0 g
s
.46685 .19497 m .46501 .20168 L .43023 .1581 L p .949 .749 .599 r
F P
0 g
s
.43023 .1581 m .43212 .15134 L .46685 .19497 L p .949 .749 .599 r
F P
0 g
s
.49176 .44282 m .48834 .4565 L .45374 .41786 L p .953 .749 .59 r
F P
0 g
s
.45374 .41786 m .45727 .40381 L .49176 .44282 L p .953 .749 .59 r
F P
0 g
s
.47777 .32423 m .4752 .33403 L .44048 .2925 L p .951 .749 .595 r
F P
0 g
s
.44048 .2925 m .44312 .28257 L .47777 .32423 L p .951 .749 .595 r
F P
0 g
s
.46501 .20168 m .46312 .20859 L .42828 .16506 L p .949 .749 .599 r
F P
0 g
s
.42828 .16506 m .43023 .1581 L .46501 .20168 L p .949 .749 .599 r
F P
0 g
s
.50236 .57432 m .49754 .59407 L .46292 .56155 L p .958 .752 .584 r
F P
0 g
s
.46292 .56155 m .4679 .54049 L .50236 .57432 L p .958 .752 .584 r
F P
0 g
s
.42663 .79962 m .39985 .8053 L .3643 .76943 L p .55 .737 .963 r
F P
0 g
s
.31903 .78118 m .3643 .76943 L .39985 .8053 L p .62 .75 .94 r
F P
0 g
s
.46312 .20859 m .46117 .21572 L .42628 .17225 L p .949 .749 .599 r
F P
0 g
s
.42628 .17225 m .42828 .16506 L .46312 .20859 L p .949 .749 .599 r
F P
0 g
s
.48834 .4565 m .48473 .47105 L .45002 .43284 L p .954 .749 .589 r
F P
0 g
s
.45002 .43284 m .45374 .41786 L .48834 .4565 L p .954 .749 .589 r
F P
0 g
s
.4752 .33403 m .47253 .34427 L .43773 .30288 L p .951 .749 .595 r
F P
0 g
s
.43773 .30288 m .44048 .2925 L .4752 .33403 L p .951 .749 .595 r
F P
0 g
s
.50831 .71149 m .50103 .73433 L .46628 .71376 L p .961 .78 .614 r
F P
0 g
s
.46628 .71376 m .47377 .68834 L .50831 .71149 L p .961 .78 .614 r
F P
0 g
s
.46117 .21572 m .45916 .22308 L .42421 .17967 L p .949 .749 .598 r
F P
0 g
s
.42421 .17967 m .42628 .17225 L .46117 .21572 L p .949 .749 .598 r
F P
0 g
s
.47253 .34427 m .46975 .355 L .43486 .31376 L p .951 .748 .594 r
F P
0 g
s
.43486 .31376 m .43773 .30288 L .47253 .34427 L p .951 .748 .594 r
F P
0 g
s
.49754 .59407 m .49235 .61537 L .45755 .58453 L p .959 .753 .582 r
F P
0 g
s
.45755 .58453 m .46292 .56155 L .49754 .59407 L p .959 .753 .582 r
F P
0 g
s
.48473 .47105 m .48091 .48657 L .44608 .44888 L p .954 .749 .587 r
F P
0 g
s
.44608 .44888 m .45002 .43284 L .48473 .47105 L p .954 .749 .587 r
F P
0 g
s
.45916 .22308 m .45709 .23068 L .42209 .18734 L p .949 .749 .598 r
F P
0 g
s
.42209 .18734 m .42421 .17967 L .45916 .22308 L p .949 .749 .598 r
F P
0 g
s
.44582 .79625 m .42663 .79962 L .39123 .76559 L p .444 .711 .98 r
F P
0 g
s
.3643 .76943 m .39123 .76559 L .42663 .79962 L p .55 .737 .963 r
F P
0 g
s
.31903 .78118 m .28833 .79123 L .28322 .78601 L p .651 .754 .925 r
F P
0 g
s
.45709 .23068 m .45496 .23855 L .41989 .19527 L p .949 .749 .598 r
F P
0 g
s
.41989 .19527 m .42209 .18734 L .45709 .23068 L p .949 .749 .598 r
F P
0 g
s
.46975 .355 m .46684 .36625 L .43187 .3252 L p .951 .748 .593 r
F P
0 g
s
.43187 .3252 m .43486 .31376 L .46975 .355 L p .951 .748 .593 r
F P
0 g
s
.50103 .73433 m .4929 .75551 L .45793 .7366 L p .957 .802 .648 r
F P
0 g
s
.45793 .7366 m .46628 .71376 L .50103 .73433 L p .957 .802 .648 r
F P
0 g
s
.48091 .48657 m .47685 .50321 L .44189 .46616 L p .955 .749 .585 r
F P
0 g
s
.44189 .46616 m .44608 .44888 L .48091 .48657 L p .955 .749 .585 r
F P
0 g
s
.45496 .23855 m .45275 .2467 L .41762 .20349 L p .95 .749 .597 r
F P
0 g
s
.41762 .20349 m .41989 .19527 L .45496 .23855 L p .95 .749 .597 r
F P
0 g
s
.28322 .78601 m .25148 .75389 L p .31903 .78118 L .651 .754 .925 r
F P
0 g
s
.46684 .36625 m .4638 .37809 L .42874 .33725 L p .952 .748 .592 r
F P
0 g
s
.42874 .33725 m .43187 .3252 L .46684 .36625 L p .952 .748 .592 r
F P
0 g
s
.49235 .61537 m .48671 .6383 L .4517 .60964 L p .96 .754 .581 r
F P
0 g
s
.4517 .60964 m .45755 .58453 L .49235 .61537 L p .96 .754 .581 r
F P
0 g
s
.46082 .79236 m .44582 .79625 L .41048 .76525 L p .382 .71 .986 r
F P
0 g
s
.39123 .76559 m .41048 .76525 L .44582 .79625 L p .444 .711 .98 r
F P
0 g
s
.45275 .2467 m .45047 .25515 L .41527 .21202 L p .95 .749 .597 r
F P
0 g
s
.41527 .21202 m .41762 .20349 L .45275 .2467 L p .95 .749 .597 r
F P
0 g
s
.4929 .75551 m .48371 .773 L .44857 .75361 L p .937 .843 .726 r
F P
0 g
s
.44857 .75361 m .45793 .7366 L .4929 .75551 L p .937 .843 .726 r
F P
0 g
s
.3643 .76943 m .31903 .78118 L .28241 .74365 L p .609 .746 .942 r
F P
0 g
s
.25148 .75389 m .28241 .74365 L .31903 .78118 L p .651 .754 .925 r
F P
0 g
s
.4638 .37809 m .46061 .39059 L .42545 .34998 L p .952 .748 .591 r
F P
0 g
s
.42545 .34998 m .42874 .33725 L .4638 .37809 L p .952 .748 .591 r
F P
0 g
s
.47685 .50321 m .47253 .52112 L .43742 .48486 L p .956 .749 .583 r
F P
0 g
s
.43742 .48486 m .44189 .46616 L .47685 .50321 L p .956 .749 .583 r
F P
0 g
s
.45047 .25515 m .44811 .26392 L .41284 .22089 L p .95 .748 .596 r
F P
0 g
s
.41284 .22089 m .41527 .21202 L .45047 .25515 L p .95 .748 .596 r
F P
0 g
s
.47317 .78525 m .46082 .79236 L .42552 .76549 L p .554 .82 .995 r
F P
0 g
s
.41048 .76525 m .42552 .76549 L .46082 .79236 L p .382 .71 .986 r
F P
0 g
s
.48371 .773 m .47317 .78525 L .43793 .7628 L p .837 .891 .879 r
F P
0 g
s
.43793 .7628 m .44857 .75361 L .48371 .773 L p .837 .891 .879 r
F P
0 g
s
.42552 .76549 m .43793 .7628 L .47317 .78525 L p .554 .82 .995 r
F P
0 g
s
.44811 .26392 m .44566 .27305 L .41032 .23011 L p .95 .748 .596 r
F P
0 g
s
.41032 .23011 m .41284 .22089 L .44811 .26392 L p .95 .748 .596 r
F P
0 g
s
.48671 .6383 m .48054 .66278 L .44531 .63695 L p .962 .757 .581 r
F P
0 g
s
.44531 .63695 m .4517 .60964 L .48671 .6383 L p .962 .757 .581 r
F P
0 g
s
.46061 .39059 m .45727 .40381 L .422 .36348 L p .953 .748 .59 r
F P
0 g
s
.422 .36348 m .42545 .34998 L .46061 .39059 L p .953 .748 .59 r
F P
0 g
s
.47253 .52112 m .4679 .54049 L .43263 .50525 L p .957 .749 .581 r
F P
0 g
s
.43263 .50525 m .43742 .48486 L .47253 .52112 L p .957 .749 .581 r
F P
0 g
s
.44566 .27305 m .44312 .28257 L .40771 .23972 L p .95 .748 .595 r
F P
0 g
s
.40771 .23972 m .41032 .23011 L .44566 .27305 L p .95 .748 .595 r
F P
0 g
s
.43212 .15134 m .43023 .1581 L .39468 .11343 L p .949 .749 .599 r
F P
0 g
s
.39468 .11343 m .39662 .10662 L .43212 .15134 L p .949 .749 .599 r
F P
0 g
s
.45727 .40381 m .45374 .41786 L .41836 .37784 L p .953 .748 .588 r
F P
0 g
s
.41836 .37784 m .422 .36348 L .45727 .40381 L p .953 .748 .588 r
F P
0 g
s
.44312 .28257 m .44048 .2925 L .40499 .24976 L p .95 .748 .595 r
F P
0 g
s
.40499 .24976 m .40771 .23972 L .44312 .28257 L p .95 .748 .595 r
F P
0 g
s
.43023 .1581 m .42828 .16506 L .39268 .12044 L p .949 .749 .599 r
F P
0 g
s
.39268 .12044 m .39468 .11343 L .43023 .1581 L p .949 .749 .599 r
F P
0 g
s
.48054 .66278 m .47377 .68834 L .43827 .66604 L p .964 .763 .584 r
F P
0 g
s
.43827 .66604 m .44531 .63695 L .48054 .66278 L p .964 .763 .584 r
F P
0 g
s
.39123 .76559 m .3643 .76943 L .32796 .73255 L p .506 .716 .966 r
F P
0 g
s
.28241 .74365 m .32796 .73255 L .3643 .76943 L p .609 .746 .942 r
F P
0 g
s
.42828 .16506 m .42628 .17225 L .39062 .12767 L p .949 .749 .599 r
F P
0 g
s
.39062 .12767 m .39268 .12044 L .42828 .16506 L p .949 .749 .599 r
F P
0 g
s
.4679 .54049 m .46292 .56155 L .42747 .52763 L p .958 .749 .578 r
F P
0 g
s
.42747 .52763 m .43263 .50525 L .4679 .54049 L p .958 .749 .578 r
F P
0 g
s
.44048 .2925 m .43773 .30288 L .40215 .26027 L p .951 .748 .594 r
F P
0 g
s
.40215 .26027 m .40499 .24976 L .44048 .2925 L p .951 .748 .594 r
F P
0 g
s
.45374 .41786 m .45002 .43284 L .41452 .3932 L p .954 .747 .586 r
F P
0 g
s
.41452 .3932 m .41836 .37784 L .45374 .41786 L p .954 .747 .586 r
F P
0 g
s
.42628 .17225 m .42421 .17967 L .38849 .13514 L p .949 .749 .598 r
F P
0 g
s
.38849 .13514 m .39062 .12767 L .42628 .17225 L p .949 .749 .598 r
F P
0 g
s
.43773 .30288 m .43486 .31376 L .3992 .27129 L p .951 .748 .593 r
F P
0 g
s
.3992 .27129 m .40215 .26027 L .43773 .30288 L p .951 .748 .593 r
F P
0 g
s
.42421 .17967 m .42209 .18734 L .3863 .14286 L p .949 .749 .598 r
F P
0 g
s
.3863 .14286 m .38849 .13514 L .42421 .17967 L p .949 .749 .598 r
F P
0 g
s
.45002 .43284 m .44608 .44888 L .41045 .40971 L p .954 .747 .584 r
F P
0 g
s
.41045 .40971 m .41452 .3932 L .45002 .43284 L p .954 .747 .584 r
F P
0 g
s
.28241 .74365 m .25148 .75389 L .24626 .74855 L p .651 .753 .925 r
F P
0 g
s
.47377 .68834 m .46628 .71376 L .43049 .69526 L p .965 .774 .596 r
F P
0 g
s
.43049 .69526 m .43827 .66604 L .47377 .68834 L p .965 .774 .596 r
F P
0 g
s
.46292 .56155 m .45755 .58453 L .42188 .55238 L p .96 .749 .575 r
F P
0 g
s
.42188 .55238 m .42747 .52763 L .46292 .56155 L p .96 .749 .575 r
F P
0 g
s
.42209 .18734 m .41989 .19527 L .38404 .15086 L p .949 .748 .597 r
F P
0 g
s
.38404 .15086 m .3863 .14286 L .42209 .18734 L p .949 .748 .597 r
F P
0 g
s
.41048 .76525 m .39123 .76559 L .35501 .73039 L p .299 .632 .963 r
F P
0 g
s
.32796 .73255 m .35501 .73039 L .39123 .76559 L p .506 .716 .966 r
F P
0 g
s
.43486 .31376 m .43187 .3252 L .39612 .28287 L p .951 .748 .592 r
F P
0 g
s
.39612 .28287 m .3992 .27129 L .43486 .31376 L p .951 .748 .592 r
F P
0 g
s
.41989 .19527 m .41762 .20349 L .38171 .15914 L p .949 .748 .597 r
F P
0 g
s
.38171 .15914 m .38404 .15086 L .41989 .19527 L p .949 .748 .597 r
F P
0 g
s
.24626 .74855 m .21382 .71567 L p .28241 .74365 L .651 .753 .925 r
F P
0 g
s
.44608 .44888 m .44189 .46616 L .40612 .42755 L p .955 .747 .582 r
F P
0 g
s
.40612 .42755 m .41045 .40971 L .44608 .44888 L p .955 .747 .582 r
F P
0 g
s
.43187 .3252 m .42874 .33725 L .39289 .29509 L p .952 .747 .591 r
F P
0 g
s
.39289 .29509 m .39612 .28287 L .43187 .3252 L p .952 .747 .591 r
F P
0 g
s
.41762 .20349 m .41527 .21202 L .37929 .16773 L p .95 .748 .597 r
F P
0 g
s
.37929 .16773 m .38171 .15914 L .41762 .20349 L p .95 .748 .597 r
F P
0 g
s
.32796 .73255 m .28241 .74365 L .24497 .70524 L p .6 .741 .943 r
F P
0 g
s
.21382 .71567 m .24497 .70524 L .28241 .74365 L p .651 .753 .925 r
F P
0 g
s
.46628 .71376 m .45793 .7366 L .42189 .72068 L p .963 .799 .632 r
F P
0 g
s
.42189 .72068 m .43049 .69526 L .46628 .71376 L p .963 .799 .632 r
F P
0 g
s
.42552 .76549 m .41048 .76525 L .37429 .73308 L p .027 .49 .879 r
F P
0 g
s
.35501 .73039 m .37429 .73308 L .41048 .76525 L p .299 .632 .963 r
F P
0 g
s
.45755 .58453 m .4517 .60964 L .41579 .57995 L p .961 .75 .571 r
F P
0 g
s
.41579 .57995 m .42188 .55238 L .45755 .58453 L p .961 .75 .571 r
F P
0 g
s
.42874 .33725 m .42545 .34998 L .3895 .30801 L p .952 .747 .59 r
F P
0 g
s
.3895 .30801 m .39289 .29509 L .42874 .33725 L p .952 .747 .59 r
F P
0 g
s
.41527 .21202 m .41284 .22089 L .37679 .17667 L p .95 .748 .596 r
F P
0 g
s
.37679 .17667 m .37929 .16773 L .41527 .21202 L p .95 .748 .596 r
F P
0 g
s
.44189 .46616 m .43742 .48486 L .40149 .44698 L p .956 .746 .579 r
F P
0 g
s
.40149 .44698 m .40612 .42755 L .44189 .46616 L p .956 .746 .579 r
F P
0 g
s
.41284 .22089 m .41032 .23011 L .37419 .18596 L p .95 .748 .595 r
F P
0 g
s
.37419 .18596 m .37679 .17667 L .41284 .22089 L p .95 .748 .595 r
F P
0 g
s
.42545 .34998 m .422 .36348 L .38594 .32174 L p .953 .747 .588 r
F P
0 g
s
.38594 .32174 m .3895 .30801 L .42545 .34998 L p .953 .747 .588 r
F P
0 g
s
.43793 .7628 m .42552 .76549 L .38931 .738 L p .023 .524 .872 r
F P
0 g
s
.37429 .73308 m .38931 .738 L .42552 .76549 L p .027 .49 .879 r
F P
0 g
s
.45793 .7366 m .44857 .75361 L .41236 .73675 L p .937 .862 .741 r
F P
0 g
s
.41236 .73675 m .42189 .72068 L .45793 .7366 L p .937 .862 .741 r
F P
0 g
s
.41032 .23011 m .40771 .23972 L .3715 .19566 L p .95 .748 .595 r
F P
0 g
s
.3715 .19566 m .37419 .18596 L .41032 .23011 L p .95 .748 .595 r
F P
0 g
s
.39662 .10662 m .39468 .11343 L .35834 .06762 L p .949 .749 .599 r
F P
0 g
s
.35834 .06762 m .36034 .06078 L .39662 .10662 L p .949 .749 .599 r
F P
0 g
s
.4517 .60964 m .44531 .63695 L .40911 .61071 L p .963 .751 .568 r
F P
0 g
s
.40911 .61071 m .41579 .57995 L .4517 .60964 L p .963 .751 .568 r
F P
0 g
s
.43742 .48486 m .43263 .50525 L .39652 .4683 L p .957 .746 .576 r
F P
0 g
s
.39652 .4683 m .40149 .44698 L .43742 .48486 L p .957 .746 .576 r
F P
0 g
s
.44857 .75361 m .43793 .7628 L .40169 .74118 L p .661 .895 .98 r
F P
0 g
s
.38931 .738 m .40169 .74118 L .43793 .7628 L p .023 .524 .872 r
F P
0 g
s
.40169 .74118 m .41236 .73675 L .44857 .75361 L p .661 .895 .98 r
F P
0 g
s
.422 .36348 m .41836 .37784 L .38219 .33636 L p .953 .747 .587 r
F P
0 g
s
.38219 .33636 m .38594 .32174 L .422 .36348 L p .953 .747 .587 r
F P
0 g
s
.40771 .23972 m .40499 .24976 L .3687 .20578 L p .95 .748 .594 r
F P
0 g
s
.3687 .20578 m .3715 .19566 L .40771 .23972 L p .95 .748 .594 r
F P
0 g
s
.39468 .11343 m .39268 .12044 L .35628 .07467 L p .949 .749 .599 r
F P
0 g
s
.35628 .07467 m .35834 .06762 L .39468 .11343 L p .949 .749 .599 r
F P
0 g
s
.35501 .73039 m .32796 .73255 L .29081 .69462 L p .464 .694 .967 r
F P
0 g
s
.24497 .70524 m .29081 .69462 L .32796 .73255 L p .6 .741 .943 r
F P
0 g
s
.39268 .12044 m .39062 .12767 L .35416 .08195 L p .949 .748 .599 r
F P
0 g
s
.35416 .08195 m .35628 .07467 L .39268 .12044 L p .949 .748 .599 r
F P
0 g
s
.40499 .24976 m .40215 .26027 L .36578 .21638 L p .951 .747 .593 r
F P
0 g
s
.36578 .21638 m .3687 .20578 L .40499 .24976 L p .951 .747 .593 r
F P
0 g
s
.41836 .37784 m .41452 .3932 L .37822 .35203 L p .954 .746 .585 r
F P
0 g
s
.37822 .35203 m .38219 .33636 L .41836 .37784 L p .954 .746 .585 r
F P
0 g
s
.39062 .12767 m .38849 .13514 L .35197 .08946 L p .949 .748 .598 r
F P
0 g
s
.35197 .08946 m .35416 .08195 L .39062 .12767 L p .949 .748 .598 r
F P
0 g
s
.43263 .50525 m .42747 .52763 L .39116 .49194 L p .959 .746 .573 r
F P
0 g
s
.39116 .49194 m .39652 .4683 L .43263 .50525 L p .959 .746 .573 r
F P
0 g
s
.40215 .26027 m .3992 .27129 L .36274 .22751 L p .951 .747 .592 r
F P
0 g
s
.36274 .22751 m .36578 .21638 L .40215 .26027 L p .951 .747 .592 r
F P
0 g
s
.44531 .63695 m .43827 .66604 L .40173 .64456 L p .966 .755 .568 r
F P
0 g
s
.40173 .64456 m .40911 .61071 L .44531 .63695 L p .966 .755 .568 r
F P
0 g
s
.38849 .13514 m .3863 .14286 L .34972 .09722 L p .949 .748 .598 r
F P
0 g
s
.34972 .09722 m .35197 .08946 L .38849 .13514 L p .949 .748 .598 r
F P
0 g
s
.24497 .70524 m .21382 .71567 L .20848 .71021 L p .651 .753 .925 r
F P
0 g
s
.41452 .3932 m .41045 .40971 L .37401 .36892 L p .954 .746 .583 r
F P
0 g
s
.37401 .36892 m .37822 .35203 L .41452 .3932 L p .954 .746 .583 r
F P
0 g
s
.3863 .14286 m .38404 .15086 L .3474 .10526 L p .949 .748 .597 r
F P
0 g
s
.3474 .10526 m .34972 .09722 L .3863 .14286 L p .949 .748 .597 r
F P
0 g
s
.3992 .27129 m .39612 .28287 L .35956 .23921 L p .951 .747 .591 r
F P
0 g
s
.35956 .23921 m .36274 .22751 L .3992 .27129 L p .951 .747 .591 r
F P
0 g
s
.37429 .73308 m .35501 .73039 L .31796 .69392 L p .142 .532 .92 r
F P
0 g
s
.29081 .69462 m .31796 .69392 L .35501 .73039 L p .464 .694 .967 r
F P
0 g
s
.42747 .52763 m .42188 .55238 L .38534 .51846 L p .96 .745 .568 r
F P
0 g
s
.38534 .51846 m .39116 .49194 L .42747 .52763 L p .96 .745 .568 r
F P
0 g
s
.38404 .15086 m .38171 .15914 L .34499 .11359 L p .949 .748 .597 r
F P
0 g
s
.34499 .11359 m .3474 .10526 L .38404 .15086 L p .949 .748 .597 r
F P
0 g
s
.20848 .71021 m .17531 .67654 L p .24497 .70524 L .651 .753 .925 r
F P
0 g
s
.39612 .28287 m .39289 .29509 L .35623 .25156 L p .951 .747 .59 r
F P
0 g
s
.35623 .25156 m .35956 .23921 L .39612 .28287 L p .951 .747 .59 r
F P
0 g
s
.41045 .40971 m .40612 .42755 L .36953 .38723 L p .955 .745 .58 r
F P
0 g
s
.36953 .38723 m .37401 .36892 L .41045 .40971 L p .955 .745 .58 r
F P
0 g
s
.38171 .15914 m .37929 .16773 L .34251 .12224 L p .949 .748 .597 r
F P
0 g
s
.34251 .12224 m .34499 .11359 L .38171 .15914 L p .949 .748 .597 r
F P
0 g
s
.43827 .66604 m .43049 .69526 L .39357 .67961 L p .968 .764 .574 r
F P
0 g
s
.39357 .67961 m .40173 .64456 L .43827 .66604 L p .968 .764 .574 r
F P
0 g
s
.29081 .69462 m .24497 .70524 L .2067 .6659 L p .593 .737 .944 r
F P
0 g
s
.17531 .67654 m .2067 .6659 L .24497 .70524 L p .651 .753 .925 r
F P
0 g
s
.37929 .16773 m .37679 .17667 L .33993 .13122 L p .95 .748 .596 r
F P
0 g
s
.33993 .13122 m .34251 .12224 L .37929 .16773 L p .95 .748 .596 r
F P
0 g
s
.39289 .29509 m .3895 .30801 L .35274 .26463 L p .952 .746 .589 r
F P
0 g
s
.35274 .26463 m .35623 .25156 L .39289 .29509 L p .952 .746 .589 r
F P
0 g
s
.35956 .71971 m .33724 .69948 L p .36823 .72241 L 0 .186 .636 r
F P
0 g
s
.40169 .74118 m .38931 .738 L .36908 .72247 L p .589 .033 0 r
F P
0 g
s
.36908 .72247 m .35216 .70948 L p .37575 .72458 L .589 .033 0 r
F P
0 g
s
.37575 .72458 m .40169 .74118 L .36908 .72247 L .589 .033 0 r
F
.35216 .70948 m .33724 .69948 L .29931 .66416 L p .589 .06 0 r
F P
0 g
s
.29931 .66416 m .33724 .69948 L p .33198 .69549 L .001 .431 .861 r
F P
0 g
s
.28006 .65607 m .29931 .66416 L p .33198 .69549 L .001 .431 .861 r
F P
0 g
s
.2605 .62683 m .29931 .66416 L p .29446 .6602 L 0 .347 .805 r
F P
0 g
s
.24129 .61674 m .2605 .62683 L p .29446 .6602 L 0 .347 .805 r
F P
0 g
s
.22082 .58719 m .2605 .62683 L p .25583 .62278 L 0 .296 .77 r
F P
0 g
s
.20164 .57584 m .22082 .58719 L p .25583 .62278 L 0 .296 .77 r
F P
0 g
s
.16109 .53331 m .18026 .54504 L .22082 .58719 L p 0 .284 .765 r
F P
0 g
s
.22082 .58719 m .18026 .54504 L p .18579 .5516 L .765 .291 0 r
F P
0 g
s
.2605 .62683 m .24129 .61674 L .20164 .57584 L p 0 .296 .77 r
F P
0 g
s
.22082 .58719 m .20164 .57584 L .16109 .53331 L p 0 .284 .765 r
F P
0 g
s
.23514 .61004 m .22082 .58719 L p .18579 .5516 L .765 .291 0 r
F P
0 g
s
.2605 .62683 m .22082 .58719 L p .22658 .59349 L .76 .276 0 r
F P
0 g
s
.29931 .66416 m .28006 .65607 L .24129 .61674 L p 0 .347 .805 r
F P
0 g
s
.27504 .64647 m .2605 .62683 L p .22658 .59349 L .76 .276 0 r
F P
0 g
s
.29931 .66416 m .2605 .62683 L p .26675 .63295 L .71 .206 0 r
F P
0 g
s
.31407 .67926 m .29931 .66416 L p .26675 .63295 L .71 .206 0 r
F P
0 g
s
.35216 .70948 m .31407 .67926 L p .32729 .69006 L .822 .344 0 r
F P
0 g
s
.33724 .69948 m .35216 .70948 L p .36541 .71982 L 0 .186 .636 r
F P
0 g
s
.33724 .69948 m .36908 .72247 L .36823 .72241 L 0 .186 .636 r
F
.36438 .72034 m .35216 .70948 L p .32729 .69006 L .822 .344 0 r
F P
0 g
s
.35216 .70948 m .36908 .72247 L p .36541 .71982 L 0 .186 .636 r
F P
0 g
s
.36908 .72247 m .38931 .738 L p .36823 .72241 L 0 .186 .636 r
F P
0 g
s
.36823 .72241 m .38931 .738 L .35956 .71971 L 0 .186 .636 r
F
.36438 .72034 m .40169 .74118 L p .39643 .73782 L .589 .033 0 r
F P
0 g
s
.35216 .70948 m .36438 .72034 L p .39643 .73782 L .589 .033 0 r
F P
0 g
s
.31796 .69392 m .33724 .69948 L .37429 .73308 L p .142 .532 .92 r
F P
0 g
s
.33724 .69948 m .31796 .69392 L .28006 .65607 L p .001 .431 .861 r
F P
0 g
s
.31407 .67926 m .32596 .69975 L .36438 .72034 L p .822 .344 0 r
F P
0 g
s
.36438 .72034 m .32596 .69975 L p .33211 .70274 L .815 .335 .043 r
F P
0 g
s
.33211 .70274 m .36844 .72046 L .36438 .72034 L .815 .335 .043 r
F
.37496 .72364 m .37187 .72267 L p .36844 .72046 L F P
0 g
s
.37187 .72267 m .36438 .72034 L p .36844 .72046 L .815 .335 .043 r
F P
0 g
s
.37496 .72364 m .39515 .73071 L p .39091 .72928 L 0 .394 .701 r
F P
0 g
s
.37113 .72262 m .37496 .72364 L .39091 .72928 L 0 .394 .701 r
F
.36438 .72034 m .37185 .72267 L p .37113 .72262 L F P
0 g
s
.37185 .72267 m .37496 .72364 L p .37113 .72262 L 0 .394 .701 r
F P
0 g
s
.36438 .72034 m .39515 .73071 L .39432 .73045 L 0 .394 .701 r
F
.36438 .72034 m .39653 .7312 L .39217 .72984 L F
.38931 .738 m .37429 .73308 L .35956 .71971 L p 0 .186 .636 r
F P
0 g
s
.41236 .73675 m .40169 .74118 L .36438 .72034 L p 0 .394 .701 r
F P
0 g
s
.31796 .69392 m .29081 .69462 L .25281 .6556 L p .429 .674 .965 r
F P
0 g
s
.2067 .6659 m .25281 .6556 L .29081 .69462 L p .593 .737 .944 r
F P
0 g
s
.28642 .67776 m .29569 .71666 L .33616 .71611 L p .915 .536 .286 r
F P
0 g
s
.33616 .71611 m .29569 .71666 L p .30851 .71394 L .229 0 0 r
F P
0 g
s
.33279 .70308 m .33616 .71611 L .36399 .71829 L .815 .335 .043 r
F
.32596 .69975 m .32907 .70474 L p .33279 .70308 L F P
0 g
s
.32907 .70474 m .33616 .71611 L p .33279 .70308 L .815 .335 .043 r
F P
0 g
s
.32596 .69975 m .28642 .67776 L p .32515 .70762 L .915 .536 .286 r
F P
0 g
s
.33616 .71611 m .32907 .70474 L p .32515 .70762 L .915 .536 .286 r
F P
0 g
s
.32907 .70474 m .32596 .69975 L p .32515 .70762 L .915 .536 .286 r
F P
0 g
s
.34588 .70602 m .33616 .71611 L p .30851 .71394 L .229 0 0 r
F P
0 g
s
.31557 .7145 m .3159 .7144 L p .30851 .71394 L .229 0 0 r
F P
0 g
s
.30516 .71741 m .31557 .7145 L p .30851 .71394 L .229 0 0 r
F P
0 g
s
.3159 .7144 m .34588 .70602 L p .31978 .71155 L .229 0 0 r
F P
0 g
s
.30851 .71394 m .3159 .7144 L .31978 .71155 L .229 0 0 r
F
.29569 .71666 m .30143 .71711 L p .30851 .71394 L F P
0 g
s
.30143 .71711 m .30516 .71741 L p .30851 .71394 L .229 0 0 r
F P
0 g
s
.33616 .71611 m .37496 .72364 L p .36399 .71829 L .815 .335 .043 r
F P
0 g
s
.33616 .71611 m .34879 .71437 L .37496 .72364 L .877 .967 .849 r
F
.38462 .70943 m .37496 .72364 L p .34879 .71437 L F P
0 g
s
.33616 .71611 m .34588 .70602 L .34612 .70604 L p .877 .967 .849 r
F P
0 g
s
.29931 .66416 m .31407 .67926 L .35216 .70948 L p .589 .06 0 r
F P
0 g
s
.34612 .70604 m .38462 .70943 L p .35721 .71321 L .877 .967 .849 r
F P
0 g
s
.33616 .71611 m .34612 .70604 L .35721 .71321 L .877 .967 .849 r
F
.39515 .73071 m .39653 .7312 L p .39432 .73045 L 0 .394 .701 r
F P
0 g
s
.39653 .7312 m .41236 .73675 L p .39217 .72984 L 0 .394 .701 r
F P
0 g
s
.42188 .55238 m .41579 .57995 L .37897 .5486 L p .962 .745 .563 r
F P
0 g
s
.37897 .5486 m .38534 .51846 L .42188 .55238 L p .962 .745 .563 r
F P
0 g
s
.40612 .42755 m .40149 .44698 L .36473 .40725 L p .956 .744 .577 r
F P
0 g
s
.36473 .40725 m .36953 .38723 L .40612 .42755 L p .956 .744 .577 r
F P
0 g
s
.37679 .17667 m .37419 .18596 L .33726 .14058 L p .95 .748 .595 r
F P
0 g
s
.33726 .14058 m .33993 .13122 L .37679 .17667 L p .95 .748 .595 r
F P
0 g
s
.3895 .30801 m .38594 .32174 L .34907 .27851 L p .952 .746 .588 r
F P
0 g
s
.34907 .27851 m .35274 .26463 L .3895 .30801 L p .952 .746 .588 r
F P
0 g
s
.37419 .18596 m .3715 .19566 L .33449 .15033 L p .95 .747 .595 r
F P
0 g
s
.33449 .15033 m .33726 .14058 L .37419 .18596 L p .95 .747 .595 r
F P
0 g
s
.43049 .69526 m .42189 .72068 L .38462 .70943 L p .97 .793 .608 r
F P
0 g
s
.38462 .70943 m .39357 .67961 L .43049 .69526 L p .97 .793 .608 r
F P
0 g
s
.40149 .44698 m .39652 .4683 L .35958 .42936 L p .957 .744 .573 r
F P
0 g
s
.35958 .42936 m .36473 .40725 L .40149 .44698 L p .957 .744 .573 r
F P
0 g
s
.38594 .32174 m .38219 .33636 L .34519 .29334 L p .953 .746 .586 r
F P
0 g
s
.34519 .29334 m .34907 .27851 L .38594 .32174 L p .953 .746 .586 r
F P
0 g
s
.3715 .19566 m .3687 .20578 L .3316 .16052 L p .95 .747 .594 r
F P
0 g
s
.3316 .16052 m .33449 .15033 L .3715 .19566 L p .95 .747 .594 r
F P
0 g
s
.41579 .57995 m .40911 .61071 L .37194 .58331 L p .964 .745 .557 r
F P
0 g
s
.37194 .58331 m .37897 .5486 L .41579 .57995 L p .964 .745 .557 r
F P
0 g
s
.3687 .20578 m .36578 .21638 L .3286 .17119 L p .95 .747 .593 r
F P
0 g
s
.3286 .17119 m .3316 .16052 L .3687 .20578 L p .95 .747 .593 r
F P
0 g
s
.38219 .33636 m .37822 .35203 L .34109 .30923 L p .953 .745 .584 r
F P
0 g
s
.34109 .30923 m .34519 .29334 L .38219 .33636 L p .953 .745 .584 r
F P
0 g
s
.42189 .72068 m .41236 .73675 L .37496 .72364 L p .931 .896 .771 r
F P
0 g
s
.37496 .72364 m .38462 .70943 L .42189 .72068 L p .931 .896 .771 r
F P
0 g
s
.39652 .4683 m .39116 .49194 L .354 .45407 L p .959 .743 .569 r
F P
0 g
s
.354 .45407 m .35958 .42936 L .39652 .4683 L p .959 .743 .569 r
F P
0 g
s
.36578 .21638 m .36274 .22751 L .32546 .18238 L p .951 .747 .592 r
F P
0 g
s
.32546 .18238 m .3286 .17119 L .36578 .21638 L p .951 .747 .592 r
F P
0 g
s
.2067 .6659 m .17531 .67654 L .16985 .67096 L p .65 .753 .924 r
F P
0 g
s
.37822 .35203 m .37401 .36892 L .33674 .32639 L p .954 .744 .582 r
F P
0 g
s
.33674 .32639 m .34109 .30923 L .37822 .35203 L p .954 .744 .582 r
F P
0 g
s
.36274 .22751 m .35956 .23921 L .32219 .19417 L p .951 .746 .591 r
F P
0 g
s
.32219 .19417 m .32546 .18238 L .36274 .22751 L p .951 .746 .591 r
F P
0 g
s
.25281 .6556 m .28006 .65607 L .31796 .69392 L p .429 .674 .965 r
F P
0 g
s
.40911 .61071 m .40173 .64456 L .36411 .62341 L p .967 .746 .551 r
F P
0 g
s
.36411 .62341 m .37194 .58331 L .40911 .61071 L p .967 .746 .551 r
F P
0 g
s
.16985 .67096 m .13594 .63647 L p .2067 .6659 L .65 .753 .924 r
F P
0 g
s
.35956 .23921 m .35623 .25156 L .31876 .2066 L p .951 .746 .59 r
F P
0 g
s
.31876 .2066 m .32219 .19417 L .35956 .23921 L p .951 .746 .59 r
F P
0 g
s
.39116 .49194 m .38534 .51846 L .34793 .48215 L p .96 .742 .563 r
F P
0 g
s
.34793 .48215 m .354 .45407 L .39116 .49194 L p .96 .742 .563 r
F P
0 g
s
.37401 .36892 m .36953 .38723 L .33211 .34504 L p .955 .744 .579 r
F P
0 g
s
.33211 .34504 m .33674 .32639 L .37401 .36892 L p .955 .744 .579 r
F P
0 g
s
.25281 .6556 m .2067 .6659 L .16755 .6256 L p .588 .734 .944 r
F P
0 g
s
.13594 .63647 m .16755 .6256 L .2067 .6659 L p .65 .753 .924 r
F P
0 g
s
.35623 .25156 m .35274 .26463 L .31516 .21976 L p .952 .746 .589 r
F P
0 g
s
.31516 .21976 m .31876 .2066 L .35623 .25156 L p .952 .746 .589 r
F P
0 g
s
.36953 .38723 m .36473 .40725 L .32714 .36548 L p .956 .743 .575 r
F P
0 g
s
.32714 .36548 m .33211 .34504 L .36953 .38723 L p .956 .743 .575 r
F P
0 g
s
.35274 .26463 m .34907 .27851 L .31137 .23375 L p .952 .745 .587 r
F P
0 g
s
.31137 .23375 m .31516 .21976 L .35274 .26463 L p .952 .745 .587 r
F P
0 g
s
.40173 .64456 m .39357 .67961 L .35538 .66772 L p .971 .752 .55 r
F P
0 g
s
.35538 .66772 m .36411 .62341 L .40173 .64456 L p .971 .752 .55 r
F P
0 g
s
.38534 .51846 m .37897 .5486 L .34125 .5147 L p .962 .74 .556 r
F P
0 g
s
.34125 .5147 m .34793 .48215 L .38534 .51846 L p .962 .74 .556 r
F P
0 g
s
.34907 .27851 m .34519 .29334 L .30737 .24869 L p .952 .745 .586 r
F P
0 g
s
.30737 .24869 m .31137 .23375 L .34907 .27851 L p .952 .745 .586 r
F P
0 g
s
.36473 .40725 m .35958 .42936 L .32179 .38815 L p .957 .742 .571 r
F P
0 g
s
.32179 .38815 m .32714 .36548 L .36473 .40725 L p .957 .742 .571 r
F P
0 g
s
.28006 .65607 m .25281 .6556 L .21395 .61543 L p .402 .656 .962 r
F P
0 g
s
.16755 .6256 m .21395 .61543 L .25281 .6556 L p .588 .734 .944 r
F P
0 g
s
.34519 .29334 m .34109 .30923 L .30314 .26472 L p .953 .744 .584 r
F P
0 g
s
.30314 .26472 m .30737 .24869 L .34519 .29334 L p .953 .744 .584 r
F P
0 g
s
.37897 .5486 m .37194 .58331 L .33381 .55344 L p .964 .738 .547 r
F P
0 g
s
.33381 .55344 m .34125 .5147 L .37897 .5486 L p .964 .738 .547 r
F P
0 g
s
.39357 .67961 m .38462 .70943 L .34588 .70602 L p .975 .779 .575 r
F P
0 g
s
.34588 .70602 m .35538 .66772 L .39357 .67961 L p .975 .779 .575 r
F P
0 g
s
.35958 .42936 m .354 .45407 L .316 .41363 L p .958 .74 .566 r
F P
0 g
s
.316 .41363 m .32179 .38815 L .35958 .42936 L p .958 .74 .566 r
F P
0 g
s
.16755 .6256 m .13594 .63647 L .13035 .63077 L p .65 .752 .924 r
F P
0 g
s
.34109 .30923 m .33674 .32639 L .29864 .28203 L p .954 .743 .581 r
F P
0 g
s
.29864 .28203 m .30314 .26472 L .34109 .30923 L p .954 .743 .581 r
F P
0 g
s
.13035 .63077 m .09566 .59544 L p .16755 .6256 L .65 .752 .924 r
F P
0 g
s
.21395 .61543 m .24129 .61674 L .28006 .65607 L p .402 .656 .962 r
F P
0 g
s
.33674 .32639 m .33211 .34504 L .29385 .30086 L p .954 .743 .578 r
F P
0 g
s
.29385 .30086 m .29864 .28203 L .33674 .32639 L p .954 .743 .578 r
F P
0 g
s
.354 .45407 m .34793 .48215 L .30966 .44284 L p .96 .739 .56 r
F P
0 g
s
.30966 .44284 m .316 .41363 L .354 .45407 L p .96 .739 .56 r
F P
0 g
s
.21395 .61543 m .16755 .6256 L .12751 .58433 L p .585 .731 .944 r
F P
0 g
s
.09566 .59544 m .12751 .58433 L .16755 .6256 L p .65 .752 .924 r
F P
0 g
s
.37194 .58331 m .36411 .62341 L .3254 .60099 L p .967 .737 .537 r
F P
0 g
s
.3254 .60099 m .33381 .55344 L .37194 .58331 L p .967 .737 .537 r
F P
0 g
s
.33211 .34504 m .32714 .36548 L .28871 .32152 L p .955 .742 .575 r
F P
0 g
s
.28871 .32152 m .29385 .30086 L .33211 .34504 L p .955 .742 .575 r
F P
0 g
s
.34793 .48215 m .34125 .5147 L .30266 .47719 L p .961 .736 .552 r
F P
0 g
s
.30266 .47719 m .30966 .44284 L .34793 .48215 L p .961 .736 .552 r
F P
0 g
s
.32714 .36548 m .32179 .38815 L .28317 .34446 L p .956 .74 .571 r
F P
0 g
s
.28317 .34446 m .28871 .32152 L .32714 .36548 L p .956 .74 .571 r
F P
0 g
s
.24129 .61674 m .21395 .61543 L .1742 .57409 L p .387 .645 .959 r
F P
0 g
s
.12751 .58433 m .1742 .57409 L .21395 .61543 L p .585 .731 .944 r
F P
0 g
s
.36411 .62341 m .35538 .66772 L .31576 .65984 L p .971 .737 .527 r
F P
0 g
s
.31576 .65984 m .3254 .60099 L .36411 .62341 L p .971 .737 .527 r
F P
0 g
s
.32596 .69975 m .31407 .67926 L .27504 .64647 L p .895 .473 .146 r
F P
0 g
s
.2605 .62683 m .27504 .64647 L .31407 .67926 L p .71 .206 0 r
F P
0 g
s
.32179 .38815 m .316 .41363 L .27716 .37031 L p .957 .739 .566 r
F P
0 g
s
.27716 .37031 m .28317 .34446 L .32179 .38815 L p .957 .739 .566 r
F P
0 g
s
.12751 .58433 m .09566 .59544 L .08995 .5896 L p .65 .752 .924 r
F P
0 g
s
.34125 .5147 m .33381 .55344 L .29478 .51918 L p .964 .733 .542 r
F P
0 g
s
.29478 .51918 m .30266 .47719 L .34125 .5147 L p .964 .733 .542 r
F P
0 g
s
.08995 .5896 m .05446 .5534 L p .12751 .58433 L .65 .752 .924 r
F P
0 g
s
.1742 .57409 m .20164 .57584 L .24129 .61674 L p .387 .645 .959 r
F P
0 g
s
.1742 .57409 m .12751 .58433 L .08654 .54203 L p .584 .73 .943 r
F P
0 g
s
.05446 .5534 m .08654 .54203 L .12751 .58433 L p .65 .752 .924 r
F P
0 g
s
.316 .41363 m .30966 .44284 L .27057 .40002 L p .959 .736 .559 r
F P
0 g
s
.27057 .40002 m .27716 .37031 L .316 .41363 L p .959 .736 .559 r
F P
0 g
s
.27504 .64647 m .28642 .67776 L .32596 .69975 L p .895 .473 .146 r
F P
0 g
s
.35538 .66772 m .34588 .70602 L .30516 .71741 L p .978 .755 .534 r
F P
0 g
s
.30516 .71741 m .31576 .65984 L .35538 .66772 L p .978 .755 .534 r
F P
0 g
s
.33381 .55344 m .3254 .60099 L .2857 .5737 L p .966 .729 .528 r
F P
0 g
s
.2857 .5737 m .29478 .51918 L .33381 .55344 L p .966 .729 .528 r
F P
0 g
s
.30966 .44284 m .30266 .47719 L .26326 .43516 L p .96 .734 .551 r
F P
0 g
s
.26326 .43516 m .27057 .40002 L .30966 .44284 L p .96 .734 .551 r
F P
0 g
s
.20164 .57584 m .1742 .57409 L .13354 .53153 L p .384 .639 .956 r
F P
0 g
s
.08654 .54203 m .13354 .53153 L .1742 .57409 L p .584 .73 .943 r
F P
0 g
s
.28642 .67776 m .27504 .64647 L .23514 .61004 L p .921 .529 .208 r
F P
0 g
s
.22082 .58719 m .23514 .61004 L .27504 .64647 L p .76 .276 0 r
F P
0 g
s
.3254 .60099 m .31576 .65984 L .27475 .65177 L p .97 .724 .509 r
F P
0 g
s
.27475 .65177 m .2857 .5737 L .3254 .60099 L p .97 .724 .509 r
F P
0 g
s
.30266 .47719 m .29478 .51918 L .25499 .47856 L p .962 .73 .54 r
F P
0 g
s
.25499 .47856 m .26326 .43516 L .30266 .47719 L p .962 .73 .54 r
F P
0 g
s
.13354 .53153 m .16109 .53331 L .20164 .57584 L p .384 .639 .956 r
F P
0 g
s
.29478 .51918 m .2857 .5737 L .24533 .53628 L p .964 .724 .525 r
F P
0 g
s
.24533 .53628 m .25499 .47856 L .29478 .51918 L p .964 .724 .525 r
F P
0 g
s
.29569 .71666 m .28642 .67776 L .24591 .65083 L p .939 .604 .367 r
F P
0 g
s
.23514 .61004 m .24591 .65083 L .28642 .67776 L p .921 .529 .208 r
F P
0 g
s
.29569 .71666 m .25332 .72501 L p .29217 .71931 L .887 .524 .351 r
F P
0 g
s
.30516 .71741 m .30098 .71708 L p .29217 .71931 L .887 .524 .351 r
F P
0 g
s
.30098 .71708 m .29569 .71666 L p .29217 .71931 L .887 .524 .351 r
F P
0 g
s
.26117 .7636 m .25332 .72501 L .21029 .71388 L p .937 .629 .433 r
F P
0 g
s
.21029 .71388 m .21162 .87199 L .26117 .7636 L p .937 .629 .433 r
F P
0 g
s
.26117 .7636 m .21162 .87199 L p .25251 .72936 L .969 .702 .47 r
F P
0 g
s
.24591 .65083 m .25332 .72501 L .29569 .71666 L p .939 .604 .367 r
F P
0 g
s
.25332 .72501 m .26117 .7636 L .30516 .71741 L p .887 .524 .351 r
F P
0 g
s
.27475 .65177 m .26573 .72601 L p .25251 .72936 L .969 .702 .47 r
F P
0 g
s
.26573 .72601 m .26117 .7636 L p .25251 .72936 L .969 .702 .47 r
F P
0 g
s
.31576 .65984 m .30516 .71741 L .26117 .7636 L p .974 .724 .493 r
F P
0 g
s
.26117 .7636 m .27475 .65177 L .31576 .65984 L p .974 .724 .493 r
F P
0 g
s
.24591 .65083 m .23514 .61004 L .19443 .56906 L p .93 .547 .21 r
F P
0 g
s
.18026 .54504 m .19443 .56906 L .23514 .61004 L p .765 .291 0 r
F P
0 g
s
.2857 .5737 m .27475 .65177 L .23319 .62578 L p .967 .716 .504 r
F P
0 g
s
.23319 .62578 m .24533 .53628 L .2857 .5737 L p .967 .716 .504 r
F P
0 g
s
.25332 .72501 m .24591 .65083 L .20475 .61389 L p .954 .632 .377 r
F P
0 g
s
.19443 .56906 m .20475 .61389 L .24591 .65083 L p .93 .547 .21 r
F P
0 g
s
.20475 .61389 m .21029 .71388 L .25332 .72501 L p .954 .632 .377 r
F P
0 g
s
.21162 .87199 m .23319 .62578 L .27475 .65177 L p .969 .702 .47 r
F P
0 g
s
.25 Mabswid
.07041 .11422 m
.35102 0 L
s
.08177 .1096 m
.08865 .11752 L
s
[(-10)] .06802 .09374 .86746 1 Mshowa
.1576 .07873 m
.16437 .08675 L
s
[(-5)] .14408 .06268 .84274 1 Mshowa
.23458 .0474 m
.24122 .05552 L
s
[(0)] .22129 .03115 .81802 1 Mshowa
.31273 .01559 m
.31925 .02381 L
s
[(5)] .29968 -0.00086 .7933 1 Mshowa
.125 Mabswid
.09685 .10346 m
.10096 .10823 L
s
.11197 .0973 m
.11607 .10208 L
s
.12713 .09113 m
.13122 .09592 L
s
.14235 .08494 m
.14642 .08974 L
s
.17291 .0725 m
.17695 .07733 L
s
.18826 .06625 m
.19228 .07109 L
s
.20365 .05999 m
.20767 .06484 L
s
.21909 .0537 m
.22309 .05856 L
s
.25012 .04107 m
.25409 .04596 L
s
.2657 .03473 m
.26966 .03963 L
s
.28133 .02837 m
.28527 .03328 L
s
.297 .02199 m
.30093 .02691 L
s
.3285 .00917 m
.3324 .01411 L
s
.34432 .00273 m
.3482 .00768 L
s
gsave
.12858 -0.03919 -135.877 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
81.000000 12.812500 moveto
(Log) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(@) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
135.000000 12.812500 moveto
(D) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.25 Mabswid
0 .93669 m
.7259 1.59056 L
s
.02144 .956 m
.03142 .95275 L
s
[(0)] .00148 .96249 1 -0.32536 Mshowa
.2354 1.14873 m
.24545 1.14571 L
s
[(20)] .21529 1.15476 1 -0.29983 Mshowa
.42556 1.32003 m
.43567 1.31721 L
s
[(40)] .40534 1.32565 1 -0.27802 Mshowa
.5957 1.47328 m
.60586 1.47065 L
s
[(60)] .57538 1.47854 1 -0.25916 Mshowa
.125 Mabswid
.0774 1.00641 m
.0834 1.0045 L
s
.13166 1.05529 m
.13767 1.05341 L
s
.1843 1.10271 m
.19032 1.10086 L
s
.28501 1.19342 m
.29105 1.19164 L
s
.3332 1.23683 m
.33925 1.23508 L
s
.38003 1.27901 m
.38609 1.2773 L
s
.46984 1.35991 m
.47592 1.35826 L
s
.51293 1.39872 m
.51901 1.39709 L
s
.55487 1.4365 m
.56095 1.43489 L
s
.63547 1.5091 m
.64157 1.50755 L
s
.67422 1.54401 m
.68032 1.54248 L
s
.71198 1.57803 m
.7181 1.57652 L
s
gsave
.28171 1.33368 -119 -8.51891 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(zeta) show
93.000000 12.812500 moveto
(x) show
105.000000 12.812500 moveto
(50) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{181.062, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002e000181000`40O003h00O]Goo002eOol00;Eo
o`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eo
o`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eo
o`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eo
o`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`009Woo0P001goo0P00
87oo0P00HWoo000XOol00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`1P
Ool000Qoo`D0009oo`03001oogoo00Qoo`D0009oo`8000=oo`<000Ioo`03001oogoo00D0009oo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oo`0000Aoo`03001oogoo061oo`002Woo00L007ooOomo
o`00Ool0000:Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo
009oo`07001oogooOol007oo00001Woo00<007ooOol01Woo00D007oo001oo`0000=oo`03001oogoo
061oo`002Woo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03
001oogoo00Aoo`03001oogoo009oo`07001oogooOol007oo00003goo00D007oo001oo`0000=oo`03
001oogoo061oo`002Woo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`03Ool20003Ool30006Ool0
0`00Oomoo`02Ool01`00Oomoogoo001oo`0000moo`800003Ool0000000=oo`03001oogoo061oo`00
2Woo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`0AOol00`00Oomoo`02Ool01`00Oomoogoo001o
o`0001Moo`03001oogoo061oo`002Goo0P0017oo00<007ooOol027oo0`004Woo0P000Woo0P0017oo
00<007ooOol05Goo0P003goo00<007ooOol0D7oo001QOol00`00Ool0001AOol006=oo`03001oogoo
04moo`00FGoo00<007ooOol01Goo0P00DWoo001HOol00`00Ool00006Ool00`00Oomoo`1AOol005Qo
o`03001oo`0000Ioo`<0055oo`00F7oo00<007oo0000FWoo001AOol00`00Oomoo`04Ool00`00Ool0
001JOol0051oo`03001oo`0000Ioo`03001oogoo00eoo`8004Yoo`00Bgoo0`0017oo00<007ooOol0
4Goo0`0000=oo`00Ool0BGoo0011Ool50002Ool00`00Oomoo`05Ool2000BOol4001=Ool004=oo`07
001oogooOol007oo00001Woo00<007ooOol03goo1000Cgoo000mOol30003Ool01`00Oomoogoo001o
o`0000Ioo`<000aoo`<005=oo`00@goo00L007ooOomoo`00Ool0000COol3001EOol004=oo`07001o
ogooOol007oo000047oo0`0000=oo`00Ool0EGoo0012Ool20004Ool00`00Oomoo`0=Ool3000@Ool0
0`00Oomoo`17Ool005Ioo`<0019oo`8004Qoo`00Dgoo0`005Goo0`00Agoo001AOol3000FOol01000
M_800000Agoo001>Ool3000IOol200000gKb00000016Ool004aoo`<001]oo`H004Eoo`00Bgoo0`00
6goo00D007Kb000007Kb00<004Aoo`00Bgoo00<007ooOol06goo1@0000AflP00000004=oo`00Bgoo
00<007ooOol06goo0P0000EflP00000007Kb008004=oo`00Bgoo00<007ooOol06goo0`0000EflP00
000007Kb0080049oo`00Bgoo00<007ooOol06Woo00<007Kb00002@00@Goo001;Ool00`00Oomoo`0J
Ool2000017Kb000007Kb1`00@7oo001:Ool00`00Oomoo`0KOol6000017Kb000007Kb1000?goo001:
Ool2000KOol00`00M_800005000017Kb000007Kb0`00?goo001:Ool00`00Oomoo`0JOol200000gKb
001flP07000017Kb00000000?Woo001:Ool00`00Oomoo`0JOol00`00M_80000200000gKb00000009
000mOol004Yoo`03001oogoo01Yoo`800005M_800000001flP0200000gKb00000006000lOol004Yo
o`03001oogoo01Uoo`05001flP00001flP03000017Kb000007Kb100000AflP00000003]oo`00BWoo
00<007ooOol06Goo0P0000AflP00M_9flPH00003M_80000000800004M_800000000jOol004Yoo`03
001oogoo01Uoo`800005M_800000001flP0200001GKb00000000M_80100000AflP00000003Uoo`00
BWoo00<007ooOol067oo00D007Kb000007Kb0080009flP800003M_80000000X003Qoo`00BGoo0P00
6Woo00<007KbM_800P0000AflP00001flP<00003M_80000000D00003M_800000008003Moo`00?Woo
0`000goo00<007ooOol00goo00<007ooOol067oo0P0000EflP00000007Kb00800005M_800000001f
lP07000017Kb00000000=goo000nOol00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0HOol0
1000M_8007Kb0P000WKb00<007KbM_80100000=flP000000100000AflP00000003Ioo`00>Goo0`00
0goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0HOol01P00N_8007Kb001flP800005M_800000
001flP0200000gKb0000000200001GKb00000000M_800`00=Goo000oOol01`00Oomoogoo001oo`00
00=oo`03001oogoo01Qoo`05001jlW[b001flP070002M_8200000gKb001flP0200000gKb00000005
000dOol003ioo`03001oo`00009oo`03001oo`0000=oo`03001oogoo01Qoo`800008N_8007KbM_80
07Kb001flP<00005M_800000001flP0400000gKb00000005000cOol003moo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01Qoo`04001jl@00N_8200000gKb00000002M_8300001GKb00000000
M_802`00<goo0019Ool00`00Oomoo`0GOol01`00N_4007[a001jlP00009flP<00005M_800000001f
lP0300000gKb00000009000bOol004Uoo`03001oogoo01Moo`05001jlG[a001jl@03000017Kb001f
lP000WKb00@007Kb001flP<00003M_80000000800003M_80000000800003M_8007oo031oo`00BGoo
00<007ooOol05goo0P0000Qjl@00N_5jl@00N_8007Kb0`0000=flP0000000P0000EflP00M_8007Kb
00@00003M_80000000800003M_8007oo02moo`00BGoo00<007ooOol05goo00@007[a001jl@800009
N_8007[b001flP00M_8007Kb00800003M_80000000d00003M_8007oo02ioo`00BGoo00<007ooOol0
5goo00H007[aN_4007[a0002N_801000N_8007[b0P000WKb0`0000AflP00001flP`002moo`00BGoo
00<007ooOol05Woo00<007[a00000W[a0`000W[b0`0000EjlP00000007Kb00<00003M_8000000080
0003M_80000000800003M_80000000<002ioo`00BGoo00<007ooOol05Woo00@007[aN_40009jl@03
001jl@00009jlP04001jlP00N_820002M_8300000gKb0000000200000gKb0000000200000gKb0000
0003000]Ool004Qoo`03001oogoo01Moo`80009jl@800003N_4007[a00800003N_800000009jlP80
0003M_8007Kb00800003M_80000000800003M_80000000800003M_8007Kb00<002aoo`00B7oo0P00
5goo00@007[aN_40009jl@06001jlG[a001jl@000W[b0`0000AjlP00001flP@00003M_80000000<0
0003M_80000000<00003M_80000002aoo`00B7oo00<007ooOol05Woo00@007[aN_40009jl@800003
N_4007[a00800004N_8007[b0002N_82000017Kb001flP000WKb1@0000=flP0000001P00:goo0018
Ool00`00Oomoo`0FOol01000N_5jlG[a0P000W[a00L007[a000007[a001jlP0300001G[b001flP00
M_80100000=flP0000002P0000=flP00Ool0:Goo0018Ool00`00Oomoo`0FOol20003N_401000N_5j
l@000W[a00<007[a00000W[b00@007[b001jlP<00005M_800000001flP0200000gKb000000080000
0gKb001oo`0XOol004Qoo`03001oogoo01Eoo`04001jlG[a0002N_420002N_4200000g[a001jl@02
00000g[b00000002N_801000M_8007Kb0`0000=flP000000100000=flP0000001P00:7oo0018Ool0
0`00Oomoo`0EOol02@00N_5jlG[a001jl@00N_400002N_401P00N_5jl@00N_40009jlP<00003N_80
0000009flP@00003M_8007Kb00<00003M_80000000D002Qoo`00B7oo00<007ooOol05Goo00<007[a
N_400W[a0P000W[a00@007[a0000009jl@<0009jlP80009jlP<00003M_80000000800003M_800000
00<00003M_8007Kb00D002Moo`00B7oo00<007ooOol05Goo0P0017[a00@007[aN_5jl@800006N_40
07[aN_4007[b0P0000=jlP0000000W[b0P0000=flP00M_800`0000=flP0000001@0000=flP000000
0`009Woo0017Ool2000GOol00`00N_000003N_420003N_400`00N_400002N_420002N_840002N_82
00000gKb001flP0400000gKb0000000400000gKb001flP03000UOol004Qoo`03001oogoo01Aoo`07
001jl7[`N_0007[a00000W[a00<007[aN_400P0000=jl@0000000W[a00D007[bN_8007[b00<00003
M_80000000800003M_80000000800003M_80000000H00004M_800000000TOol004Qoo`03001oogoo
01Aoo`03001jl7[`009jl08000=jl@80009jl@03001jl@0000=jl@800005N_800000N_800002M_83
0002M_8400000gKb001flP06000017Kb001flP008goo0017Ool00`00Oomoo`0EOol00`00N_1jl003
N_000`00N_5jl@02N_401000N_5jlG[a0`000g[a00<007[bN_8010000WKb0`0000=flP00M_801@00
00=flP0000001P0000=flP00Ool08Goo0017Ool00`00Oomoo`0EOol20004N_020003N_420003N_40
0`00N_400002N_4200001W[b001jlP00N_80009flP<00003M_8007Kb00D00003M_8007Kb00H00003
M_8007oo021oo`00Agoo00<007ooOol05Goo00H007[@000007[`0002N_000`00N_400002N_400`00
N_5jl@0200000g[a00000002N_801P00N_8007[b001jlP800003M_80000000<00003M_80000000D0
0003M_80000000D0025oo`00Agoo00<007ooOol057oo00<007[@N]000W[@0P000g[`0P000g[a0P00
0W[a00<007[a00000W[b00/007[b000007[b001jlP00M_8007Kb00800004M_800000M_8600000gKb
001flP05000POol004Moo`03001oogoo01Aoo`03001jd7[@00=jd003001jl7[`009jl003001jlG[a
009jl@04001jlG[aN_430002N_8200000g[b001jlP0300000gKb001flP02000017Kb000007Kb2000
00=flP0000000`007goo0017Ool2000EOol00`00N]1jd003N]020003N_020003N_420003N_400`00
N_400002N_800`00N_800002N_800`00M_800002000017Kb000007Kb0P0000=flP00M_801P0000=f
lP0000000`007Woo000TOol00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`06Ool60008Ool0
0`00N]1jd003N]001@00N_0007[`00000W[a00<007[a00000W[a00<007[aN_400P0000Ijl@00001j
lP00N_8200000g[b001flP020002M_8700000gKb00000009000NOol002=oo`03001oogoo00ioo`03
001oogoo00Yoo`03001oogoo00=oo`04001oogooOol50003B_d3;Yh20006Ool20003N]001000N_1j
l7[`0P000g[a0P000g[a0P000W[a00<007[a00000W[b0`000W[b00T007Kb000007Kb001flP00M_80
100000=flP00M_802@007Goo0004Ool20002Ool400001Goo00000000Ool00P000Woo00<007ooOol0
2Woo00<007ooOol00goo1`001Woo00<007ooOol027oo00<007oo000017oo00@007oo0000009Bo@03
001:oD[m00A:o@03000^WRjN008000Eoo`06001jc`00001jd00017[`00<007[aN_400W[a00<007[a
N_400W[a00@007[aN_5jl@<000=jlP80009jlPH00003M_8007Kb00H00004M_800000M_86000LOol0
00=oo`03001oo`00009oo`<000=oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`02
Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`03001oogoo00Qoo`03001oo`0000Aoo`04001o
ogoo0003D_d00`00B_e:o@03B_d00`00;Yh^WP030004Ool01000N/mjcg[?0P0017[`0P000g[a0`00
0W[a0P000g[a00<007[b00000W[b100000EjlP00M_8007Kb00800003M_8007Kb00H00004M_800000
M_82000017Kb000000006goo0003Ool01000Ool000000goo00D007ooOomoo`0000=oo`04001oogoo
000<Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oogoo00=oo`03001oogoo00Qoo`03
001oo`0000Aoo`05001oogooOol00003D_d00`00B_e:o@03B_d00`00;Yh^WP030003Ool00`00N/mj
c`02N/l00`00N_1jl002N_001P00N_000000N_40009jl@<00004N_4007[aN_4200000g[b00000002
N_801P00N_8007Kb001flPH00003M_80000000L00004M_800000M_82000KOol000=oo`03001oogoo
00=oo`80009oo`80009oo`@000eoo`03001oogoo00=oo`<00004Ool000000006Ool00`00Oomoo`08
Ool00`00Ool00003Ool00`00Oomoo`03Ool01@00D_eBoE;m00000d[m200000=oo`00N/l017[?0P00
0W[`00<007[`N_000W[`0P0017[a00<007[aN_400P000W[b00<007[b00000g[b0`0000EflP00M_80
07Kb00<0009flP03001flP0000T00003M_80000001Yoo`000goo00<007ooOol07Goo00<007ooOol0
17oo00<007oo00000Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
17oo00@005;mD_eBo@<000=:o@04000^WP00MRH30005N/l01@00N/l007[`00001G[`00<007[aN_40
0W[a0P000W[a00@007[bN_9jlP<000=jlP03001jlP0000800003M_8007Kb00<00004M_800000M_82
00000gKb00000008000IOol000=oo`<000Qoo`03001oogoo01=oo`03001oogoo009oo`H000Aoo`03
001oogoo011oo`03001oogoo00Aoo`<0009Bo@03001:oD[m00=:o@H000Ejc`03001jcg[?008000Ej
l080009jl@05001jlG[a001jl@020003N_800`00N_80000200000g[b001jlP020002M_800`00M_80
0002000017Kb000007Kb0P0000AflP00001flPL001Qoo`00AWoo00<007ooOol01Goo00<005;mD_d0
0U;m0P001D[m00@007HV000000Ejc`04001jcg[?N/l20003N_000`00N_5jl@030003N_4200001W[b
00000000N_80009jlP05001jlW[b001jlP02000017Kb000007Kb2@0000AflP00001fl`800004M_80
0000000HOol004Ioo`03001oogoo00Ioo`03001BoE;m00=Bo@04001:oD[mB_d20002MRH00`00N/mj
c`02N/l00`00N/mjc`02N/l01P00N_000000N_0000Ajl@03001jlG[a009jl@05001jlW[bN_800002
N_84000017[b000007LB10000WKb00@007Kb001flPP00004M_<00000M_<3000GOol004Ioo`03001o
ogoo00Moo`03001BoE;m00=Bo@<00005B_d00000MRH00004N/l00`00N/mjc`02N/l01000N_1jl7[`
0P0017[a0P000g[a0P000W[b0P000g[b00D007/B001jlP00009g4P05001flP00001flP02000017Kb
000007Kb2P0000Afl`00000001Ioo`00AWoo00<007ooOol027oo00<005;mD_d00P0000IBo@00B_e:
o@00NV/40002N/l01@00N/mjcg[?00001G[`0`0000Ajl@00N_5jl@<0009jlP<00004Na8007[bN_82
00001G/B00000000Ma800P0000=g4P0000000`0000AflP00001fl`h001Eoo`00AWoo00<007ooOol0
2Goo0P0015;m00<004[m00000WY[00<007[>N/h00`000g[?00<007[`N_000g[`00<007[aN_400P00
17[a00<007[bN_800W[b00<007/BNa800P000W/B00L007/B001g4P00Ma800002Ma800`00Ma800005
00000gKc001fl`0300001GKc00000000M_<0100057oo0016Ool00`00Oomoo`0:Ool00`00D_eBo@02
D_d00`00B_d00002NV/00`00N/ijcP02N/h20002N/l00`00N_1jl002N_000`00N_5jl@02N_420003
N_420003N_820002Na800`00Na9k4P0200000g/B001g4P03000017LB000007LC0P0000=g4`000000
0`0000Efl`00000007Kc00<00003M_<00000008001=oo`00AWoo00<007ooOol02goo0P000e;m0P00
0WY[00<007[>N/h00W[>00<007[?000010000W[`00D007[aN_5jl@00009k4@<0009k4P<0009k4P80
0005Na8007/BNa800002Na801000Ma8007LB0`000WLC0P0000=g4`0000000`0000Efl`00000007Kc
00<00003M_<000000080019oo`00AWoo00<007ooOol03Goo00D005;mD_eBo@00009jJ`03001jcW[>
009jcP05001jcg[?N/l00002N_040002N_400`00Na5k4@02Na400`00Na9k4P02Na801@00Na9k4W/B
00000W/B10000W/B00<007LC00000WLB0P0000=g4`0000000WLC00<007LC00003`004Goo0016Ool0
0`00Oomoo`0=Ool300001E;m001jJgY[000017[>00D007[?N/mjc`0000Ajl003001k4@00008000Ak
4@<00003Na8007/B00800003Na80000000=k4P03001k4P0000<00004Ma<00000Ma<5000017LC0000
07LC0P0000Eg4`00000007Kc00L00003M_<007oo00moo`00AGoo00<007ooOol03goo00H005;mD_d0
07Y[0004N/h00`00N/mjc`02N/l01@00N_1jl7[`000017/A0`0000=k4@00Na800W/B0P000g/B0P00
00Ik4P00000007/C0002Na801@00Ma<007LC00000WLC00<007LC00001@0000Ag4`00001g4`<00003
Ma<0000000D00003M_<007oo00ioo`00AGoo00<007ooOol047oo00D005;m001jJ`0000AjcP05001j
cg[?N/l00004N_001@00Na5k4G/A00000g/b0P0017/B0P000g/B0P000W/B00<007/CNa<00P0000=g
4`00Ma<00`0000Ag4`00001g4`800005Ma<00000001g4`0200001GLC00000000Ma<020003goo0015
Ool00`00Oomoo`0AOol200000gY[001jcP03N/h01@00N/mjcg[?00000g[`0`000W/A00<007/bNc80
0W/b0`0000Ak4P00Na=k4`<0009k4`@0009k4`03001g4gLC00<00004Ma<000000002Ma<200000gLC
0000000A000>Ool004Eoo`03001oogoo019oo`<000AjcP06001jcg[?N/l007[`0`000VoJ10000W/b
00@007/cNc=k<`8000Ak4`03001k4g/C009k4`03001k4`0000<000=g4`80009g4`800003Ma<00000
009g4`06001g4`00Ma<007LC1`0000=fl`0000000P003Woo0015Ool00`00Oomoo`0BOol00`00MVd0
0004N/h01000N/mjcg[?1@000foJ00<007NHMiP00`0017/c0P000g/C0P000g/C0P000W/C00<007LC
00000P0000=g4`0000001`0000Ag4`00001g4`<00004Ma<00000Ma<400000gKc00000002000=Ool0
04Eoo`03001oogoo019oo`03001fK@00009jcP03001jcP00009jc`03001:oD[m00T00003MiP007Mg
00800004Nc<007/dNc@30002Na<30002Na<200001GLC001g4gLC00000WLC00H007LC001g4`00Ma<6
00001GLC00000000Ma<00P0000=g4`0000000P0000=fl`0000000P0037oo0015Ool00`00Oomoo`0B
Ool00`00MVd00003N/h00`00N/mjc`040002B_d3?]h29Wh40003MgL20004Nc@00`00Na=k4`02Na<0
1@00Na=k4g/C00000WLC0P0000=g4`00Ma<00P0000Eg4`00000007LC00800003Ma<0000000P00003
Ma<0000000L000]oo`00AGoo00<007ooOol04Woo00<007I]00000g[>00@007[?000000I:o@07000n
gSkN000VOP000Q/00`0000=gM`00MeH00P0000=k=000Mc@00P0000=k4`00Ma@00P0000=k4`000000
0WLC00<007LCMa<00`000WLC0P000WLC0P0000Ag4`00001g4`<00005Ma<00000001g4`0300000gKc
00000003000:Ool004Eoo`03001oogoo019oo`03001fK@0000=jcP800003D_d004[m00E:o@06000n
gSkN?]h002In1P000gMF0P000gLd0P000gLD0P0000=g4`0000000P000gLC0P000WLC0P0000Eg4`00
000007LC00800005Ma<00000001g4`0300001GLC00000000Ma<01@002Goo0014Ool2000DOol00`00
MVd00003N/h01000D_eBoE;m0P001D[m00<003kN?]h01`0000I[V`00001gEP00MeH2000017Ld001g
=0000gLD0P000WLC00<007LC00000P0000Eg4`00000007LC00@00003Ma<007LC00800005Ma<00000
001g4`0300000gLC000000060009Ool004Eoo`03001oogoo019oo`03001fK@0000=jcP<000=Bo@04
001:oD[mB_d40002A_h2=]h00`00;]l0000200000f^K00000003MeH20002Mc@30002Ma@200001GLD
001g4gLC00000WLC0P000WLC00D007LC000007LC00@00003Ma<0000000h000Qoo`00A7oo00<007oo
Ool04goo00<007I]00000W[>00D007ooOomoo`0000=Bo@<000=>o@080016oTKnA_h003KN000^g`@0
0007KgT00000MeH007MF00000gLd00D007LDMaAg5000009g50800003Ma@007LC00<00004Ma<00000
Ma<200000gLC001g4`02000017LC000007LC300027oo0014Ool00`00Oomoo`0DOol20002N/h01000
Oomoogoo0`000U;m00<004kmC_d00dkm00L004KnA_i6oP00=]h00002;]l00`00Ggd00002KgT20002
MeH300001WLe00000000Mc@0009g5007001g57LD001g4`00Ma<00`000WLC0P0000Ag4`000000009g
4`800003Ma<0000000L00003Ma<007oo00Moo`00A7oo00<007ooOol057oo0P0000=jcP00Ool017oo
00<005;mD_d00U;m00<004kmC_d00dkm00<004KnA_h01@0000=;?P00Ggd00`0000=cF000MeH00WMF
00D007LeMcEg=@00009g=0@0009g5003001g5000009g4`80009g4`800005Ma<00000001g4`030000
0gLC0000000200000gLC000000020009Ool004Aoo`03001oogoo01Aoo`04001jcW[>0006Ool00`00
D_eBo@02D_d01000C_e>oDkm10000T[n00<004LN00000T/n0P0000AOO@00LeQcF0<00004McH00000
McD20003Mc@00`00Ma@00003000017LD000007LD0`0000Ag4`00001g4`L00003Ma<0000000800004
Ma<000000009Ool004Aoo`03001oogoo01Aoo`03001jcP0000Qoo`03001BoE;m009Bo@<000=>o@06
001:oT[nB_h004LN0P000T/n00<006Mk00000g=H00@007LfMcIg=P800006McD00000001g=0000WLD
00<007LD00000P000WLD0P000WLC0P0000Ag4`00001g4`@00003Ma<0000000800003Ma<0000000Uo
o`00A7oo00<007ooOol057oo00<007[>00002Goo0`000U;m00<004kmC_d00dkm00D004[nB_i:oP00
00977P800003Fed006Mk00<00003LeL007Lf009g=P80009g=@03001g=7Ld00800004Ma@007LDMa@2
0002Ma@20002Ma<2000017LC000007LC100000=g4`00000010002Goo0014Ool2000EOol00`00N/h0
000:Ool00`00D_eBo@02D_d00`00C_e>o@03C_d00`00B_i:oP0300001E<m001KGE]M00000VMk00<0
07=GLeL00`000WLf0P0000Eg=@00McAg=000009g50800003Ma@0000000/00003Ma<0000000800003
Ma<0000000<000Uoo`00A7oo00<007ooOol057oo0P0037oo00<005;mD_d00U;m00@004kmC_e>o@@0
009?7@03001C?E<m00800004Fed00000KeT20002LeL01@00McIg=WLf00000WLe0P0000Eg=000MaAg
5000009g500:001g5000Ma@007LD001g5000Ma<300000gLC00000002000017LC000000002Woo000h
Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`0DOol2000=Ool00`00D_eBo@02D_d30003Dad01000
Cae?7DlM0P000U<m00<006=K00000fmI0P0000IcE`00000007Lf0002McD00`00McAg=00200002WLD
001g57LD001g5000Ma@007LD0`0000Eg5000000007LC00L000Yoo`00>7oo00<007ooOol00Woo00<0
07oo000017oo00<007ooOol057oo00<007ooOol03Goo0`000U;m00<005<MDad00e<M0P000TlM0`00
00=K?@00He/00`0000=_F@00LeL00W=G00<007LfMcH010000WLd00<007LDMa@00P0000=g5000Ma@0
0`0000=g500000000WLD0`0000=g4`00000010002Woo000iOol01`00Oomoogoo001oo`0000Aoo`03
001oogoo01Aoo`03001oogoo00ioo`03001BoE;m009Bo@03001C7E<M00=C7@<0009G7@=K?@04001S
Ff=K0002KeT300000g<g001g=P02McH00`00McD000030002Ma@02@00MaAg5000Ma@007LD001g5002
0002Ma@300000gLC00000002000;Ool003Uoo`07001oogooOol007oo000017oo00<007ooOol09Woo
00<005;mD_d00U;m00<005<MDad00P000U<M00/005LMEaeG7@00Fcd006=K001WFP0000=_F@03001c
=g<g00<00006McD007LeMcD007Le10000WLD00H007LD001g5000Ma@300001GLD00000000Ma@00`00
2goo000hOol00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`0XOol00`00D_eBo@02D_d20005
Dad01000EaeG7@000U/m00@006MJIeYWFP<00003KeP007<g009c=`03001g=GLe00800006McD007Le
McD007LD100000Eg5000000007LD0080009g50@00003Ma<007oo00Yoo`00>Goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0:Goo0`000U;m00<005<MDad00e<M00<005LMEad00`0000=O?000
IeX00fMJ00P006mHKeP007<g001c=P000WLe00<007LeMcD00P0000ag5@00MaAg5000Ma@007LD001g
5000Ma@200000gLD00000003000<Ool004=oo`03001oogoo02Yoo`03001BoE;m009Bo@03001C7E<M
009C7@<0009K?003001O?5ll00800004IeX006]I0002KeP01000LcIc=W<f0P0000Eg=@00001g=@00
009g5@800009Ma@007LD001g5000Ma@007LD00800003Ma@007LD008000aoo`00@goo00<007ooOol0
:goo00D005;mD_eBo@00009C7@80009C7@04001K?5/lFc`20002Gc`01000JeU[FF]I0P0000=cE`00
LcH00W<f00H007LeMcEg=@00McD2000017LE001g57LD0`0000Eg5000000007LD00800004Ma@007LD
000<Ool004=oo`03001oogoo02aoo`04001BoE;mD_d20005Dad00`00FcaK?002Fc`200000f=K001[
F@02JeT00`00LeMcE`0300001W<f00000000McD0009g=@0=001g5@00001g5000Ma@007LD001g5000
Ma@010003Goo0013Ool00`00Oomoo`0]Ool20002D_d00`00DaeC7@04Dad01P00Fc`00000Fc`0009S
F`<00003KeT007=G009cE`05001c=W<fLcH00002McD40002MaD02P00MaD007LD001g5000Ma@007LD
0`003Goo0014Ool00`00Oomoo`0]Ool01@00D_eBoE;m00001E<M0P0015/l00D006=KHe]SF`00009_
F@<00004LcL007<fLcH20003McD01`00McD00000MaD007LE00<00005Ma@00000001g5002000=Ool0
04Eoo`8002ioo`05001BoE;mD_d00002Dad20002Ea`01P00FcaK?5/l001SF`800003IeX006mI009_
F@03001c=g<g0080009c=P<00004McD007Le0002MaD02`00MaD007LD001g5000Ma@007LD00003Goo
0010Ool00`00Oomoo`02Ool2000_Ool01000D_eBoE;m0P001ELL0P000U/l00<006MJIeX00VMJ00D0
06mI001_F000009c=`03001c=W<f009c=P03001g=GLe00<0009g5@03001g5@0000800004Ma@00000
000>Ool003moo`03001oo`0000Eoo`03001oogoo02eoo`80009Bo@03001G75LL00AG70<00003Gc/0
06MJ00=WFP04001_F6mHKeP200001g<g000007<f001c=P00009g=@03001g=@0000<0009g5@80009g
5003001oogoo00aoo`00?goo00<007oo00001Woo0P00;Woo00@005;mD_eBo@80009G7080009G7003
001O>elk00800004IeX006/j0003KeP01000LcMc=g<g0P000W<f0P0000Ig=@00McEg=@00MaD20000
17LE000000003goo000oOol00`00Ool00008Ool00`00Oomoo`0/Ool00`00D_eBo@02D_d20005Ea`0
1@00Gc]O>elk00000f/j00D006mH001_>000009c=`03001c=`00009c=P03001g=GLe00800004McD0
07LE0002MaD2000?Ool003moo`03001oo`0000Uoo`03001oogoo02aoo`<0009C7@03001G75LL00=G
7006001O>`00001S>`000f/j00L006lhKcQ_>000LcL00002LcL200001G<f001g=GLe00000WLe0`00
0WLE00<007ooOol03Goo0010Ool00`00Oomoo`08Ool2000^Ool00`00DaeC7@02Dad00`00EaaG7002
Ea`20004Hc/01@00JcX006/i00000flh00<007<gLcL00W<g00<007<fLcH00P0000Ig=@00McEg=@00
MaD2000@Ool004eoo`03001oogoo02aoo`05001C7E<MDad00002Ea`20002Fa`00`00Hc]S>`02Hc/0
1000JcU[>F/i0`0000M_>000001c=`00LcH00002LcH00`00McEg=@02000017Le0000000047oo001>
Ool00`00Oomoo`0[Ool00`00DaeC7@02Dad20005Fa`2000016<k001S>`0016/i00@006lhKcQ_>080
009c=P800005LcH00000McD00003McD00`00Oomoo`0>Ool004moo`03001oogoo02]oo`<0009C7@03
001K75/L00EK7004001S>f<kHc/2000016/i001_>@000Vlh00<007<g00000W<f00H007<fLcIc=P00
McD3000AOol0051oo`03001oogoo02aoo`05001C7E<MDad00004Fa`200000e/L001S>`03Hc/01`00
KcU_>Fli001_>000009c=`800004LcH007<fLcH20002McD00`00Oomoo`0?Ool0055oo`03001oogoo
02aoo`06001C7E<MDad005/L0P0015/L00H006<kHc/006Lj0003KcT00`00LcMc=`02LcL00`00LcIc
=P020002LcH2000BOol0055oo`<002eoo`05001C7E<MDad00006Fa`00`00Hc/00003IcX01@00KcT0
06lh00000W<g00<007<g00000W<f00D007<fLcIc=P00019oo`00E7oo00<007ooOol0:Woo0`000U<M
00<005/LFa`00e/L0P001FLj00L006lhKcQ_>000LcL00002LcL2000017<f000000004goo001EOol0
0`00Oomoo`0ZOol00`00DaeC7@02Dad00`00FaaK70020002Ga`01`00IcYW>VLj001W>P0000=_>003
001c=g<g009c=`05001c=W<fLcH0000COol005Ioo`03001oogoo02Yoo`03001C7E<M009C7@8000EO
7003001W>P0000=W>P04001_>000KcP2000017<g001c=`000W<f00<007ooOol04Goo001GOol00`00
Oomoo`0ZOol30002Dad00`00GaaO7004Ga`00`00IcYW>P03IcX00`00KcQ_>002KcP01000LcMc=g<g
0P0057oo001GOol2000]Ool01000DaeC7E<M0P000UlL0P0000=O>`00IcX00VLj00<006/i00000Vlh
00<006lh00000g<g00<007ooOol04Woo001IOol00`00Oomoo`0[Ool00`00DaeC7@02Dad20004Gc/2
00001fLj001[>F/i001_>000009_>003001c=`0001Eoo`00FWoo00<007ooOol0:goo0`000U<M00<0
05lkGc/015lk00<006/iJcT00V/i00<006lhKcP00Vlh00<007ooOol057oo001KOol00`00Oomoo`0[
Ool00`00DaeC7@02Dad01000Gc]O>elk0P0000MO>`00JcU[>@00JcT00003KcP00`00Oomoo`0DOol0
05aoo`8002aoo`06001C7E<MDad005lk0P0015lk00<006/i00000V/i0`005goo001MOol2000/Ool0
1@00DaeC7E<M00001elk00<006/iJcT00f/i00<007ooOol05Goo001BOol30003Ool00`00Oomoo`04
Ool00`00Oomoo`0ZOol20002Dad00`00Gc]O>`02Gc/200000f<k001[>@02JcT00`00Oomoo`0FOol0
059oo`03001oogoo009oo`03001oo`0000Ioo`03001oogoo02Yoo`06001C7E<MDad005lk0P0016<k
00<006/i00006Goo001COol01`00Oomoogoo001oo`0000Moo`03001oogoo02Uoo`03001C7E<M009C
7@03001S>f<k00ES>`03001oogoo01Qoo`00Dgoo00L007ooOomoo`00Ool00008Ool00`00Oomoo`0Y
Ool30002Dad00`00Hc]S>`02Hc/2000KOol0059oo`03001oo`00009oo`03001oo`0000Uoo`03001o
ogoo02Yoo`06001C7E<MDad006<k0P007Goo001COol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00
Oomoo`0ZOol01@00DaeC7E<M00007goo001UOol00`00Oomoo`0ZOol2000QOol006Ioo`8004eoo`00
J7oo00<007ooOol0BWoo001XOol2001;Ool006Yoo`03001oogoo04Qoo`00Jgoo00<007ooOol0Agoo
001/Ool00`00Oomoo`16Ool006eoo`03001oogoo04Eoo`00KWoo00<007ooOol0A7oo001_Ool00`00
Oomoo`13Ool0071oo`03001oogoo049oo`00LGoo0P00@Woo001cOol20010Ool006Qoo`<0009oo`03
001oogoo00=oo`80041oo`00JGoo00H007ooOol007oo0006Ool00`00Oomoo`0mOol002]oo`@0009o
o`8000=oo`80009oo`@000]oo`04001oogoo0009Ool00`00Oomoo`02Ool00`00Oomoo`09Ool40000
17oo001oo`001goo00<007ooOol0?7oo000/Ool01@00Ool007oo000017oo00D007ooOol007oo00<0
00eoo`8000Uoo`03001oo`00009oo`03001oo`0000Yoo`03001oo`00009oo`03001oo`0000Qoo`03
001oogoo03]oo`00:goo00<007oo00000Woo0`000Woo00<007ooOol017oo00<007ooOol02goo0P00
2goo00H007ooOol007oo000;Ool20002Ool00`00Ool00009Ool00`00Oomoo`0jOol002]oo`@00005
Ool00000001oo`040003Ool2000<Ool01000Oomoo`0027oo0P000goo00<007oo000037oo00D007oo
Oomoo`0000]oo`03001oogoo03Uoo`00=Goo00<007ooOol07Goo00<007ooOol00Woo00<007oo0000
7Goo00<007ooOol0>7oo001EOol30003Ool00`00Oomoo`0MOol2000hOol007eoo`03001oogoo03Eo
o`00OGoo0P00=Woo001oOol00`00Oomoo`0cOol0081oo`03001oogoo039oo`00PGoo00<007ooOol0
<Goo0021Ool2000bOol008=oo`03001oogoo02moo`00Q7oo00<007ooOol0;Woo0025Ool2000^Ool0
07]oo`8000Aoo`03001oogoo009oo`8002eoo`00Ngoo00<007oo00000Woo00<007oo00001Goo00<0
07ooOol0:Woo001kOol00`00Ool00002Ool00`00Ool00006Ool00`00Oomoo`0YOol007]oo`8000=o
o`03001oo`0000Moo`03001oogoo02Qoo`00Ngoo00<007ooOol00Woo00<007oo00001goo0P00:Goo
001lOol20003Ool00`00Oomoo`08Ool00`00Oomoo`0VOol008eoo`03001oogoo02Eoo`00SWoo00<0
07ooOol097oo002?Ool2000TOol0095oo`03001oogoo025oo`00TWoo00<007ooOol087oo002COol0
0`00Oomoo`0OOol009=oo`80021oo`00UGoo00<007ooOol07Goo002eOol00;Eoo`00]Goo002eOol0
0;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol0
0;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol0
0;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol00;Eoo`00]Goo002eOol0
0;Eoo`00]Goo002eOol00;Eoo`00]Goo0000\
\>"],
  ImageRangeCache->{{{0, 180.062}, {287, 0}} -> {-0.180593, -0.327653, 
  0.00527182, 0.00527182}},
  CellTags->"5.2.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gain and Phase Margins", "Subsubsection",
  CellTags->"5.2.2"],

Cell[TextData[{
  "Important insight into the stability of the closed\[Hyphen]loop system can \
be achieved by analyzing the gain and phase margins of the system before \
closing the loop. The margins can be computed using ",
  StyleBox["GainPhaseMargins", "MR"],
  " and displayed on the Bode plot using the option ",
  StyleBox["Margins", "MR"],
  ", which accepts either the result of ",
  StyleBox["GainPhaseMargins", "MR"],
  " (if it was computed prior the call to ",
  StyleBox["BodePlot", "MR"],
  ") or ",
  StyleBox["True", "MR"],
  " to compute the margins transparently. The ",
  StyleBox["MarginStyle", "MR"],
  " option can be used to specify the graphics primitive for margins in a \
manner similar to the ",
  StyleBox["PlotStyle", "MR"],
  " option. If ",
  StyleBox["Margins", "MR"],
  " is set to ",
  StyleBox["False", "MR"],
  ", the margins are not computed (the default). "
}], "Text",
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["GainPhaseMargins",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["compute",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["gain",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["and",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["phase",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["margins",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["BodePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["Margins",
                        "MR"], 
                      StyleBox[" ",
                        "MR"], 
                      StyleBox["->",
                        "MR"], " ", "margins"}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(show\ precomputed\ gain\ and\ phase\ margins\ on\ the\ Bode\ 
                plot\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["BodePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["Margins",
                        "MR"], " ", 
                      StyleBox["->",
                        "MR"], " ", 
                      StyleBox["True",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            StyleBox[\(compute\ and\ show\ gain\ and\ phase\ margins\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.55}},
  CellTags->"5.2.2"],

Cell["Gain and phase margins. ", "Caption",
  CellTags->"5.2.2"],

Cell[TextData[{
  "As an exercise, let us select gain ",
  Cell[BoxData[
      \(TraditionalForm\`k\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " for the system shown in Figure\[NonBreakingSpace]5.2 such that the phase \
margin is greater than ",
  Cell[BoxData[
      \(TraditionalForm\`30  \[Degree]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and the gain margin is greater than ",
  Cell[BoxData[
      \(TraditionalForm\`10\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " dB (Brogan (1991)).  \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.3"],
  "   "
}], "Text",
  CellTags->"5.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 252 78
%%HiResBoundingBox: 47 4 252 78
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:53:48 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 82 translate 1 -1 scale
gsave
47 78 translate
205 -74 scale
1 string
814 294 1 [814 0 0 294 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFE57FFFE7FFF001F11FFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFEFBFFFEFFFF803F3EFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF9FFFE7FFF955E7C7FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFF9FFFEFFFFEFEEFEFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF1FFFE7FFFE7FC7E7FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFE3FFFEFFFFF3FCFE3FFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFC7FF8001FFF9FC7E3FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFCFFFAA2BFFFDF8FE3FFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFC7FFFE7FFFFC7C7E3FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFF8FFFFEFFFFFE78FE3FFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFDE7FFE7FFFFF7C7E3FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFEEFFFEFFFFFE3CFE3FFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF77FFE7FFFFF1C7E3FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFEFFFFFF3EFE3FFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF7F1C7C7FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFE3E7EFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFF143E7C7FFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFE07FBBFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFF1FFC7FFFFF
FFFFFFFC3FFFFFFFFF57FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFE8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFF401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFA003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFD00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFE80000AAAAAAAAAAAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3F40000000000000000000000000000000003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83A00000000000000000000000000000000003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC0000000000000000000000000000000000003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83E80000000000000000000000000000000003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FD0000000000000000000000000000000003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFA0000FFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000000000000000000001FFFFFFFF0000000000000000000001FF
FFFFFFFC3FFFFD0007FFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82AAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAA0FFFFFFFFAAAAAAAAAAAAAAAAAAAAABFF
FFFFFFF83FFFFFFA03FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFF407FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFF47FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFA7FFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF03DFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEF839FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7031FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3833FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1021FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0803FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFE7FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFF3FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFABFEFABFFFFBFFFFAAFFAFFBFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFDE7CFDC7FFF9FFFFC7FC77F9FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFE7CFBE7FFF9FFFFE7FCFBF8FF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFDE7DFFE7FFF9FFFFE7F9F1FCFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFE39FFE7FFF9FFFFE7FBF9FCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFC79FFC7FFF9FFFFE7F1F9FCFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF8F9FF8FFEA8AFFFE7F3F8FCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF0F9FF1FFE0007FFE7F1FCFC7F
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFBF9FF3FFFF9FFFFE7F3F8FCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF1D9FF1DFFF9FFFFE7F1FC7CFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFBF8FF3FFFF9FFFFE7F3F8FCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF1DDFF31FFF9FFFFE7F1FC7CFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFABCFFAFFFF9FFFFE7F3F8F9FF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFCFFFFFFF9FFFFE7F1F8F9FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFEFFFFFFFFFFFFE7F9F8FBFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFE7F1F1F3FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFA7F8FBF7FF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFF9FFFFFFFFFFFC7FCF3CFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFEFFFFFFFFFFFE7FE2FFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD007FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF5FFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00003FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF005401FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FF80FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF17FFFFFFFFF05DDC07FFFFF
FFFFFFFFD5FFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFFFFE0FFFF87FFFFF
FFFFFFFFF8BFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFFFF
FFFFEFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0017FFFFFC1777703FFFFF
FFFFFFFFFC017FFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFF
FFFFF05FFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE002FFFFFE3FFFF83FFFFF
FFFFFFFFFF002BFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00005FFFC1DDDDC1FFFFF
FFFFFFFFFF80005FFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC0003FFFFFFFFFFFFFF
FFFFFF0017FFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000BFF83FFFFE3FFFFF
FFFFFFFFFFC00002FFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC0003FFFFFFFFFFFFFF
FFFFFF8000BFFFFFFFFFFFFC
FFFFFFFFFE00000000000000000000000000000000000178377774000000
000000000000000007F0FFFFFFFFFFFF0000000000000000000000000000
3FFFFFFFFFFFC00000000000000000000000000000000000000000000000
0000000000017FFFFFFFFFFC
FFFFFFFFFE000000000000000000000000000000000000283FFFFE000000
000000000000000000A0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC00000000000000000000000000000000000000000000000
0000000000002FFFFFFFFFFC
FFFFFFFFFE000000000000000000000000000000000000105DDDDC000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC00000000000000000000000000000000000000000000000
000000000000005FFFFFFFFC
FFFFFFFFFE00000000000000000000000000000000000BF83FFFFE000000
00000000000000000BE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC00000000000000000000000000000000000000000000000
000000000000000FFFFFFFFC
FFFFFFFFFE00000000000000000000000000000000005FF8777774000000
00000000000000005FF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC00000000000000000000000000000000000000000000000
000000000000007FFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0002FFFF83FFFFE1FFFFF
FFFFFFFFFF80002FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFF80003FFFFFFFFFFFFFF
FFFFFFE000003FFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001FFFFFC1DDDDC1FFFFF
FFFFFFFFFF0001FFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFF
FFFFFFC00005FFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFC3FFFFC3FFFFF
FFFFFFFFFE00FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFF
FFFFFF8002FFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FFFFFFFC1777703FFFFF
FFFFFFFFF417FFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFF
FFFFFF0057FFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFE0FFFF83FFFFF
FFFFFFFFEBFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FFFFFFFFFFFFFF
FFFFFE2BFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE05DDD07FFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFDFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFF
FFFFF17FFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFE0FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFEFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007700FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFF7FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF802A03FFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFBFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00007FFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFF5F3E7D5FFFFDFFFF17FF17FDFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFBE3EFCEFFFFCFFFE3BFE7BFCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFF9C7C7DF7FFFDFFFD7CFC71FCFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFABFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFF9EFEFFF3FFFCFFFFFEF8F9FEFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFDCFCFFE3FFFDFFFFFF79FCFC7F
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFC8FCFFE7FFFCFFFFFE79FCFEFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFC1FCFFC7FF5457FFFF71FC7C7F
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFEBF8FF8FFF0003FFFE39FCFEFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF83FFFFFFFFFFC
FFFFFFFFF15FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFC5FCFF1FFF5557FFFC71FC7C7F
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF01FFFFFFFFFFC
FFFFFFFFE020FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFEEFCFFBFFFFCFFFFFE79FCFEFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF0FFFFFFFFFFFC
FFFFFFFFE101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFE73CFF1DFFFDFFFFF071FC7C7F
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF1DFFFFFFFFFFC
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFE3BEFFB9FFFCFFFFE0F9FCFEFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFFFFFFFFFFC
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF35C7FD5FFFDFFFF01F1FC7CFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFCFFFFFFFFFFC
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF3FEFFFFFFFCFFFF0FF9FCFCFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFFFFFFFFFFC
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF1FE7FFFFFFDFFFF7FF1FC7DFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC7FFFFFFFFFC
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFBFF3FFFFFFFFFFFBFF8F8FBFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF87FFFFFFFFFC
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF9FFBFFFFFFFFFFF95FCF9F7FF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF87FFFFFFFFFC
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF9FFFFFFFFFFFFFFC0FEFBEFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF83FFFFFFFFFC
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFF1FFC7FFFFFFFFFFC07F07DFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF01FFFFFFFFFC
FFFFFFFFE3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0BFFFFFFFFFC
FFFFFFFFC1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0DFFFFFFFFFC
FFFFFFFFEBABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0EFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC1CFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE3EFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC1E7FFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFAAEBFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF05555555555555555555555555555555555555555
55555555555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00000000000000000000000000000000000000000
00000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000000
00000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{205, 74},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003=0000BQ000`40O003h00OcGoo003=Ool00<eo
o`00cGoo003=Ool00<eoo`00cGoo003=Ool00<eoo`00Egoo00=2400000009`0000=247ooOol0BGoo
001GOol00d8@<Haoo`0VOol00c6<@Q1oo`1:Ool005Moo`03@Q0aS7oo02Ioo`03<Ha247oo04Yoo`00
Egoo00=2436<Ool02Goo00=W>FmkIcT00goo00QJeWooOomoogNm:DXaS6<H0Ukg00=BU7ooOol02Woo
00<aS48@Ool0BWoo001GOol00d8@<Haoo`0:Ool025:DF]IoogooG_M245kgKg/2Ool01f<HIcUg_CW>
Oom:DVmk00]oo`03<Ha247oo04Yoo`00Egoo00=2436<Ool02Woo00PicVmkOomoofmk@Q1_NgNm0goo
00I:DWoo8@Qood8@G_L;Ool00c6<@Q1oo`1:Ool005Moo`03@Q0aS7oo00Yoo`9_N`=oo`0<G_Moogoo
Oomg_GooE[EBU3W>OolicVLi2goo00<aS48@Ool0BWoo001GOol00d8@<Haoo`0COol01gNmCW<YBVmk
HaQNmeJe00aoo`03<Ha247oo00Qoo`03Kg]g_Goo03moo`00Egoo00=2436<Ool09Woo00<aS48@Ool0
0Woo00Ig_EkgDY@YBQS6>Li2Ool005Moo`03@Q0YBWoo02Ioo`06:DY246]J=JdQ20Q210003aBU00<L
iaBU5:D02ABU00<e[GooOol09Goo000bOol00c6<0000000S00000c6<Oomoo`0UOol2<H`015Je@Q0Q
212410006R4800<@Q248Ool09Woo000bOol00c6<001BU00PDY@015JeDY@YBS6<1goo00=g_E:DDY@0
4e:D00=W>GooOol01goo00<aS48@Ool00goo00Ig_EkgDY@YBT8@Kg/HOol00c6<8@Qoo`0VOol0039o
o`03<H`007oo029oo`03@Q0aS7oo02Ioo`03<Ha247oo025oo`03<H`Q27oo02Ioo`00<Woo00<aS000
Ool08Woo00=2436<Ool09Woo00<aS48@Ool08Goo00<aS248Ool09Woo000bOol00c6<001oo`0ROol0
0d8@<Haoo`0BOol00ekgMkeoo`0AOol00c6<@Q1oo`0QOol00c6<8@Qoo`0VOol0039oo`03<H`007oo
029oo`03@Q0aS7oo019oo`03<Haoogoo015oo`03<Ha247oo025oo`03<H`Q27oo02Ioo`00<Woo00<a
S000Ool08Woo00=2436<Ool04Woo00<aS7ooOol04Goo00<aS48@Ool08Goo00<aS248Ool09Woo000b
Ool00c6<001oo`0ROol00d8@<Haoo`0BOol00c6<Oomoo`0AOol00c6<@Q1oo`0QOol00c6<8@Qoo`0V
Ool0039oo`03<H`007oo029oo`03@Q0aS7oo015oo`03MkdYBWoo019oo`03<Ha247oo025oo`03<H`Q
27oo02Ioo`00<Woo00<aS000Ool08Woo00=2436<Ool04Woo00=W>GooOol04Goo00<aS48@Ool08Goo
00<aS248Ool09Woo000bOol00c6<001oo`0ROol00d8@<Haoo`0VOol00c6<@Q1oo`0QOol00c6<8@Qo
o`0VOol0039oo`03<H`007oo029oo`03@Q0HaT8@02I240036<I247oo025oo`03<H`Q27oo02Ioo`00
<Woo00<aS000Ool08Woo00=S648@@Q009d8@00=S67ooOol087oo00<aS248Ool09Woo000bOol00c6<
001oo`1_Ool00c6<8@Qoo`0VOol0039oo`03<H`007oo06moo`03<H`Q27oo02Ioo`00<Woo00<aS000
Ool0Kgoo00<aS248Ool09Woo000bOol00c6<001oo`1_Ool00c6<8@Qoo`0VOol0039oo`03<H`007oo
06moo`03<H`Q27oo02Ioo`00<Woo00<aS000Ool0Kgoo00<aS248Ool09Woo000bOol00c6<001oo`1_
Ool00c6<8@Qoo`0VOol0039oo`03<H`007oo06moo`03<H`Q27oo02Ioo`00<Woo00<aS000Ool0Kgoo
00<aS248Ool09Woo000bOol00c6<001oo`1_Ool00c6<8@Qoo`0VOol0031oo`04Mkeooc6<001`Ool0
0c6<8@Qoo`0VOol0031oo`06MkeBU36<001JeVLiKWoo00<aS248Ool09Woo000aOol01AS648@000Q2
Mkd06Goo00=JeT8@@Q00=48@00=JeWooOol06goo00<aS248Ool09Woo000aOol0136<000001246Woo
00<aS248@Q00<d8@00<Q236<Ool077oo00<aS248Ool09Woo000aOol015[F0000036<6Woo00<aS48@
Ool0<goo00=2436<Ool077oo00<aS248Ool09Woo000aOol016mk000003W>6Woo00<aS48@Ool03Goo
00A_NgNmOomW>@9_N`03Mkeoogoo009oo`03Mkeoogoo009oo`9_N`9oo`04Kg]oofLiKg/>Ool00d8@
<Haoo`0LOol00c6<8@Qoo`0VOol0039oo`036<H005Je01Yoo`03<Ha247oo00eoo`07Kg]247NmBU9o
ofmk>Lh017oo00=247ooOol00Woo00PicWooOom246mkF]IoocW>3Woo00=2436<Ool077oo00<aS248
Ool09Woo000bOol00c6<001_N`0JOol00c6<@Q1oo`0=Ool01gNm<Haood8@Oom_NcW>009oo`04IcUB
U2U:DY@3Ool0248@OomNme:DOolaS7oo>Lh>Ool00d8@<Haoo`0LOol00c6<8@Qoo`0VOol0039oo`03
DY@007Nm01Yoo`03<Ha247oo00eoo`08Kg]:DVLi@Q1oofLiAS5W>@=oo`03@Q1oogoo009oo`08@Q1o
oekgDYAoob48Oom240ioo`03@Q0aS7oo01aoo`03<H`Q27oo02Ioo`00<Woo00=_Nb48Ool06Woo00<a
S48@Ool047oo00=NmgNmOol01Goo00=_NgooOol00Woo00PicWooKg/icWNm>Li_Nekg3Woo00=2436<
Ool077oo00<aS248Ool09Woo000aOol016LiBU8Q24YB6Woo00<aS48@Ool04Goo00=W>GooOol02Goo
00MBU7ooOomJeUkgMke_N`0?Ool00d8@<Haoo`0LOol00c6<8@Qoo`0VOol0031oo`07F]H@Q2U:=JdH
aPQ2IcT067oo00<aS48@Ool0<goo00=2436<Ool077oo00<aS248Ool09Woo000UOol01VLi@Q0aS48@
G_Mg_@Aoo`08Mkd@Q5[FKg]g_Fmk@Q0@Q0ioo`05IcTaS48@DYA_N`05Ool00c6<@Q1oo`0cOol00d8@
<Haoo`0KOol0148@248@Q6<H4goo00=NmdYBE[D047oo0009Ool00gNmE[EF]@0JE[D00dYB00000002
00001PQ2@Q1F]GNmBU8DY@9[FP05Lia[FV]J249:DP0>E[D02dYB00000000248Q24YBG_MoocF]@Q00
2goo00=g_EJeE[D06UJe00=[FWooOol02Goo00=24248E[D06UJe00E24000000001BU01AF]@07:DX0
00005:De[EJeJeX02goo0009Ool00ekg0000000P00001@Q2<Ha:DS6<:DX00Vmk00Ag_FmkKg/@Q1D0
0005248Q24YB8@Q2400dOol00d8@0000000j00000aS6<HaW>@08Ool002Eoo`07Mke241S6>Li246Li
Mkd00goo00UF]A24Kg]_NgNmKg]W>@Q2Kg/03Goo00Mg_C6<48@aS48@E[Eg_@03Ool00c6<@Q1oo`0c
Ool00d8@<Haoo`0JOol01Ekg000000008@P057oo00MNm`Q2248@Q3W>BU9F]@0;Ool002Eoo`03Mkeo
ogoo00Qoo`0548@YBVLiMkeW>@02:DX>Ool00fmkOomoo`07Ool00c6<@Q1oo`0@Ool00gNmIcUoo`0@
Ool00fLiOomoo`0=Ool00d8@<Haoo`0KOol014YB48@YBVmk4goo00=W>EJeKg/047oo000`Ool00fLi
:DX8@P0224800c6<Oomoo`0GOol00c6<@Q1oo`0<Ool027NmHaQBU6mkBU9ooeJeIcT4Ool03EkgOomo
ogooE[ENmfLiOomBU5kgIcUooe:D00ioo`03@Q0aS7oo04Eoo`00<Woo00=g_F]JOol06Woo00<aS48@
Ool03Goo0T8@00]oodYBOomood8@Kg]oogNmKg]246mk00Aoo`07F]Ig_CW>OolicWoo@Q003Woo00=2
436<Ool0>Goo00=g_GooOol02Goo0008Ool016mk<H`icTYB@goo00<aS48@Ool03Goo00i:DUkgMkdi
cWooKg]247NmOom_Ne:D>LiBU7Nm0Woo00Qg_BU:IcU247oo<Haood8@3Woo00=2436<Ool0>7oo00=:
DRU:Kg/02Woo0008Ool015:D<HaBU36<@goo00<aS48@Ool03Goo00AF]DicKg]:DP9oo`9W>@=oo`0=
DYAoogooOomW>CW>F]I_Nd8@OolaS7ooDY@03Woo00=2436<Ool0>Woo00=:DWooOol027oo0008Ool0
15:D<HaBU36<@goo00<aS48@Ool03Goo00Eg_DYBOomg_EJe00]oo`08<Ha247ooBU9Nme:DIcUg_@io
o`03@Q0aS7oo03Uoo`03E[D@Q7Nm00Uoo`0027oo00ANme:DE[EBU4=oo`03<Ha247oo03=oo`03@Q0a
S7oo03Uoo`03:DY246<H00Uoo`00Cgoo00<aS48@Ool0<goo00=2436<Ool0>7oo00Ag_CW>Kg]F]@Uo
o`00Cgoo00<aS3W>Kg/00fmk00=[FVmkKg/07fmk00=g_FmkKg/02fmk00<icS6<Ool0AGoo001?Ool0
0c6<0000000d00000c6<Oomoo`14Ool00<eoo`00cGoo003=Ool00<eoo`00cGoo003=Ool00001\
\>"],
  CellTags->"5.2.2"],

Cell[TextData[{
  StyleBox["Figure 5.2. ",
    FontWeight->"Bold"],
  "Example system for gain and phase margin selection."
}], "Caption",
  CellTags->"5.2.2"],

Cell["This defines the plant. ", "MathCaption",
  CellTags->"5.2.2"],

Cell["g = TransferFunction[s, k(s+50)/(s(s+10))];", "Input",
  CellLabel->"In[17]:=",
  CellTags->"5.2.2"],

Cell["This is the regulator. ", "MathCaption",
  CellTags->"5.2.2"],

Cell["h = TransferFunction[s, 1/(s+20)];", "Input",
  CellLabel->"In[18]:=",
  CellTags->"5.2.2"],

Cell["Here is the open\[Hyphen]loop system formed from the above blocks. ", 
  "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{

Cell["SeriesConnect[g, h]", "Input",
  CellLabel->"In[19]:=",
  CellTags->"5.2.2"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(k\ \((50 + s)\)\)\/\(s\ \((10 + s)\)\ \((20 + s)\)\)}}]\)], 
  "Output",
  CellLabel->"Out[19]=",
  CellTags->"5.2.2"]
}, Open  ]],

Cell[TextData[{
  "This is the Bode plot for a particular value of ",
  StyleBox["k", "MR"],
  ". "
}], "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{

Cell["BodePlot[% /. k -> 4.]", "Input",
  CellLabel->"In[20]:=",
  CellTags->"5.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 1.131 0.005815 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2619 -0.0125 -5 -12.5625 ]
[.2619 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.7381 -0.0125 -11 -12.5625 ]
[.7381 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12.5625 ]
[.97619 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .0843 -24 -4.5 ]
[-0.0125 .0843 0 4.5 ]
[-0.0125 .2006 -24 -4.5 ]
[-0.0125 .2006 0 4.5 ]
[-0.0125 .3169 -24 -4.5 ]
[-0.0125 .3169 0 4.5 ]
[-0.0125 .4332 -24 -4.5 ]
[-0.0125 .4332 0 4.5 ]
[-0.0125 .5495 -24 -4.5 ]
[-0.0125 .5495 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2619 .63053 -5 0 ]
[.2619 .63053 5 12.5625 ]
[.5 .63053 -8 0 ]
[.5 .63053 8 12.5625 ]
[.7381 .63053 -11 0 ]
[.7381 .63053 11 12.5625 ]
[.97619 .63053 -14 0 ]
[.97619 .63053 14 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.09548 0 m
.09548 .61803 L
s
.13741 0 m
.13741 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.19023 0 m
.19023 .61803 L
s
.20908 0 m
.20908 .61803 L
s
.22502 0 m
.22502 .61803 L
s
.23883 0 m
.23883 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.33358 0 m
.33358 .61803 L
s
.37551 0 m
.37551 .61803 L
s
.40525 0 m
.40525 .61803 L
s
.42833 0 m
.42833 .61803 L
s
.44718 0 m
.44718 .61803 L
s
.46312 0 m
.46312 .61803 L
s
.47693 0 m
.47693 .61803 L
s
.48911 0 m
.48911 .61803 L
s
.57167 0 m
.57167 .61803 L
s
.6136 0 m
.6136 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.66642 0 m
.66642 .61803 L
s
.68527 0 m
.68527 .61803 L
s
.70121 0 m
.70121 .61803 L
s
.71502 0 m
.71502 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.80977 0 m
.80977 .61803 L
s
.8517 0 m
.8517 .61803 L
s
.88144 0 m
.88144 .61803 L
s
.90452 0 m
.90452 .61803 L
s
.92337 0 m
.92337 .61803 L
s
.93931 0 m
.93931 .61803 L
s
.95312 0 m
.95312 .61803 L
s
.9653 0 m
.9653 .61803 L
s
0 .0843 m
1 .0843 L
s
0 .2006 m
1 .2006 L
s
0 .3169 m
1 .3169 L
s
0 .4332 m
1 .4332 L
s
0 .5495 m
1 .5495 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .0843 m
.00625 .0843 L
s
[(-180)] -0.0125 .0843 1 0 Mshowa
0 .2006 m
.00625 .2006 L
s
[(-160)] -0.0125 .2006 1 0 Mshowa
0 .3169 m
.00625 .3169 L
s
[(-140)] -0.0125 .3169 1 0 Mshowa
0 .4332 m
.00625 .4332 L
s
[(-120)] -0.0125 .4332 1 0 Mshowa
0 .5495 m
.00625 .5495 L
s
[(-100)] -0.0125 .5495 1 0 Mshowa
.125 Mabswid
0 .11337 m
.00375 .11337 L
s
0 .14245 m
.00375 .14245 L
s
0 .17152 m
.00375 .17152 L
s
0 .22967 m
.00375 .22967 L
s
0 .25875 m
.00375 .25875 L
s
0 .28782 m
.00375 .28782 L
s
0 .34597 m
.00375 .34597 L
s
0 .37505 m
.00375 .37505 L
s
0 .40413 m
.00375 .40413 L
s
0 .46228 m
.00375 .46228 L
s
0 .49135 m
.00375 .49135 L
s
0 .52043 m
.00375 .52043 L
s
0 .05522 m
.00375 .05522 L
s
0 .02615 m
.00375 .02615 L
s
0 .57858 m
.00375 .57858 L
s
0 .60765 m
.00375 .60765 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0843 m
1 .0843 L
s
.99375 .2006 m
1 .2006 L
s
.99375 .3169 m
1 .3169 L
s
.99375 .4332 m
1 .4332 L
s
.99375 .5495 m
1 .5495 L
s
.125 Mabswid
.99625 .11337 m
1 .11337 L
s
.99625 .14245 m
1 .14245 L
s
.99625 .17152 m
1 .17152 L
s
.99625 .22967 m
1 .22967 L
s
.99625 .25875 m
1 .25875 L
s
.99625 .28782 m
1 .28782 L
s
.99625 .34597 m
1 .34597 L
s
.99625 .37505 m
1 .37505 L
s
.99625 .40413 m
1 .40413 L
s
.99625 .46228 m
1 .46228 L
s
.99625 .49135 m
1 .49135 L
s
.99625 .52043 m
1 .52043 L
s
.99625 .05522 m
1 .05522 L
s
.99625 .02615 m
1 .02615 L
s
.99625 .57858 m
1 .57858 L
s
.99625 .60765 m
1 .60765 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .6017 L
.08949 .59948 L
.12233 .59642 L
.15517 .59223 L
.18801 .58647 L
.22085 .57857 L
.25369 .56774 L
.28654 .55294 L
.31938 .53279 L
.35222 .50557 L
.38506 .46931 L
.4179 .42218 L
.45074 .36336 L
.48358 .29429 L
.51642 .21973 L
.54926 .14741 L
.5821 .08609 L
.61494 .04274 L
.64778 .01991 L
.68062 .01472 L
.71346 .02079 L
.74631 .0317 L
.77915 .04315 L
.81199 .05314 L
.84483 .06113 L
.87767 .06724 L
.91051 .07181 L
.94335 .07518 L
.97619 .07765 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.511316 0.00460028 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2619 -0.0125 -5 -12.5625 ]
[.2619 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.7381 -0.0125 -11 -12.5625 ]
[.7381 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12.5625 ]
[.97619 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .05129 -24 -4.5 ]
[-0.0125 .05129 0 4.5 ]
[-0.0125 .14329 -18 -4.5 ]
[-0.0125 .14329 0 4.5 ]
[-0.0125 .2353 -18 -4.5 ]
[-0.0125 .2353 0 4.5 ]
[-0.0125 .3273 -18 -4.5 ]
[-0.0125 .3273 0 4.5 ]
[-0.0125 .41931 -18 -4.5 ]
[-0.0125 .41931 0 4.5 ]
[-0.0125 .51132 -6 -4.5 ]
[-0.0125 .51132 0 4.5 ]
[-0.0125 .60332 -12 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -44 ]
[-0.01875 .30902 -24 44 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2619 .63053 -5 0 ]
[.2619 .63053 5 12.5625 ]
[.5 .63053 -8 0 ]
[.5 .63053 8 12.5625 ]
[.7381 .63053 -11 0 ]
[.7381 .63053 11 12.5625 ]
[.97619 .63053 -14 0 ]
[.97619 .63053 14 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2619 0 m
.2619 .61803 L
s
.5 0 m
.5 .61803 L
s
.7381 0 m
.7381 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.09548 0 m
.09548 .61803 L
s
.13741 0 m
.13741 .61803 L
s
.16716 0 m
.16716 .61803 L
s
.19023 0 m
.19023 .61803 L
s
.20908 0 m
.20908 .61803 L
s
.22502 0 m
.22502 .61803 L
s
.23883 0 m
.23883 .61803 L
s
.25101 0 m
.25101 .61803 L
s
.33358 0 m
.33358 .61803 L
s
.37551 0 m
.37551 .61803 L
s
.40525 0 m
.40525 .61803 L
s
.42833 0 m
.42833 .61803 L
s
.44718 0 m
.44718 .61803 L
s
.46312 0 m
.46312 .61803 L
s
.47693 0 m
.47693 .61803 L
s
.48911 0 m
.48911 .61803 L
s
.57167 0 m
.57167 .61803 L
s
.6136 0 m
.6136 .61803 L
s
.64335 0 m
.64335 .61803 L
s
.66642 0 m
.66642 .61803 L
s
.68527 0 m
.68527 .61803 L
s
.70121 0 m
.70121 .61803 L
s
.71502 0 m
.71502 .61803 L
s
.7272 0 m
.7272 .61803 L
s
.80977 0 m
.80977 .61803 L
s
.8517 0 m
.8517 .61803 L
s
.88144 0 m
.88144 .61803 L
s
.90452 0 m
.90452 .61803 L
s
.92337 0 m
.92337 .61803 L
s
.93931 0 m
.93931 .61803 L
s
.95312 0 m
.95312 .61803 L
s
.9653 0 m
.9653 .61803 L
s
0 .05129 m
1 .05129 L
s
0 .14329 m
1 .14329 L
s
0 .2353 m
1 .2353 L
s
0 .3273 m
1 .3273 L
s
0 .41931 m
1 .41931 L
s
0 .51132 m
1 .51132 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .05129 m
.00625 .05129 L
s
[(-100)] -0.0125 .05129 1 0 Mshowa
0 .14329 m
.00625 .14329 L
s
[(-80)] -0.0125 .14329 1 0 Mshowa
0 .2353 m
.00625 .2353 L
s
[(-60)] -0.0125 .2353 1 0 Mshowa
0 .3273 m
.00625 .3273 L
s
[(-40)] -0.0125 .3273 1 0 Mshowa
0 .41931 m
.00625 .41931 L
s
[(-20)] -0.0125 .41931 1 0 Mshowa
0 .51132 m
.00625 .51132 L
s
[(0)] -0.0125 .51132 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(20)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .07429 m
.00375 .07429 L
s
0 .09729 m
.00375 .09729 L
s
0 .12029 m
.00375 .12029 L
s
0 .16629 m
.00375 .16629 L
s
0 .1893 m
.00375 .1893 L
s
0 .2123 m
.00375 .2123 L
s
0 .2583 m
.00375 .2583 L
s
0 .2813 m
.00375 .2813 L
s
0 .3043 m
.00375 .3043 L
s
0 .35031 m
.00375 .35031 L
s
0 .37331 m
.00375 .37331 L
s
0 .39631 m
.00375 .39631 L
s
0 .44231 m
.00375 .44231 L
s
0 .46531 m
.00375 .46531 L
s
0 .48831 m
.00375 .48831 L
s
0 .53432 m
.00375 .53432 L
s
0 .55732 m
.00375 .55732 L
s
0 .58032 m
.00375 .58032 L
s
0 .02829 m
.00375 .02829 L
s
0 .00529 m
.00375 .00529 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -135.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05129 m
1 .05129 L
s
.99375 .14329 m
1 .14329 L
s
.99375 .2353 m
1 .2353 L
s
.99375 .3273 m
1 .3273 L
s
.99375 .41931 m
1 .41931 L
s
.99375 .51132 m
1 .51132 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .07429 m
1 .07429 L
s
.99625 .09729 m
1 .09729 L
s
.99625 .12029 m
1 .12029 L
s
.99625 .16629 m
1 .16629 L
s
.99625 .1893 m
1 .1893 L
s
.99625 .2123 m
1 .2123 L
s
.99625 .2583 m
1 .2583 L
s
.99625 .2813 m
1 .2813 L
s
.99625 .3043 m
1 .3043 L
s
.99625 .35031 m
1 .35031 L
s
.99625 .37331 m
1 .37331 L
s
.99625 .39631 m
1 .39631 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .46531 m
1 .46531 L
s
.99625 .48831 m
1 .48831 L
s
.99625 .53432 m
1 .53432 L
s
.99625 .55732 m
1 .55732 L
s
.99625 .58032 m
1 .58032 L
s
.99625 .02829 m
1 .02829 L
s
.99625 .00529 m
1 .00529 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59063 L
.08949 .57793 L
.12233 .56523 L
.15517 .55253 L
.18801 .53981 L
.22085 .52707 L
.25369 .51428 L
.28654 .50141 L
.31938 .48838 L
.35222 .47506 L
.38506 .46123 L
.4179 .44649 L
.45074 .4303 L
.48358 .41196 L
.51642 .39086 L
.54926 .36671 L
.5821 .33975 L
.61494 .3108 L
.64778 .28101 L
.68062 .2515 L
.71346 .22291 L
.74631 .19536 L
.77915 .16865 L
.81199 .1425 L
.84483 .1167 L
.87767 .09108 L
.91051 .06558 L
.94335 .04013 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[20]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025o
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000aOol00`00Oomoo`02Ool00`00Oomo
o`05000IOol5000JOol50002Ool00`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0A
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0031oo`03001oo`0000Qo
o`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool0
0002Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eo
o`00<7oo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000H
Ool01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo
00000Woo00<007oo00005Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol0
1`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomo
o`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`0000Qoo`03001oogoo
01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00
Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`00<Goo00<0
07ooOol01Woo0P0077oo0P007Goo0P0017oo00<007ooOol05Woo0P0017oo00<007ooOol00Woo00<0
07ooOol04Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo003MOol00=eo
o`00gGoo000dOonA000HOol003Aoo`05001oogooOol00009Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00<007oo00000Woo00@007oo001oo`8000Uoo`03001oogoo00=oo`03001oogoo009oo`04
001oogoo0002Ool01P00Ool007oo001oo`8000Yoo`03001oogoo00=oo`05001oogooOol00002Ool0
2@00Oomoo`00Ool007oo001oo`02000:Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00`007oo
Ool007oo001oo`00Ool007oo0002Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`09Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo
00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`05
001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo
00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00mo
o`803`Yoo`0300moogoo00=oo`0400moogooOol<000200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`80009oo`03
00moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo
0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?
2Woo00<03gooOol00goo00D03gooOol0000?009oo`0900moogoo00moo`0?Ool03goo008000Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool03goo008001Qo
o`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02
Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600mo
o`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03goo001oo`0?009oo`0900moogoo00moo`0?Ool0
3goo00803`8000Qoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol0
0Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03`00Oomoo`0?
009oo`0900moogoo00moo`0?Ool03goo00803`9oo`8000Ioo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomo
o`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?
2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo
00<03gooOol00goo00D007ooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Aoo`@0009o
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03
001oogoo01Ioo`00=7oo0P000Woo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`02Ool00`0000moo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l8Ool50003Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00mo
o`0?Ool03goo00moo`02000HOol003Aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0700moogooOol007oo00l00goo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol010000goo00@03gooOol03`9oo`0900mo
o`0?Ool03goo00moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo
00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo
00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00@03gooOol0009oo`05
00moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool00`0?0000
000300003Goo00moogoo00moo`0?Ool03goo00moo`0?009oo`03001oogoo01Ioo`0097oo1@000Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`0300moogoo00Moo`0300moogoo00=oo`0500moogoo
Ool03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00@03gooOol0009oo`0500moogooOol03`02
Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01P0?Oomoogoo00moo`X00003
00moo`0?009oo`03001oogoo01Ioo`009Woo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool0
1@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400mo
o`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?
Ool200l:Ool00`0?Ool00003Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00<0009oo`03
001oogoo01Ioo`0047oo00<007ooOol00Woo00<007ooOol027oo0`000goo00L007ooOomoo`00Ool0
0002Ool00`00Ool00002Ool2001B00l00`0000l03`0h00l2000HOol0011oo`H0011oo`03001oogoo
009oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<007ooOol00goo00D03gooOomoo`0?009o
o`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`0047oo00H007ooOol007oo000@Ool0
1`00Oomoogoo001oo`00009oo`03001oo`00009oo`05001oogooOol03`09Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`03001oogoo00=oo`0500moogoo
Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0011oo`04001oogoo000A
Ool20004Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol01goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l9Ool00`0000moo`04Ool01@0?Oomo
ogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000AOol2000QOol20002
Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo
00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00mo
o`803`Uoo`0300003goo00Aoo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00moo`0?Ool03goo00moo`02
000HOol003Aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool0
1P0?Ool03goo00moo`803`Qoo`03001oo`0?00Eoo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool0
3goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l2Ool00`00Oomoo`0FOol0011oo`03001oogoo009oo`03001oogoo01aoo`05001oogoo
Ool03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`80
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Qo
o`03001oo`0?00Eoo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomo
o`0FOol0011oo`H001ioo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`Moo`04001oogoo00l5Ool01@0?Oomoogoo00l00Woo00T03goo
Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol01000Oomoo`007Woo0P000Woo00<03goo
Ool01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l7Ool0
1000Oomoo`0?1Goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool03goo008001Qoo`00
4Woo00<007ooOol07goo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?1Woo00D007ooOomoo`0?00Eoo`0500moogooOol03`02Ool02@0?
Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol001=oo`<001ioo`05001oogooOol03`09Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300mo
ogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Ioo`05001oogoo
Ool03`05Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo
000EOol00`00Oomoo`0LOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03goo00moo`0?Ool200l5Ool00`00Oomoo`02Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomo
o`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Eoo`03
001oogoo009oo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`02
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00moo`0?Ool03goo00mo
o`02000HOol001Aoo`8001ioo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00moo`803`Aoo`03001oogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`04001oo`00000>
Ool500000goo00000004Ool01@00Oomoogoo00000goo00<03gooOol01goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l4Ool00`00Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol0
1000Ool0000047oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l4Ool00`00Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<0
07ooOol05Woo000BOol4000:Ool30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`80
04X03`0300003`0?04003`8001Qoo`005Goo00<007ooOol03Woo00@007ooOomoo`8000=oo`03001o
o`00009oo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l0
0Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
Ool03goo00moo`803`=oo`03001oogoo00Aoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?
Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol0
3goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol002Ioo`05001oogooOol00004Ool00`00Ool0
0002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009o
o`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00moo`0?Ool200l2Ool00`00Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03goo
Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol200000goo001oo`0>Ool20004Ool20003
Ool01@00Oomoogoo00000goo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l2Ool00`00Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol200000goo001oo`0MOol2
0002Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@0
3goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo
00moo`803`9oo`03001oogoo00Eoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?
Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00mo
o`0?Ool03goo00moo`02000HOol0019oo`800003Ool007oo01eoo`05001oogooOol03`09Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo
00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`03Ool007oo00Moo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0F
Ool0019oo`03001oo`0001moo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Ool03goo00moo`803`03Ool007oo00Moo`0300moogoo00=oo`0500moogooOol0
3`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`09
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`03
00moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`03001oogoo
00Moo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00
Oomoo`0FOol003Aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<0
3goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool03goo00moo`803`03001oogoo00Moo`0300moogoo00=oo`0500moogooOol03`02Ool0
2@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol001=oo`8001moo`80009oo`0300moogoo
00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo
00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0800moo`0?Ool03goo00l000Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00moo`0?Ool03goo00moo`02000HOol0019o
o`800003Ool007oo01eoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Ool03goo00moo`0?000:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03goo
Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol200000goo001oo`0MOol01@00Oomoogoo
00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo00moo`0?Ool0000?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo
01Ioo`004goo00<007oo00007Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol0
3`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moo`0?Ool03goo00003`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0
2@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00Moo`03
00moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03`000P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`05
00moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool03goo008001Qoo`00=7oo00D007oo
Oomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo
0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03`000P0?
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001o
ogoo01Ioo`0097oo1@000Woo0`000Woo00D007ooOomoo`0000=oo`0300moogoo00Moo`0300moogoo
00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo
00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool007oo0P0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`009Woo00<007oo
Ool00goo00H007ooOol007oo0002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`00Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00mo
ogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000POol30003Ool01000Oomoogoo1000
00Aoo`00Ool0009oo`8004803`0300003`0?04P03`8001Qoo`009Woo00L007ooOomoo`00Ool00002
Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00l0000?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol0
3goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?0Woo00<007ooOol05Woo000VOol00`00Oomoo`02Ool20002Ool00`00Ool00002
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`04
00moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo001o
o`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool0
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
0Woo00<007ooOol05Woo000UOol20005Ool01@00Oomoogoo00000goo00D007ooOomoo`0?00Uoo`03
00moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`00Ool03goo0P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`05
00moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo
0P000Woo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`04
00moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03`0000mo
o`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool0
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0=00moogoo00moo`0?Ool03goo00moo`0?
Ool00P0067oo000BOol4000NOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03`0000moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T0
3gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000AOol00`00Oomoo`02Ool00`00Oomoo`0K
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`04
00moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H007oo00mo
o`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool0
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
0Woo00<007ooOol05Woo000@Ool00`00Oomoo`04Ool00`00Oomoo`0JOol01@00Oomoogoo00l02Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H007oo00moo`0?Ool200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000d
Ool20002Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0<00moogoo00moo`0000moo`0?
Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo
00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool0
3goo008001Qoo`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00`03gooOol0
3goo00003goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol0
3goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?0Woo00<007ooOol05Woo000COol2000OOol01@00Oomoogoo00l02Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0300?Oomoo`0?001oo`0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`05
00moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`04001o
ogoo000NOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?
009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`000Woo00H0
3goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00mo
o`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?0Woo00<007ooOol05Woo000@Ool00`00Ool00002Ool00`00Oomoo`0LOol20002Ool00`0?
Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`80
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo0002Ool01P0?Ool03goo00moo`803`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00d03gooOol03goo00moo`0?Ool03goo00moo`02000HOol0
011oo`H001ioo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moo`0000l2Ool0
1P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool0
3goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l2Ool00`00Oomoo`0FOol001Eoo`03001oogoo01aoo`05001oogooOol03`09Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo
00=oo`0300moogoo009oo`0400moo`0000l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol002Aoo`D0
0004Ool000000003Ool01@00Oomoogoo00000goo00<03gooOol01goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool0100?001oo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<
00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000COol2000AOol01@00Oomoogoo
000017oo00<007oo00000Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03
Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@007oo
Ool03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900mo
ogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?
Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Woo0P0000=oo`00Ool02Goo0`000goo00<0
07ooOol00Woo00L007ooOomoo`00Ool00002Ool2000i00l00`0000l03`1A00l2000HOol0019oo`80
0003Ool007oo00moo`03001oogoo009oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00Uo
o`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<0
3gooOol00goo00H03gooOomoo`0000l2Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo
00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000C
Ool00`00Ool0000@Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`05001oogooOol03`09
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`03
00moogoo00=oo`0600moogooOol0000?0Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00
9Goo0P0017oo00<007ooOol00Woo00D007ooOomoo`0000=oo`0300moogoo00Moo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00H0
3gooOol007oo00l2Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000dOol20002Ool00`0?
Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`80
3`Uoo`0300moogoo00=oo`0600moogoo001oo`0?0Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool03goo008001Qoo`00
4goo0P000Woo00<007ooOol06Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol0
3`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03gooOol00goo00<03goo00000Woo00@0
3gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`09
00moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomo
o`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Woo00H007ooOol007oo000LOol01@00
Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?
Ool200l9Ool00`0?Oomoo`03Ool00`0?001oo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool2
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<0
07ooOol05Woo000BOol01P00Oomoo`00Ool001aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`03001o
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`D001eoo`80009o
o`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool0100?Ool0
3goo0P0?2Goo00<03gooOol00Woo00<0000?Ool00goo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool03goo0080
01Qoo`004Woo00<007ooOol07goo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol0
3`03Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00L03gooOomoo`00Ool03`04Ool0100?Oomo
o`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03goo
Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00mo
o`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l9Ool0100?Oomoo`000Woo
00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`0047oo00<007oo
Ool017oo00<007ooOol06Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03
Ool00`0?Ool03`02Ool0100?Ool03goo0P0?2Goo00<03goo00000goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900mo
ogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?
Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Goo00<007ooOol00Woo00<007ooOol06goo
0P000Woo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`04
00moo`0?Ool200l9Ool20004Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool2
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0=00moogoo00moo`0?Ool03goo00moo`0?Ool00P00
67oo000BOol4000NOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0400moo`0?Ool200l8Ool00`0000moo`04Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol0
3goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?
Ool03goo00moo`0?0Woo00<007ooOol05Woo000TOol50002Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`04
00moo`0?Ool200l7Ool00`00Ool03`05Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool0
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?
0Woo00<007ooOol05Woo000VOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`05001oogoo
Ool03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`80
3`Ioo`04001oogoo00l5Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007oo
Ool05Woo000POol30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`8002T03`800680
3`8001Qoo`009Woo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0400moo`0?Ool200l2Ool20005
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol0
5Woo000VOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`05001oogooOol03`09Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`8000Moo`0300mo
ogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo
00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol002Eo
o`8000Aoo`03001oogoo009oo`05001oogooOol00003Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00<03goo00000`002Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo0P000Woo00<03goo
Ool01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?00@0000400moo`0?00l9Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0=00moogoo00moo`0?Ool03goo00moo`0?Ool00P0067oo000dOol0
1@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300l00000009oo`0400mo
o`0?Ool200l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?
Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo
00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03gooOol00goo00<03`0000001P0000Qo
o`0?Oomoo`0?Ool03goo0P0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`06
00moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?
Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00mo
o`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00Moo`T000=oo`0700moogooOol0
3goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?
Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`04001oogooOol80002Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00@03goo00moo`803`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`80009oo`03001o
ogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03goo00l0
00Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool0200?Ool03goo00moo`0?000:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00/03gooOol03goo00moo`0?Ool03`0000Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool03@0?Oomoo`0?Ool03goo00moo`0?Ool007oo008001Qo
o`00=7ooT@0067oo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000aOol00`00Oomoo`02Ool0
0`00Oomoo`05000IOol5000JOol50002Ool00`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00
Oomoo`0AOol50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0031oo`03001o
o`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomo
o`00Ool00002Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001o
o`0001Eoo`00<7oo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00
Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo
00<007oo00000Woo00<007oo00005Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomo
o`0LOol01`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L0
07ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`0000Qoo`03
001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002
Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`00
<Goo00<007ooOol01Woo0P0077oo0P007Goo0P0017oo00<007ooOol05Woo0P0017oo00<007ooOol0
0Woo00<007ooOol04Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo003M
Ool00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003M
Ool00=eoo`00gGoo003MOol00=eoo`00C7oo0P005Goo0P005Goo00<007ooOol0?7oo00<007ooOol0
8Goo001=Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0XOol00`00
Oomoo`0POol003Yoo`<000=oo`<000=oo`8000=oo`<0009oo`<0009oo`800003Ool00000009oo`03
001oo`00008000=oo`03001oogoo015oo`04001oogooOol300000goo001oo`040002Ool30005Ool0
0`00Oomoo`02Ool30003Ool20002Ool30003Ool200000goo00000002Ool00`00Oomoo`030009Ool0
0`00Oomoo`0OOol003]oo`03001oogoo00=oo`05001oogooOol00004Ool01P00Oomoo`00Ool0009o
o`03001oo`0000Aoo`06001oogoo001oo`0017oo00<007oo00004Woo00<007ooOol00Woo00D007oo
Ool007oo00<0009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03001o
ogoo01moo`00>goo00<007ooOol00goo00@007ooOomoo`<0009oo`06001oogoo001oo`000Woo00<0
07oo00000P000Woo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00Oomoo`02Ool30004Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol00`000Woo00<007ooOol0
0Woo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0OOol003]o
o`8000=oo`@00004Ool000000003Ool5000017oo000007oo0`0000=oo`0000000P000Woo0`0000Ao
o`00001oo`80015oo`03001oogoo009oo`04001oogoo0002Ool20003Ool30006Ool00`00Oomoo`02
Ool01000Oomoogoo0`000Woo0`000goo0P0000=oo`0000000P000goo0`002Goo00<007ooOol07goo
000kOol01000Oomoo`00>Woo00D007ooOomoo`00009oo`03001oogoo00Moo`03001oogoo00Aoo`07
001oogooOol007oo00006Goo00<007ooOol01Woo00<007ooOol087oo000jOol5000kOol00`00Ool0
00030009Ool20007Ool00`00Oomoo`03000HOol20007Ool00`00Oomoo`0QOol00=eoo`00gGoo003M
Ool00=eoo`00gGoo003MOol00=eoo`00<Goo00<007ooOol00Woo00<007ooOol01@006Goo1@006Woo
1@000Woo00<007ooOol05Goo1@000Woo00<007ooOol00Woo00<007ooOol04Goo1@000Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol057oo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol0
0`00Oomoo`0LOol01`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo0000
57oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`00
00Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00
Ool00002Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`00
01Eoo`00<7oo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0
000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<0
07oo00000Woo00<007oo00005Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0L
Ool01`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007oo
Oomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0035oo`03001oogoo00Ioo`8001ao
o`8001eoo`8000Aoo`03001oogoo01Ioo`8000Aoo`03001oogoo009oo`03001oogoo019oo`8000Ao
o`03001oogoo009oo`03001oogoo009oo`03001oogoo01Aoo`00gGoo003MOol00=eoo`00=7ooT@00
67oo000dOol20002Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00<007oo
00000Woo00H007oo000007oo0009Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01000Oomoo`000Woo
00H007oo001oo`00Ool2000:Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00T007ooOol007oo
001oo`00Ool00P002Woo00<007ooOol00goo00D007ooOomoo`00009oo`0<001oogoo001oo`00Ool0
07oo001oo`000Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?
00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo0002Ool00`00Oomoo`0F
Ool0011oo`H001ioo`80009oo`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomo
o`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo
00moo`0?Ool00P0000@03gooOol001Qoo`0047oo0`000Woo00<007ooOol077oo00D007ooOomoo`0?
00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uo
o`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00L03gooOol03goo00moo`0200000`0?Ool03`02Ool00`00Oomo
o`0FOol001=oo`03001oogoo00ioo`D0009oo`03001oogoo009oo`05001oogooOol00003Ool00`0?
Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo
00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?00003goo00moo`0?0Woo00<007oo
Ool05Woo000@Ool30002Ool00`00Oomoo`0>Ool01`00Oomoogoo001oo`00009oo`03001oo`00009o
o`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H0
3goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool0
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`00Ool03goo00moo`0?
0Woo00<007ooOol05Woo000@Ool6000:Ool30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`8008<03`8000P03`8001Qoo`0047oo00<007ooOol00Woo00<007ooOol03Woo00L007ooOomo
o`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Ool0000?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`009Woo00L007ooOomoo`00Ool00002
Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo
00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?001oo`0?Ool0
3goo00moo`0?Ool03`9oo`03001oogoo01Ioo`0057oo0P003goo0P0017oo00<007ooOol00Woo00@0
07ooOomoo`80009oo`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool0
3`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool0
1P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool0
3goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`007ooOol03goo00moo`0?
Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`04001oo`00000NOol01@00Oomoogoo00l02Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03goo
Ool00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`08
00moogooOol03goo00003`9oo`0900moo`0?Ool03goo00moo`0?009oo`03001oogoo01Ioo`004Woo
00@007oo000001ioo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<0
3goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol0
3goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00P03gooOomoo`0?001oo`0?0Woo00T03goo00mo
o`0?Ool03goo00l00Woo00<007ooOol05Woo000BOol4000NOol20002Ool00`0?Oomoo`07Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D0
3gooOomoo`00009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000EOol0
0`00Oomoo`0LOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300mo
o`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9o
o`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00mo
o`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moo`0000003`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`05
00moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool20002Ool0100?Oomo
o`0?0Woo00T03goo00moo`0?Ool03goo00l00Woo00<007ooOol05Woo000COol20002Ool00`00Oomo
o`0JOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009o
o`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600mo
o`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool0
3goo00803`Yoo`0300moogoo009oo`0300003goo009oo`0400moogoo00l2Ool02@0?Ool03goo00mo
o`0?Ool03`02Ool00`00Oomoo`0FOol0019oo`06001oogoo001oo`0077oo0P000Woo00<03gooOol0
1goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo
00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0700moogoo
Ool007oo00l00goo00@03gooOol03`9oo`0900moo`0?Ool03goo00moo`0?009oo`03001oogoo01Io
o`004Woo00H007ooOol007oo000COol00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol0
1goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo
00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0400moo`00
0002Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0F
Ool0019oo`D001=oo`03001oo`00009oo`03001oo`00009oo`05001oogooOol03`09Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03`00Ool00goo00D03goo
Oomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol00`00
Oomoo`0@Ool30002Ool00`00Ool00002Ool00`00Ool00002Ool2001c00l00`0000l03`0G00l2000H
Ool0019oo`04001oogoo000EOol01`00Oomoogoo001oo`00009oo`05001oogooOol03`09Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Goo00<0000?Ool017oo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol4
000DOol00`00Ool00002Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0900moogoo00moo`0?Ool03goo00803`Moo`800003Ool03goo00Aoo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Woo00<007ooOol0
5Woo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo00Moo`0300moogoo00=oo`0500mo
ogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo
009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l6Ool01@00Oomoogoo00l01Goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol00`00Oomoo`0O
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo
00803`Eoo`03001oogoo009oo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool0
3goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004goo0`007Woo00D007ooOomoo`0?00Uoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo
00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=o
o`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l4Ool00`00Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomo
o`0FOol001Eoo`03001oogoo01aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00T03gooOol03goo00moo`0?Ool00P0?0Woo0P001Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomo
o`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?00=oo`00Ool0
1goo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo
00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900mo
ogoo00moo`0?Ool03goo00803`03001oogoo00Moo`0300moogoo00=oo`0500moogooOol03`02Ool0
300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Woo00@007ooOol001ioo`05
001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo
00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?
Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P00
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo
00<007ooOol05Woo000@Ool00`00Ool00003000NOol20002Ool00`0?Oomoo`07Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00Woo00T03gooOol03goo00moo`0?00000P0?2Woo00<03gooOol00goo00D03gooOomo
o`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000EOol00`00Oomo
o`0BOol20004Ool01@00Oomoogoo00000goo00<03gooOol01goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo
00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009o
o`0900moogoo00moo`0?Ool007oo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?
Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00:Woo00<007oo00000Woo00<007oo
00000Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02
Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03`00
00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool0
3goo00l2Ool00`00Oomoo`0FOol0019oo`03001oogoo011oo`<0009oo`03001oo`00009oo`03001o
o`00009oo`8006<03`0300003`0?02L03`8001Qoo`004Goo10005Goo0P000goo00<007oo00000Woo
00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?
Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo
00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?00003goo00moo`02
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2
Ool00`00Oomoo`0FOol0019oo`04001oogoo000DOol00`00Oomoo`02Ool00`00Ool00002Ool01@00
Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?
00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo001oo`0?Ool03goo00803`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03
001oogoo01Ioo`004Woo00@007ooOol001Eoo`8000=oo`05001oogooOol00003Ool00`0?Oomoo`07
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03goo00003goo00moo`0?Ool00P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo
000BOol00`00Ool0000OOol20002Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T0
3`00Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol0
0goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo
00H03gooOomoo`0?Ool20002Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogoo
Ool03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004Woo00<007oo
Ool07goo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02
Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
Ool03goo00moo`803`Yoo`0300moogoo00=oo`0800moogooOol03`00Ool03`9oo`0600moo`0?Ool0
3goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?0Woo00<007ooOol05Woo000BOol3000OOol20002Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00000Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?
009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000EOol00`00Oomoo`0L
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOol0000?009oo`0900moogoo00moo`0?Ool03goo
00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`9oo`03001oogoo01Ioo`004Woo00<007oo00007goo00D007ooOomoo`0?00Uoo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`03
00moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500mo
o`00Ool03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`@001ioo`80
009oo`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?
Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo
00moo`803`Yoo`0300moogoo00=oo`0500l007ooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`02
00l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2
Ool00`00Oomoo`0FOol001Eoo`03001oogoo01=oo`<0009oo`05001oogooOol00003Ool00`0?Oomo
o`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool0
0`0?Oomoo`03Ool01@00Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol0
5Woo000/Ool01P00Oomoo`00Ool0009oo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`02Ool00`0000moo`02Ool0
100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol001=oo`80011oo`<0009oo`@0
0004Ool007oo0002Ool2001D00l2000g00l2000HOol0019oo`04001oogoo000DOol00`00Ool00002
Ool00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`03
00moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moo`0?Ool03goo0P0?2Woo00<03goo00000goo00D03gooOomoo`0?009oo`0900moogoo
00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool0
3goo00moo`0?Ool03`9oo`03001oogoo01Ioo`0047oo00<007oo00000Woo00<007ooOol04goo0P00
0Woo00<007oo00000Woo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool0
0`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Ool03goo00moo`803`Yoo`0300l007oo00=oo`0500moogooOol03`02Ool02@0?Oomo
o`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo
00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0011oo`H001Ioo`05001oogooOol00003Ool01@00
Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?
00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?2Woo00<007ooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03
001oogoo01Ioo`005Goo00<007ooOol077oo0P000Woo00<03gooOol01goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?27oo0P0000<03gooOol00goo00D03goo
Oomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomo
o`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool0
3`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Mo
o`04001oogoo00l5Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007oo
Ool05Woo000COol2000OOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03goo
Ool03`9oo`0600moo`0?Ool03goo0P0?1Woo00D007ooOomoo`0?00Eoo`0500moogooOol03`02Ool0
2@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`800003Ool007oo01eoo`80009o
o`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool0
3`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00mo
o`803`Eoo`03001oogoo009oo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool0
3goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?
Ool03goo00l2Ool00`00Oomoo`0FOol0019oo`800003Ool007oo01eoo`05001oogooOol03`09Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l4Ool00`00Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<0
07ooOol05Woo000COol00`00Ool0000NOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol0
0Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?0goo00<007ooOol017oo00<03gooOol00goo
00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo0P00
0Woo00<03gooOol01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600mo
o`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool0
3goo0P0?0Woo00<007ooOol01Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00mo
o`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`9oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00Uoo`0300moogoo00=oo`05
00moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`8000Qoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol002Yoo`<000=oo`05
001oogooOol00003Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo
00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00moo`0?Ool2000:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo
00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool0
3goo00moo`0?0Woo00<007ooOol05Woo000ZOol00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomo
ogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00mo
o`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0400moo`0?Ool2000200l:
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<0
3gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007oo
Ool05Woo000UOol30003Ool01`00Oomoogoo001oo`00009oo`8004403`8004X03`8001Qoo`00:goo
00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@0
3gooOol03`9oo`80000400moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T0
3gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000ZOol00`00Ool00002Ool00`00Ool00002
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`80000600moo`0?
Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo
00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`9oo`03001oogoo01Ioo`00:goo00<007ooOol00Woo00@007ooOomoo`80009oo`0300moogoo00Mo
o`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`03
00moogoo00=oo`0300moogoo009oo`0400moo`000002Ool01P0?Ool03goo00moo`803`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0
03Aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo
00H03goo00l03goo00l9Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?001oo`0?0Woo00H03goo
00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?
Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00mo
o`0?0Woo00<007ooOol05Woo000BOol4000NOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00@03goo
Oomoo`80009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol0
3`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0015oo`03001oogoo009oo`03
001oogoo01]oo`80009oo`0300moogoo00Moo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?
Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0600l00000001oo`0?0Woo00T03goo
Ool03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00mo
o`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`9oo`03001oogoo01Ioo`0047oo00<007ooOol017oo00<007ooOol06Woo00D007oo
Oomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?
Ool03`Uoo`0300moogoo009oo`8000Aoo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0F
Ool003Aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l0
0Woo00H03goo00l03goo00l9Ool00`0?Ool0000200000goo00moo`03Ool0100?Oomoo`0?0Woo00H0
3goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00mo
o`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo
00moo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l02Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?2Goo0P0017oo00<03gooOol00Woo00@0
3gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`09
00moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomo
o`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`004goo0P007goo0P000Woo00<03gooOol0
1goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?1Woo
0`0000<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo
00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300mo
ogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo
01Ioo`004Woo00@007ooOol001Yoo`05001oogooOol00003Ool00`0?Oomoo`07Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l2Ool40003Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D0
3gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000@Ool0
0`00Ool00002Ool00`00Oomoo`0GOol00`00Ool00002Ool01@00Oomoogoo00l02Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`0600moo`0?00moo`0?0P001goo00<03gooOol0
0goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo
00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001oogoo01Ioo`0047oo1P00
6Goo00<007oo00000Woo0P008P0?0`00J00?0P0067oo000EOol00`00Oomoo`0GOol00`00Ool00002
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0?009oo`06
00l0000000moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?
Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo
00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool0
3`9oo`03001oogoo01Ioo`0047oo00<007ooOol00Woo00<007ooOol05goo00<007oo00000Woo00D0
07ooOomoo`0?00Uoo`0300moogoo00=oo`0500moogooOol03`03Ool00`0?Ool03`0300001Goo00l0
3goo00l02Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo
0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yo
o`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03
001oogoo01Ioo`0047oo1P006Woo00@007ooOomoo`80009oo`0300moogoo00Moo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0?00000002Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`03
00moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500mo
ogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol0011oo`03001oo`00
009oo`03001oogoo01aoo`05001oogooOol03`09Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo
0P0000Ioo`0?Oomoo`0?Ool200l00goo00moo`08Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T0
3gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0<00moogoo
00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000@Ool00`00Ool00002Ool00`00Oomoo`0L
Ool01@00Oomoogoo00l02Goo00<03gooOol00goo00D03gooOomoo`0?00800004Ool03goo00l2Ool0
1P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0
3goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00mo
o`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo
00l2Ool00`00Oomoo`0FOol0015oo`04001oo`00000OOol20002Ool00`0?Oomoo`07Ool00`0?Oomo
o`03Ool00`0?Ool000020003Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`05
00moogooOol03`02Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00Woo00`03gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol003Aoo`05001o
ogooOol03`09Ool00`0?Oomoo`03Ool20002Ool01`0?Oomoogoo00moo`0?009oo`0600moo`0?00mo
o`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9oo`0600moo`0?Ool03goo0P0?
2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00moo`0?Ool03goo00803`Yoo`03
00moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo00moo`0?Ool03`9oo`03001o
ogoo01Ioo`00=7oo00D007ooOomoo`0?00Uoo`0300moo`0000<0000500moogooOol03`03Ool00`0?
Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009oo`0400moogoo00l2
Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool02@0?Oomoo`0?
Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03gooOol03goo00mo
o`0?Ool03goo00l2Ool00`00Oomoo`0FOol0011oo`03001oogoo00Aoo`03001oogoo01Yoo`05001o
ogooOol03`08Ool30004Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03goo
Ool00goo00D03gooOomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol0
5Woo000AOol00`00Oomoo`02Ool00`00Oomoo`0KOol20002Ool00`0?Oomoo`04Ool200000goo00mo
o`04Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol00goo00D03goo
Oomoo`0?009oo`0<00moogoo00moo`0?Ool03goo00moo`0?0Woo00<007ooOol05Woo000BOol4000D
Ool30003Ool01@00Oomoogoo00000goo00@03gooOomoo`<000=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool00`0?Ool03`02Ool01P0?Ool03`0?Ool03`Uoo`0300moogoo00=oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Ool03goo00moo`803`Yoo`0300moogoo00=oo`0500moogooOol03`02
Ool02@0?Oomoo`0?Ool03goo00moo`0200l:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`0
3gooOol03goo00moo`0?Ool03goo00l2Ool00`00Oomoo`0FOol002Yoo`03001oogoo009oo`03001o
o`00009oo`06001oogooOol03goo0P001Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300mo
o`0?009oo`0600moo`0?00moo`0?2Goo00<03gooOol00goo00<03gooOol00Woo00@03gooOol03`9o
o`0600moo`0?Ool03goo0P0?2Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0900moogoo00mo
o`0?Ool03goo00803`Yoo`0300moogoo00=oo`0500moogooOol03`02Ool0300?Oomoo`0?Ool03goo
00moo`0?Ool03`9oo`03001oogoo01Ioo`00:goo00L007ooOomoo`00Ool00002Ool20002Ool20008
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<03goo00l00Woo00H03goo00l03goo00l9Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo00moo`0?Ool200l:Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00Woo00T03gooOol03goo00moo`0?Ool00P0?2Woo00<03gooOol0
0goo00D03gooOomoo`0?009oo`0=00moogoo00moo`0?Ool03goo00moo`0?Ool00P0067oo000[Ool0
1`00Oomoogoo001oo`00009oo`05001oogooOol00009Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00<03goo00l00Woo00H03goo00l03goo0009Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03goo00moo`0?Ool03`002Woo00<03gooOol00goo00D03gooOomoo`0?009oo`0;
00moogoo00moo`0?Ool03goo00l0000:Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00`03goo
Ool03goo00moo`0?Ool03goo0002Ool00`00Oomoo`0FOol002Yoo`03001oo`00009oo`03001oo`00
009ooi4001Qoo`00:goo00<007ooOol00Woo00<007ooOol0ZWoo003MOol00=eoo`00gGoo003MOol0
0=eoo`00<Goo00<007ooOol00Woo00<007ooOol01@006Goo1@006Woo1@000Woo00<007ooOol05Goo
1@000Woo00<007ooOol00Woo00<007ooOol04Goo1@000Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol057oo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol01`00Oomo
ogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomoo`00Ool0
0002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`0000Qoo`03001oogoo01]oo`03
001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0000D
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`00<7oo00<007oo0000
27oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001o
o`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo0000
5Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol01`00Oomoogoo001oo`00
01Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomoo`00Ool00002Ool00`00
Ool00002Ool00`00Ool0000EOol0035oo`03001oogoo00Ioo`8001aoo`8001eoo`8000Aoo`03001o
ogoo01Ioo`8000Aoo`03001oogoo009oo`03001oogoo019oo`8000Aoo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo01Aoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol0
0=eoo`00\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-2.64955, -235.13, 0.0292567, 1.19791}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-2.64714, -378.866, 0.0292369, 1.5132}},
  CellTags->"5.2.2"]
}, Open  ]],

Cell[TextData[{
  "We observe that at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 10\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " the phase is around ",
  Cell[BoxData[
      \(TraditionalForm\`\(-150\) \[Degree]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", which would give the desired phase margin of ",
  Cell[BoxData[
      \(TraditionalForm\`30  \[Degree]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " if we increase the gain by ",
  Cell[BoxData[
      \(TraditionalForm\`24\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " dB, the value by which the current gain at this frequency is less than \
zero. That would lead to a gain margin somewhat more than ",
  Cell[BoxData[
      \(TraditionalForm\`10\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " dB at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 24\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", the current crossover frequency, which would satisfy the specification.  \
"
}], "Text",
  CellTags->"5.2.2"],

Cell["\<\
This is the Bode plot for the increased gain, with the gain and \
phase margins displayed. We can see that the specifications are met. \
\>", 
  "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{

Cell["BodePlot[%% /. k -> 4. 10^(24/20), Margins -> True]", "Input",
  CellLabel->"In[21]:=",
  CellTags->"5.2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 1.131 0.005815 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2619 -0.0125 -5 -12.5625 ]
[.2619 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.7381 -0.0125 -11 -12.5625 ]
[.7381 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12.5625 ]
[.97619 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .0843 -24 -4.5 ]
[-0.0125 .0843 0 4.5 ]
[-0.0125 .2006 -24 -4.5 ]
[-0.0125 .2006 0 4.5 ]
[-0.0125 .3169 -24 -4.5 ]
[-0.0125 .3169 0 4.5 ]
[-0.0125 .4332 -24 -4.5 ]
[-0.0125 .4332 0 4.5 ]
[-0.0125 .5495 -24 -4.5 ]
[-0.0125 .5495 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2619 .63053 -5 0 ]
[.2619 .63053 5 12.5625 ]
[.5 .63053 -8 0 ]
[.5 .63053 8 12.5625 ]
[.7381 .63053 -11 0 ]
[.7381 .63053 11 12.5625 ]
[.97619 .63053 -14 0 ]
[.97619 .63053 14 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 1 r
.25 Mabswid
[ .01 ] 0 setdash
0 .0843 m
1 .0843 L
s
0 g
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .0843 m
.00625 .0843 L
s
[(-180)] -0.0125 .0843 1 0 Mshowa
0 .2006 m
.00625 .2006 L
s
[(-160)] -0.0125 .2006 1 0 Mshowa
0 .3169 m
.00625 .3169 L
s
[(-140)] -0.0125 .3169 1 0 Mshowa
0 .4332 m
.00625 .4332 L
s
[(-120)] -0.0125 .4332 1 0 Mshowa
0 .5495 m
.00625 .5495 L
s
[(-100)] -0.0125 .5495 1 0 Mshowa
.125 Mabswid
0 .11337 m
.00375 .11337 L
s
0 .14245 m
.00375 .14245 L
s
0 .17152 m
.00375 .17152 L
s
0 .22967 m
.00375 .22967 L
s
0 .25875 m
.00375 .25875 L
s
0 .28782 m
.00375 .28782 L
s
0 .34597 m
.00375 .34597 L
s
0 .37505 m
.00375 .37505 L
s
0 .40413 m
.00375 .40413 L
s
0 .46228 m
.00375 .46228 L
s
0 .49135 m
.00375 .49135 L
s
0 .52043 m
.00375 .52043 L
s
0 .05522 m
.00375 .05522 L
s
0 .02615 m
.00375 .02615 L
s
0 .57858 m
.00375 .57858 L
s
0 .60765 m
.00375 .60765 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0843 m
1 .0843 L
s
.99375 .2006 m
1 .2006 L
s
.99375 .3169 m
1 .3169 L
s
.99375 .4332 m
1 .4332 L
s
.99375 .5495 m
1 .5495 L
s
.125 Mabswid
.99625 .11337 m
1 .11337 L
s
.99625 .14245 m
1 .14245 L
s
.99625 .17152 m
1 .17152 L
s
.99625 .22967 m
1 .22967 L
s
.99625 .25875 m
1 .25875 L
s
.99625 .28782 m
1 .28782 L
s
.99625 .34597 m
1 .34597 L
s
.99625 .37505 m
1 .37505 L
s
.99625 .40413 m
1 .40413 L
s
.99625 .46228 m
1 .46228 L
s
.99625 .49135 m
1 .49135 L
s
.99625 .52043 m
1 .52043 L
s
.99625 .05522 m
1 .05522 L
s
.99625 .02615 m
1 .02615 L
s
.99625 .57858 m
1 .57858 L
s
.99625 .60765 m
1 .60765 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .6017 L
.08949 .59948 L
.12233 .59642 L
.15517 .59223 L
.18801 .58647 L
.22085 .57857 L
.25369 .56774 L
.28654 .55294 L
.31938 .53279 L
.35222 .50557 L
.38506 .46931 L
.4179 .42218 L
.45074 .36336 L
.48358 .29429 L
.51642 .21973 L
.54926 .14741 L
.5821 .08609 L
.61494 .04274 L
.64778 .01991 L
.68062 .01472 L
.71346 .02079 L
.74631 .0317 L
.77915 .04315 L
.81199 .05314 L
.84483 .06113 L
.87767 .06724 L
.91051 .07181 L
.94335 .07518 L
.97619 .07765 L
s
0 0 1 r
.50135 .0843 m
.50135 .25414 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.238095 0.400909 0.00460028 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2619 -0.0125 -5 -12.5625 ]
[.2619 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.7381 -0.0125 -11 -12.5625 ]
[.7381 -0.0125 11 0 ]
[.97619 -0.0125 -14 -12.5625 ]
[.97619 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .03289 -18 -4.5 ]
[-0.0125 .03289 0 4.5 ]
[-0.0125 .12489 -18 -4.5 ]
[-0.0125 .12489 0 4.5 ]
[-0.0125 .2169 -18 -4.5 ]
[-0.0125 .2169 0 4.5 ]
[-0.0125 .3089 -18 -4.5 ]
[-0.0125 .3089 0 4.5 ]
[-0.0125 .40091 -6 -4.5 ]
[-0.0125 .40091 0 4.5 ]
[-0.0125 .49291 -12 -4.5 ]
[-0.0125 .49291 0 4.5 ]
[-0.0125 .58492 -12 -4.5 ]
[-0.0125 .58492 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2619 .63053 -5 0 ]
[.2619 .63053 5 12.5625 ]
[.5 .63053 -8 0 ]
[.5 .63053 8 12.5625 ]
[.7381 .63053 -11 0 ]
[.7381 .63053 11 12.5625 ]
[.97619 .63053 -14 0 ]
[.97619 .63053 14 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 1 r
.25 Mabswid
[ .01 ] 0 setdash
0 .40091 m
1 .40091 L
s
0 g
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 0 m
.09548 .00375 L
s
.13741 0 m
.13741 .00375 L
s
.16716 0 m
.16716 .00375 L
s
.19023 0 m
.19023 .00375 L
s
.20908 0 m
.20908 .00375 L
s
.22502 0 m
.22502 .00375 L
s
.23883 0 m
.23883 .00375 L
s
.25101 0 m
.25101 .00375 L
s
.33358 0 m
.33358 .00375 L
s
.37551 0 m
.37551 .00375 L
s
.40525 0 m
.40525 .00375 L
s
.42833 0 m
.42833 .00375 L
s
.44718 0 m
.44718 .00375 L
s
.46312 0 m
.46312 .00375 L
s
.47693 0 m
.47693 .00375 L
s
.48911 0 m
.48911 .00375 L
s
.57167 0 m
.57167 .00375 L
s
.6136 0 m
.6136 .00375 L
s
.64335 0 m
.64335 .00375 L
s
.66642 0 m
.66642 .00375 L
s
.68527 0 m
.68527 .00375 L
s
.70121 0 m
.70121 .00375 L
s
.71502 0 m
.71502 .00375 L
s
.7272 0 m
.7272 .00375 L
s
.80977 0 m
.80977 .00375 L
s
.8517 0 m
.8517 .00375 L
s
.88144 0 m
.88144 .00375 L
s
.90452 0 m
.90452 .00375 L
s
.92337 0 m
.92337 .00375 L
s
.93931 0 m
.93931 .00375 L
s
.95312 0 m
.95312 .00375 L
s
.9653 0 m
.9653 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .03289 m
.00625 .03289 L
s
[(-80)] -0.0125 .03289 1 0 Mshowa
0 .12489 m
.00625 .12489 L
s
[(-60)] -0.0125 .12489 1 0 Mshowa
0 .2169 m
.00625 .2169 L
s
[(-40)] -0.0125 .2169 1 0 Mshowa
0 .3089 m
.00625 .3089 L
s
[(-20)] -0.0125 .3089 1 0 Mshowa
0 .40091 m
.00625 .40091 L
s
[(0)] -0.0125 .40091 1 0 Mshowa
0 .49291 m
.00625 .49291 L
s
[(20)] -0.0125 .49291 1 0 Mshowa
0 .58492 m
.00625 .58492 L
s
[(40)] -0.0125 .58492 1 0 Mshowa
.125 Mabswid
0 .05589 m
.00375 .05589 L
s
0 .07889 m
.00375 .07889 L
s
0 .10189 m
.00375 .10189 L
s
0 .14789 m
.00375 .14789 L
s
0 .1709 m
.00375 .1709 L
s
0 .1939 m
.00375 .1939 L
s
0 .2399 m
.00375 .2399 L
s
0 .2629 m
.00375 .2629 L
s
0 .2859 m
.00375 .2859 L
s
0 .3319 m
.00375 .3319 L
s
0 .35491 m
.00375 .35491 L
s
0 .37791 m
.00375 .37791 L
s
0 .42391 m
.00375 .42391 L
s
0 .44691 m
.00375 .44691 L
s
0 .46991 m
.00375 .46991 L
s
0 .51592 m
.00375 .51592 L
s
0 .53892 m
.00375 .53892 L
s
0 .56192 m
.00375 .56192 L
s
0 .00989 m
.00375 .00989 L
s
0 .60792 m
.00375 .60792 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2619 .61178 m
.2619 .61803 L
s
gsave
.2619 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 .61178 m
.5 .61803 L
s
gsave
.5 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.7381 .61178 m
.7381 .61803 L
s
gsave
.7381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1000) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.09548 .61428 m
.09548 .61803 L
s
.13741 .61428 m
.13741 .61803 L
s
.16716 .61428 m
.16716 .61803 L
s
.19023 .61428 m
.19023 .61803 L
s
.20908 .61428 m
.20908 .61803 L
s
.22502 .61428 m
.22502 .61803 L
s
.23883 .61428 m
.23883 .61803 L
s
.25101 .61428 m
.25101 .61803 L
s
.33358 .61428 m
.33358 .61803 L
s
.37551 .61428 m
.37551 .61803 L
s
.40525 .61428 m
.40525 .61803 L
s
.42833 .61428 m
.42833 .61803 L
s
.44718 .61428 m
.44718 .61803 L
s
.46312 .61428 m
.46312 .61803 L
s
.47693 .61428 m
.47693 .61803 L
s
.48911 .61428 m
.48911 .61803 L
s
.57167 .61428 m
.57167 .61803 L
s
.6136 .61428 m
.6136 .61803 L
s
.64335 .61428 m
.64335 .61803 L
s
.66642 .61428 m
.66642 .61803 L
s
.68527 .61428 m
.68527 .61803 L
s
.70121 .61428 m
.70121 .61803 L
s
.71502 .61428 m
.71502 .61803 L
s
.7272 .61428 m
.7272 .61803 L
s
.80977 .61428 m
.80977 .61803 L
s
.8517 .61428 m
.8517 .61803 L
s
.88144 .61428 m
.88144 .61803 L
s
.90452 .61428 m
.90452 .61803 L
s
.92337 .61428 m
.92337 .61803 L
s
.93931 .61428 m
.93931 .61803 L
s
.95312 .61428 m
.95312 .61803 L
s
.9653 .61428 m
.9653 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .03289 m
1 .03289 L
s
.99375 .12489 m
1 .12489 L
s
.99375 .2169 m
1 .2169 L
s
.99375 .3089 m
1 .3089 L
s
.99375 .40091 m
1 .40091 L
s
.99375 .49291 m
1 .49291 L
s
.99375 .58492 m
1 .58492 L
s
.125 Mabswid
.99625 .05589 m
1 .05589 L
s
.99625 .07889 m
1 .07889 L
s
.99625 .10189 m
1 .10189 L
s
.99625 .14789 m
1 .14789 L
s
.99625 .1709 m
1 .1709 L
s
.99625 .1939 m
1 .1939 L
s
.99625 .2399 m
1 .2399 L
s
.99625 .2629 m
1 .2629 L
s
.99625 .2859 m
1 .2859 L
s
.99625 .3319 m
1 .3319 L
s
.99625 .35491 m
1 .35491 L
s
.99625 .37791 m
1 .37791 L
s
.99625 .42391 m
1 .42391 L
s
.99625 .44691 m
1 .44691 L
s
.99625 .46991 m
1 .46991 L
s
.99625 .51592 m
1 .51592 L
s
.99625 .53892 m
1 .53892 L
s
.99625 .56192 m
1 .56192 L
s
.99625 .00989 m
1 .00989 L
s
.99625 .60792 m
1 .60792 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59063 L
.08949 .57793 L
.12233 .56523 L
.15517 .55253 L
.18801 .53981 L
.22085 .52707 L
.25369 .51428 L
.28654 .50141 L
.31938 .48838 L
.35222 .47506 L
.38506 .46123 L
.4179 .44649 L
.45074 .4303 L
.48358 .41196 L
.51642 .39086 L
.54926 .36671 L
.5821 .33975 L
.61494 .3108 L
.64778 .28101 L
.68062 .2515 L
.71346 .22291 L
.74631 .19536 L
.77915 .16865 L
.81199 .1425 L
.84483 .1167 L
.87767 .09108 L
.91051 .06558 L
.94335 .04013 L
.97619 .01472 L
s
0 0 1 r
.58322 .40091 m
.58322 .33879 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025o
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000aOol00`00Oomoo`02Ool00`00Oomo
o`05000IOol5000JOol50002Ool00`00Oomoo`0EOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0A
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0DOol0031oo`03001oo`0000Qo
o`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool0
0002Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eo
o`00<7oo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000H
Ool01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo
00000Woo00<007oo00005Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol0
1`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomo
o`00Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`0000Qoo`03001oogoo
01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00
Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`00<Goo00<0
07ooOol01Woo0P0077oo0P007Goo0P0017oo00<007ooOol05Woo0P0017oo00<007ooOol00Woo00<0
07ooOol04Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol057oo003MOol00=eo
o`00gGoo000dOonA000HOol003Aoo`05001oogooOol00009Ool00`00Oomoo`03Ool01@00Oomoogoo
00000goo00<007oo00000Woo00@007oo001oo`8000Uoo`03001oogoo00=oo`03001oogoo009oo`04
001oogoo0002Ool01P00Ool007oo001oo`8000Yoo`03001oogoo00=oo`05001oogooOol00002Ool0
2@00Oomoo`00Ool007oo001oo`02000:Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00`007oo
Ool007oo001oo`00Ool007oo0002Ool00`00Oomoo`0FOol003Aoo`03001oogoo08eoo`03001oogoo
01Ioo`00=7oo00<007ooOol0FWoo30009goo00<007ooOol05Woo000dOol2001JOol00`00Oomoo`0:
Ool2000TOol2000HOol003Aoo`03001oogoo05Qoo`03001oogoo00eoo`8002=oo`03001oogoo01Io
o`00=7oo00<007ooOol0Egoo00<007ooOol047oo0P008Goo00<007ooOol05Woo000dOol00`00Oomo
o`1FOol00`00Oomoo`0COol4000MOol00`00Oomoo`0FOol003Aoo`8005Ioo`03001oogoo01Qoo`D0
01Moo`8001Qoo`00=7oo00<007ooOol0E7oo00<007ooOol07Woo100057oo00<007ooOol05Woo000d
Ool00`00Oomoo`1COol00`00Oomoo`0SOol5000?Ool00`00Oomoo`0FOol002Aoo`D0009oo`03001o
ogoo009oo`05001oogooOol0001EOol00`00Oomoo`0XOol:0005Ool00`00Oomoo`0FOol002Ioo`07
001oogooOol007oo00000Woo00<007oo00000Woo00<007ooOol0DWoo00<007ooOol0<goo0`000Woo
00<007ooOol05Woo000@Ool00`00Oomoo`02Ool00`00Oomoo`08Ool30003Ool01`00Oomoogoo001o
o`00009oo`03001oo`00009oo`8000T07`04Ool07`0OOol201l017oo01l07goo3@0O00Aoo`0O01mo
o`807`04Ool07`0OOol=01l017oo01l07goo0P0O00=oo`0O01l03P0O00Moo`0O01moo`0001moo`0=
01l017oo01l07goo0P0O00Aoo`0O01moo`d07`04Ool07`0OOol201l017oo01l07goo2P0O0P0067oo
000@Ool6000@Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00009oo`03001oogoo04Eoo`0301mo
ogoo00Qoo`03001oogoo03Yoo`03001oogoo01Ioo`0047oo00H007ooOol007oo000@Ool01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`03001oogoo04Eoo`0301moogoo00Qoo`03001oogoo03Yo
o`03001oogoo01Ioo`0047oo00@007ooOol0015oo`8000Aoo`03001oogoo009oo`05001oogooOol0
0017Ool00`0OOomoo`07Ool00`00Oomoo`0kOol00`00Oomoo`0FOol0015oo`80025oo`8004Ioo`03
01moogoo00Moo`03001oogoo03Yoo`8001Qoo`00=7oo00<007ooOol0AGoo00<07gooOol01Woo00<0
07ooOol0?7oo00<007ooOol05Woo000@Ool00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Oomoo`15
Ool00`0OOomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`0FOol0011oo`H001ioo`03001oogoo04Eo
o`0301moogoo00Eoo`03001oogoo03eoo`03001oogoo01Ioo`004Woo00@007ooOol001ioo`8004Io
o`0301moogoo00Eoo`03001oogoo03aoo`8001Qoo`004Woo00<007ooOol07goo00<007ooOol0AGoo
00<07gooOol017oo00<007ooOol0?Woo00<007ooOol05Woo000COol3000NOol00`00Oomoo`15Ool0
0`0OOomoo`04Ool00`00Oomoo`0nOol00`00Oomoo`0FOol001Eoo`03001oogoo01aoo`03001oogoo
04Eoo`0301moogoo00=oo`03001oogoo03moo`03001oogoo01Ioo`00=7oo0P00AWoo00<07gooOol0
0goo00<007ooOol0?Woo0P0067oo000DOol2000NOol00`00Oomoo`15Ool00`0OOomoo`02Ool00`00
Oomoo`10Ool00`00Oomoo`0FOol0019oo`04001oo`00000>Ool500000goo00000004Ool01@00Oomo
ogoo0000Agoo00<07gooOol00Woo00<007ooOol0@7oo00<007ooOol05Woo000BOol01000Ool00000
47oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`15Ool00`0OOomoo`02Ool0
0`00Oomoo`10Ool00`00Oomoo`0FOol0019oo`@000Yoo`<000=oo`07001oogooOol007oo00000Woo
00<007oo00000Woo0P00AWoo00D07gooOomoo`00049oo`8001Qoo`005Goo00<007ooOol03Woo00@0
07ooOomoo`8000=oo`03001oo`00009oo`03001oogoo04Eoo`0501moogooOol00013Ool00`00Oomo
o`0FOol002Ioo`05001oogooOol00004Ool00`00Ool00002Ool00`00Oomoo`15Ool0100OOomoo`00
A7oo00<007ooOol05Woo000BOol200000goo001oo`0>Ool20004Ool20003Ool01@00Oomoogoo0000
Agoo00@07gooOol004Aoo`03001oogoo01Ioo`004Woo0P0000=oo`00Ool07Goo0P00AWoo00@07goo
Ool004=oo`8001Qoo`004Woo0P0000=oo`00Ool07Goo00<007ooOol0AGoo00<07goo0000AGoo00<0
07ooOol05Woo000BOol00`00Ool0000OOol00`00Oomoo`15Ool00`0OOol00015Ool00`00Oomoo`0F
Ool003Aoo`03001oogoo04Eoo`0301l007oo04Eoo`03001oogoo01Ioo`00=7oo00<007ooOol0AGoo
00<07`00Ool0AGoo00<007ooOol05Woo000COol2000OOol20016Ool00`00Oomoo`14Ool2000HOol0
019oo`800003Ool007oo01eoo`03001oogoo04Eoo`03001oogoo04Eoo`03001oogoo01Ioo`004Woo
0P0000=oo`00Ool07Goo00<007ooOol0A7oo00<007ooOol0AWoo00<007ooOol05Woo000COol00`00
Ool0000NOol00`00Oomoo`14Ool00`00Oomoo`16Ool00`00Oomoo`0FOol003Aoo`8004Aoo`03001o
ogoo04Ioo`8001Qoo`00=7oo00<007ooOol0@goo00<007ooOol0Agoo00<007ooOol05Woo000TOol5
0002Ool30002Ool01@00Oomoogoo0000A7oo00<007ooOol0B7oo00<007ooOol05Woo000VOol00`00
Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001oogoo049oo`03001oogoo04Qoo`03001oogoo01Io
o`0087oo0`000goo00@007ooOomoo`@00004Ool007oo0002Ool20012Ool00`00Oomoo`18Ool2000H
Ool002Ioo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007ooOol0@Goo00<007ooOol0
BGoo00<007ooOol05Woo000VOol00`00Oomoo`02Ool20002Ool00`00Ool00002Ool00`00Oomoo`10
Ool00`00Oomoo`1:Ool00`00Oomoo`0FOol002Eoo`8000Eoo`05001oogooOol00003Ool00`00Oomo
o`10Ool00`00Oomoo`1:Ool00`00Oomoo`0FOol003Aoo`80041oo`03001oogoo04Yoo`8001Qoo`00
4Woo10007Woo00<007ooOol0?goo00<007ooOol0Bgoo00<007ooOol05Woo000AOol00`00Oomoo`02
Ool00`00Oomoo`0KOol00`00Oomoo`0nOol00`00Oomoo`1<Ool00`00Oomoo`0FOol0011oo`03001o
ogoo00Aoo`03001oogoo01Yoo`03001oogoo03ioo`03001oogoo04aoo`03001oogoo01Ioo`00=7oo
0P00?Woo00<007ooOol0C7oo0P0067oo000dOol00`00Oomoo`0mOol00`00Oomoo`1=Ool00`00Oomo
o`0FOol001=oo`8001moo`03001oogoo03aoo`03001oogoo04ioo`03001oogoo01Ioo`004Woo00@0
07ooOol001ioo`03001oogoo03]oo`03001oogoo04moo`03001oogoo01Ioo`0047oo00<007oo0000
0Woo00<007ooOol077oo0P00?7oo00<007ooOol0CWoo0P0067oo000@Ool6000NOol00`00Oomoo`0j
Ool00`00Oomoo`1@Ool00`00Oomoo`0FOol001Eoo`03001oogoo01aoo`03001oogoo03Yoo`03001o
ogoo051oo`03001oogoo01Ioo`0097oo1@0000Aoo`00000000=oo`05001oogooOol0000kOol00`00
Oomoo`1AOol00`00Oomoo`0FOol001=oo`80015oo`05001oogooOol00004Ool00`00Ool00002Ool0
0`00Oomoo`0hOol00`00Oomoo`1BOol00`00Oomoo`0FOol0019oo`800003Ool007oo00Uoo`<000=o
o`03001oogoo009oo`07001oogooOol007oo00000Woo0P00>Goo00<007ooOol0DGoo0P0067oo000B
Ool200000goo001oo`0?Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00009oo`03001oogoo03Mo
o`03001oogoo05=oo`03001oogoo01Ioo`004goo00<007oo000047oo00L007ooOomoo`00Ool00002
Ool00`00Ool00002Ool00`00Oomoo`0gOol00`00Oomoo`1COol00`00Oomoo`0FOol002Eoo`8000Ao
o`03001oogoo009oo`05001oogooOol0000hOol00`00Oomoo`1DOol00`00Oomoo`0FOol003Aoo`80
03Moo`03001oogoo05=oo`8001Qoo`004goo0P000Woo00<007ooOol06Woo00<007ooOol0=Goo00<0
07ooOol0EGoo00<007ooOol05Woo000BOol01P00Oomoo`00Ool001aoo`03001oogoo03Aoo`03001o
ogoo05Ioo`03001oogoo01Ioo`004Woo00H007ooOol007oo000LOol00`00Oomoo`0cOol00`00Oomo
o`1GOol00`00Oomoo`0FOol0019oo`D001eoo`8003=oo`03001oogoo05Moo`8001Qoo`004Woo00<0
07ooOol07goo00<007ooOol0<Goo00<007ooOol0FGoo00<007ooOol05Woo000dOol00`00Oomoo`0`
Ool00`00Oomoo`1JOol00`00Oomoo`0FOol0011oo`03001oogoo00Aoo`03001oogoo01Yoo`03001o
ogoo02moo`03001oogoo05]oo`03001oogoo01Ioo`004Goo00<007ooOol00Woo00<007ooOol06goo
0P00;Woo0P00GGoo0P0067oo000BOol4000NOol00`00Oomoo`0/Ool00`00Oomoo`1NOol00`00Oomo
o`0FOol002Aoo`D0009oo`03001oogoo009oo`05001oogooOol0000]Ool00`00Oomoo`1OOol00`00
Oomoo`0FOol002Ioo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007ooOol0:Woo00<0
07ooOol0H7oo00<007ooOol05Woo000POol30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`8002Uoo`80069oo`8001Qoo`009Woo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool0
0`00Oomoo`0VOol2001UOol00`00Oomoo`0FOol002Ioo`07001oogooOol007oo00000Woo00<007oo
00000Woo00<007ooOol097oo0P00Igoo00<007ooOol05Woo000UOol20004Ool00`00Oomoo`02Ool0
1@00Oomoogoo00008Woo1000JGoo00<007ooOol05Woo000dOol2000MOol4001/Ool2000HOol003Ao
o`03001oogoo01Yoo`80075oo`03001oogoo01Ioo`00=7oo00<007ooOol04Woo2000Lgoo00<007oo
Ool05Woo000dOol00`00Oomoo`09Ool9001kOol00`00Oomoo`0FOol003Aoo`04001oogooOol80024
Ool00`00Oomoo`0FOol003Aoo`80009oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo021oo`04001oo`00000HOol003Aooi4001Qoo`00gGoo003MOol00=eoo`00gGoo003M
Ool00=eoo`00<Goo00<007ooOol00Woo00<007ooOol01@006Goo1@006Woo1@000Woo00<007ooOol0
5Goo1@000Woo00<007ooOol00Woo00<007ooOol04Goo1@000Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol057oo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol01`00
Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomoo`00
Ool00002Ool00`00Ool00002Ool00`00Ool0000EOol0031oo`03001oo`0000Qoo`03001oogoo01]o
o`03001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0
000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Eoo`00<7oo00<007oo
000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo
001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo
00005Goo000`Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol01`00Oomoogoo001o
o`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomoo`00Ool00002Ool0
0`00Ool00002Ool00`00Ool0000EOol0035oo`03001oogoo00Ioo`8001aoo`8001eoo`8000Aoo`03
001oogoo01Ioo`8000Aoo`03001oogoo009oo`03001oogoo019oo`8000Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01Aoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003M
Ool00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol004Uoo`8001Eoo`80
01Eoo`03001oogoo03aoo`03001oogoo02Aoo`00BWoo00<007ooOol057oo00<007ooOol04Woo00<0
07ooOol04goo00<007ooOol0:7oo00<007ooOol08goo000gOol30003Ool30003Ool20003Ool30002
Ool30002Ool200000goo00000002Ool00`00Ool000020003Ool00`00Oomoo`0AOol01000Oomoogoo
0`0000=oo`00Ool010000Woo0`001Goo00<007ooOol00Woo0`000goo0P000Woo0`000goo0P0000=o
o`0000000Woo00<007ooOol00`002Goo00<007ooOol08Woo000hOol00`00Oomoo`03Ool01@00Oomo
ogoo000017oo00H007ooOol007oo0002Ool00`00Ool00004Ool01P00Oomoo`00Ool000Aoo`03001o
o`00019oo`03001oogoo009oo`05001oogoo001oo`030002Ool01000Oomoo`001Goo00<007ooOol0
0Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00
Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0ROol003Qoo`03001oogoo00=oo`04001oogooOol3
0002Ool01P00Oomoo`00Ool0009oo`03001oo`000080009oo`06001oogoo001oo`0017oo00<007oo
00004Woo00<007ooOol00Woo0`0017oo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo00<0009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol08Woo000hOol20003Ool4000017oo000000000goo1@0000Aoo`00001o
o`<00003Ool000000080009oo`<00004Ool00000Ool2000AOol00`00Oomoo`02Ool01000Oomoo`00
0Woo0P000goo0`001Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`<000=oo`800003Ool00000
008000=oo`<000Uoo`03001oogoo029oo`00>7oo00@007ooOol003Yoo`05001oogooOol00002Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0001Uoo`03001oogoo00Ioo`03001o
ogoo02=oo`00=goo1@00>goo00<007oo00000`002Goo0P001goo00<007ooOol00`0067oo0P001goo
00<007ooOol097oo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol002ioo`03001oogoo
009oo`03001oogoo00D001Uoo`D001Yoo`D0009oo`03001oogoo01Eoo`D0009oo`03001oogoo009o
o`03001oogoo015oo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo01Moo`00;Goo
00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00
Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo00000Woo
00<007oo000067oo000]Ool00`00Ool00008Ool00`00Oomoo`0KOol00`00Oomoo`0LOol01`00Oomo
ogoo001oo`0001Qoo`07001oogooOol007oo00000Woo00<007oo000057oo00L007ooOomoo`00Ool0
0002Ool00`00Ool00002Ool00`00Ool0000HOol002eoo`03001oo`0000Qoo`03001oogoo01]oo`03
001oogoo01aoo`07001oogooOol007oo000067oo00L007ooOomoo`00Ool00002Ool00`00Ool0000D
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0001Qoo`00;Goo00<007oo0000
27oo00<007ooOol06goo00<007ooOol077oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001o
o`00009oo`03001oo`0001Aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo0000
67oo000^Ool00`00Oomoo`06Ool2000LOol2000MOol20004Ool00`00Oomoo`0FOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`0BOol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0G
Ool00=eoo`00gGoo003MOol0035ooi4001]oo`00<Goo00D007ooOomoo`0000Uoo`03001oogoo00=o
o`05001oogooOol00003Ool00`00Ool00002Ool01P00Ool00000Ool000Uoo`03001oogoo00=oo`03
001oogoo009oo`04001oogoo0002Ool01P00Ool007oo001oo`8000Yoo`03001oogoo00=oo`05001o
ogooOol00002Ool02@00Oomoo`00Ool007oo001oo`02000:Ool00`00Oomoo`03Ool01@00Oomoogoo
00000Woo00`007ooOol007oo001oo`00Ool007oo0002Ool00`00Oomoo`0IOol0035oo`8008ioo`03
001oogoo01Uoo`00:7oo00<007ooOol00Woo00D007ooOomoo`0008aoo`04001oogoo000KOol001=o
o`H000ioo`03001oo`00009oo`03001oo`00009oo`03001oogoo08Qoo`8000=oo`03001oogoo01Uo
o`004goo0`000Woo00<007ooOol01goo0`000Woo00<007oo00000Woo00<007oo00000Woo0P00Qgoo
0P0017oo0P006goo000FOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`00009oo`03001oogoo08Eo
o`03001oogoo00Eoo`03001oogoo01Uoo`004goo0`000Woo00<007ooOol037oo00<007oo00000Woo
00<007oo00000Woo00<007ooOol0Q7oo00<007ooOol01Woo00<007ooOol06Goo000COol6000?Ool0
0`00Oomoo`02Ool01000Oomoogoo0P00Pgoo0P002Goo00<007ooOol06Goo000COol00`00Oomoo`02
Ool00`00Oomoo`0FOol00`00Oomoo`21Ool00`00Oomoo`09Ool00`00Oomoo`0IOol0035oo`03001o
ogoo081oo`03001oogoo00Yoo`03001oogoo01Uoo`005goo0P0067oo00<007ooOol0Ogoo00<007oo
Ool02goo00<007ooOol06Goo000EOol01000Ool0000067oo0P00Ogoo00<007ooOol037oo00<007oo
Ool06Goo000EOol01000Ool0000067oo00<007ooOol0OGoo00<007ooOol03Goo00<007ooOol06Goo
000EOol4000HOol00`00Oomoo`1lOol00`00Oomoo`0>Ool00`00Oomoo`0IOol001Qoo`03001oogoo
01Ioo`8007]oo`80015oo`03001oogoo01Uoo`009goo0P0017oo00D007ooOomoo`0007Yoo`8001=o
o`03001oogoo01Uoo`005Woo0P000Woo00<007ooOol02Woo00<007oo00000Woo00<007oo00000Woo
00<007ooOol0Mgoo00<007ooOol04goo00<007ooOol06Goo000EOol01P00Oomoo`00Ool000Moo`<0
009oo`03001oo`00009oo`03001oo`00009oo`8007Moo`03001oogoo01=oo`8001]oo`005Goo00H0
07ooOol007oo000<Ool20003Ool00`00Ool00002Ool00`00Oomoo`1dOol2000GOol00`00Oomoo`0I
Ool001Eoo`D000eoo`03001oogoo009oo`03001oo`00009oo`03001oogoo07=oo`03001oogoo01Mo
o`03001oogoo01Uoo`005Goo00<007ooOol047oo0P000goo00D007ooOomoo`0007Aoo`03001oogoo
01Qoo`03001oogoo01Uoo`005Goo00@007ooOol001Qoo`80079oo`03001oogoo01Uoo`03001oogoo
01Uoo`005Goo100067oo00<007ooOol0Kgoo0P0077oo00<007ooOol06Goo000EOol00`00Oomoo`0I
Ool00`00Oomoo`1^Ool00`00Oomoo`0LOol00`00Oomoo`0IOol001Eoo`03001oogoo01Uoo`8006io
o`03001oogoo01eoo`03001oogoo01Uoo`005Woo0`0067oo00<007ooOol0K7oo00<007ooOol07Woo
00<007ooOol06Goo000HOol00`00Oomoo`0FOol00`00Oomoo`1ZOol2000QOol00`00Oomoo`0IOol0
035oo`8006Yoo`03001oogoo025oo`03001oogoo01Uoo`00<Goo00<007ooOol0J7oo00<007ooOol0
8Woo00<007ooOol06Goo000EOol01000Oomoo`003goo0`000Woo00D007ooOomoo`0006Qoo`8002Eo
o`03001oogoo01Uoo`004goo00<007oo00000`0047oo00H007ooOol007oo0002Ool00`00Oomoo`1U
Ool00`00Oomoo`0UOol00`00Oomoo`0IOol001Qoo`03001oogoo00Moo`<0009oo`@00004Ool007oo
0002Ool2001UOol00`00Oomoo`0UOol2000KOol002Moo`03001oo`00009oo`03001oo`00009oo`03
001oogoo06=oo`03001oogoo02Moo`03001oogoo01Uoo`005Goo00<007ooOol047oo0P000Woo00<0
07oo00000Woo00<007ooOol0HWoo00<007ooOol0:7oo00<007ooOol06Goo000DOol4000AOol01@00
Oomoogoo00000goo0P00HWoo00<007ooOol0:Goo00<007ooOol06Goo000EOol01000Oomoo`0067oo
00<007ooOol0H7oo00<007ooOol0:Woo00<007ooOol06Goo000EOol01000Oomoo`0067oo00<007oo
Ool0Ggoo00<007ooOol0:goo00<007ooOol06Goo000EOol00`00Ool0000IOol2001OOol00`00Oomo
o`0/Ool00`00Oomoo`0IOol0035oo`03001oogoo05aoo`8002moo`03001oogoo01Uoo`005Goo00<0
07ooOol06Goo00<007ooOol0Fgoo00<007ooOol0;goo00<007ooOol06Goo000EOol3000IOol2001K
Ool00`00Oomoo`0`Ool00`00Oomoo`0IOol001Qoo`03001oogoo01Ioo`03001oogoo05Uoo`03001o
ogoo035oo`03001oogoo01Uoo`005Goo00<007oo00003goo0`000goo00D007ooOomoo`0005Yoo`03
001oogoo039oo`03001oogoo01Uoo`005Goo10003Woo00<007ooOol00Woo00<007oo00000Woo00<0
07ooOol0Egoo00<007ooOol0<goo00<007ooOol06Goo000HOol00`00Oomoo`07Ool30003Ool01`00
Oomoogoo001oo`00009oo`8005Moo`03001oogoo03=oo`8001]oo`00:7oo00L007ooOomoo`00Ool0
0002Ool00`00Oomoo`1EOol00`00Oomoo`0eOol00`00Oomoo`0IOol001Ioo`8000moo`03001oo`00
009oo`03001oo`00009oo`03001oogoo05=oo`8003Qoo`03001oogoo01Uoo`005Goo00@007ooOol0
00moo`03001oogoo009oo`04001oogooOol2001COol00`00Oomoo`0hOol00`00Oomoo`0IOol001=o
o`03001oo`00009oo`03001oogoo01Ioo`03001oogoo055oo`0301moogoo03Uoo`03001oogoo01Uo
o`004goo1P0067oo00<007ooOol0D7oo00<0000OOol0>Woo00<007ooOol06Goo000HOol00`00Oomo
o`0FOol2001?Ool200000goo01moo`0jOol00`00Oomoo`0IOol0035oo`03001oogoo04eoo`05001o
ogooOol07`0kOol00`00Oomoo`0IOol001Ioo`8001Uoo`03001oogoo04aoo`03001oogoo009oo`03
01moogoo03Uoo`03001oogoo01Uoo`005Goo0P0000=oo`00Ool05goo00<007ooOol0Bgoo00<007oo
Ool00goo00<07gooOol0>Goo00<007ooOol06Goo000EOol200000goo001oo`0GOol2001;Ool00`00
Oomoo`04Ool00`0OOomoo`0iOol00`00Oomoo`0IOol001Ioo`03001oo`0001Aoo`05001oogooOol0
001;Ool00`00Oomoo`05Ool00`0OOomoo`0iOol00`00Oomoo`0IOol002aoo`03001oo`00009oo`03
001oogoo04Qoo`03001oogoo00Ioo`0301moogoo03Uoo`03001oogoo01Uoo`00;7oo00<007oo0000
0Woo0P002@0O00Aoo`0O01moo`807`03Ool07`0O00h07`04Ool07`0OOol201l00goo01l07`0>01l0
17oo01l07goo0P0O00=oo`0O01l01`0O0P001@0O00Aoo`0O01moo`807`03Ool07`0O00/07`04Ool0
7`0OOol201l017oo01l07goo3@0O00Aoo`0O01moo`807`04Ool07`0OOol:01l2000KOol002aoo`03
001oo`00009oo`03001oogoo04Aoo`8004Moo`03001oogoo01Uoo`00;7oo00<007oo00000Woo00<0
07ooOol0@Woo0P00BGoo00<007ooOol06Goo000]Ool01000Oomoogoo0P00@Goo0P00Bgoo00<007oo
Ool06Goo000aOol00`00Oomoo`0nOol2001=Ool00`00Oomoo`0IOol0035oo`03001oogoo03aoo`80
04moo`03001oogoo01Uoo`00<Goo00<007ooOol0>Woo0P00DGoo00<007ooOol06Goo000aOol2000j
Ool00`00Oomoo`1AOol00`00Oomoo`0IOol001Eoo`@001Qoo`03001oogoo03Moo`8005Aoo`03001o
ogoo01Uoo`0057oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol0=7oo0`00EWoo00<007oo
Ool06Goo000COol00`00Oomoo`04Ool00`00Oomoo`0DOol2000cOol2001IOol00`00Oomoo`0IOol0
02Moo`<000=oo`05001oogooOol0000aOol3001KOol00`00Oomoo`0IOol002Moo`03001oogoo009o
o`03001oo`00009oo`03001oogoo02eoo`8005ioo`03001oogoo01Uoo`005Woo0P0047oo00L007oo
Oomoo`00Ool00002Ool2000[Ool3001OOol2000KOol001Eoo`04001oogoo000?Ool01`00Oomoogoo
001oo`00009oo`03001oogoo02Ioo`@006=oo`03001oogoo01Uoo`004goo00<007oo00000Woo00<0
07ooOol037oo00<007oo00000Woo00<007oo00000Woo00<007ooOol097oo0P00Igoo00<007ooOol0
6Goo000COol6000?Ool00`00Oomoo`02Ool01@00Oomoogoo00008goo0`00JGoo00<007ooOol06Goo
000HOol00`00Oomoo`0FOol2000POol2001/Ool00`00Oomoo`0IOol001=oo`03001oogoo009oo`03
001oogoo01Ioo`03001oogoo01aoo`<006ioo`03001oogoo01Uoo`004goo1P0067oo00<007ooOol0
6Woo0P00LGoo00<007ooOol06Goo000COol00`00Ool00002Ool00`00Oomoo`0FOol2000IOol2001c
Ool00`00Oomoo`0IOol001=oo`03001oo`00009oo`03001oogoo01Ioo`03001oogoo01Ioo`8007Eo
o`03001oogoo01Uoo`0057oo00@007oo000001Uoo`03001oogoo01=oo`<007Moo`03001oogoo01Uo
o`00<Goo0P004Woo0P00NWoo00<007ooOol06Goo000XOol30002Ool01@00Oomoogoo00003goo1000
O7oo00<007ooOol06Goo000COol00`00Oomoo`04Ool00`00Oomoo`0<Ool01P00Oomoo`00Ool0009o
o`03001oogoo00Yoo`<0081oo`03001oogoo01Uoo`0057oo00<007ooOol00Woo00<007ooOol02goo
100000Aoo`00Ool0009oo`8000Uoo`80089oo`8001]oo`005Goo10003Woo00<007oo00000Woo00<0
07oo00000Woo00<007ooOol01Goo0`00QGoo00<007ooOol06Goo000XOol20002Ool00`00Ool00002
Ool00`00Oomoo`03Ool20028Ool00`00Oomoo`0IOol002Uoo`05001oogooOol00003Ool01000Oomo
ogoo0P00RWoo00<007ooOol06Goo000aOol20002Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0POol01000Oomoo`006goo000aOonA000KOol00=eoo`00gGoo003MOol0
0=eoo`00gGoo003MOol002ioo`03001oogoo009oo`03001oogoo00D001Uoo`D001Yoo`D0009oo`03
001oogoo01Eoo`D0009oo`03001oogoo009oo`03001oogoo015oo`D0009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo01Moo`00;Goo00<007oo000027oo00<007ooOol06goo00<007ooOol0
77oo00L007ooOomoo`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001o
ogooOol007oo00000Woo00<007oo00000Woo00<007oo000067oo000]Ool00`00Ool00008Ool00`00
Oomoo`0KOol00`00Oomoo`0LOol01`00Oomoogoo001oo`0001Qoo`07001oogooOol007oo00000Woo
00<007oo000057oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool0000HOol002eo
o`03001oo`0000Qoo`03001oogoo01]oo`03001oogoo01aoo`07001oogooOol007oo000067oo00L0
07ooOomoo`00Ool00002Ool00`00Ool0000DOol01`00Oomoogoo001oo`00009oo`03001oo`00009o
o`03001oo`0001Qoo`00;Goo00<007oo000027oo00<007ooOol06goo00<007ooOol077oo00L007oo
Oomoo`00Ool0000HOol01`00Oomoogoo001oo`00009oo`03001oo`0001Aoo`07001oogooOol007oo
00000Woo00<007oo00000Woo00<007oo000067oo000^Ool00`00Oomoo`06Ool2000LOol2000MOol2
0004Ool00`00Oomoo`0FOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0BOol20004Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol0
0=eoo`00gGoo003MOol00001\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-2.64955, -235.13, 0.0292567, 1.19791}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-2.55943, -354.866, 0.0292369, 1.5132}},
  CellTags->"5.2.2"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[21]=",
  CellTags->"5.2.2"]
}, Open  ]],

Cell[TextData[{
  "Gain and phase margins are determined by finding the crossover points of \
the frequency response, which can be done either analytically or from the \
interpolation of the response curve computed on a frequency grid. The method \
can be selected using the option ",
  StyleBox["Method", "MR"],
  ", which accepts values ",
  StyleBox["Analytic", "MR"],
  " or ",
  StyleBox["Interpolation", "MR"],
  ". The freedom of choosing the method is restricted to \
continuous\[Hyphen]time systems; for discrete\[Hyphen]time systems, the \
margins are always computed via interpolation.    "
}], "Text",
  CellTags->"5.2.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["Mathod",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ the\ margins\ should\ be\ computed\ analytically\ or
                \ by\ interpolation\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"5.2.2"],

Cell[TextData[{
  "Options specific to ",
  StyleBox["GainPhaseMargins", "MR"],
  ". "
}], "Caption",
  CellTags->"5.2.2"],

Cell[TextData[{
  "When margins are to be plotted, the ",
  StyleBox["Automatic", "MR"],
  " value for ",
  StyleBox["PhaseRange", "MR"],
  " corresponds to the phase range of ",
  StyleBox["{-360,", "MR"],
  " ",
  StyleBox["0}", "MR"],
  " degrees. Using the option ",
  StyleBox["PhaseRange", "MR"],
  ", you may set the phase range differently. "
}], "Text",
  CellTags->"5.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3 The Nyquist Plot", "Subsection",
  CellTags->"5.3"],

Cell["\<\
The Nyquist plot allows us to gain insight into the stability of \
the closed\[Hyphen]loop system by analyzing the contour of the frequency \
response function on the complex plane. \
\>", "Text",
  CellTags->"5.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NyquistPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Nyquist",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  CellTags->"5.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NyquistPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"w", 
                        StyleBox[",",
                          "MR"], " ", "wmin", 
                        StyleBox[",",
                          "MR"], " ", "wmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Nyquist",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["frequency",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["w",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["running",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmin",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"5.3"],

Cell["Creating the Nyquist plots. ", "Caption",
  CellTags->"5.3"],

Cell[TextData[{
  "If no frequency range is specified, ",
  StyleBox["NyquistPlot", "MR"],
  " will try to plot the graph for both negative and positive frequencies (a \
task that can be avoided by plotting only half of the curve and then \
reflecting it over the real axis). \nNote that jumps may appear in the \
Nyquist plot when the frequency response changes rapidly. That may be \
corrected by choosing a higher value for the ",
  StyleBox["PlotPoints", "MR"],
  " option. "
}], "Text",
  CellTags->"5.3"],

Cell["Consider an open\[Hyphen]loop transfer function. ", "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{

Cell["TransferFunction[s, 1/(s+1)^2]", "Input",
  CellLabel->"In[22]:=",
  CellTags->"5.3"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/\((1 + s)\)\^2}}]\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->"5.3"]
}, Open  ]],

Cell[TextData[{
  "This is the corresponding Nyquist plot. The contour does not encircle the \
",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-1\), 0)\)\)], "InlineFormula",
    CellTags->"S0.0.4"],
  " point and the transfer function does not have unstable poles; therefore, \
the closed\[Hyphen]loop system will be stable. "
}], "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{

Cell["NyquistPlot[%]", "Input",
  CellLabel->"In[23]:=",
  CellTags->"5.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16226 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.130301 0.852254 0.581129 0.852254 [
[.30075 .56863 -9 -9 ]
[.30075 .56863 9 0 ]
[.4712 .56863 -9 -9 ]
[.4712 .56863 9 0 ]
[.64165 .56863 -9 -9 ]
[.64165 .56863 9 0 ]
[.8121 .56863 -9 -9 ]
[.8121 .56863 9 0 ]
[.98256 .56863 -3 -9 ]
[.98256 .56863 3 0 ]
[1.025 .58113 0 -6.28125 ]
[1.025 .58113 16 6.28125 ]
[.1178 .06978 -24 -4.5 ]
[.1178 .06978 0 4.5 ]
[.1178 .24023 -24 -4.5 ]
[.1178 .24023 0 4.5 ]
[.1178 .41068 -24 -4.5 ]
[.1178 .41068 0 4.5 ]
[.1178 .75158 -18 -4.5 ]
[.1178 .75158 0 4.5 ]
[.1178 .92203 -18 -4.5 ]
[.1178 .92203 0 4.5 ]
[.1178 1.09248 -18 -4.5 ]
[.1178 1.09248 0 4.5 ]
[.1303 1.18726 -8 0 ]
[.1303 1.18726 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 1.16226 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.30075 .58113 m
.30075 .58738 L
s
[(0.2)] .30075 .56863 0 1 Mshowa
.4712 .58113 m
.4712 .58738 L
s
[(0.4)] .4712 .56863 0 1 Mshowa
.64165 .58113 m
.64165 .58738 L
s
[(0.6)] .64165 .56863 0 1 Mshowa
.8121 .58113 m
.8121 .58738 L
s
[(0.8)] .8121 .56863 0 1 Mshowa
.98256 .58113 m
.98256 .58738 L
s
[(1)] .98256 .56863 0 1 Mshowa
.125 Mabswid
.17291 .58113 m
.17291 .58488 L
s
.21553 .58113 m
.21553 .58488 L
s
.25814 .58113 m
.25814 .58488 L
s
.34337 .58113 m
.34337 .58488 L
s
.38598 .58113 m
.38598 .58488 L
s
.42859 .58113 m
.42859 .58488 L
s
.51382 .58113 m
.51382 .58488 L
s
.55643 .58113 m
.55643 .58488 L
s
.59904 .58113 m
.59904 .58488 L
s
.68427 .58113 m
.68427 .58488 L
s
.72688 .58113 m
.72688 .58488 L
s
.76949 .58113 m
.76949 .58488 L
s
.85472 .58113 m
.85472 .58488 L
s
.89733 .58113 m
.89733 .58488 L
s
.93994 .58113 m
.93994 .58488 L
s
.08769 .58113 m
.08769 .58488 L
s
.04508 .58113 m
.04508 .58488 L
s
.00246 .58113 m
.00246 .58488 L
s
.25 Mabswid
0 .58113 m
1 .58113 L
s
gsave
1.025 .58113 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.1303 .06978 m
.13655 .06978 L
s
[(-0.6)] .1178 .06978 1 0 Mshowa
.1303 .24023 m
.13655 .24023 L
s
[(-0.4)] .1178 .24023 1 0 Mshowa
.1303 .41068 m
.13655 .41068 L
s
[(-0.2)] .1178 .41068 1 0 Mshowa
.1303 .75158 m
.13655 .75158 L
s
[(0.2)] .1178 .75158 1 0 Mshowa
.1303 .92203 m
.13655 .92203 L
s
[(0.4)] .1178 .92203 1 0 Mshowa
.1303 1.09248 m
.13655 1.09248 L
s
[(0.6)] .1178 1.09248 1 0 Mshowa
.125 Mabswid
.1303 .11239 m
.13405 .11239 L
s
.1303 .155 m
.13405 .155 L
s
.1303 .19761 m
.13405 .19761 L
s
.1303 .28284 m
.13405 .28284 L
s
.1303 .32545 m
.13405 .32545 L
s
.1303 .36807 m
.13405 .36807 L
s
.1303 .45329 m
.13405 .45329 L
s
.1303 .4959 m
.13405 .4959 L
s
.1303 .53852 m
.13405 .53852 L
s
.1303 .62374 m
.13405 .62374 L
s
.1303 .66635 m
.13405 .66635 L
s
.1303 .70897 m
.13405 .70897 L
s
.1303 .79419 m
.13405 .79419 L
s
.1303 .83681 m
.13405 .83681 L
s
.1303 .87942 m
.13405 .87942 L
s
.1303 .96464 m
.13405 .96464 L
s
.1303 1.00726 m
.13405 1.00726 L
s
.1303 1.04987 m
.13405 1.04987 L
s
.1303 .02716 m
.13405 .02716 L
s
.1303 1.13509 m
.13405 1.13509 L
s
.25 Mabswid
.1303 0 m
.1303 1.16226 L
s
gsave
.1303 1.18726 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 Mabswid
.12203 .5828 m
.12113 .58309 L
.12013 .58342 L
.11903 .58381 L
.11781 .58427 L
.11647 .58481 L
.115 .58543 L
.11338 .58616 L
.1116 .58701 L
.10965 .58799 L
.10752 .58914 L
.10519 .59048 L
.10266 .59203 L
.09991 .59383 L
.09692 .59591 L
.0937 .59832 L
.09024 .6011 L
.08653 .6043 L
.08258 .60798 L
.07839 .61221 L
.07397 .61704 L
.06935 .62256 L
.06455 .62884 L
.05963 .63596 L
.05463 .64401 L
.04963 .65307 L
.04471 .66323 L
.03998 .67457 L
.03556 .68716 L
.03159 .70106 L
.02825 .71633 L
.0257 .73298 L
.02415 .75102 L
.02381 .77042 L
.02489 .79112 L
.02763 .81302 L
.03222 .83599 L
.03888 .85983 L
.04779 .88433 L
.05909 .90924 L
.0729 .93425 L
.08928 .95905 L
.10824 .98332 L
.12975 1.0067 L
.15369 1.02888 L
.17992 1.04953 L
.20823 1.06836 L
.23835 1.08513 L
.27001 1.09963 L
.3029 1.11171 L
Mistroke
.33667 1.12126 L
.371 1.12825 L
.40555 1.13267 L
.44002 1.13459 L
.47412 1.13409 L
.50757 1.13132 L
.54016 1.12643 L
.57168 1.11961 L
.60198 1.11106 L
.63094 1.10098 L
.65845 1.08957 L
.68447 1.07705 L
.70896 1.06361 L
.73191 1.04943 L
.75334 1.03468 L
.77327 1.01953 L
.79175 1.00411 L
.80883 .98856 L
.82458 .97298 L
.83907 .95748 L
.85236 .94213 L
.86453 .92702 L
.87565 .91219 L
.88581 .8977 L
.89506 .88358 L
.90347 .86987 L
.91112 .85659 L
.91806 .84375 L
.92436 .83136 L
.93006 .81944 L
.93522 .80798 L
.93989 .79698 L
.94411 .78643 L
.94793 .77634 L
.95137 .76668 L
.95448 .75745 L
.95728 .74864 L
.95981 .74023 L
.96209 .73221 L
.96414 .72457 L
.96599 .7173 L
.96765 .71037 L
.96915 .70378 L
.9705 .69752 L
.97172 .69156 L
.97281 .68589 L
.97379 .68051 L
.97468 .6754 L
.97547 .67054 L
.97619 .66593 L
Mistroke
.97619 .49633 L
.97547 .49172 L
.97468 .48686 L
.97379 .48175 L
.97281 .47636 L
.97172 .4707 L
.9705 .46474 L
.96915 .45847 L
.96765 .45188 L
.96599 .44496 L
.96414 .43768 L
.96209 .43004 L
.95981 .42203 L
.95728 .41362 L
.95448 .40481 L
.95137 .39558 L
.94793 .38592 L
.94411 .37582 L
.93989 .36528 L
.93522 .35428 L
.93006 .34282 L
.92436 .33089 L
.91806 .31851 L
.91112 .30567 L
.90347 .29239 L
.89506 .27868 L
.88581 .26456 L
.87565 .25007 L
.86453 .23524 L
.85236 .22013 L
.83907 .20478 L
.82458 .18928 L
.80883 .1737 L
.79175 .15815 L
.77327 .14273 L
.75334 .12758 L
.73191 .11283 L
.70896 .09865 L
.68447 .08521 L
.65845 .07268 L
.63094 .06128 L
.60198 .0512 L
.57168 .04265 L
.54016 .03583 L
.50757 .03094 L
.47412 .02817 L
.44002 .02767 L
.40555 .02959 L
.371 .03401 L
.33667 .041 L
Mistroke
.3029 .05055 L
.27001 .06263 L
.23835 .07713 L
.20823 .0939 L
.17992 .11273 L
.15369 .13338 L
.12975 .15555 L
.10824 .17894 L
.08928 .20321 L
.0729 .22801 L
.05909 .25302 L
.04779 .27793 L
.03888 .30243 L
.03222 .32627 L
.02763 .34924 L
.02489 .37114 L
.02381 .39184 L
.02415 .41124 L
.0257 .42928 L
.02825 .44593 L
.03159 .46119 L
.03556 .4751 L
.03998 .48769 L
.04471 .49902 L
.04963 .50918 L
.05463 .51825 L
.05963 .5263 L
.06455 .53342 L
.06935 .5397 L
.07397 .54522 L
.07839 .55005 L
.08258 .55427 L
.08653 .55796 L
.09024 .56116 L
.0937 .56394 L
.09692 .56635 L
.09991 .56843 L
.10266 .57023 L
.10519 .57178 L
.10752 .57311 L
.10965 .57426 L
.1116 .57525 L
.11338 .5761 L
.115 .57683 L
.11647 .57745 L
.11781 .57799 L
.11903 .57844 L
.12013 .57884 L
.12113 .57917 L
.12203 .57946 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 1.16226 L
0 1.16226 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{247.75, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003g000181000`40O003h00Omgoo003gOol00?Mo
o`00mgoo000MOol00`00Oomoo`3GOol001eoo`03001oogoo0=Moo`007Goo00<007ooOol0egoo000M
Ool00`00Oomoo`3GOol001eoo`03001oogoo0=Moo`007Goo00<007ooOol0egoo000MOol20011Ool>
0029Ool001eoo`03001oogoo03Qoo`P000ioo`P0085oo`007Goo00<007ooOol0<7oo20007Woo1@00
O7oo000MOol00`00Oomoo`0ZOol6000[Ool4001hOol001eoo`03001oogoo02Ioo`@003Eoo`<007Eo
o`007Goo00<007ooOol08goo0`00?7oo1000LGoo000MOol00`00Oomoo`0QOol20013Ool3001^Ool0
01eoo`03001oogoo01ioo`<004Qoo`@006Yoo`003Goo00<007ooOol00Woo00@007ooOomoo`8000Eo
o`03001oogoo01]oo`<004moo`<006Moo`0037oo00<007oo00001goo00<007oo000017oo00<007oo
Ool06Goo0P00EGoo0`00I7oo0007Ool30002Ool00`00Ool00007Ool00`00Ool00004Ool2000HOol2
001JOol2001ROol000aoo`03001oo`0000Moo`8000Eoo`03001oogoo01Eoo`8005ioo`80061oo`00
37oo00<007oo00001goo00<007ooOol017oo00<007ooOol04goo0P00HWoo0P00GWoo000=Ool00`00
Oomoo`07Ool20004Ool00`00Oomoo`0AOol2001VOol2001LOol001eoo`03001oogoo00moo`8006Yo
o`8005Yoo`007Goo00<007ooOol03Woo00<007ooOol0K7oo0P00F7oo000MOol00`00Oomoo`0<Ool2
001aOol00`00Oomoo`1EOol001eoo`03001oogoo00]oo`03001oogoo079oo`8005Eoo`007Goo00<0
07ooOol02Goo0P00Mgoo0P00Dgoo000MOol20009Ool00`00Oomoo`1iOol00`00Oomoo`1@Ool001eo
o`03001oogoo00Moo`03001oogoo07]oo`03001oogoo04moo`007Goo00<007ooOol01Woo00<007oo
Ool0OGoo0P00Cgoo000MOol00`00Oomoo`04Ool20022Ool00`00Oomoo`1<Ool001eoo`03001oogoo
00=oo`03001oogoo08=oo`03001oogoo04]oo`007Goo00<007ooOol00Woo00<007ooOol0QGoo0P00
Bgoo000MOol01@00Oomoogoo0000RWoo0P00BGoo000MOol01000Oomoo`00SGoo00<007ooOol0AWoo
000MOol00`00Ool0002?Ool00`00Oomoo`15Ool001eoo`80095oo`03001oogoo04Aoo`007Goo0P00
TWoo00<007ooOol0@goo000LOol2002DOol00`00Oomoo`12Ool001]oo`03001oo`0009Eoo`03001o
ogoo045oo`006Woo00@007ooOol009Ioo`80045oo`006Goo00D007ooOomoo`0009Qoo`03001oogoo
03ioo`0067oo00<007ooOol00Woo00<007ooOol0Ugoo00<007ooOol0?Goo000GOol00`00Oomoo`03
Ool00`00Oomoo`2HOol00`00Oomoo`0lOol001Moo`03001oogoo00=oo`03001oogoo09Qoo`03001o
ogoo03aoo`005Woo00<007ooOol017oo00<007ooOol0VGoo00<007ooOol0>goo000EOol00`00Oomo
o`05Ool00`00Oomoo`2JOol00`00Oomoo`0jOol001Eoo`03001oogoo00Eoo`8009aoo`03001oogoo
03Uoo`0057oo00<007ooOol01Woo00<007ooOol0W7oo00<007ooOol0>7oo000COol00`00Oomoo`07
Ool00`00Oomoo`2MOol00`00Oomoo`0gOol0019oo`03001oogoo00Qoo`03001oogoo09ioo`03001o
ogoo03Ioo`004Woo00<007ooOol027oo00<007ooOol0WWoo00<007ooOol0=Woo000AOol00`00Oomo
o`09Ool00`00Oomoo`2OOol00`00Oomoo`0eOol0011oo`03001oogoo00Yoo`03001oogoo0:1oo`03
001oogoo03Aoo`003Goo00<007oo00000Woo00<007ooOol00Woo0`000goo00<007ooOol0XGoo00<0
07ooOol0<goo000<Ool01000Ool0000027oo00<007ooOol00Woo00<007ooOol0XWoo00<007ooOol0
<Woo0007Ool30002Ool00`00Ool00007Ool40003Ool2002TOol00`00Oomoo`0aOol000aoo`03001o
o`0000Moo`03001oo`0000Aoo`03001oogoo0:Aoo`03001oogoo031oo`0037oo0`0027oo0P0017oo
00<007ooOol0YGoo00<007ooOol0;goo000=Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`2VOol00`00Oomoo`0^Ool000aoo`03001oogoo00ioo`03001oogoo0:Ioo`03001oogoo02ioo`00
37oo00<007ooOol03Woo00<007ooOol0Ygoo00<007ooOol0;Goo000;Ool00`00Oomoo`0?Ool00`00
Oomoo`2WOol00`00Oomoo`0]Ool000]oo`03001oogoo00moo`03001oogoo0:Qoo`03001oogoo02ao
o`002Woo00<007ooOol047oo00<007ooOol0Z7oo00<007ooOol0;7oo000:Ool00`00Oomoo`0@Ool0
0`00Oomoo`2YOol00`00Oomoo`0[Ool000Yoo`03001oogoo011oo`800:]oo`03001oogoo02Yoo`00
2Goo00<007ooOol04Goo00<007ooOol0ZWoo00<007ooOol0:Woo0009Ool00`00Oomoo`0AOol00`00
Oomoo`2[Ool00`00Oomoo`0YOol000Qoo`03001oogoo019oo`03001oogoo0:aoo`03001oogoo02Qo
o`0027oo00<007ooOol04Woo00<007ooOol0[7oo00<007ooOol0:7oo0008Ool00`00Oomoo`0BOol0
0`00Oomoo`2]Ool00`00Oomoo`0WOol000Qoo`03001oogoo019oo`03001oogoo0:eoo`03001oogoo
02Moo`001goo00<007ooOol04goo00<007ooOol0[Woo00<007ooOol09Woo0007Ool00`00Oomoo`0C
Ool00`00Oomoo`2^Ool00`00Oomoo`0VOol000Moo`03001oogoo01=oo`800;1oo`03001oogoo02Eo
o`001goo00<007ooOol04goo00<007ooOol0[goo00<007ooOol09Goo0007Ool00`00Oomoo`0COol0
0`00Oomoo`2`Ool00`00Oomoo`0TOol000Moo`03001oogoo01=oo`03001oogoo0;5oo`03001oogoo
02=oo`001Woo00<007ooOol057oo00<007ooOol0/Goo00<007ooOol08goo0006Ool00`00Oomoo`0D
Ool00`00Oomoo`2aOol00`00Oomoo`0SOol000Ioo`03001oogoo01Aoo`03001oogoo0;9oo`03001o
ogoo029oo`001Woo00<007ooOol057oo00<007ooOol0/Woo00<007ooOol08Woo0006Ool00`00Oomo
o`0DOol00`00Oomoo`2cOol00`00Oomoo`0QOol000Eoo`03001oogoo01Eoo`03001oogoo0;=oo`03
001oogoo025oo`001Goo00<007ooOol05Goo0P00]7oo00<007ooOol08Goo0005Ool00`00Oomoo`0E
Ool00`00Oomoo`2dOol00`00Oomoo`0POol000Eoo`03001oogoo01Eoo`03001oogoo0;Aoo`03001o
ogoo021oo`001Goo00<007ooOol05Goo00<007ooOol0]Goo00<007ooOol07goo0005Ool00`00Oomo
o`0EOol00`00Oomoo`2eOol00`00Oomoo`0OOol000Eoo`03001oogoo01Eoo`03001oogoo0;Ioo`03
001oogoo01ioo`001Goo00<007ooOol05Goo00<007ooOol0]Woo00<007ooOol07Woo0005Ool00`00
Oomoo`0EOol00`00Oomoo`2fOol00`00Oomoo`0NOol000Eoo`03001oogoo00Eoo`03001oogoo009o
o`04001oogooOol30004Ool00`00Oomoo`2fOol00`00Oomoo`0NOol000Eoo`03001oogoo00Aoo`03
001oo`0000Moo`03001oogoo00Aoo`03001oogoo0;Moo`03001oogoo01eoo`001Goo00<007oo0000
0P000Woo00<007oo000027oo00<007ooOol00goo0P00^7oo00<007ooOol07Goo0005Ool00`00Oomo
o`04Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`2hOol00`00Oomoo`0LOol000Eoo`03
001oogoo00Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0;Qoo`03001oogoo01aoo`00
1Goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0^7oo00<007ooOol0
77oo0005Ool00`00Oomoo`0EOol00`00Oomoo`2hOol00`00Oomoo`0LOol000Eoo`03001oogoo01Eo
o`03001oogoo0;Uoo`03001oogoo01]oo`001Woo00<007ooOol057oo00<007ooOol0^Goo00<007oo
Ool06goo0006Ool00`00Oomoo`0DOol00`00Oomoo`2iOol00`00Oomoo`0KOol000Ioo`03001oogoo
01Aoo`03001oogoo0;Uoo`03001oogoo01]oo`001goo00<007ooOol04goo0P00^Woo00<007ooOol0
6goo0007Ool00`00Oomoo`0COol00`00Oomoo`2jOol00`00Oomoo`0JOol000Moo`03001oogoo01=o
o`03001oogoo0;Yoo`03001oogoo01Yoo`001goo00<007ooOol04goo00<007ooOol0^Woo00<007oo
Ool06Woo0008Ool00`00Oomoo`0BOol00`00Oomoo`2jOol00`00Oomoo`0JOol000Qoo`03001oogoo
019oo`03001oogoo0;]oo`03001oogoo01Uoo`0027oo00<007ooOol04Woo00<007ooOol0^goo00<0
07ooOol06Goo0009Ool00`00Oomoo`0AOol00`00Oomoo`2kOol00`00Oomoo`0IOol000Uoo`03001o
ogoo015oo`03001oogoo0;]oo`03001oogoo01Uoo`002Woo00<007ooOol047oo00<007ooOol0^goo
00<007ooOol06Goo000:Ool00`00Oomoo`0@Ool2002lOol00`00Oomoo`0IOol000Yoo`03001oogoo
011oo`03001oogoo0;]oo`03001oogoo01Uoo`002goo00<007ooOol03goo00<007ooOol0^goo00<0
07ooOol06Goo000;Ool00`00Oomoo`0?Ool00`00Oomoo`2kOol00`00Oomoo`0IOol000aoo`03001o
ogoo00ioo`03001oogoo0;]oo`03001oogoo01Uoo`0037oo00<007ooOol03Woo00<007ooOol0^goo
00<007ooOol06Goo000=Ool00`00Oomoo`0=Ool00`00Oomoo`2kOol00`00Oomoo`0IOol000eoo`03
001oogoo00eoo`03001oogoo0;]oo`03001oogoo01Uoo`003Woo00<007ooOol037oo00<007ooOol0
7Woo00<007ooOol00Woo00@007ooOomoo`<001Yoo`03001oogoo009oo`03001oogoo009oo`<001Uo
o`03001oogoo009oo`04001oogooOol2000LOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`0LOol5000HOol000moo`03001oogoo00]oo`8001ioo`03001oo`0000Moo`03001oogoo01Uoo`03
001oo`0000Uoo`03001oogoo01Moo`03001oo`0000Moo`03001oo`0001Yoo`03001oo`0000Moo`03
001oo`0001ioo`8001Yoo`003goo00<007ooOol02goo00<007ooOol07Goo00<007oo000027oo00<0
07ooOol067oo00<007oo00001goo100067oo00<007oo00001goo00<007oo00006Woo00<007oo0000
1goo00<007oo00007Woo0P006Woo000@Ool00`00Oomoo`0:Ool00`00Oomoo`0MOol00`00Ool00008
Ool00`00Oomoo`0HOol00`00Ool00007Ool00`00Ool0000IOol00`00Ool00007Ool2000KOol00`00
Ool00008Ool00`00Oomoo`0MOol2000JOol0015oo`03001oogoo00Uoo`03001oogoo01eoo`03001o
o`0000Moo`03001oo`0001Uoo`03001oo`0000Qoo`8001Uoo`03001oo`0000Moo`03001oogoo01Yo
o`03001oo`0000Moo`03001oo`0001ioo`8001Yoo`004Woo00<007ooOol027oo00<007ooOol07Woo
00<007ooOol01goo00<007ooOol06Goo00<007ooOol027oo00<007ooOol067oo00<007ooOol01goo
0P006goo00<007ooOol01goo00<007ooOol07Goo0P006Woo000COol20008Ool00`00Oomoo`2kOol0
0`00Oomoo`0IOol001Eoo`03001oogoo00Eoo`03001oogoo0;]oo`03001oogoo01Uoo`005Goo0`00
1Goo00<007ooOol0^goo00<007ooOol06Goo000GOol20004Ool00`00Oomoo`2kOol00`00Oomoo`0:
Ool3000017oo001oogoo0P001Woo000IOol300000goo001oo`2lOol00`00Oomoo`0;Ool01P00Oomo
o`00Ool000Qoo`00hP001goo0`000Woo0`001Woo00000`00Oomoo`07Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool30002Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Ool0000;Ool01@00Oomoo`00Ool00`001Woo000GOol20004Ool00`00
Oomoo`2kOol00`00Oomoo`0;Ool01000Oomoo`002Woo000EOol20006Ool00`00Oomoo`2kOol00`00
Oomoo`0:Ool4000;Ool001Aoo`8000Moo`03001oogoo0;]oo`03001oogoo01Uoo`004goo00<007oo
Ool01goo00<007ooOol0^goo00<007ooOol06Goo000BOol00`00Oomoo`08Ool00`00Oomoo`2kOol0
0`00Oomoo`0IOol0015oo`03001oogoo00Uoo`03001oogoo0;]oo`03001oogoo01Uoo`0047oo00<0
07ooOol02Woo00<007ooOol0^goo00<007ooOol06Goo000?Ool00`00Oomoo`0;Ool2002lOol00`00
Oomoo`0IOol000ioo`03001oogoo00aoo`03001oogoo0;]oo`03001oogoo01Uoo`003Woo00<007oo
Ool037oo00<007ooOol0^goo00<007ooOol06Goo000=Ool00`00Oomoo`0=Ool00`00Oomoo`2kOol0
0`00Oomoo`0IOol000aoo`03001oogoo00ioo`03001oogoo0;]oo`03001oogoo01Uoo`0037oo00<0
07ooOol03Woo00<007ooOol0^goo00<007ooOol06Goo000;Ool00`00Oomoo`0?Ool00`00Oomoo`2k
Ool00`00Oomoo`0IOol000]oo`03001oogoo00moo`03001oogoo0;]oo`03001oogoo01Uoo`002Woo
00<007ooOol047oo00<007ooOol0^goo00<007ooOol06Goo000:Ool00`00Oomoo`0@Ool00`00Oomo
o`2kOol00`00Oomoo`0IOol000Yoo`03001oogoo011oo`800;aoo`03001oogoo01Uoo`002Goo00<0
07ooOol04Goo00<007ooOol0^goo00<007ooOol06Goo0009Ool00`00Oomoo`0AOol00`00Oomoo`2k
Ool00`00Oomoo`0IOol000Uoo`03001oogoo015oo`03001oogoo0;]oo`03001oogoo01Uoo`0027oo
00<007ooOol04Woo00<007ooOol0^goo00<007ooOol06Goo0008Ool00`00Oomoo`0BOol00`00Oomo
o`2jOol00`00Oomoo`0JOol000Qoo`03001oogoo019oo`03001oogoo0;Yoo`03001oogoo01Yoo`00
1goo00<007ooOol04goo00<007ooOol0^Woo00<007ooOol06Woo0007Ool00`00Oomoo`0COol00`00
Oomoo`2jOol00`00Oomoo`0JOol000Moo`03001oogoo01=oo`03001oogoo0;Yoo`03001oogoo01Yo
o`001Woo00<007ooOol057oo0P00^Woo00<007ooOol06goo0006Ool00`00Oomoo`0DOol00`00Oomo
o`2iOol00`00Oomoo`0KOol000Ioo`03001oogoo01Aoo`03001oogoo0;Uoo`03001oogoo01]oo`00
1Goo00<007ooOol05Goo00<007ooOol0^Goo00<007ooOol06goo0005Ool00`00Oomoo`0EOol00`00
Oomoo`2hOol00`00Oomoo`0LOol000Eoo`03001oogoo01Eoo`03001oogoo0;Qoo`03001oogoo01ao
o`001Goo00<007ooOol05Goo00<007ooOol0^7oo00<007ooOol077oo0005Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol0^7oo00<007ooOol077oo0005Ool00`00
Oomoo`04Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`2gOol00`00Oomoo`0MOol000Eo
o`03001oogoo00Aoo`03001oo`0000Qoo`03001oogoo00=oo`800;Qoo`03001oogoo01eoo`001Goo
00<007ooOol017oo00<007oo000027oo00<007ooOol00goo00<007ooOol0]Woo00<007ooOol07Woo
0005Ool00`00Oomoo`04Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`2fOol00`00Oomo
o`0NOol000Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0;Ioo`03
001oogoo01ioo`001Goo00<007ooOol05Goo00<007ooOol0]Woo00<007ooOol07Woo0005Ool00`00
Oomoo`0EOol00`00Oomoo`2eOol00`00Oomoo`0OOol000Eoo`03001oogoo01Eoo`03001oogoo0;Eo
o`03001oogoo01moo`001Goo00<007ooOol05Goo00<007ooOol0]7oo00<007ooOol087oo0005Ool0
0`00Oomoo`0EOol00`00Oomoo`2dOol00`00Oomoo`0POol000Eoo`03001oogoo01Eoo`03001oogoo
0;=oo`03001oogoo025oo`001Goo00<007ooOol05Goo0P00]7oo00<007ooOol08Goo0005Ool00`00
Oomoo`0EOol00`00Oomoo`2cOol00`00Oomoo`0QOol000Ioo`03001oogoo01Aoo`03001oogoo0;9o
o`03001oogoo029oo`001Woo00<007ooOol057oo00<007ooOol0/Woo00<007ooOol08Woo0006Ool0
0`00Oomoo`0DOol00`00Oomoo`2bOol00`00Oomoo`0ROol000Ioo`03001oogoo01Aoo`03001oogoo
0;5oo`03001oogoo02=oo`001Woo00<007ooOol057oo00<007ooOol0/Goo00<007ooOol08goo0007
Ool00`00Oomoo`0COol00`00Oomoo`2`Ool00`00Oomoo`0TOol000Moo`03001oogoo01=oo`03001o
ogoo0;1oo`03001oogoo02Aoo`001goo00<007ooOol04goo0P00/7oo00<007ooOol09Goo0007Ool0
0`00Oomoo`0COol00`00Oomoo`2_Ool00`00Oomoo`0UOol000Moo`03001oogoo01=oo`03001oogoo
0:ioo`03001oogoo02Ioo`0027oo00<007ooOol04Woo00<007ooOol0[Woo00<007ooOol09Woo0008
Ool00`00Oomoo`0BOol00`00Oomoo`2]Ool00`00Oomoo`0WOol000Qoo`03001oogoo019oo`03001o
ogoo0:eoo`03001oogoo02Moo`0027oo00<007ooOol04Woo00<007ooOol0[7oo00<007ooOol0:7oo
0008Ool00`00Oomoo`0BOol00`00Oomoo`2/Ool00`00Oomoo`0XOol000Uoo`03001oogoo015oo`03
001oogoo0:]oo`03001oogoo02Uoo`002Goo00<007ooOol04Goo00<007ooOol0ZWoo00<007ooOol0
:Woo000:Ool00`00Oomoo`0@Ool2002[Ool00`00Oomoo`0ZOol000Yoo`03001oogoo011oo`03001o
ogoo0:Uoo`03001oogoo02]oo`002goo00<007ooOol03goo00<007ooOol0Z7oo00<007ooOol0;7oo
000;Ool00`00Oomoo`0?Ool00`00Oomoo`2XOol00`00Oomoo`0/Ool000aoo`03001oogoo00ioo`03
001oogoo0:Moo`03001oogoo02eoo`0037oo00<007ooOol03Woo00<007ooOol0YWoo00<007ooOol0
;Woo000=Ool00`00Oomoo`0=Ool00`00Oomoo`2VOol00`00Oomoo`0^Ool000eoo`03001oogoo00eo
o`03001oogoo0:Eoo`03001oogoo02moo`003Goo0P000goo00<007ooOol00Woo0`000goo00<007oo
Ool0Y7oo00<007ooOol0<7oo000<Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`2SOol0
0`00Oomoo`0aOol000aoo`04001oo`000006Ool40003Ool2002TOol00`00Oomoo`0aOol000aoo`04
001oo`000006Ool00`00Ool00004Ool00`00Oomoo`2ROol00`00Oomoo`0bOol000aoo`05001oo`00
Ool00006Ool20004Ool00`00Oomoo`2QOol00`00Oomoo`0cOol000eoo`05001oogooOol00006Ool0
0`00Oomoo`02Ool00`00Oomoo`2POol00`00Oomoo`0dOol0015oo`03001oogoo00Uoo`03001oogoo
09moo`03001oogoo03Eoo`004Woo00<007ooOol027oo00<007ooOol0WWoo00<007ooOol0=Woo000C
Ool00`00Oomoo`07Ool00`00Oomoo`2MOol00`00Oomoo`0gOol001=oo`03001oogoo00Moo`03001o
ogoo09eoo`03001oogoo03Moo`0057oo00<007ooOol01Woo00<007ooOol0W7oo00<007ooOol0>7oo
000EOol00`00Oomoo`05Ool2002LOol00`00Oomoo`0iOol001Ioo`03001oogoo00Aoo`03001oogoo
09Yoo`03001oogoo03Yoo`005Woo00<007ooOol017oo00<007ooOol0VGoo00<007ooOol0>goo000G
Ool00`00Oomoo`03Ool00`00Oomoo`2HOol00`00Oomoo`0lOol001Qoo`03001oogoo009oo`03001o
ogoo09Moo`03001oogoo03eoo`006Goo00D007ooOomoo`0009Uoo`03001oogoo03eoo`006Woo00@0
07ooOol009Qoo`03001oogoo03ioo`006goo00<007oo0000Ugoo00<007ooOol0?goo000KOol00`00
Ool0002EOol20012Ool001aoo`8009Aoo`03001oogoo049oo`007Goo0P00TWoo00<007ooOol0@goo
000MOol2002AOol00`00Oomoo`14Ool001eoo`03001oo`0008moo`03001oogoo04Eoo`007Goo00@0
07ooOol008eoo`03001oogoo04Ioo`007Goo00D007ooOomoo`0008Yoo`8004Uoo`007Goo00<007oo
Ool00Woo00<007ooOol0QGoo0P00Bgoo000MOol00`00Oomoo`03Ool20024Ool00`00Oomoo`1;Ool0
01eoo`03001oogoo00Eoo`03001oogoo07moo`8004ioo`007Goo00<007ooOol01Woo0P00OGoo0P00
D7oo000MOol20009Ool00`00Oomoo`1iOol00`00Oomoo`1@Ool001eoo`03001oogoo00Uoo`03001o
ogoo07Moo`03001oogoo055oo`007Goo00<007ooOol02Woo00<007ooOol0M7oo0P00E7oo000MOol0
0`00Oomoo`0;Ool2001cOol00`00Oomoo`1DOol001eoo`03001oogoo00eoo`03001oogoo06moo`03
001oogoo05Eoo`007Goo00<007ooOol03Woo0P00KGoo0P00F7oo000MOol00`00Oomoo`0@Ool2001Y
Ool2001JOol001eoo`03001oogoo019oo`8006Eoo`8005aoo`003Goo00<007ooOol00Woo00@007oo
Oomoo`8000Eoo`03001oogoo01Aoo`80061oo`<005ioo`0037oo00<007oo00001goo00<007oo0000
17oo00<007ooOol05Woo0P00G7oo0P00HGoo000<Ool00`00Ool00007Ool00`00Ool00004Ool2000I
Ool2001HOol2001SOol000aoo`03001oo`0000Moo`8000Eoo`03001oogoo01Yoo`8005Aoo`8006Eo
o`0037oo00<007oo00001goo00<007ooOol017oo00<007ooOol077oo0P00Cgoo0`00Igoo000=Ool0
0`00Oomoo`07Ool20004Ool00`00Oomoo`0NOol40017Ool4001ZOol001eoo`03001oogoo029oo`@0
041oo`<006ioo`007Goo00<007ooOol09Woo1000>7oo1000LGoo000MOol00`00Oomoo`0ZOol3000b
Ool3001eOol001eoo`03001oogoo02eoo`@002Yoo`@007Qoo`007Goo00<007ooOol0<Goo1P007goo
1@00O7oo000MOol00`00Oomoo`0gOolO0021Ool001eoo`800=Qoo`007Goo00<007ooOol0egoo000M
Ool00`00Oomoo`3GOol001eoo`03001oogoo0=Moo`007Goo00<007ooOol0egoo000MOol00`00Oomo
o`3GOol001eoo`03001oogoo0=Moo`00mgoo003gOol00?Moo`00mgoo003gOol00?Moo`00mgoo003g
Ool00?Moo`0067oo0`0000Ioo`00Ool007oo003FOol001Uoo`08001oogoo001oo`00Ool00=Ioo`00
6Goo00P007ooOol007oo001oo`00eWoo000IOol00`00Oomoo`0200000goo001oo`3FOol001Uoo`03
001oogoo0=]oo`0067oo0`00g7oo003gOol00?Moo`00mgoo003gOol00?Moo`00mgoo0000\
\>"],
  ImageRangeCache->{{{0, 246.75}, {287, 0}} -> {-0.152896, -0.700538, 
  0.00521216, 0.00521216}},
  CellTags->"5.3"]
}, Open  ]],

Cell[TextData[{
  "Like the other frequency response plotting functions, ",
  StyleBox["NyquistPlot", "MR"],
  " is capable of handling nonpolynomial transfer functions. Note, however, \
that such systems must be supplied in transfer function form and the desired \
frequency range must be specified, since conversion from the state space \
works for linear systems only and so does the routine which determines the \
default frequency range. "
}], "Text",
  CellTags->"5.3"],

Cell[TextData[{
  "Here is a system consisting of a transport lag ",
  Cell[BoxData[
      \(TraditionalForm\`e\^\(\(-\[Tau]\) s\)\)], "InlineFormula",
    CellTags->"S0.0.4"],
  " and first\[Hyphen]order lag ",
  Cell[BoxData[
      \(TraditionalForm\`1/\((1 + T  s)\)\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ", for the unit values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)], "InlineFormula",
    CellTags->"S0.0.4"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)], "InlineFormula",
    CellTags->"S0.0.4"],
  ". "
}], "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{

Cell["TransferFunction[s, E^(-s)/(1+s)]", "Input",
  CellLabel->"In[24]:=",
  CellTags->"5.3"],

Cell[BoxData[
    \(TransferFunction[s, {{E\^\(-s\)\/\(1 + s\)}}]\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->"5.3"]
}, Open  ]],

Cell["This is the Nyquist plot for this system. ", "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{

Cell["NyquistPlot[%, {.01, 20}, PlotPoints -> 500]", "Input",
  CellLabel->"In[25]:=",
  CellTags->"5.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .73669 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.327365 0.648988 0.531375 0.648988 [
[.06777 .51888 -12 -9 ]
[.06777 .51888 12 0 ]
[.19757 .51888 -12 -9 ]
[.19757 .51888 12 0 ]
[.45716 .51888 -9 -9 ]
[.45716 .51888 9 0 ]
[.58696 .51888 -9 -9 ]
[.58696 .51888 9 0 ]
[.71676 .51888 -9 -9 ]
[.71676 .51888 9 0 ]
[.84656 .51888 -9 -9 ]
[.84656 .51888 9 0 ]
[.97635 .51888 -3 -9 ]
[.97635 .51888 3 0 ]
[1.025 .53138 0 -6.28125 ]
[1.025 .53138 16 6.28125 ]
[.31487 .01219 -24 -4.5 ]
[.31487 .01219 0 4.5 ]
[.31487 .14198 -24 -4.5 ]
[.31487 .14198 0 4.5 ]
[.31487 .27178 -24 -4.5 ]
[.31487 .27178 0 4.5 ]
[.31487 .40158 -24 -4.5 ]
[.31487 .40158 0 4.5 ]
[.31487 .66117 -18 -4.5 ]
[.31487 .66117 0 4.5 ]
[.32737 .76169 -8 0 ]
[.32737 .76169 8 12.5625 ]
[ 0 0 0 0 ]
[ 1 .73669 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06777 .53138 m
.06777 .53763 L
s
[(-0.4)] .06777 .51888 0 1 Mshowa
.19757 .53138 m
.19757 .53763 L
s
[(-0.2)] .19757 .51888 0 1 Mshowa
.45716 .53138 m
.45716 .53763 L
s
[(0.2)] .45716 .51888 0 1 Mshowa
.58696 .53138 m
.58696 .53763 L
s
[(0.4)] .58696 .51888 0 1 Mshowa
.71676 .53138 m
.71676 .53763 L
s
[(0.6)] .71676 .51888 0 1 Mshowa
.84656 .53138 m
.84656 .53763 L
s
[(0.8)] .84656 .51888 0 1 Mshowa
.97635 .53138 m
.97635 .53763 L
s
[(1)] .97635 .51888 0 1 Mshowa
.125 Mabswid
.10022 .53138 m
.10022 .53513 L
s
.13267 .53138 m
.13267 .53513 L
s
.16512 .53138 m
.16512 .53513 L
s
.23002 .53138 m
.23002 .53513 L
s
.26247 .53138 m
.26247 .53513 L
s
.29492 .53138 m
.29492 .53513 L
s
.35981 .53138 m
.35981 .53513 L
s
.39226 .53138 m
.39226 .53513 L
s
.42471 .53138 m
.42471 .53513 L
s
.48961 .53138 m
.48961 .53513 L
s
.52206 .53138 m
.52206 .53513 L
s
.55451 .53138 m
.55451 .53513 L
s
.61941 .53138 m
.61941 .53513 L
s
.65186 .53138 m
.65186 .53513 L
s
.68431 .53138 m
.68431 .53513 L
s
.74921 .53138 m
.74921 .53513 L
s
.78166 .53138 m
.78166 .53513 L
s
.81411 .53138 m
.81411 .53513 L
s
.879 .53138 m
.879 .53513 L
s
.91145 .53138 m
.91145 .53513 L
s
.9439 .53138 m
.9439 .53513 L
s
.03532 .53138 m
.03532 .53513 L
s
.00287 .53138 m
.00287 .53513 L
s
.25 Mabswid
0 .53138 m
1 .53138 L
s
gsave
1.025 .53138 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Re) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.32737 .01219 m
.33362 .01219 L
s
[(-0.8)] .31487 .01219 1 0 Mshowa
.32737 .14198 m
.33362 .14198 L
s
[(-0.6)] .31487 .14198 1 0 Mshowa
.32737 .27178 m
.33362 .27178 L
s
[(-0.4)] .31487 .27178 1 0 Mshowa
.32737 .40158 m
.33362 .40158 L
s
[(-0.2)] .31487 .40158 1 0 Mshowa
.32737 .66117 m
.33362 .66117 L
s
[(0.2)] .31487 .66117 1 0 Mshowa
.125 Mabswid
.32737 .04463 m
.33112 .04463 L
s
.32737 .07708 m
.33112 .07708 L
s
.32737 .10953 m
.33112 .10953 L
s
.32737 .17443 m
.33112 .17443 L
s
.32737 .20688 m
.33112 .20688 L
s
.32737 .23933 m
.33112 .23933 L
s
.32737 .30423 m
.33112 .30423 L
s
.32737 .33668 m
.33112 .33668 L
s
.32737 .36913 m
.33112 .36913 L
s
.32737 .43403 m
.33112 .43403 L
s
.32737 .46648 m
.33112 .46648 L
s
.32737 .49893 m
.33112 .49893 L
s
.32737 .56382 m
.33112 .56382 L
s
.32737 .59627 m
.33112 .59627 L
s
.32737 .62872 m
.33112 .62872 L
s
.32737 .69362 m
.33112 .69362 L
s
.32737 .72607 m
.33112 .72607 L
s
.25 Mabswid
.32737 0 m
.32737 .73669 L
s
gsave
.32737 .76169 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Im) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.5 Mabswid
.97619 .5184 m
.97619 .5182 L
.97618 .518 L
.97617 .51779 L
.97617 .51758 L
.97616 .51737 L
.97616 .51716 L
.97615 .51694 L
.97615 .51672 L
.97614 .51649 L
.97613 .51626 L
.97613 .51603 L
.97612 .5158 L
.97611 .51556 L
.9761 .51531 L
.9761 .51507 L
.97609 .51482 L
.97608 .51456 L
.97607 .51431 L
.97606 .51404 L
.97605 .51378 L
.97605 .51351 L
.97604 .51323 L
.97603 .51295 L
.97602 .51267 L
.97601 .51239 L
.97599 .51209 L
.97598 .5118 L
.97597 .5115 L
.97596 .51119 L
.97595 .51088 L
.97594 .51057 L
.97592 .51025 L
.97591 .50993 L
.9759 .5096 L
.97588 .50926 L
.97587 .50892 L
.97585 .50858 L
.97584 .50823 L
.97582 .50788 L
.9758 .50751 L
.97579 .50715 L
.97577 .50678 L
.97575 .5064 L
.97573 .50602 L
.97571 .50563 L
.97569 .50523 L
.97567 .50483 L
.97565 .50443 L
.97563 .50401 L
Mistroke
.97561 .50359 L
.97559 .50317 L
.97556 .50273 L
.97554 .5023 L
.97551 .50185 L
.97549 .5014 L
.97546 .50094 L
.97543 .50047 L
.9754 .5 L
.97537 .49952 L
.97534 .49903 L
.97531 .49853 L
.97528 .49803 L
.97525 .49752 L
.97521 .497 L
.97518 .49647 L
.97514 .49594 L
.9751 .4954 L
.97507 .49485 L
.97503 .49429 L
.97499 .49372 L
.97494 .49314 L
.9749 .49256 L
.97485 .49196 L
.97481 .49136 L
.97476 .49075 L
.97471 .49012 L
.97466 .48949 L
.97461 .48885 L
.97455 .4882 L
.9745 .48754 L
.97444 .48687 L
.97438 .48619 L
.97432 .4855 L
.97426 .48479 L
.97419 .48408 L
.97413 .48336 L
.97406 .48263 L
.97399 .48188 L
.97391 .48112 L
.97384 .48035 L
.97376 .47958 L
.97368 .47878 L
.9736 .47798 L
.97351 .47716 L
.97343 .47634 L
.97334 .4755 L
.97324 .47464 L
.97315 .47378 L
.97305 .4729 L
Mistroke
.97295 .472 L
.97284 .4711 L
.97273 .47018 L
.97262 .46924 L
.97251 .4683 L
.97239 .46733 L
.97227 .46636 L
.97214 .46537 L
.97201 .46436 L
.97188 .46334 L
.97174 .4623 L
.9716 .46125 L
.97145 .46018 L
.9713 .4591 L
.97114 .458 L
.97098 .45688 L
.97082 .45575 L
.97064 .4546 L
.97047 .45343 L
.97029 .45225 L
.9701 .45105 L
.96991 .44983 L
.96971 .44859 L
.9695 .44733 L
.96929 .44606 L
.96908 .44476 L
.96885 .44345 L
.96862 .44212 L
.96838 .44077 L
.96814 .43939 L
.96789 .438 L
.96763 .43659 L
.96736 .43516 L
.96708 .4337 L
.9668 .43223 L
.9665 .43073 L
.9662 .42921 L
.96589 .42767 L
.96557 .4261 L
.96524 .42452 L
.96489 .42291 L
.96454 .42128 L
.96418 .41962 L
.96381 .41794 L
.96342 .41624 L
.96303 .41451 L
.96262 .41275 L
.9622 .41097 L
.96176 .40917 L
.96132 .40734 L
Mistroke
.96086 .40549 L
.96038 .4036 L
.95989 .4017 L
.95939 .39976 L
.95887 .3978 L
.95834 .39581 L
.95779 .39379 L
.95722 .39175 L
.95664 .38967 L
.95603 .38757 L
.95541 .38544 L
.95478 .38328 L
.95412 .38109 L
.95344 .37887 L
.95274 .37662 L
.95203 .37434 L
.95129 .37202 L
.95052 .36968 L
.94974 .36731 L
.94893 .3649 L
.9481 .36247 L
.94724 .36 L
.94636 .3575 L
.94545 .35496 L
.94451 .3524 L
.94355 .3498 L
.94256 .34717 L
.94154 .3445 L
.94049 .3418 L
.93941 .33907 L
.93829 .3363 L
.93715 .3335 L
.93597 .33067 L
.93475 .3278 L
.9335 .32489 L
.93221 .32195 L
.93089 .31898 L
.92953 .31597 L
.92813 .31293 L
.92669 .30985 L
.9252 .30674 L
.92368 .30359 L
.92211 .30041 L
.92049 .29719 L
.91883 .29394 L
.91712 .29065 L
.91536 .28733 L
.91356 .28397 L
.9117 .28058 L
.90979 .27716 L
Mistroke
.90782 .2737 L
.9058 .27021 L
.90373 .26668 L
.90159 .26312 L
.8994 .25953 L
.89715 .25591 L
.89483 .25225 L
.89245 .24857 L
.89001 .24485 L
.8875 .2411 L
.88492 .23733 L
.88227 .23352 L
.87955 .22969 L
.87676 .22583 L
.87389 .22195 L
.87094 .21803 L
.86792 .2141 L
.86482 .21014 L
.86164 .20616 L
.85837 .20216 L
.85502 .19813 L
.85159 .19409 L
.84806 .19003 L
.84445 .18596 L
.84074 .18187 L
.83695 .17777 L
.83305 .17366 L
.82906 .16954 L
.82497 .16541 L
.82079 .16127 L
.8165 .15714 L
.8121 .153 L
.80761 .14886 L
.803 .14473 L
.79829 .1406 L
.79347 .13648 L
.78853 .13236 L
.78349 .12827 L
.77833 .12419 L
.77305 .12012 L
.76766 .11608 L
.76215 .11207 L
.75652 .10808 L
.75078 .10412 L
.7449 .1002 L
.73891 .09632 L
.7328 .09248 L
.72656 .08868 L
.72019 .08494 L
.7137 .08124 L
Mistroke
.70708 .07761 L
.70034 .07403 L
.69347 .07052 L
.68647 .06708 L
.67935 .06372 L
.6721 .06043 L
.66472 .05722 L
.65722 .05411 L
.64959 .05108 L
.64183 .04815 L
.63395 .04533 L
.62595 .04261 L
.61783 .04 L
.60959 .03751 L
.60122 .03514 L
.59274 .03289 L
.58415 .03078 L
.57544 .02881 L
.56662 .02697 L
.5577 .02529 L
.54867 .02375 L
.53954 .02237 L
.5303 .02116 L
.52098 .02011 L
.51156 .01923 L
.50205 .01853 L
.49246 .01801 L
.48279 .01768 L
.47305 .01754 L
.46324 .0176 L
.45336 .01785 L
.44343 .01831 L
.43344 .01898 L
.4234 .01986 L
.41332 .02096 L
.40321 .02228 L
.39306 .02383 L
.3829 .0256 L
.37271 .0276 L
.36252 .02984 L
.35233 .03231 L
.34215 .03503 L
.33197 .03798 L
.32182 .04118 L
.3117 .04463 L
.30162 .04832 L
.29158 .05226 L
.2816 .05645 L
.27167 .06089 L
.26182 .06558 L
Mistroke
.25205 .07052 L
.24236 .07571 L
.23278 .08115 L
.2233 .08684 L
.21393 .09278 L
.20469 .09896 L
.19558 .10539 L
.18661 .11206 L
.17779 .11897 L
.16913 .12612 L
.16064 .1335 L
.15232 .14112 L
.1442 .14896 L
.13626 .15702 L
.12853 .1653 L
.12102 .17379 L
.11372 .18249 L
.10665 .19139 L
.09982 .20049 L
.09323 .20978 L
.0869 .21926 L
.08083 .22891 L
.07503 .23873 L
.0695 .24871 L
.06426 .25885 L
.0593 .26913 L
.05465 .27955 L
.05029 .2901 L
.04625 .30077 L
.04252 .31155 L
.03912 .32244 L
.03604 .33341 L
.0333 .34447 L
.0309 .3556 L
.02883 .36679 L
.02712 .37802 L
.02575 .3893 L
.02475 .4006 L
.0241 .41192 L
.02381 .42324 L
.02389 .43455 L
.02433 .44584 L
.02514 .45709 L
.02633 .4683 L
.02788 .47944 L
.02981 .49051 L
.03211 .5015 L
.03478 .51238 L
.03783 .52315 L
.04124 .53379 L
Mistroke
.04503 .54428 L
.04918 .55461 L
.0537 .56477 L
.05857 .57475 L
.0638 .58452 L
.06939 .59407 L
.07532 .60339 L
.08159 .61245 L
.0882 .62126 L
.09513 .62979 L
.10238 .63802 L
.10994 .64594 L
.11781 .65353 L
.12596 .66079 L
.13439 .66769 L
.14308 .67421 L
.15204 .68036 L
.16123 .6861 L
.17064 .69143 L
.18026 .69633 L
.19008 .70079 L
.20007 .70479 L
.21021 .70833 L
.22049 .71139 L
.23089 .71396 L
.24138 .71603 L
.25194 .71759 L
.26254 .71863 L
.27317 .71915 L
.28379 .71913 L
.29438 .71858 L
.30492 .71748 L
.31536 .71584 L
.32569 .71365 L
.33587 .71091 L
.34587 .70763 L
.35566 .70381 L
.36521 .69945 L
.37449 .69457 L
.38345 .68917 L
.39208 .68326 L
.40033 .67687 L
.40817 .67 L
.41557 .66267 L
.42249 .65491 L
.42891 .64675 L
.43479 .6382 L
.4401 .62931 L
.44481 .6201 L
.4489 .6106 L
Mistroke
.45234 .60087 L
.4551 .59093 L
.45716 .58084 L
.45851 .57063 L
.45913 .56037 L
.459 .5501 L
.45812 .53988 L
.45649 .52976 L
.4541 .51981 L
.45095 .51007 L
.44706 .50062 L
.44243 .49152 L
.4371 .48282 L
.43108 .47459 L
.42441 .46689 L
.41713 .45979 L
.40927 .45333 L
.40089 .44759 L
.39204 .4426 L
.38279 .43843 L
.37321 .43511 L
.36338 .43268 L
.35337 .43118 L
.34326 .43064 L
.33316 .43106 L
.32316 .43247 L
.31334 .43485 L
.30383 .43821 L
.29471 .44251 L
.28608 .44774 L
.27806 .45383 L
.27074 .46074 L
.26421 .4684 L
.25857 .47672 L
.25389 .48562 L
.25025 .49499 L
.24771 .5047 L
.24632 .51464 L
.24612 .52467 L
.24712 .53465 L
.24933 .54443 L
.25274 .55385 L
.2573 .56277 L
.26296 .57103 L
.26964 .57848 L
.27724 .58498 L
.28564 .59041 L
.29469 .59465 L
.30424 .5976 L
.3141 .59919 L
Mistroke
.32408 .59937 L
.33398 .5981 L
.34359 .5954 L
.35268 .59131 L
.36106 .58589 L
.3685 .57926 L
.37482 .57156 L
.37985 .56295 L
.38343 .55366 L
.38546 .54391 L
.38584 .53396 L
.38456 .5241 L
.38162 .51459 L
.37709 .50574 L
.37107 .49782 L
.36375 .4911 L
.35533 .48581 L
.34609 .48216 L
.33633 .48029 L
.3264 .4803 L
.31666 .48221 L
.30748 .48598 L
.29922 .49149 L
.29224 .49854 L
.28684 .50686 L
.28328 .51612 L
.28174 .52592 L
.28233 .53581 L
.28504 .54535 L
.28977 .55405 L
.29633 .56149 L
.30439 .56724 L
.31356 .57099 L
.32334 .5725 L
.33321 .57165 L
.34258 .56846 L
.35089 .56309 L
.35761 .55582 L
.36229 .54711 L
.36459 .53749 L
.36433 .5276 L
.36148 .51813 L
.35621 .50977 L
.34888 .50314 L
.34001 .49878 L
.33028 .49706 L
.32047 .49816 L
.31138 .50204 L
.30382 .50839 L
.29847 .51669 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .73669 L
0 .73669 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 212.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000e1000`40O003h00Oogoo8Goo003oOolQ
Ool005Moo`03001oogoo0<Ioo`00Agoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol0aWoo0016Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`36Ool0045oo`<0
009oo`03001oo`0000Moo`03001oo`0000Aoo`<00<Ioo`00AWoo00<007oo000027oo00<007ooOol0
0goo00<007ooOol06goo3P00WGoo0016Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0@
Ool;000>Ool:002COol004Moo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00]oo`D002=o
o`L008aoo`00Egoo00<007ooOol01Woo1@00;goo1@00Qgoo001GOol00`00Oomoo`03Ool3000iOol4
0023Ool005Moo`03001oogoo00<0041oo`@007moo`00EGoo1@00Agoo0P00OGoo001BOol30002Ool2
001:Ool4001iOol0051oo`8000Eoo`03001oogoo04eoo`8007Moo`00CGoo0`001goo00<007ooOol0
Cgoo0P00MGoo001;Ool2000:Ool00`00Oomoo`1AOol2001cOol004Uoo`8000aoo`03001oogoo05=o
o`@006moo`00Agoo0P003Woo00<007ooOol0Egoo0P00KGoo0016Ool00`00Oomoo`0>Ool00`00Oomo
o`1IOol2001[Ool004=oo`<0015oo`03001oogoo05]oo`8006Uoo`00@Goo0P0057oo00<007ooOol0
GGoo0P00Igoo0010Ool00`00Oomoo`0DOol2001POol00`00Oomoo`1TOol003ioo`8001Moo`03001o
ogoo061oo`8006Aoo`00?7oo0P006Goo00<007ooOol0HWoo0P00HWoo000kOol00`00Oomoo`0IOol0
0`00Oomoo`1TOol00`00Oomoo`1OOol003Uoo`8001aoo`03001oogoo06Eoo`8005moo`00=goo0P00
7Woo00<007ooOol0Igoo0P00GGoo000fOol00`00Oomoo`0NOol00`00Oomoo`1YOol00`00Oomoo`1J
Ool003Eoo`03001oogoo01moo`03001oogoo06Yoo`8005Yoo`00=7oo00<007ooOol087oo0P00KGoo
00<007ooOol0Egoo000cOol00`00Oomoo`0QOol00`00Oomoo`1]Ool2001GOol0035oo`8002Aoo`03
001oogoo06moo`03001oogoo05Aoo`00<7oo00<007ooOol097oo00<007ooOol0L7oo00<007ooOol0
Dgoo000^Ool2000WOol00`00Oomoo`1aOol2001COol002eoo`03001oogoo02Moo`03001oogoo07=o
o`03001oogoo051oo`00;7oo00<007ooOol067oo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03
001oogoo07Aoo`03001oogoo04moo`00:goo00<007ooOol067oo00<007oo00001goo00<007oo0000
17oo00<007ooOol0MGoo0P00Cgoo000ZOol00`00Oomoo`0DOol30002Ool00`00Ool00007Ool00`00
Ool00004Ool3001gOol00`00Oomoo`1<Ool002Uoo`03001oogoo01Yoo`03001oo`0000Moo`8000Eo
o`03001oogoo07Qoo`03001oogoo04]oo`00:7oo00<007ooOol06goo00<007oo00001goo00<007oo
Ool017oo00<007ooOol0NGoo00<007ooOol0BWoo000WOol00`00Oomoo`0MOol00`00Oomoo`07Ool2
0004Ool00`00Oomoo`1jOol2001:Ool002Ioo`03001oogoo02ioo`03001oogoo07aoo`03001oogoo
04Moo`009Goo00<007ooOol0;goo00<007ooOol0OGoo00<007ooOol0AWoo000UOol00`00Oomoo`0_
Ool00`00Oomoo`1nOol00`00Oomoo`15Ool002Aoo`03001oogoo031oo`03001oogoo07ioo`03001o
ogoo04Eoo`008goo00<007ooOol0<Goo00<007ooOol0Ogoo00<007ooOol0A7oo000ROol00`00Oomo
o`0bOol20021Ool00`00Oomoo`13Ool0025oo`03001oogoo03=oo`03001oogoo085oo`03001oogoo
049oo`0087oo00<007ooOol0=7oo00<007ooOol0PWoo00<007ooOol0@Goo000OOol00`00Oomoo`0e
Ool00`00Oomoo`23Ool00`00Oomoo`10Ool001ioo`03001oogoo03Ioo`03001oogoo08Aoo`03001o
ogoo03moo`007Goo00<007ooOol0=goo00<007ooOol0QGoo00<007ooOol0?Woo000MOol00`00Oomo
o`0gOol00`00Oomoo`26Ool00`00Oomoo`0mOol001aoo`03001oogoo03Qoo`03001oogoo08Moo`03
001oogoo03aoo`006goo00<007ooOol0>Goo0P00R7oo00<007ooOol0?7oo000JOol00`00Oomoo`0j
Ool00`00Oomoo`28Ool00`00Oomoo`0kOol001Uoo`03001oogoo03]oo`03001oogoo08Uoo`03001o
ogoo03Yoo`006Goo00<007ooOol0>goo00<007ooOol0RWoo00<007ooOol0>Goo000HOol00`00Oomo
o`0lOol00`00Oomoo`2;Ool00`00Oomoo`0hOol001Qoo`03001oogoo03aoo`03001oogoo08]oo`03
001oogoo03Qoo`005goo00<007ooOol0?Goo00<007ooOol0S7oo00<007ooOol0=goo000GOol00`00
Oomoo`0mOol00`00Oomoo`2=Ool00`00Oomoo`0fOol001Ioo`03001oogoo03ioo`03001oogoo08eo
o`03001oogoo03Ioo`005Woo00<007ooOol0?Woo0P00Sgoo00<007ooOol0=Goo000EOol00`00Oomo
o`0oOol00`00Oomoo`2?Ool00`00Oomoo`0dOol001Aoo`03001oogoo041oo`03001oogoo08moo`03
001oogoo03Aoo`0057oo00<007ooOol0@7oo00<007ooOol0T7oo00<007ooOol0<goo000COol00`00
Oomoo`11Ool00`00Oomoo`2AOol00`00Oomoo`0bOol001=oo`03001oogoo045oo`03001oogoo095o
o`03001oogoo039oo`004Woo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol00Woo0`000goo
00<007ooOol0TWoo00<007ooOol0<Goo000BOol00`00Oomoo`0aOol00`00Ool00009Ool00`00Oomo
o`02Ool00`00Oomoo`2BOol00`00Oomoo`0aOol0015oo`03001oogoo02eoo`<0009oo`03001oo`00
00Moo`@000=oo`<009=oo`03001oogoo031oo`004Goo00<007ooOol0<Woo00<007oo00001goo00<0
07oo000017oo00<007ooOol0Tgoo0P00<Goo000@Ool00`00Oomoo`0cOol00`00Ool00008Ool20004
Ool00`00Oomoo`2DOol00`00Oomoo`0_Ool0011oo`03001oogoo03Aoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo09Eoo`03001oogoo02ioo`003goo00<007ooOol0AGoo00<007ooOol0UGoo
00<007ooOol0;Woo000?Ool00`00Oomoo`15Ool00`00Oomoo`2FOol00`00Oomoo`0]Ool000moo`03
001oogoo04Eoo`03001oogoo09Ioo`03001oogoo02eoo`003Woo00<007ooOol0AWoo00<007ooOol0
Ugoo00<007ooOol0;7oo000>Ool00`00Oomoo`16Ool2002HOol00`00Oomoo`0/Ool000eoo`03001o
ogoo04Moo`03001oogoo09Qoo`03001oogoo02]oo`003Goo00<007ooOol0Agoo00<007ooOol0V7oo
00<007ooOol0:goo000=Ool00`00Oomoo`17Ool00`00Oomoo`2IOol00`00Oomoo`0ZOol000aoo`03
001oogoo04Qoo`03001oogoo09Uoo`03001oogoo02Yoo`0037oo00<007ooOol0B7oo00<007ooOol0
VWoo00<007ooOol0:Goo000<Ool00`00Oomoo`18Ool00`00Oomoo`2JOol00`00Oomoo`0YOol000ao
o`03001oogoo04Qoo`03001oogoo09Yoo`8002Yoo`0037oo00<007ooOol0B7oo00<007ooOol0Vgoo
00<007ooOol0:7oo000<Ool00`00Oomoo`18Ool2002LOol00`00Oomoo`0XOol000]oo`03001oogoo
04Uoo`03001oogoo09aoo`03001oogoo02Moo`002goo00<007ooOol0BGoo00<007ooOol0W7oo00<0
07ooOol09goo000;Ool00`00Oomoo`19Ool00`00Oomoo`2LOol2000XOol000Yoo`03001oogoo04Yo
o`03001oogoo09eoo`03001oogoo02Ioo`002Woo00<007ooOol0BWoo00<007ooOol0WGoo00<007oo
Ool09Woo000:Ool00`00Oomoo`1:Ool00`00Oomoo`2NOol00`00Oomoo`0UOol000Yoo`03001oogoo
04Yoo`03001oogoo09ioo`03001oogoo02Eoo`002Woo00<007ooOol0BWoo0P00Wgoo00<007ooOol0
9Goo000:Ool00`00Oomoo`1:Ool00`00Oomoo`2OOol00`00Oomoo`0TOol000Uoo`03001oogoo04]o
o`03001oogoo09moo`03001oogoo02Aoo`002Goo00<007ooOol0Bgoo00<007ooOol0Wgoo00<007oo
Ool097oo0009Ool00`00Oomoo`1;Ool00`00Oomoo`2POol00`00Oomoo`0SOol000Uoo`03001oogoo
04]oo`03001oogoo0:1oo`03001oogoo02=oo`002Goo00<007ooOol0Bgoo00<007ooOol0X7oo00<0
07ooOol08goo0009Ool00`00Oomoo`0kOol00`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007oo
Ool0X7oo00<007ooOol08goo0009Ool00`00Oomoo`0jOol00`00Ool00007Ool00`00Oomoo`04Ool0
0`00Oomoo`2QOol00`00Oomoo`0ROol000Uoo`03001oogoo03Eoo`<0009oo`03001oo`0000Qoo`03
001oogoo00=oo`<00:5oo`03001oogoo029oo`002Goo00<007ooOol0>Woo00<007oo000027oo00<0
07ooOol00goo00<007ooOol0XGoo00<007ooOol08Woo0009Ool00`00Oomoo`0jOol00`00Ool00007
Ool00`00Ool00004Ool00`00Oomoo`2QOol00`00Oomoo`0ROol000Uoo`03001oogoo03]oo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo0:9oo`03001oogoo025oo`0027oo00<007ooOol0C7oo
00<007ooOol0XWoo00<007ooOol08Goo0008Ool00`00Oomoo`1<Ool00`00Oomoo`2ROol00`00Oomo
o`0QOol000Qoo`03001oogoo04aoo`03001oogoo0:9oo`03001oogoo025oo`0027oo00<007ooOol0
C7oo2000WGoo0P008Woo0008Ool00`00Oomoo`18Ool60006Ool5002IOol00`00Oomoo`0POol000Qo
o`03001oogoo04Ioo`8000Aoo`03001oogoo00Yoo`<009Ioo`03001oogoo021oo`002Goo00<007oo
Ool0@goo0P001Woo00<007ooOol03Goo0P00U7oo00<007ooOol087oo0009Ool00`00Oomoo`11Ool2
0008Ool00`00Oomoo`0?Ool00`00Oomoo`2AOol00`00Oomoo`0POol000Uoo`03001oogoo041oo`03
001oogoo00Qoo`03001oogoo011oo`03001oogoo091oo`03001oogoo021oo`002Goo00<007ooOol0
?Woo0P002goo00<007ooOol04Goo0P00T7oo0P008Goo0009Ool00`00Oomoo`0mOol00`00Oomoo`0;
Ool00`00Oomoo`0COol00`00Oomoo`2>Ool00`00Oomoo`0OOol000Uoo`03001oogoo03aoo`03001o
ogoo00aoo`03001oogoo01Aoo`03001oogoo08eoo`03001oogoo01moo`002Goo00<007ooOol0>goo
00<007ooOol03Goo0P005Woo00<007ooOol0S7oo00<007ooOol07goo0009Ool00`00Oomoo`0kOol0
0`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`2;Ool00`00Oomoo`0OOol000Uoo`03001oogoo
03Yoo`03001oogoo00ioo`03001oogoo01Moo`03001oogoo08Yoo`03001oogoo01moo`002Woo00<0
07ooOol0>7oo00<007ooOol03goo00<007ooOol067oo00<007ooOol0RGoo00<007ooOol07goo000:
Ool00`00Oomoo`0gOol00`00Oomoo`0?Ool5000HOol00`00Oomoo`28Ool00`00Oomoo`0OOol000Yo
o`03001oogoo03Moo`03001oogoo00eoo`800003Ool007oo009oo`8001Ioo`03001oogoo08Uoo`03
001oogoo01ioo`002Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo0`0057oo00<0
07ooOol00Woo00@007ooOomoo`<000Ioo`03001oogoo00]oo`8000=oo`03001oogoo00=oo`8001Ao
o`8000=oo`04001oogooOol3000FOol00`00Oomoo`02Ool00`00Oomoo`02Ool3000DOol00`00Oomo
o`02Ool01000Oomoogoo0P005goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol067oo1@00
7Woo000:Ool00`00Oomoo`03Ool00`00Ool00009Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool20005Ool00`00Oomoo`05Ool2000AOol01000Ool000001Woo00<0
07ooOol05Goo00<007oo00002Goo00<007ooOol04Woo00<007oo00001goo00<007oo00005Goo00<0
07oo00001goo00<007oo00006goo00<007ooOol07Woo000:Ool40002Ool00`00Ool00007Ool4000>
Ool30002Ool00`00Ool00008Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`05Ool20008
Ool00`00Oomoo`0>Ool01@00Ool007oo00001Woo00<007ooOol057oo00<007oo00001goo10004goo
00<007oo00001goo00<007oo00005Goo00<007oo00001goo00<007oo00006goo00<007ooOol07Woo
000;Ool00`00Oomoo`02Ool00`00Ool00007Ool00`00Ool0000DOol00`00Ool00008Ool00`00Oomo
o`03Ool00`00Oomoo`09Ool00`00Oomoo`04Ool70006Ool00`00Oomoo`0=Ool01@00Ool007oo0000
1Woo00<007ooOol057oo00<007oo00001goo00<007oo000057oo00<007oo00001goo0P005Woo00<0
07oo000027oo00<007ooOol06Woo00<007ooOol07Woo000;Ool00`00Oomoo`02Ool00`00Ool00008
Ool2000DOol00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`08Ool00`00Oomoo`03Ool20002
Ool00`00Oomoo`02Ool20005Ool00`00Oomoo`0<Ool01@00Ool007oo00001Goo00<007oo00005Goo
00<007oo000027oo0P0057oo00<007oo00001goo00<007ooOol05Goo00<007oo00001goo00<007oo
00006goo00<007ooOol07Woo000;Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0COol0
0`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`08Ool01000Oomoogoo0P0017oo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol037oo00D007ooOomoo`0000Eoo`03001oogoo01Eoo`03001o
ogoo00Qoo`03001oogoo01=oo`03001oogoo00Moo`8001Ioo`03001oogoo00Moo`03001oogoo01Uo
o`80021oo`002goo00<007ooOol0=7oo00<007ooOol01goo00D007ooOomoo`0000Ioo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo00moo`03001oogoo08Eoo`03001oogoo01ioo`002goo00<0
07ooOol0=7oo00<007ooOol01goo00D007ooOomoo`0000Ioo`03001oogoo00Ioo`03001oogoo009o
o`03001oogoo011oo`03001oogoo08Aoo`03001oogoo01ioo`0037oo00<007ooOol0<goo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol03goo00<007oo
Ool0Q7oo00<007ooOol07Woo000<Ool00`00Oomoo`0cOol00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`2UOol000aoo`03001oogoo
03=oo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo
00moo`03001oogoo09=oo`<00004Ool007ooOol20009Ool0009oool000D000Uoo`06001oogoo001o
o`002goo0003Ool00`00Oomoo`05Ool00`00Ool00006Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00D007ooOomoo`0000Moo`03001oogoo00Eoo`03001oo`0000Aoo`03001oo`0000Moo`03001o
ogoo00Eoo`8000Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo00eoo`<0009oo`<000Uoo`003Goo00<007ooOol017oo00<007oo
Ool07Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01goo00<007oo
Ool00Woo00<007ooOol047oo00<007ooOol07Woo00<007ooOol07goo00<007ooOol07Woo00<007oo
Ool07goo00<007ooOol03Goo00D007ooOol007oo00<000Uoo`003Woo00<007ooOol0<Woo00<007oo
Ool01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol047oo00<007oo
Ool0Tgoo00@007ooOol000eoo`003Woo00<007ooOol0<Woo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol047oo00<007ooOol0TWoo10003Woo000?Ool0
0`00Oomoo`0bOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`0@Ool00`00Oomoo`2TOol000moo`03001oogoo039oo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo0:Aoo`003goo00<0
07ooOol0<goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol04Goo00<007ooOol0Y7oo000@Ool00`00Oomoo`0bOol00`00Oomoo`07Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`2TOol0011oo`03001o
ogoo039oo`03001oogoo00Qoo`03001oogoo00Aoo`8000Aoo`03001oogoo00Aoo`03001oogoo019o
o`03001oogoo0:Aoo`0047oo00<007ooOol0<goo00<007ooOol027oo00<007ooOol00goo00@007oo
Oomoo`8000Moo`03001oogoo019oo`03001oogoo0:Aoo`004Goo00<007ooOol0<Woo00<007ooOol0
2Goo2@0027oo00<007ooOol04goo00<007ooOol0Y7oo000AOol00`00Oomoo`0cOol2000>Ool00`00
Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`2TOol0019oo`03001oogoo03Aoo`03001oogoo00]o
o`03001oogoo00Qoo`03001oogoo01Aoo`03001oogoo0:Aoo`004goo00<007ooOol0=7oo00<007oo
Ool02Woo00<007ooOol01Woo0P005goo00<007ooOol0Y7oo000COol00`00Oomoo`0eOol00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`2UOol001Aoo`03001oogoo03Eoo`80
00Uoo`03001oogoo00=oo`8001Uoo`03001oogoo0:Eoo`0057oo00<007ooOol0=goo1@0017oo0P00
0Woo0P006Woo00<007ooOol0YWoo000EOol00`00Oomoo`0kOol8000LOol00`00Oomoo`2VOol001Io
o`03001oogoo03ioo`03001oogoo01eoo`03001oogoo0:Ioo`005goo00<007ooOol0?Goo00<007oo
Ool07Goo00<007ooOol0YWoo000GOol00`00Oomoo`0mOol00`00Oomoo`0MOol00`00Oomoo`2VOol0
01Qoo`03001oogoo03aoo`03001oogoo01aoo`03001oogoo0:Moo`0067oo00<007ooOol0?7oo00<0
07ooOol06goo00<007ooOol0Z7oo000IOol00`00Oomoo`0kOol00`00Oomoo`0KOol00`00Oomoo`2X
Ool001Yoo`03001oogoo03Yoo`03001oogoo01Yoo`03001oogoo0:Uoo`006goo00<007ooOol0>Goo
0P006goo00<007ooOol0ZGoo000LOol00`00Oomoo`0hOol00`00Oomoo`0IOol00`00Oomoo`2ZOol0
01eoo`03001oogoo03Moo`03001oogoo01Uoo`03001oogoo0:Yoo`007Woo00<007ooOol0=Woo00<0
07ooOol067oo00<007ooOol0Zgoo000OOol00`00Oomoo`0eOol00`00Oomoo`0GOol00`00Oomoo`2/
Ool0021oo`03001oogoo03Aoo`03001oogoo01Ioo`03001oogoo0:eoo`008Goo00<007ooOol08goo
00<007ooOol00Woo00@007ooOomoo`<000Aoo`03001oogoo01Ioo`03001oogoo0:eoo`008Woo00<0
07ooOol08Goo00<007oo00001goo00<007ooOol017oo00<007ooOol05Goo00<007ooOol0[Woo000S
Ool00`00Oomoo`0POol00`00Ool00008Ool00`00Oomoo`03Ool3000DOol00`00Oomoo`2_Ool002Ao
o`03001oogoo01moo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo01=oo`03001oogoo0;1o
o`009Goo00<007ooOol07Woo00<007oo00001goo00<007oo000017oo00<007ooOol04Woo00<007oo
Ool0/Goo000VOol2000OOol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomo
o`2bOol002Qoo`8002eoo`03001oogoo011oo`03001oogoo0;=oo`00:Woo00<007ooOol0:Woo00<0
07ooOol03goo00<007ooOol0]7oo000[Ool2000ZOol00`00Oomoo`0>Ool00`00Oomoo`2eOol002eo
o`03001oogoo02Moo`03001oogoo00aoo`800;Qoo`00;Woo0P009goo0P002goo0P00^Woo000`Ool3
000TOol00`00Oomoo`09Ool00`00Oomoo`2jOol003=oo`80029oo`03001oogoo00Ioo`<00;eoo`00
=Goo0`007goo00<007ooOol017oo0P00`7oo000hOol2000MOol01000Oomoogoo0`00`Woo000jOol3
000IOol50035Ool003eoo`H000ioo`D00003Ool007oo0<Moo`00@goo3P001Woo00<007ooOol0aWoo
001GOol00`00Oomoo`36Ool005Moo`800<Moo`00Egoo00<007ooOol0aWoo001GOol00`00Oomoo`36
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001BOol300001Woo001oo`00Ool00<Eoo`00Dgoo
00P007ooOol007oo001oo`00aGoo001COol02000Oomoo`00Ool007oo0035Ool005=oo`03001oogoo
00800003Ool007oo0<Eoo`00Dgoo00<007ooOol0bWoo001BOol3003;Ool00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {211.125, 0}} -> {-0.521108, -0.826777, 
  0.00595111, 0.00595111}},
  CellTags->"5.3"]
}, Open  ]],

Cell[TextData[{
  "Like ",
  StyleBox["BodePlot", "MR"],
  ", ",
  StyleBox["NyquistPlot", "MR"],
  " accepts the ",
  StyleBox["PlotPoints", "MR"],
  " and ",
  StyleBox["PlotSampling", "MR"],
  " options, as well as options pertinent to ",
  StyleBox["ListPlot", "MR"],
  ". "
}], "Text",
  CellTags->"5.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4 The Nichols Plot", "Subsection",
  CellTags->"5.4"],

Cell[TextData[{
  StyleBox["NicholsPlot", "MR"],
  " gives yet another way to depict frequency response \
information\[LongDash]by plotting the magnitude versus phase curve in the \
semilogarithmic scale. "
}], "Text",
  CellTags->"5.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NicholsPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Nichols",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  CellTags->"5.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["NicholsPlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"w", 
                        StyleBox[",",
                          "MR"], " ", "wmin", 
                        StyleBox[",",
                          "MR"], " ", "wmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["generate",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Nichols",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plot",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["frequency",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["w",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["running",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["from",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmin",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["wmax",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"5.4"],

Cell["Creating the Nichols plots. ", "Caption",
  CellTags->"5.4"],

Cell[TextData[{
  "Here is an open\[Hyphen]loop transfer function for the spacecraft attitude \
control system, compensated with a PID controller from Franklin ",
  StyleBox["et al.", "TI"],
  " (1991). "
}], "MathCaption",
  CellTags->"5.4"],

Cell[CellGroupData[{

Cell["\<\
TransferFunction[s,
 .05/s(10s+1)(s+.005) .9/s^2 2/(s+2)]\
\>", "Input",
  CellLabel->"In[26]:=",
  CellTags->"5.4"],

Cell[BoxData[
    RowBox[{"TransferFunction", "[", 
      RowBox[{"s", ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            FractionBox[
              RowBox[{"0.0900000000000000177`", " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["0.005`",
                        StyleBoxAutoDelete->True,
                        PrintPrecision->1], "\[InvisibleSpace]"}], "+", 
                    "s"}], ")"}], " ", \((1 + 10\ s)\)}], 
              \(s\^3\ \((2 + s)\)\)], "}"}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[26]=",
  CellTags->"5.4"]
}, Open  ]],

Cell["This is the Nichols plot for the system. ", "MathCaption",
  CellTags->"5.4"],

Cell[CellGroupData[{

Cell["NicholsPlot[%]", "Input",
  CellLabel->"In[27]:=",
  CellTags->"5.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.72899 0.01512 0.505769 0.00606862 [
[.0074 -0.0125 -12 -9 ]
[.0074 -0.0125 12 0 ]
[.1586 -0.0125 -12 -9 ]
[.1586 -0.0125 12 0 ]
[.30979 -0.0125 -12 -9 ]
[.30979 -0.0125 12 0 ]
[.46099 -0.0125 -12 -9 ]
[.46099 -0.0125 12 0 ]
[.61219 -0.0125 -12 -9 ]
[.61219 -0.0125 12 0 ]
[.76339 -0.0125 -12 -9 ]
[.76339 -0.0125 12 0 ]
[.91459 -0.0125 -12 -9 ]
[.91459 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -47 -21.5625 ]
[.5 -0.0125 47 -9 ]
[-0.0125 .02028 -18 -4.5 ]
[-0.0125 .02028 0 4.5 ]
[-0.0125 .14165 -18 -4.5 ]
[-0.0125 .14165 0 4.5 ]
[-0.0125 .26302 -18 -4.5 ]
[-0.0125 .26302 0 4.5 ]
[-0.0125 .3844 -18 -4.5 ]
[-0.0125 .3844 0 4.5 ]
[-0.0125 .50577 -6 -4.5 ]
[-0.0125 .50577 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -29 ]
[-0.01875 .30902 -18 29 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.0074 0 m
.0074 .00625 L
s
[(-180)] .0074 -0.0125 0 1 Mshowa
.1586 0 m
.1586 .00625 L
s
[(-170)] .1586 -0.0125 0 1 Mshowa
.30979 0 m
.30979 .00625 L
s
[(-160)] .30979 -0.0125 0 1 Mshowa
.46099 0 m
.46099 .00625 L
s
[(-150)] .46099 -0.0125 0 1 Mshowa
.61219 0 m
.61219 .00625 L
s
[(-140)] .61219 -0.0125 0 1 Mshowa
.76339 0 m
.76339 .00625 L
s
[(-130)] .76339 -0.0125 0 1 Mshowa
.91459 0 m
.91459 .00625 L
s
[(-120)] .91459 -0.0125 0 1 Mshowa
.125 Mabswid
.03764 0 m
.03764 .00375 L
s
.06788 0 m
.06788 .00375 L
s
.09812 0 m
.09812 .00375 L
s
.12836 0 m
.12836 .00375 L
s
.18884 0 m
.18884 .00375 L
s
.21908 0 m
.21908 .00375 L
s
.24932 0 m
.24932 .00375 L
s
.27955 0 m
.27955 .00375 L
s
.34003 0 m
.34003 .00375 L
s
.37027 0 m
.37027 .00375 L
s
.40051 0 m
.40051 .00375 L
s
.43075 0 m
.43075 .00375 L
s
.49123 0 m
.49123 .00375 L
s
.52147 0 m
.52147 .00375 L
s
.55171 0 m
.55171 .00375 L
s
.58195 0 m
.58195 .00375 L
s
.64243 0 m
.64243 .00375 L
s
.67267 0 m
.67267 .00375 L
s
.70291 0 m
.70291 .00375 L
s
.73315 0 m
.73315 .00375 L
s
.79363 0 m
.79363 .00375 L
s
.82387 0 m
.82387 .00375 L
s
.85411 0 m
.85411 .00375 L
s
.88435 0 m
.88435 .00375 L
s
.94483 0 m
.94483 .00375 L
s
.97507 0 m
.97507 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -108 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(degrees) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(L) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .02028 m
.00625 .02028 L
s
[(-80)] -0.0125 .02028 1 0 Mshowa
0 .14165 m
.00625 .14165 L
s
[(-60)] -0.0125 .14165 1 0 Mshowa
0 .26302 m
.00625 .26302 L
s
[(-40)] -0.0125 .26302 1 0 Mshowa
0 .3844 m
.00625 .3844 L
s
[(-20)] -0.0125 .3844 1 0 Mshowa
0 .50577 m
.00625 .50577 L
s
[(0)] -0.0125 .50577 1 0 Mshowa
.125 Mabswid
0 .05062 m
.00375 .05062 L
s
0 .08097 m
.00375 .08097 L
s
0 .11131 m
.00375 .11131 L
s
0 .17199 m
.00375 .17199 L
s
0 .20234 m
.00375 .20234 L
s
0 .23268 m
.00375 .23268 L
s
0 .29337 m
.00375 .29337 L
s
0 .32371 m
.00375 .32371 L
s
0 .35405 m
.00375 .35405 L
s
0 .41474 m
.00375 .41474 L
s
0 .44508 m
.00375 .44508 L
s
0 .47543 m
.00375 .47543 L
s
0 .53611 m
.00375 .53611 L
s
0 .56645 m
.00375 .56645 L
s
0 .5968 m
.00375 .5968 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -114.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
90 10.2813 translate
90 rotate
-90 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Gain) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
111.000000 12.812500 moveto
(L) show
117.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.0074 .61178 m
.0074 .61803 L
s
.1586 .61178 m
.1586 .61803 L
s
.30979 .61178 m
.30979 .61803 L
s
.46099 .61178 m
.46099 .61803 L
s
.61219 .61178 m
.61219 .61803 L
s
.76339 .61178 m
.76339 .61803 L
s
.91459 .61178 m
.91459 .61803 L
s
.125 Mabswid
.03764 .61428 m
.03764 .61803 L
s
.06788 .61428 m
.06788 .61803 L
s
.09812 .61428 m
.09812 .61803 L
s
.12836 .61428 m
.12836 .61803 L
s
.18884 .61428 m
.18884 .61803 L
s
.21908 .61428 m
.21908 .61803 L
s
.24932 .61428 m
.24932 .61803 L
s
.27955 .61428 m
.27955 .61803 L
s
.34003 .61428 m
.34003 .61803 L
s
.37027 .61428 m
.37027 .61803 L
s
.40051 .61428 m
.40051 .61803 L
s
.43075 .61428 m
.43075 .61803 L
s
.49123 .61428 m
.49123 .61803 L
s
.52147 .61428 m
.52147 .61803 L
s
.55171 .61428 m
.55171 .61803 L
s
.58195 .61428 m
.58195 .61803 L
s
.64243 .61428 m
.64243 .61803 L
s
.67267 .61428 m
.67267 .61803 L
s
.70291 .61428 m
.70291 .61803 L
s
.73315 .61428 m
.73315 .61803 L
s
.79363 .61428 m
.79363 .61803 L
s
.82387 .61428 m
.82387 .61803 L
s
.85411 .61428 m
.85411 .61803 L
s
.88435 .61428 m
.88435 .61803 L
s
.94483 .61428 m
.94483 .61803 L
s
.97507 .61428 m
.97507 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02028 m
1 .02028 L
s
.99375 .14165 m
1 .14165 L
s
.99375 .26302 m
1 .26302 L
s
.99375 .3844 m
1 .3844 L
s
.99375 .50577 m
1 .50577 L
s
.125 Mabswid
.99625 .05062 m
1 .05062 L
s
.99625 .08097 m
1 .08097 L
s
.99625 .11131 m
1 .11131 L
s
.99625 .17199 m
1 .17199 L
s
.99625 .20234 m
1 .20234 L
s
.99625 .23268 m
1 .23268 L
s
.99625 .29337 m
1 .29337 L
s
.99625 .32371 m
1 .32371 L
s
.99625 .35405 m
1 .35405 L
s
.99625 .41474 m
1 .41474 L
s
.99625 .44508 m
1 .44508 L
s
.99625 .47543 m
1 .47543 L
s
.99625 .53611 m
1 .53611 L
s
.99625 .56645 m
1 .56645 L
s
.99625 .5968 m
1 .5968 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.60124 .60332 m
.72064 .58156 L
.82323 .56176 L
.90197 .54349 L
.95331 .52623 L
.97619 .50949 L
.97058 .49284 L
.9368 .47585 L
.87586 .45806 L
.79065 .43896 L
.68747 .41807 L
.57604 .39507 L
.46719 .37 L
.36948 .34317 L
.28724 .31503 L
.22106 .28601 L
.16931 .25644 L
.12954 .22654 L
.0993 .19645 L
.07645 .16625 L
.05924 .13599 L
.04629 .1057 L
.03658 .07538 L
.02928 .04505 L
.02381 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool009aoo`03001oogoo00]oo`8001eoo`03001oogoo05Aoo`00Vgoo00<007ooOol03Woo00<007oo
Ool06goo00<007ooOol0Dgoo001dOol30002Ool300000goo001oo`0400000goo00000004Ool2000>
Ool00`00Oomoo`03Ool30002Ool20003Ool3000017oo000000000goo0P000goo0P000Woo0P0037oo
00<007ooOol0DWoo001eOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`0017oo00@007ooOol0011o
o`03001oogoo009oo`06001oogoo001oo`0017oo00@007ooOol0009oo`05001oogooOol00004Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`1BOol007Eoo`<0009oo`04001oogoo0003Ool0
1@00Oomoogoo00000goo0`003Woo00<007ooOol00Woo00D007ooOol007oo00<0009oo`04001oogoo
0002Ool01000Oomoogoo0`000Woo0`000goo00<007ooOol02Woo00<007ooOol0DWoo001eOol01@00
Oomoo`00Ool00`000goo0P000goo0P000Woo0`003Woo00<007ooOol00goo0`0000Aoo`00000000=o
o`<00003Ool0000000800004Ool000000002Ool30003Ool2000;Ool00`00Oomoo`1BOol007Eoo`06
001oogoo001oo`0087oo00<007ooOol017oo00<007ooOol09Goo00<007ooOol0Dgoo001dOol40000
0goo0000000QOol00`00Oomoo`02Ool2000VOol00`00Oomoo`1DOol00?moob5oo`00ogoo8Goo003o
OolQOol0029oo`D0009oo`03001oogoo009oo`03001oogoo01Ioo`D0009oo`03001oogoo009oo`03
001oogoo01Moo`D00003Ool0000000Aoo`03001oogoo01Ioo`D0009oo`03001oogoo009oo`03001o
ogoo01Ioo`D0009oo`<0009oo`03001oogoo01Ioo`D00003Ool0000000Aoo`03001oogoo01Moo`D0
0004Ool000000003Ool00`00Oomoo`0?Ool002Aoo`07001oogooOol007oo00000Woo00<007oo0000
6Goo00<007ooOol00Woo00L007ooOomoo`00Ool0000JOol01`00Oomoogoo001oo`00009oo`03001o
o`0001Uoo`07001oogooOol007oo00000Woo00<007oo00006Goo00<007ooOol00goo00H007ooOol0
07oo000IOol00`00Oomoo`03Ool01P00Oomoo`00Ool001Yoo`05001oogooOol00004Ool00`00Ool0
000@Ool001ioo`<000=oo`07001oogooOol007oo00000Woo00<007oo00004goo0`000goo00<007oo
Ool00Woo00L007ooOomoo`00Ool0000DOol30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00
01=oo`<000=oo`03001oogoo00=oo`06001oogoo001oo`004goo0`000goo00@007ooOomoo`@00004
Ool007oo000COol30003Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0001Aoo`<000=oo`03001o
ogoo009oo`07001oogooOol007oo000047oo000TOol00`00Oomoo`02Ool01`00Oomoogoo001oo`00
01Uoo`03001oogoo00=oo`06001oogoo001oo`006Woo00@007ooOomoo`8000=oo`03001oo`0001Uo
o`04001oogooOol20003Ool00`00Ool0000IOol01`00Oomoogoo001oo`00009oo`03001oo`0001Uo
o`03001oogoo00=oo`06001oogoo001oo`006Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000@
Ool002Aoo`07001oogooOol007oo00000Woo00<007oo00006Goo00L007ooOomoo`00Ool00002Ool0
0`00Ool0000JOol01@00Oomoogoo000017oo00<007oo00006Goo00D007ooOomoo`0000Aoo`03001o
o`0001Uoo`03001oogoo009oo`80009oo`03001oo`0001Uoo`07001oogooOol007oo00000Woo00<0
07oo00006Woo00L007ooOomoo`00Ool00002Ool00`00Ool0000@Ool002=oo`8000Aoo`03001oogoo
009oo`03001oogoo01Moo`8000=oo`<000=oo`03001oogoo01Qoo`8000Aoo`8000=oo`03001oogoo
01Moo`8000=oo`<000=oo`03001oogoo01Moo`8000Eoo`05001oogooOol0000IOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`0HOol20004Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000UOooh0003Ool002Eoo`03001oo`0000Moo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00=oo`03001oogoo005oo`009Goo00<007oo000097oo00<007ooOol0
8goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol08goo00<007ooOol0
4Woo00<007ooOol00Goo000JOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3dOol00`00
Oomoo`01Ool001Uoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00=oo`03001oogoo0>io
o`03001oogoo005oo`0057oo0`000Woo00<007oo00000Woo00<007oo000017oo0`000goo00<007oo
Ool0k7oo0`000goo000JOol01`00Oomoogoo001oo`0000Aoo`03001oogoo00Aoo`03001oogoo0>eo
o`03001oogoo005oo`006Goo00<007oo00000Woo00<007oo000017oo00<007ooOol017oo00<007oo
Ool0kGoo00<007ooOol00Goo000JOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`3]Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Aoo`03001oogoo0>eoo`03001oogoo
005oo`009Goo00<007ooOol01Goo00<007ooOol0k7oo00<007ooOol00Goo000UOol00`00Oomoo`05
Ool00`00Oomoo`3/Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Eoo`03001oogoo0>aoo`03001o
ogoo005oo`009Goo0P001Woo00<007ooOol0jgoo0P000goo000UOol00`00Oomoo`05Ool00`00Oomo
o`3/Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Ioo`03001oogoo0>]oo`03001oogoo005oo`00
9Goo00<007ooOol01Woo00<007ooOol0jgoo00<007ooOol00Goo000UOol00`00Oomoo`06Ool00`00
Oomoo`3[Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Ioo`03001oogoo0>]oo`03001oogoo005o
o`009Goo00<007ooOol01Woo00<007ooOol0jgoo00<007ooOol00Goo000UOol20007Ool00`00Oomo
o`3ZOol20003Ool002Eoo`03001oogoo00Moo`03001oogoo0>Yoo`03001oogoo005oo`009Goo00<0
07ooOol01goo00<007ooOol0jWoo00<007ooOol00Goo000UOol00`00Oomoo`08Ool00`00Oomoo`3Y
Ool00`00Oomoo`01Ool002Eoo`03001oogoo00Qoo`03001oogoo0>Uoo`03001oogoo005oo`009Goo
00<007ooOol02Goo00<007ooOol0j7oo00<007ooOol00Goo000UOol00`00Oomoo`09Ool00`00Oomo
o`3XOol00`00Oomoo`01Ool002Eoo`03001oogoo00Uoo`03001oogoo0>Qoo`03001oogoo005oo`00
9Goo0P002goo00<007ooOol0iWoo0P000goo000UOol00`00Oomoo`0:Ool00`00Oomoo`3WOol00`00
Oomoo`01Ool002Eoo`03001oogoo00]oo`03001oogoo0>Ioo`03001oogoo005oo`009Goo00<007oo
Ool02goo00<007ooOol0iWoo00<007ooOol00Goo000UOol00`00Oomoo`0;Ool00`00Oomoo`3VOol0
0`00Oomoo`01Ool001Uoo`8000Aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo0>Eoo`03
001oogoo005oo`006Goo00<007oo00000Woo00<007oo000017oo00<007ooOol037oo00<007ooOol0
iGoo00<007ooOol00Goo000DOol30002Ool00`00Ool00002Ool00`00Ool00004Ool3000=Ool00`00
Oomoo`3ROol30003Ool001Uoo`8000=oo`03001oo`0000Aoo`03001oogoo00eoo`03001oogoo0>Ao
o`03001oogoo005oo`006Goo00<007ooOol00Woo00<007oo000017oo00<007ooOol03Woo00<007oo
Ool0hgoo00<007ooOol00Goo000JOol20003Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomo
o`3SOol00`00Oomoo`01Ool002Eoo`03001oogoo00moo`03001oogoo0>9oo`03001oogoo005oo`00
9Goo00<007ooOol03goo00<007ooOol0hWoo00<007ooOol00Goo000UOol00`00Oomoo`0@Ool00`00
Oomoo`3QOol00`00Oomoo`01Ool002Eoo`03001oogoo015oo`03001oogoo0>1oo`03001oogoo005o
o`009Goo0P004goo00<007ooOol0gWoo0P000goo000UOol00`00Oomoo`0BOol00`00Oomoo`3OOol0
0`00Oomoo`01Ool002Eoo`03001oogoo01=oo`03001oogoo0=ioo`03001oogoo005oo`009Goo00<0
07ooOol057oo00<007ooOol0gGoo00<007ooOol00Goo000UOol00`00Oomoo`0EOol00`00Oomoo`3L
Ool00`00Oomoo`01Ool002Eoo`03001oogoo01Eoo`03001oogoo0=aoo`03001oogoo005oo`009Goo
00<007ooOol05Woo00<007ooOol0fgoo00<007ooOol00Goo000UOol2000HOol00`00Oomoo`3IOol2
0003Ool000Ioo`@001]oo`03001oogoo01Qoo`03001oogoo0=Uoo`03001oogoo005oo`001Goo00<0
07ooOol00Woo00<007ooOol067oo00<007ooOol06Goo00<007ooOol0f7oo00<007ooOol00Goo0005
Ool01P00Oomoo`00Ool001Yoo`03001oogoo01Yoo`03001oogoo0=Moo`03001oogoo005oo`001Goo
00<007ooOol00P006goo00<007ooOol06goo00<007ooOol0eWoo00<007ooOol00Goo0008Ool00`00
Oomoo`0JOol00`00Oomoo`0LOol00`00Oomoo`3EOol00`00Oomoo`01Ool002Eoo`03001oogoo01eo
o`03001oogoo0=Aoo`03001oogoo005oo`002Goo0P006Woo00<007ooOol07Woo0P00e7oo00<007oo
Ool00Goo0007Ool01000Ool000006Woo0P008Goo00<007ooOol0d7oo0P000goo0007Ool01000Ool0
00006Woo00<007ooOol08Goo00<007ooOol0d7oo00<007ooOol00Goo0007Ool4000JOol00`00Oomo
o`0ROol2003@Ool00`00Oomoo`01Ool000Yoo`03001oogoo01Qoo`03001oogoo02Aoo`03001oogoo
0<eoo`03001oogoo005oo`009Goo00<007ooOol09Goo0P00cGoo00<007ooOol00Goo000JOol30002
Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`3:Ool00`00Oomoo`01Ool000Moo`04001o
ogoo000@Ool01P00Oomoo`00Ool000Aoo`03001oogoo02Qoo`800<Yoo`03001oogoo005oo`001Goo
00<007oo00000`002Goo0`000Woo100000Aoo`00Ool000Aoo`<002Yoo`800<Ioo`<000=oo`002Woo
00<007ooOol037oo00<007oo00000Woo00<007oo000017oo00<007ooOol0;7oo00<007ooOol0aGoo
00<007ooOol00Goo000JOol20002Ool00`00Ool00004Ool00`00Oomoo`0]Ool20035Ool00`00Oomo
o`01Ool000Moo`04001oogoo000@Ool01@00Oomoogoo00001Goo00<007ooOol0;goo00<007ooOol0
`Woo00<007ooOol00Goo0007Ool4000JOol00`00Oomoo`0`Ool20032Ool00`00Oomoo`01Ool000Mo
o`03001oogoo01]oo`03001oogoo039oo`800<1oo`03001oogoo005oo`001goo00<007ooOol06goo
00<007ooOol0=7oo0P00_Woo00<007ooOol00Goo0008Ool3000JOol2000gOol2002kOol20003Ool0
00Yoo`03001oogoo01Qoo`03001oogoo03Qoo`800;Yoo`03001oogoo005oo`009Goo00<007ooOol0
>Woo0P00^7oo00<007ooOol00Goo000UOol00`00Oomoo`0lOol3002eOol00`00Oomoo`01Ool002Eo
o`03001oogoo03moo`800;=oo`03001oogoo005oo`009Goo00<007ooOol0@Goo0P00/Goo00<007oo
Ool00Goo000UOol00`00Oomoo`13Ool3002^Ool00`00Oomoo`01Ool002Eoo`03001oogoo04Ioo`<0
0:]oo`03001oogoo005oo`009Goo0P00BWoo0`00Ygoo0P000goo000UOol00`00Oomoo`1<Ool2002V
Ool00`00Oomoo`01Ool000Moo`@001Yoo`03001oogoo04ioo`<00:=oo`03001oogoo005oo`001Woo
00<007ooOol00Woo00<007ooOol05goo00<007ooOol0DGoo0`00X7oo00<007ooOol00Goo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`1DOol3002MOol00`00Oomoo`01Ool002Eoo`03
001oogoo05Moo`<009Yoo`03001oogoo005oo`009Goo00<007ooOol0FWoo1000UWoo00<007ooOol0
0Goo0008Ool2000KOol2001OOol4002AOol20003Ool000Moo`04001oogoo000JOol00`00Oomoo`1R
Ool4002>Ool00`00Oomoo`01Ool000Eoo`03001oo`00009oo`03001oogoo01Qoo`03001oogoo06Io
o`@008Yoo`03001oogoo005oo`001Goo1P006Woo00<007ooOol0JWoo1000QWoo00<007ooOol00Goo
000:Ool00`00Oomoo`0HOol00`00Oomoo`1^Ool40022Ool00`00Oomoo`01Ool000Eoo`03001oogoo
009oo`03001oogoo01Qoo`03001oogoo079oo`@007ioo`03001oogoo005oo`001Goo1P003Woo0`00
0goo00<007ooOol00goo00<007ooOol0MWoo1000NWoo00<007ooOol00Goo0005Ool00`00Ool00002
Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`1jOol4001fOol00`00
Oomoo`01Ool000Eoo`03001oo`00009oo`03001oogoo00Moo`<000=oo`07001oogooOol007oo0000
17oo0`00OWoo1000L7oo0`000goo0006Ool01000Ool0000047oo00L007ooOomoo`00Ool00004Ool0
0`00Oomoo`22Ool4001^Ool00`00Oomoo`01Ool001Uoo`03001oo`00009oo`03001oo`0000Aoo`03
001oogoo08Ioo`@006Yoo`03001oogoo005oo`006Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0RWoo1000IWoo00<007ooOol00Goo0005Ool00`00Oomoo`04Ool00`00Oomoo`0FOol00`00
Oomoo`2>Ool6001POol00`00Oomoo`01Ool000Ioo`03001oogoo009oo`03001oogoo01Moo`03001o
ogoo09Aoo`D005]oo`03001oogoo005oo`001goo10006Woo00<007ooOol0VGoo1P00EGoo00<007oo
Ool00Goo000UOol2002POol6001>Ool20003Ool002Eoo`03001oogoo0:Eoo`D004Yoo`03001oogoo
005oo`009Goo00<007ooOol0ZWoo1@00AGoo00<007ooOol00Goo000UOol00`00Oomoo`2_Ool50010
Ool00`00Oomoo`01Ool002Eoo`03001oogoo0;Aoo`D003]oo`03001oogoo005oo`009Goo00<007oo
Ool0^Goo1@00=Woo00<007ooOol00Goo000UOol00`00Oomoo`2nOol5000aOol00`00Oomoo`01Ool0
02Eoo`03001oogoo0<=oo`@002eoo`03001oogoo005oo`009Goo0P00b7oo1000:7oo0P000goo000U
Ool00`00Oomoo`3;Ool4000UOol00`00Oomoo`01Ool002Eoo`03001oogoo0<moo`@0025oo`03001o
ogoo005oo`009Goo00<007ooOol0dgoo10007Goo00<007ooOol00Goo000UOol00`00Oomoo`3GOol4
000IOol00`00Oomoo`01Ool002Eoo`03001oogoo0=]oo`@001Eoo`03001oogoo005oo`009Goo00<0
07ooOol0ggoo10004Goo00<007ooOol00Goo000UOol2003TOol2000>Ool20003Ool002Eoo`03001o
ogoo0>Eoo`8000eoo`03001oogoo005oo`009Goo00<007ooOol0igoo00<007ooOol02Woo00<007oo
Ool00Goo000UOol00`00Oomoo`3XOol2000:Ool00`00Oomoo`01Ool002Eoo`03001oogoo0>Yoo`80
00Qoo`03001oogoo005oo`009Goo00<007ooOol0k7oo00<007ooOol01Goo00<007ooOol00Goo000O
Ool00`00Oomoo`03Ool00`00Oomoo`3]Ool00`00Oomoo`04Ool00`00Oomoo`01Ool001ioo`03001o
o`0000Aoo`03001oogoo0>eoo`03001oogoo00Aoo`03001oogoo005oo`007Woo00<007oo000017oo
0`00kWoo00@007ooOomoo`<000=oo`007Woo00<007oo000017oo00<007ooOol0kWoo00<007ooOol0
0goo00<007ooOol00Goo000NOol00`00Ool00004Ool00`00Oomoo`3/Ool20006Ool00`00Oomoo`01
Ool001moo`03001oogoo00=oo`03001oogoo0>]oo`03001oogoo00Ioo`03001oogoo005oo`009Goo
00<007ooOol0jGoo0P002Goo00<007ooOol00Goo000UOol00`00Oomoo`3WOol2000;Ool00`00Oomo
o`01Ool002Eoo`03001oogoo0>Aoo`<000eoo`03001oogoo005oo`009Goo0P00hWoo0`003goo0P00
0goo000UOol00`00Oomoo`3NOol3000COol00`00Oomoo`01Ool002Eoo`03001oogoo0=]oo`<001Io
o`03001oogoo005oo`009Goo00<007ooOol0egoo10006Goo00<007ooOol00Goo000UOol00`00Oomo
o`3COol4000MOol00`00Oomoo`01Ool002Eoo`03001oogoo0<moo`@0025oo`03001oogoo005oo`00
9Goo00<007ooOol0bgoo10009Goo00<007ooOol00Goo000UOol00`00Oomoo`36Ool5000YOol00`00
Oomoo`01Ool002Eoo`800<9oo`D002eoo`8000=oo`009Goo00<007ooOol0_7oo1@00<goo00<007oo
Ool00Goo000UOol00`00Oomoo`2gOol5000hOol00`00Oomoo`01Ool002Eoo`03001oogoo0;9oo`D0
03eoo`03001oogoo005oo`009Goo00<007ooOol0[Goo1@00@Woo00<007ooOol00Goo000UOol00`00
Oomoo`2WOol60017Ool00`00Oomoo`01Ool002Eoo`03001oogoo0:5oo`H004eoo`03001oogoo005o
o`009Goo0P00W7oo1P00DWoo0P000goo000UOol00`00Oomoo`2EOol6001IOol00`00Oomoo`01Ool0
02Eoo`03001oogoo095oo`@005moo`03001oogoo005oo`009Goo00<007ooOol0m7oo00<007ooOol0
0Goo000UOol00`00Ool0000TOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0ROol00`00
Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0BOol00`00Oomoo`01Ool002EoooP000=oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-190.64, -99.8211, 0.268397, 
  0.668712}},
  CellTags->"5.4"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[27]=",
  CellTags->"5.4"]
}, Open  ]],

Cell[TextData[{
  StyleBox["NicholsPlot", "MR"],
  " accepts the options ",
  StyleBox["PlotPoints", "MR"],
  ", ",
  StyleBox["PlotSampling", "MR"],
  ",  and ",
  StyleBox["PhaseRange", "MR"],
  ", as does ",
  StyleBox["BodePlot", "MR"],
  ", as well as the options pertinent to ",
  StyleBox["ListPlot", "MR"],
  ". "
}], "Text",
  CellTags->"5.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.5 The Singular\[Hyphen]Value Plot", "Subsection",
  CellTags->"5.5"],

Cell[TextData[{
  "For MIMO systems, ",
  StyleBox["BodePlot", "MR"],
  " returns a total of ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\ \)\[Cross]\ q\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " individual Bode plots, and consequently, the amount of information \
quickly grows with the number of inputs ",
  Cell[BoxData[
      \(TraditionalForm\`p\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " and outputs ",
  Cell[BoxData[
      \(TraditionalForm\`q\)], "InlineFormula",
    CellTags->"S0.0.6"],
  ". ",
  StyleBox["SingularValuePlot", "MR"],
  " provides a means to generalize this information by generating a plot of \
the frequency dependence of singular values of the transfer matrix evaluated \
at different values of ",
  Cell[BoxData[
      \(TraditionalForm\`s = j  \[Omega]\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " (or ",
  Cell[BoxData[
      \(TraditionalForm\`s = e\^\(j  \[Omega]  T\)\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " for discrete\[Hyphen]time systems, ",
  Cell[BoxData[
      \(TraditionalForm\`T\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " being the sampling period). "
}], "Text",
  CellTags->"5.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SingularValuePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"5.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(generate\ a\ singular\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["value",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["plot",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["for",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"5.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SingularValuePlot",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{
                      StyleBox["{",
                        "MR"], 
                      RowBox[{"w", 
                        StyleBox[",",
                          "MR"], " ", "wmin", 
                        StyleBox[",",
                          "MR"], " ", "wmax"}], 
                      StyleBox["}",
                        "MR"]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"5.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(Generate\ a\ singular\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["value",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["plot",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["for",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["frequency",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["w",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["running",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["from",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["wmin",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["to",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["wmax",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "BottomBox",
  CellTags->"5.5"],

Cell["Creating the singular\[Hyphen]value plots. ", "Caption",
  CellTags->"5.5"],

Cell[TextData[{
  "Here is a mixing tank system (see ",
  ButtonBox["Section 10.1",
    ButtonData:>{"Linear Quadratic Regulator"},
    ButtonStyle->"AddOnsLink"],
  "). "
}], "MathCaption",
  CellTags->"5.5"],

Cell[CellGroupData[{

Cell["\<\
StateSpace[{{-.01, 0}, {0, -.02}},
 {{1, 1}, {-.004, .002}},
 {{.01, 0}, {0, 1}}]\
\>", "Input",
  CellLabel->"In[28]:=",
  CellTags->"5.5"],

Cell[BoxData[
    RowBox[{"StateSpace", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", 
                  StyleBox["0.01`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1]}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", 
                RowBox[{"-", 
                  StyleBox["0.02`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1]}]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{\({1, 1}\), ",", 
            RowBox[{"{", 
              RowBox[{
                RowBox[{"-", 
                  StyleBox["0.004`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1]}], ",", 
                StyleBox["0.002`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}], "}"}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                StyleBox["0.01`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], ",", "0"}], "}"}], ",", \({0, 1}\)}], 
          "}"}]}], "]"}]], "Output",
  CellLabel->"Out[28]=",
  CellTags->"5.5"]
}, Open  ]],

Cell["This plots the frequency dependence of the singular values. ", 
  "MathCaption",
  CellTags->"5.5"],

Cell[CellGroupData[{

Cell["SingularValuePlot[%]", "Input",
  CellLabel->"In[29]:=",
  CellTags->"5.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.31746 0.568588 0.0116614 [
[.02381 -0.0125 -17 -12.5625 ]
[.02381 -0.0125 17 0 ]
[.2457 -0.0125 -17 -12.5625 ]
[.2457 -0.0125 17 0 ]
[.34127 -0.0125 -14 -12.5625 ]
[.34127 -0.0125 14 0 ]
[.56317 -0.0125 -14 -12.5625 ]
[.56317 -0.0125 14 0 ]
[.65873 -0.0125 -11 -12.5625 ]
[.65873 -0.0125 11 0 ]
[.88063 -0.0125 -11 -12.5625 ]
[.88063 -0.0125 11 0 ]
[.97619 -0.0125 -5 -12.5625 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .10213 -18 -4.5 ]
[-0.0125 .10213 0 4.5 ]
[-0.0125 .21875 -18 -4.5 ]
[-0.0125 .21875 0 4.5 ]
[-0.0125 .33536 -18 -4.5 ]
[-0.0125 .33536 0 4.5 ]
[-0.0125 .45197 -18 -4.5 ]
[-0.0125 .45197 0 4.5 ]
[-0.0125 .56859 -6 -4.5 ]
[-0.0125 .56859 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -62 ]
[-0.01875 .30902 -18 62 ]
[.02381 .63053 -17 0 ]
[.02381 .63053 17 12.5625 ]
[.2457 .63053 -17 0 ]
[.2457 .63053 17 12.5625 ]
[.34127 .63053 -14 0 ]
[.34127 .63053 14 12.5625 ]
[.56317 .63053 -14 0 ]
[.56317 .63053 14 12.5625 ]
[.65873 .63053 -11 0 ]
[.65873 .63053 11 12.5625 ]
[.88063 .63053 -11 0 ]
[.88063 .63053 11 12.5625 ]
[.97619 .63053 -5 0 ]
[.97619 .63053 5 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .10213 m
1 .10213 L
s
0 .21875 m
1 .21875 L
s
0 .33536 m
1 .33536 L
s
0 .45197 m
1 .45197 L
s
0 .56859 m
1 .56859 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -78 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .10213 m
.00625 .10213 L
s
[(-40)] -0.0125 .10213 1 0 Mshowa
0 .21875 m
.00625 .21875 L
s
[(-30)] -0.0125 .21875 1 0 Mshowa
0 .33536 m
.00625 .33536 L
s
[(-20)] -0.0125 .33536 1 0 Mshowa
0 .45197 m
.00625 .45197 L
s
[(-10)] -0.0125 .45197 1 0 Mshowa
0 .56859 m
.00625 .56859 L
s
[(0)] -0.0125 .56859 1 0 Mshowa
.125 Mabswid
0 .12546 m
.00375 .12546 L
s
0 .14878 m
.00375 .14878 L
s
0 .1721 m
.00375 .1721 L
s
0 .19542 m
.00375 .19542 L
s
0 .24207 m
.00375 .24207 L
s
0 .26539 m
.00375 .26539 L
s
0 .28872 m
.00375 .28872 L
s
0 .31204 m
.00375 .31204 L
s
0 .35868 m
.00375 .35868 L
s
0 .38201 m
.00375 .38201 L
s
0 .40533 m
.00375 .40533 L
s
0 .42865 m
.00375 .42865 L
s
0 .4753 m
.00375 .4753 L
s
0 .49862 m
.00375 .49862 L
s
0 .52194 m
.00375 .52194 L
s
0 .54527 m
.00375 .54527 L
s
0 .07881 m
.00375 .07881 L
s
0 .05549 m
.00375 .05549 L
s
0 .03217 m
.00375 .03217 L
s
0 .00884 m
.00375 .00884 L
s
0 .59191 m
.00375 .59191 L
s
0 .61523 m
.00375 .61523 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -147.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
123 10.2813 translate
90 rotate
-123 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Singular) show
117.000000 12.812500 moveto
(Values) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
159.000000 12.812500 moveto
(H) show
165.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 12.812500 moveto
(L) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.005) show
93.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .10213 m
1 .10213 L
s
.99375 .21875 m
1 .21875 L
s
.99375 .33536 m
1 .33536 L
s
.99375 .45197 m
1 .45197 L
s
.99375 .56859 m
1 .56859 L
s
.125 Mabswid
.99625 .12546 m
1 .12546 L
s
.99625 .14878 m
1 .14878 L
s
.99625 .1721 m
1 .1721 L
s
.99625 .19542 m
1 .19542 L
s
.99625 .24207 m
1 .24207 L
s
.99625 .26539 m
1 .26539 L
s
.99625 .28872 m
1 .28872 L
s
.99625 .31204 m
1 .31204 L
s
.99625 .35868 m
1 .35868 L
s
.99625 .38201 m
1 .38201 L
s
.99625 .40533 m
1 .40533 L
s
.99625 .42865 m
1 .42865 L
s
.99625 .4753 m
1 .4753 L
s
.99625 .49862 m
1 .49862 L
s
.99625 .52194 m
1 .52194 L
s
.99625 .54527 m
1 .54527 L
s
.99625 .07881 m
1 .07881 L
s
.99625 .05549 m
1 .05549 L
s
.99625 .03217 m
1 .03217 L
s
.99625 .00884 m
1 .00884 L
s
.99625 .59191 m
1 .59191 L
s
.99625 .61523 m
1 .61523 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
.02381 .60332 m
.06349 .60293 L
.10317 .60225 L
.14286 .60106 L
.18254 .599 L
.22222 .59555 L
.2619 .58994 L
.30159 .58127 L
.34127 .5688 L
.38095 .5522 L
.42063 .53178 L
.46032 .50831 L
.5 .48268 L
.53968 .45563 L
.57937 .4277 L
.61905 .39925 L
.65873 .3705 L
.69841 .34157 L
.7381 .31255 L
.77778 .28346 L
.81746 .25435 L
.85714 .22522 L
.89683 .19608 L
.93651 .16693 L
.97619 .13779 L
s
1 0 0 r
.02381 .41128 m
.06349 .41118 L
.10317 .411 L
.14286 .41069 L
.18254 .41014 L
.22222 .40919 L
.2619 .40752 L
.30159 .40469 L
.34127 .40002 L
.38095 .39265 L
.42063 .38172 L
.46032 .3667 L
.5 .34766 L
.53968 .32523 L
.57937 .30029 L
.61905 .27367 L
.65873 .24599 L
.69841 .21769 L
.7381 .18902 L
.77778 .16015 L
.81746 .13115 L
.85714 .10208 L
.89683 .07298 L
.93651 .04385 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[29]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool0071oo`8001Eoo`8001Eoo`03001oogoo03aoo`03001oogoo041oo`00LGoo00<007ooOol057oo
00<007ooOol04Woo00<007ooOol04goo00<007ooOol0:7oo00<007ooOol0?goo001NOol30003Ool3
0003Ool20003Ool30002Ool30002Ool200000goo00000002Ool00`00Ool000020003Ool00`00Oomo
o`0AOol01000Oomoogoo0`0000=oo`00Ool010000Woo0`001Goo00<007ooOol00Woo0`000goo0P00
0Woo0`000goo0P0000=oo`0000000Woo00<007ooOol00`002Goo00<007ooOol0?Woo001OOol00`00
Oomoo`03Ool01@00Oomoogoo000017oo00H007ooOol007oo0002Ool00`00Ool00004Ool01P00Oomo
o`00Ool000Aoo`03001oo`00019oo`03001oogoo009oo`05001oogoo001oo`030002Ool01000Oomo
o`001Goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol00Woo00H007oo
Ool007oo0002Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0nOol005moo`03001oogoo
00=oo`04001oogooOol30002Ool01P00Oomoo`00Ool0009oo`03001oo`000080009oo`06001oogoo
001oo`0017oo00<007oo00004Woo00<007ooOol00Woo0`0017oo00@007ooOol0009oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00<0009oo`03001oogoo009oo`06001oogoo001oo`000Woo
00<007oo00000Woo00<007ooOol01goo00<007ooOol0?Woo001OOol20003Ool4000017oo00000000
0goo1@0000Aoo`00001oo`<00003Ool000000080009oo`<00004Ool00000Ool2000AOol00`00Oomo
o`02Ool01000Oomoo`000Woo0P000goo0`001Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`<0
00=oo`800003Ool00000008000=oo`<000Uoo`03001oogoo03ioo`00Ggoo00@007ooOol003Yoo`05
001oogooOol00002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0001Uoo`03
001oogoo00Ioo`03001oogoo03moo`00GWoo1@00>goo00<007oo00000`002Goo0P001goo00<007oo
Ool00`0067oo0P001goo00<007ooOol0@7oo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol002aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00D001Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`05000NOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`05
000SOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool5000GOol002]oo`03001oo`00
00Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo01Qoo`03001oo`0000Moo`03001oo`00
009oo`03001oo`00009oo`07001oo`00Ool007oo00001goo00<007oo00000goo00<007ooOol07Goo
00<007oo00001goo00<007oo00000Woo00<007oo00001Woo00<007oo000027oo00<007ooOol08Woo
00<007oo00001goo00<007oo00003Woo00<007ooOol05goo000[Ool00`00Ool00007Ool00`00Ool0
0002Ool00`00Ool00003Ool00`00Oomoo`0HOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool0
0004Ool01@00Ool007oo00001goo00<007oo00000goo00<007ooOol07Goo00<007oo00001goo00<0
07oo000017oo00<007ooOol017oo00<007oo000027oo00<007ooOol08Woo00<007oo00002Goo00<0
07ooOol037oo00<007ooOol05goo000[Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00003
Ool00`00Oomoo`0HOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool20002Ool00`00
Ool00007Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Ool00007Ool00`00Ool00002Ool20007
Ool00`00Ool00008Ool00`00Oomoo`0ROol00`00Ool00007Ool2000?Ool00`00Oomoo`0GOol002]o
o`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo01Qoo`03001oo`0000Mo
o`03001oo`00009oo`03001oo`00009oo`07001oogooOol007oo00001goo00<007oo00000goo00<0
07ooOol07Goo00<007oo00001goo00<007oo00000Woo00<007ooOol01Woo00<007oo000027oo00<0
07ooOol08Woo00<007oo00001goo00<007ooOol03Woo00<007ooOol05goo000/Ool00`00Oomoo`07
Ool00`00Oomoo`02Ool01000Oomoogoo0P006goo00<007ooOol01goo00<007ooOol00Woo00@007oo
Oomoo`<0009oo`03001oogoo00Moo`04001oogooOol2000POol00`00Oomoo`07Ool01000Oomoogoo
0`001goo00<007ooOol01Woo0P009Goo00<007ooOol01Woo0`003Goo0P006Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol003AoomX0019oo`00=7oo00<007ooOol00Woo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`00
00=oo`05001oogooOol00002Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007ooOomoo`00
01=oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00002Ool01000Oomoo`001Goo00<007ooOol047oo000dOol20003Ool00`00
Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`00Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?009oo`03001oogoo019oo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?
Oomoogoo00004goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<007ooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo0004Ool2000BOol003Aoo`03001oogoo
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011o
o`00=7oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoog`0
1Goo00<007ooOol047oo000dOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moog`000l5Ool00`00Oomoo`0@Ool003Aoo`03001oogoo009oo`0300moogoo019oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0C
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo0W`000=oo`0?Ool017oo00<007ooOol047oo000dOol20003Ool00`0?
Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00P03gooOomoo`0?Ooml000?0Woo00<03gooOol00Woo0P004Woo000dOol00`00
Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?O01oo`0?0Woo00<03gooOol00goo00<0
07ooOol047oo000DOol20002Ool2000JOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00W`00Woo00@03gooOol03`Eoo`03001oogoo011oo`0057oo00<007oo00000Woo00<007ooOol0
67oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moog`0Ool03`02Ool0100?Oomoo`0?1Goo
00<007ooOol047oo000DOol00`00Ool00002Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`0?Oomo
o`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo0W`00Woo00@03gooOol03`9oo`0300moogoo00=oo`03001oogoo011oo`0057oo0P00
00=oo`0000006goo0P000goo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0600moogooOoml000?0goo00@03gooOol03`9oo`0300moogoo
009oo`80019oo`00=7oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool0
0`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0600moog`0O01oo`0?0goo00@03gooOol03`9o
o`0300moogoo00=oo`03001oogoo011oo`00=7oo00<007ooOol00Woo00<03gooOol04Woo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300ml07oo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02Ool00`0?
Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?
Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00@03gooOomoo`9l
00Aoo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol01000Oomoo`00
6Woo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0600moogooO01oo`0?17oo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomo
o`0@Ool001Aoo`03001oo`0000<001Yoo`8000=oo`0300moogoo019oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Ooml0002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03`Aoo`80019oo`006Goo00<007ooOol067oo00<007ooOol00Woo00<03gooOol0
4Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomo
o`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`9l00=oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02Ool0
0`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00=l000?Ool0
0goo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Io
o`04001oogoo000JOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`03
00moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol00Woo00=l07oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00l5Ool00`00Oomoo`0@Ool001Ioo`@000moo`<0009oo`03001oogoo00=oo`03001oogoo
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`02O002Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo
011oo`005Woo00<007ooOol04Goo00H007ooOol007oo0004Ool00`00Oomoo`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooO00017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Ioo`03001oogoo
00Yoo`<0009oo`@00004Ool007oo0004Ool2002g00l00g`000l03`0K00l3000BOol001Moo`<000io
o`03001oo`00009oo`03001oo`0000Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool2O006Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03`Eoo`03001oogoo011oo`006Goo00<007ooOol03Goo0P000Woo00<007oo0000
17oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Aoo`03O01o
o`0?00Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo
00<007ooOol047oo000ZOol01@00Oomoogoo00001Goo00<007ooOol00Woo00<03gooOol04Woo00<0
3gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=o
o`0300moogoo00Uoo`0300moogoo00=oo`04O01oogoo00l6Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`005goo0P000Woo00<007oo
Ool05Woo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0400moogooOol2O003
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool03`Eoo`03001oogoo011oo`005Woo00H007ooOol007oo000HOol20003Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
4goo00<03gooOol02Goo00@03gooOoml00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?17oo0P004Woo000FOol01P00Oomoo`00Ool001Qo
o`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<0
3gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Ooml0006Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03
001oogoo011oo`005Woo1@006Goo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<0
3gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uo
o`9l00Moo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`?o1Goo00<007ooOol047oo000FOol00`00Oomoo`0KOol00`00Oomoo`02Ool00`0?Oomo
o`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomo
ogoo00l04goo00<03gooOol027oo00=l000?Ool01goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moo`?o00l5Ool00`00Oomoo`0@Ool001Ioo`03001o
ogoo01]oo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol0
4Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`06Ool2O0000goo00moo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03`?o
Ool03`Eoo`03001oogoo011oo`005Woo0`006goo0P000goo00<03gooOol04Woo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo
00Eoo`05O01oogooOol03`08Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@3ogooOol03`Aoo`80019oo`006Goo00<007ooOol067oo00<007ooOol00Woo
00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?01=oo`0300moogoo00=oo`9l00Aoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`020ol0100?Oomoo`0?1Goo00<007ooOol0
47oo000FOol00`00Ool0000KOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol00Woo
00=l07ooOol017oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`?o009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Ioo`@001Yoo`03001oogoo
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol03`0COol01@0?OomoogooO0001goo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOol3o`0?009oo`0400moogoo00l5Ool00`00Oomo
o`0@Ool001Uoo`03001oogoo01Qoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`03
00moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol0100?Ooml07`0
27oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo0omo
o`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool003Aoo`8000=oo`0300moogoo019oo`0300mo
ogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol0
0`0?O01oo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool2
0ol2Ool0100?Oomoo`0?0Woo00<03gooOol00Woo0P004Woo000DOol00`00Oomoo`02Ool00`00Oomo
o`0HOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019o
o`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00=l07ooOol02Goo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00Woo00H03gooOomoo`?o00l3Ool0100?Oomoo`0?0Woo00<03gooOol0
0goo00<007ooOol047oo000DOol6000JOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04Goo0W`000<0
3gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00H03goo0ol3ogoo00l3
Ool0100?Oomoo`0?0Woo00<03gooOol00goo00<007ooOol047oo000IOol00`00Oomoo`0HOol00`00
Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo
00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool01@0?Oomoogoo00l047oo00Al07ooOol03`]oo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo009oo`0300l3ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000dOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l03goo00El07ooOomoo`0?00]oo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0400moogooOol20ol4Ool01@0?Oomoogoo00l00Woo00@03gooOol0
3`Eoo`03001oogoo011oo`00=7oo0P000goo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool0
0`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?00eoo`9l00Aoo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00Aoo`0600moogoo0omoo`0?17oo00D03gooOomoo`0?009oo`04
00moogoo00l4Ool2000BOol003Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`03
00moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0<Ool00g`0Oomoo`04
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Ool3o`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`0067oo0P006Woo00<007oo
Ool00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00D03gooOomoo`0?00]oo`03O01oogoo00Eoo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`83o`=oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<0
07ooOol047oo000FOol01000Ool000003Woo0P0017oo00<007ooOol00goo00<007ooOol00Woo00<0
3gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D0
3gooOomoo`0?00Uoo`9l00Qoo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`030ol0
3goo00=oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo
000FOol01000Ool0000047oo00H007ooOol007oo0004Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
27oo00=l07ooOol027oo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00Woo00<3ogoo00l0
17oo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Io
o`@000Uoo`<000=oo`07001oogooOol007oo000017oo0P00U@0?00=l000?00l08@0?0P?o6P0?0`00
4Woo000IOol00`00Oomoo`0>Ool01P00Oomoo`00Ool000Aoo`03001oogoo009oo`0300moogoo019o
o`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol0
3`06Ool00g`0Oomoo`0:Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Ool3o`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00
:7oo00<007oo00000Woo00<007oo000017oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol0
2Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?00Aoo`9l00eo
o`0300moogoo00Uoo`0300moogoo00Ioo`83o`Eoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol01000Oomoo`003goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?00=oo`03O01oogoo00eoo`03
00moogoo00Uoo`0300moogoo00Eoo`030ol03goo00Eoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol4000JOol00`00Oomoo`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo00l00Woo00=l07ooOol03Woo00<03gooOol02Goo00<03gooOol00goo0P?o00=o
o`0?Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5
Ool00`00Oomoo`0@Ool001Ioo`04001oogoo000JOol20003Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l00W`04Goo00<0
3gooOol02Goo00<03gooOol00Woo00D3ogooOomoo`0?00Ioo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?17oo0P004Woo000FOol01000Oomoo`006Woo00<007oo
Ool00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00D03gooOomoog`001=oo`0300moogoo00Uoo`0300moogoo0083o`Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000dOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Ooml07`000l04goo00<03gooOol02Goo00<03goo0ol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00l5Ool00`00Oomoo`0@Ool003Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500ml07ooOol03`0COol00`0?Oomo
o`09Ool00`0?0omoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo00<007ooOol00Woo00<03gooOol0
4Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomoogoo00moo`9l00=oo`0300mo
ogoo015oo`0300moogoo00Qoo`83o`Qoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol20003Ool00`0?Oomo
o`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0800moogooOol03g`0Ool03`=oo`03
00moogoo015oo`0300moogoo00Moo`030omoo`0?00Qoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?17oo0P004Woo000dOol00`00Oomoo`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009l009o
o`0500moogooOol03`0COol00`0?Oomoo`06Ool010?oOomoo`0?27oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool0
03Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo
00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooO01oo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`04Ool20ol3Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool03`Eoo`03001oogoo011oo`00=7oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo
00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool2O002Ool0100?Oomoo`0?0goo00<03gooOol04Goo00<03gooOol0
0goo00<3ogooOol00goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Aoo`8001ioo`03001o
ogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00W`000D03gooOomo
o`0?009oo`0500moogooOol03`0COol00`0?Oomoo`02Ool00`?oOomoo`04Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
3`Eoo`03001oogoo011oo`0057oo00<007oo00000P006goo0P000goo00<03gooOol04Woo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?O01l0002Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`05
00moogooOol3o`07Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Aoo`80019oo`006Goo00<007ooOol067oo00<007oo
Ool00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0100?Oomoogoo0W`017oo00D03gooOomoo`0?009oo`05
00moogooOol03`0COol0100?Ool3o`?o27oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Uo
o`03001oogoo01Qoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Io
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<0
3gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00H03gooOoml07oo00l4
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300l3ogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
1Goo00<007ooOol047oo000DOol00`00Ool00002000KOol00`00Oomoo`02Ool00`0?Oomoo`0BOol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moog`0009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
4goo00<3ogooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Aoo`8001ioo`03001o
ogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol0
2Goo00<03gooOol01Goo00<03gooOol017oo0W`00goo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0500moogooOol03`0AOol20ol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011o
o`00=7oo0P000goo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?
Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00g`000moo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00D03gooOomoo`0?011oo`040omoogoo00l;Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Aoo`80
019oo`0067oo0P006Woo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool0
0`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00g`0Ool03`04Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?00ioo`83o`=oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol01000Ool000006Woo00<007ooOol00Woo
00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Oomoo`02O002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOomoo`0?00eoo`030omoogoo00=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo
00<007ooOol047oo000FOol01000Ool000003Woo0`000goo00<007ooOol00goo00<007ooOol00Woo
00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`05Ool00`0?Ooml0004Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?00]oo`83o`Ioo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol0
47oo000FOol4000>Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`9l
00Eoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l02Woo
00<3ogooOol01Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Uoo`03
001oogoo00Moo`<000=oo`07001oogooOol007oo000017oo0P00K`0?0W`09@0?0P?o?@0?0`004Woo
000YOol01`00Oomoogoo001oo`0000Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00@03gooOomoo`9l009oo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l01goo00<3
ogooOol02Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Aoo`03001o
ogoo009oo`03001oogoo00aoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00@03gooO01l
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?
Oomoogoo00l01Woo00<3ogooOol02Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomo
o`0@Ool001Aoo`H000moo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`0300moogoo
019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03g`0Ool01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogoo
Ool03`05Ool00`?oOomoo`0;Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011o
o`006Goo00<007ooOol067oo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`08Ool2O007Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?00Aoo`030omoogoo00aoo`0300moogoo
00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol20003Ool00`0?Oomoo`0BOol00`0?
Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Ioo`9l0003Ool03goo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
0Woo0P?o3goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l4Ool2000BOol003Aoo`03001oogoo009o
o`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol017oo0W`0
0goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0700moogooOol03goo0ol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00
Oomoo`0@Ool001Ioo`03001oogoo01]oo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04Woo00@03gooOomoo`=l00Eoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01P0?Oomoogoo00l3oa9oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol3000KOol00`00Oomoo`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0400ml07`0O008Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00D03gooOomoo`?o01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo
000IOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomo
o`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009o
o`0300moogoo011oo`=l00]oo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Ool3o`?o00l04goo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00l5Ool00`00Oomoo`0@Ool001Ioo`03001oo`0001]oo`8000=oo`0300moogoo019oo`0300mo
ogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l00Woo00<03gooOol037oo17`00Woo00<03gooOol02Goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500l3ogooOol0
3`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Aoo`80019oo`005Woo10006Woo00<007ooOol0
0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`08Ool4O006Ool00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomo
ogoo00moo`83o`=oo`0300moogoo015oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000IOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?009oo`0300moogoo00Aoo`Al00Yoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0800moogooOol03`?oOol03`=oo`0300moogoo015oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02Ool00`0?
Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo00Al00ioo`0300moogoo00Uoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moogoo0083o`9oo`05
00moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`005goo
0P006goo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moogoo00Ml019oo`0300moogoo00Uo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`?oOol0
3`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@
Ool001Ioo`800003Ool007oo01Uoo`8000=oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo
00Ioo`0300moogoo00=oo`0300moogoo00=oo`0300moogoo00Ql0005Ool03gooOol03`0DOol00`0?
Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool20ol2
Ool0100?Oomoo`0?0goo00<03gooOol04Goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l4Ool2000B
Ool001Ioo`800003Ool007oo01Uoo`03001oogoo009oocUl0003Ool03goo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool01P0?Oomoogoo0ol03`=oo`0400moogoo00l3Ool00`0?Oomoo`0AOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03`Eoo`03001oogoo011oo`005goo00<007oo00006Woo00<007ooOol00Woo00<0
3gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Ool3o`?oOol03`=oo`0400moogoo00l3Ool0
0`0?Oomoo`0AOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo00<0
07ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?0omoo`02Ool01@0?Oomo
ogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000dOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0400moogooOol20ol4Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo
00<007ooOol047oo000FOol200000goo001oo`0IOol20003Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`06
00moogoo0omoo`0?17oo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol03`Aoo`80019oo`005Woo0P0000=oo`00Ool06Goo00<007ooOol00Woo00<03goo
Ool04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Ool3o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03goo
Oomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000FOol20000
0goo001oo`0IOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`83o`=oo`0300moogoo009o
o`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5
Ool00`00Oomoo`0@Ool001Ioo`03001oo`0000ioo`D0009oo`03001oogoo00=oo`03001oogoo009o
o`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<0
3gooOol01Goo00<03gooOol00goo00<3o`0?Ool00goo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00
:Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo009oo`030omo
o`0?00Aoo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol0
2Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool002=oo`<000=oo`07001oogooOol007oo0000
17oo0P00M00?0P?oG`0?0`004Woo000YOol01`00Oomoogoo001oo`0000Aoo`03001oogoo009oo`03
00moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool01Goo00<03goo0ol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00:Goo
00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?
Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`83o`Eoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo00l5Ool00`00Oomoo`0@Ool002Qoo`8000Aoo`03001oogoo00=oo`03001oogoo009oo`03
00moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool017oo00<3o`0?Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo
00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?
Oomoo`09Ool00`0?Oomoo`02Ool20ol00goo00moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo
00<007ooOol047oo000dOol20003Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300mo
ogoo019oo`0300moogoo00Uoo`0500moogooOol3o`03Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`0?17oo0P004Woo000dOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0400moo`?o0ol4Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo
00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300l3ogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Ioo`@001Yoo`03
001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03goo
Ool027oo0P?o1goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011o
o`005Goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol00Woo00<03gooOol04Woo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`07Ool00`?oOol03`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000DOol00`00Oomoo`04Ool00`00
Oomoo`0FOol20003Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`03
00moogoo00Eoo`83o`9oo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
00l4Ool2000BOol003Aoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo
00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo
00<03gooOol04Woo00<03gooOol00goo0P?o17oo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo00<007ooOol00Woo00<03gooOol04Woo
00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`02Ool00`?oOomoo`04Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000G
Ool2000KOol00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo
019oo`0300moogoo0083o`Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00l5Ool00`00Oomoo`0@Ool001Ioo`04001oogoo000JOol00`00Oomoo`02Ool00`0?Oomoo`0B
Ool00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?009oo`0300moogoo019oo`0300moo`?o00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo
00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Aoo`03001oo`00
009oo`03001oogoo01Qoo`8000=oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03goo
Ool04Woo0P?o2Woo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Ao
o`80019oo`0057oo1P006Woo00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03goo
Ool01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02
Ool00`0?Oomoo`0AOol00`?o00moo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`0?1Goo00<007ooOol047oo000IOol00`00Oomoo`0HOol00`00Oomoo`02Ool00`0?
Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?009oo`0300moogoo00moo`83o`03Ool03goo00Yoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
1@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool001Ao
o`03001oogoo009oo`03001oogoo01Qoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uo
o`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l00Woo00<03gooOol03Goo0P?o0goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol0
0`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`0057oo1P006Woo00<007ooOol0
0Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`0;Ool20ol5Ool00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000DOol00`00Ool00002Ool00`00Oomoo`0HOol20003Ool00`0?Oomoo`0BOol00`0?Oomo
o`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?009oo`0300moogoo00Uoo`83o`Moo`0300moogoo00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l0
4goo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo00l4Ool2000BOol001Aoo`03001oo`00009oo`03001o
ogoo01Qoo`03001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol0
1goo0P?o2Goo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol03`Eoo`03001oogoo011oo`005Goo00@007oo000001]oo`03001oogoo009oo`0300moogoo
019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol01Goo0P?o2goo00<03gooOol02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00moogooOol03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo
00<007ooOol00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Woo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`0?Oomoo`03Ool20ol=
Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?
1Goo00<007ooOol047oo000^Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?
Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?009oo`0400moogooOol20ol?Ool00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?
01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000DOol00`00Oomoo`04
Ool00`00Oomoo`0?Ool00`00Ool00004Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0400moo`?o0olAOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`0300mo
ogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000EOol00`00Oomoo`02Ool00`00Oomo
o`0@Ool00`00Ool00004Ool2001600l40on;00l3000BOol001Ioo`@001=oo`03001oo`0000Aoo`03
001oogoo009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool00`0?0ol3o`020ol2Ool00`0?Oomoo`0BOol00`0?Oomo
o`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00D03gooOomoo`0?01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007oo
Ool047oo000]Ool00`00Ool00004Ool00`00Oomoo`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool0
0`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l010?o0goo00@03goo
Ool03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03gooOol02Goo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo00l5Ool00`00Oomoo`0@Ool002ioo`03001oogoo00=oo`03001oogoo009oo`0300moogoo019o
o`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0300l3o`?o0083
o`=oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?
01=oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02
Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool70ol3Ool01@0?
Oomoogoo00l00goo00@03gooOol03aAoo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<0
3gooOol02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool003Aoo`8000=oo`0300moogoo019o
o`0300moogoo00Uoo`0300moogoo00Aoo`P3o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol03`0COol00`0?
Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol03`Aoo`80019oo`00=7oo00<007ooOol00Woo00<03gooOol04Woo
00<03gooOol01goo2@?o0Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`02Ool00`0?Oomoo`0BOol00`0?Oomoo`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0?01=oo`03
00moogoo00Uoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`0?1Goo00<007ooOol047oo000dOol00`00Oomoo`02OolO0ol2
Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?009oo`0300moogoo019oo`0300moogoo00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool01@0?Oomoogoo00l04goo00<03goo
Ool02Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo00l5Ool00`00Oomoo`0@Ool003Aoo`03001oogoo009oo`0300moogoo
019oo`0300moogoo00Uoo`0300moogoo00Ioo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l00Woo00<03gooOol04Woo00<03gooOol02Goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogoo
Ool03`0COol00`0?Oomoo`09Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol03`Eoo`03001oogoo011oo`00=7oo00<007oo
Ool00Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol00goo00<007oo
Ool00goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool00`00Oomoo`0BOol00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000Woo00D007ooOomoo`0001=oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoo`001Goo00<007ooOol0
47oo000dOooJ000BOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00;7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
1@006Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo00D001ioo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00D002=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00]oo`D001Moo`00:goo00<007oo00001goo00<007oo0000
0Woo00<007oo00000goo00<007ooOol067oo00<007oo00001goo00<007oo00000Woo00<007oo0000
0Woo00L007oo001oo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Ool00007Ool0
0`00Ool00002Ool00`00Ool00006Ool00`00Ool00008Ool00`00Oomoo`0ROol00`00Ool00007Ool0
0`00Ool0000>Ool00`00Oomoo`0GOol002]oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00
00=oo`03001oogoo01Qoo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`05001oo`00
Ool00007Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00Ool00007Ool00`00Ool00004Ool00`00
Oomoo`04Ool00`00Ool00008Ool00`00Oomoo`0ROol00`00Ool00009Ool00`00Oomoo`0<Ool00`00
Oomoo`0GOol002]oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo01Qo
o`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`80009oo`03001oo`0000Moo`03001o
o`0000=oo`03001oogoo01eoo`03001oo`0000Moo`03001oo`00009oo`8000Moo`03001oo`0000Qo
o`03001oogoo029oo`03001oo`0000Moo`8000moo`03001oogoo01Moo`00:goo00<007oo00001goo
00<007oo00000Woo00<007oo00000goo00<007ooOol067oo00<007oo00001goo00<007oo00000Woo
00<007oo00000Woo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0MOol00`00
Ool00007Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`0ROol00`00
Ool00007Ool00`00Oomoo`0>Ool00`00Oomoo`0GOol002aoo`03001oogoo00Moo`03001oogoo009o
o`04001oogooOol2000KOol00`00Oomoo`07Ool00`00Oomoo`02Ool01000Oomoogoo0`000Woo00<0
07ooOol01goo00@007ooOomoo`80021oo`03001oogoo00Moo`04001oogooOol30007Ool00`00Oomo
o`06Ool2000UOol00`00Oomoo`06Ool3000=Ool2000IOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.8383, -59.7797, 
  0.0145463, 0.395995}},
  CellTags->"5.5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{4, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "5.0"->{
    Cell[1731, 51, 76, 1, 80, "Section",
      CellTags->"5.0"],
    Cell[1810, 54, 550, 12, 114, "Text",
      CellTags->"5.0"]},
  "5.1"->{
    Cell[2385, 70, 54, 1, 68, "Subsection",
      CellTags->"5.1"],
    Cell[2442, 73, 966, 31, 48, "TopSpanBox",
      CellTags->"5.1"],
    Cell[3411, 106, 2359, 64, 49, "BottomBox",
      CellTags->"5.1"],
    Cell[5773, 172, 62, 1, 26, "Caption",
      CellTags->"5.1"],
    Cell[5838, 175, 921, 23, 147, "Text",
      CellTags->"5.1"],
    Cell[6762, 200, 64, 1, 40, "MathCaption",
      CellTags->"5.1"],
    Cell[6829, 203, 77, 2, 39, "Input",
      CellTags->"5.1"],
    Cell[6909, 207, 86, 1, 40, "MathCaption",
      CellTags->"5.1"],
    Cell[7020, 212, 90, 2, 39, "Input",
      CellTags->"5.1"],
    Cell[7113, 216, 117, 3, 42, "Output",
      CellTags->"5.1"],
    Cell[7245, 222, 207, 6, 55, "MathCaption",
      CellTags->"5.1"],
    Cell[7477, 232, 89, 2, 39, "Input",
      CellTags->"5.1"],
    Cell[7569, 236, 12189, 430, 186, 6061, 348, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.1"],
    Cell[19773, 669, 323, 9, 71, "Text",
      CellTags->"5.1"],
    Cell[20099, 680, 1329, 43, 103, "DefinitionBox3Col",
      CellTags->"5.1"],
    Cell[21431, 725, 117, 5, 16, "Caption",
      CellTags->"5.1"],
    Cell[21551, 732, 416, 13, 101, "Text",
      CellTags->"5.1"],
    Cell[21970, 747, 70302, 1187, 76, 64268, 1107, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"5.1"],
    Cell[92275, 1936, 149, 5, 16, "Caption",
      CellTags->"5.1"],
    Cell[92427, 1943, 210, 7, 31, "MathCaption",
      CellTags->"5.1"],
    Cell[92640, 1952, 102, 2, 30, "Input",
      CellTags->"5.1"],
    Cell[92745, 1956, 193, 7, 31, "MathCaption",
      CellTags->"5.1"],
    Cell[92941, 1965, 93, 2, 30, "Input",
      CellTags->"5.1"],
    Cell[93037, 1969, 131, 4, 31, "MathCaption",
      CellTags->"5.1"],
    Cell[93193, 1977, 79, 2, 30, "Input",
      CellTags->"5.1"],
    Cell[93275, 1981, 167, 5, 44, "Output",
      CellTags->"5.1"],
    Cell[93457, 1989, 255, 7, 52, "Text",
      CellTags->"5.1"],
    Cell[93715, 1998, 172, 4, 53, "DisplayFormula",
      CellTags->"5.1"],
    Cell[93890, 2004, 446, 15, 33, "Text",
      CellTags->"5.1"],
    Cell[94339, 2021, 534, 13, 107, "MathCaption",
      CellTags->"5.1"],
    Cell[94898, 2038, 263, 12, 174, "Input",
      CellTags->"5.1"],
    Cell[95164, 2052, 16169, 560, 186, 8416, 458, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.1"],
    Cell[111348, 2615, 251, 6, 65, "MathCaption",
      CellTags->"5.1"],
    Cell[111624, 2625, 137, 7, 84, "Input",
      CellTags->"5.1"],
    Cell[111764, 2634, 122, 3, 29, "Output",
      CellTags->"5.1"],
    Cell[111901, 2640, 127, 4, 31, "MathCaption",
      CellTags->"5.1"],
    Cell[112053, 2648, 140, 5, 48, "Input",
      CellTags->"5.1"],
    Cell[112196, 2655, 264, 7, 76, "Output",
      CellTags->"5.1"],
    Cell[112475, 2665, 251, 6, 65, "MathCaption",
      CellTags->"5.1"],
    Cell[112751, 2675, 196, 8, 102, "Input",
      CellTags->"5.1"],
    Cell[112972, 2687, 13671, 417, 186, 4786, 301, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.1"],
    Cell[126646, 3106, 12741, 393, 198, 4577, 286, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.1"],
    Cell[139414, 3503, 502, 12, 93, "Text",
      CellTags->"5.1"],
    Cell[139919, 3517, 971, 31, 48, "TopSpanBox",
      CellTags->"5.1"],
    Cell[140893, 3550, 2812, 76, 49, "BottomBox",
      CellTags->"5.1"],
    Cell[143708, 3628, 63, 1, 26, "Caption",
      CellTags->"5.1"]},
  "5.2"->{
    Cell[143808, 3634, 69, 1, 68, "Subsection",
      CellTags->{"5.2", "5.2.1"}]},
  "5.2.1"->{
    Cell[143808, 3634, 69, 1, 68, "Subsection",
      CellTags->{"5.2", "5.2.1"}],
    Cell[143902, 3639, 64, 1, 60, "Subsubsection",
      CellTags->"5.2.1"],
    Cell[143969, 3642, 744, 16, 143, "Text",
      CellTags->"5.2.1"],
    Cell[144716, 3660, 1270, 38, 50, "TopBox",
      CellTags->"5.2.1"],
    Cell[145989, 3700, 966, 31, 32, "MiddleSpanBox",
      CellTags->"5.2.1"],
    Cell[146958, 3733, 2016, 55, 49, "BottomBox",
      CellTags->"5.2.1"],
    Cell[148977, 3790, 65, 1, 26, "Caption",
      CellTags->"5.2.1"],
    Cell[149045, 3793, 1418, 42, 162, "Text",
      CellTags->"5.2.1"],
    Cell[150466, 3837, 92, 1, 40, "MathCaption",
      CellTags->"5.2.1"],
    Cell[150561, 3840, 143, 5, 54, "Input",
      CellTags->"5.2.1"],
    Cell[150707, 3847, 199, 5, 54, "MathCaption",
      CellTags->"5.2.1"],
    Cell[150931, 3856, 81, 2, 39, "Input",
      CellTags->"5.2.1"],
    Cell[151015, 3860, 114439, 3382, 296, 53981, 2630, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.1"],
    Cell[265469, 7245, 99, 1, 40, "MathCaption",
      CellTags->"5.2.1"],
    Cell[265593, 7250, 93, 2, 39, "Input",
      CellTags->"5.2.1"],
    Cell[265689, 7254, 117852, 3445, 296, 47513, 2571, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.1"],
    Cell[383556, 10702, 2519, 69, 396, "Text",
      CellTags->"5.2.1"],
    Cell[386078, 10773, 2280, 73, 202, "DefinitionBox3Col",
      CellTags->"5.2.1"],
    Cell[388361, 10848, 114, 5, 16, "Caption",
      CellTags->"5.2.1"],
    Cell[388478, 10855, 1424, 43, 219, "Text",
      CellTags->"5.2.1"],
    Cell[389905, 10900, 234, 5, 54, "MathCaption",
      CellTags->"5.2.1"],
    Cell[390164, 10909, 146, 6, 69, "Input",
      CellTags->"5.2.1"],
    Cell[390313, 10917, 278, 6, 88, "Output",
      CellTags->"5.2.1"],
    Cell[390606, 10926, 67, 1, 40, "MathCaption",
      CellTags->"5.2.1"],
    Cell[390698, 10931, 221, 12, 159, "Input",
      CellTags->"5.2.1"],
    Cell[390922, 10945, 141227, 5085, 308, 80003, 4323, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.1"],
    Cell[532164, 16033, 632, 17, 99, "MathCaption",
      CellTags->"5.2.1"],
    Cell[532821, 16054, 318, 16, 219, "Input",
      CellTags->"5.2.1"],
    Cell[533142, 16072, 154714, 7140, 308, 131296, 6845, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.1"]},
  "5.2.2"->{
    Cell[687905, 23218, 68, 1, 60, "Subsubsection",
      CellTags->"5.2.2"],
    Cell[687976, 23221, 929, 24, 143, "Text",
      CellTags->"5.2.2"],
    Cell[688908, 23247, 1482, 43, 50, "TopBox",
      CellTags->"5.2.2"],
    Cell[690393, 23292, 849, 28, 32, "MiddleSpanBox",
      CellTags->"5.2.2"],
    Cell[691245, 23322, 347, 10, 48, "MiddleBox",
      CellTags->"5.2.2"],
    Cell[691595, 23334, 846, 28, 32, "MiddleSpanBox",
      CellTags->"5.2.2"],
    Cell[692444, 23364, 305, 8, 36, "BottomBox",
      CellTags->"5.2.2"],
    Cell[692752, 23374, 64, 1, 26, "Caption",
      CellTags->"5.2.2"],
    Cell[692819, 23377, 658, 21, 84, "Text",
      CellTags->"5.2.2"],
    Cell[693480, 23400, 67225, 1276, 94, 61700, 1203, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"5.2.2"],
    Cell[760708, 24678, 159, 5, 27, "Caption",
      CellTags->"5.2.2"],
    Cell[760870, 24685, 68, 1, 40, "MathCaption",
      CellTags->"5.2.2"],
    Cell[760941, 24688, 106, 2, 39, "Input",
      CellTags->"5.2.2"],
    Cell[761050, 24692, 67, 1, 40, "MathCaption",
      CellTags->"5.2.2"],
    Cell[761120, 24695, 97, 2, 39, "Input",
      CellTags->"5.2.2"],
    Cell[761220, 24699, 114, 2, 40, "MathCaption",
      CellTags->"5.2.2"],
    Cell[761359, 24705, 82, 2, 39, "Input",
      CellTags->"5.2.2"],
    Cell[761444, 24709, 169, 5, 44, "Output",
      CellTags->"5.2.2"],
    Cell[761628, 24717, 139, 5, 41, "MathCaption",
      CellTags->"5.2.2"],
    Cell[761792, 24726, 85, 2, 39, "Input",
      CellTags->"5.2.2"],
    Cell[761880, 24730, 117917, 3416, 296, 47065, 2535, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.2"],
    Cell[879812, 28149, 1009, 29, 90, "Text",
      CellTags->"5.2.2"],
    Cell[880824, 28180, 190, 5, 48, "MathCaption",
      CellTags->"5.2.2"],
    Cell[881039, 28189, 114, 2, 30, "Input",
      CellTags->"5.2.2"],
    Cell[881156, 28193, 67405, 2582, 296, 44894, 2298, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.2.2"],
    Cell[948564, 30777, 181, 5, 38, "Output",
      CellTags->"5.2.2"],
    Cell[948760, 30785, 634, 14, 124, "Text",
      CellTags->"5.2.2"],
    Cell[949397, 30801, 755, 24, 84, "DefinitionBox3Col",
      CellTags->"5.2.2"],
    Cell[950155, 30827, 122, 5, 26, "Caption",
      CellTags->"5.2.2"],
    Cell[950280, 30834, 383, 13, 76, "Text",
      CellTags->"5.2.2"]},
  "5.3"->{
    Cell[950712, 30853, 61, 1, 68, "Subsection",
      CellTags->"5.3"],
    Cell[950776, 30856, 225, 5, 58, "Text",
      CellTags->"5.3"],
    Cell[951004, 30863, 1274, 38, 50, "TopBox",
      CellTags->"5.3"],
    Cell[952281, 30903, 967, 31, 32, "MiddleSpanBox",
      CellTags->"5.3"],
    Cell[953251, 30936, 2017, 55, 49, "BottomBox",
      CellTags->"5.3"],
    Cell[955271, 30993, 66, 1, 26, "Caption",
      CellTags->"5.3"],
    Cell[955340, 30996, 510, 11, 117, "Text",
      CellTags->"5.3"],
    Cell[955853, 31009, 91, 1, 40, "MathCaption",
      CellTags->"5.3"],
    Cell[955969, 31014, 91, 2, 39, "Input",
      CellTags->"5.3"],
    Cell[956063, 31018, 120, 3, 44, "Output",
      CellTags->"5.3"],
    Cell[956198, 31024, 366, 9, 68, "MathCaption",
      CellTags->"5.3"],
    Cell[956589, 31037, 75, 2, 39, "Input",
      CellTags->"5.3"],
    Cell[956667, 31041, 24612, 731, 296, 8938, 532, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3"],
    Cell[981294, 31775, 475, 9, 109, "Text",
      CellTags->"5.3"],
    Cell[981772, 31786, 585, 19, 48, "MathCaption",
      CellTags->"5.3"],
    Cell[982382, 31809, 94, 2, 30, "Input",
      CellTags->"5.3"],
    Cell[982479, 31813, 123, 3, 42, "Output",
      CellTags->"5.3"],
    Cell[982617, 31819, 84, 1, 40, "MathCaption",
      CellTags->"5.3"],
    Cell[982726, 31824, 105, 2, 39, "Input",
      CellTags->"5.3"],
    Cell[982834, 31828, 28674, 1039, 233, 13876, 850, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.3"],
    Cell[1011523, 32870, 309, 13, 60, "Text",
      CellTags->"5.3"]},
  "5.4"->{
    Cell[1011869, 32888, 61, 1, 68, "Subsection",
      CellTags->"5.4"],
    Cell[1011933, 32891, 237, 6, 59, "Text",
      CellTags->"5.4"],
    Cell[1012173, 32899, 1274, 38, 50, "TopBox",
      CellTags->"5.4"],
    Cell[1013450, 32939, 967, 31, 32, "MiddleSpanBox",
      CellTags->"5.4"],
    Cell[1014420, 32972, 2017, 55, 49, "BottomBox",
      CellTags->"5.4"],
    Cell[1016440, 33029, 66, 1, 26, "Caption",
      CellTags->"5.4"],
    Cell[1016509, 33032, 242, 6, 56, "MathCaption",
      CellTags->"5.4"],
    Cell[1016776, 33042, 126, 5, 54, "Input",
      CellTags->"5.4"],
    Cell[1016905, 33049, 626, 16, 44, "Output",
      CellTags->"5.4"],
    Cell[1017546, 33068, 83, 1, 40, "MathCaption",
      CellTags->"5.4"],
    Cell[1017654, 33073, 75, 2, 39, "Input",
      CellTags->"5.4"],
    Cell[1017732, 33077, 22048, 754, 198, 9372, 592, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.4"],
    Cell[1039783, 33833, 174, 5, 38, "Output",
      CellTags->"5.4"],
    Cell[1039972, 33841, 352, 14, 60, "Text",
      CellTags->"5.4"]},
  "5.5"->{
    Cell[1040361, 33860, 76, 1, 68, "Subsection",
      CellTags->"5.5"],
    Cell[1040440, 33863, 1167, 34, 125, "Text",
      CellTags->"5.5"],
    Cell[1041610, 33899, 387, 14, 48, "TopSpanBox",
      CellTags->"5.5"],
    Cell[1042000, 33915, 956, 26, 23, "MiddleBox",
      CellTags->"5.5"],
    Cell[1042959, 33943, 973, 31, 20, "MiddleSpanBox",
      CellTags->"5.5"],
    Cell[1043935, 33976, 1966, 51, 37, "BottomBox",
      CellTags->"5.5"],
    Cell[1045904, 34029, 81, 1, 14, "Caption",
      CellTags->"5.5"],
    Cell[1045988, 34032, 209, 7, 29, "MathCaption",
      CellTags->"5.5"],
    Cell[1046222, 34043, 150, 6, 57, "Input",
      CellTags->"5.5"],
    Cell[1046375, 34051, 1301, 37, 41, "Output",
      CellTags->"5.5"],
    Cell[1047691, 34091, 105, 2, 28, "MathCaption",
      CellTags->"5.5"],
    Cell[1047821, 34097, 81, 2, 27, "Input",
      CellTags->"5.5"],
    Cell[1047905, 34101, 90246, 2186, 186, 28082, 1413, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"5.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"5.0", 1139096, 36316},
  {"5.1", 1139238, 36321},
  {"5.2", 1142730, 36420},
  {"5.2.1", 1142827, 36423},
  {"5.2.2", 1145217, 36486},
  {"5.3", 1147640, 36551},
  {"5.4", 1149257, 36596},
  {"5.5", 1150338, 36626}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 76, 1, 80, "Section",
  CellTags->"5.0"],
Cell[1810, 54, 550, 12, 114, "Text",
  CellTags->"5.0"],

Cell[CellGroupData[{
Cell[2385, 70, 54, 1, 68, "Subsection",
  CellTags->"5.1"],
Cell[2442, 73, 966, 31, 48, "TopSpanBox",
  CellTags->"5.1"],
Cell[3411, 106, 2359, 64, 49, "BottomBox",
  CellTags->"5.1"],
Cell[5773, 172, 62, 1, 26, "Caption",
  CellTags->"5.1"],
Cell[5838, 175, 921, 23, 147, "Text",
  CellTags->"5.1"],
Cell[6762, 200, 64, 1, 40, "MathCaption",
  CellTags->"5.1"],
Cell[6829, 203, 77, 2, 39, "Input",
  CellTags->"5.1"],
Cell[6909, 207, 86, 1, 40, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[7020, 212, 90, 2, 39, "Input",
  CellTags->"5.1"],
Cell[7113, 216, 117, 3, 42, "Output",
  CellTags->"5.1"]
}, Open  ]],
Cell[7245, 222, 207, 6, 55, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[7477, 232, 89, 2, 39, "Input",
  CellTags->"5.1"],
Cell[7569, 236, 12189, 430, 186, 6061, 348, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.1"]
}, Open  ]],
Cell[19773, 669, 323, 9, 71, "Text",
  CellTags->"5.1"],
Cell[20099, 680, 1329, 43, 103, "DefinitionBox3Col",
  CellTags->"5.1"],
Cell[21431, 725, 117, 5, 16, "Caption",
  CellTags->"5.1"],
Cell[21551, 732, 416, 13, 101, "Text",
  CellTags->"5.1"],
Cell[21970, 747, 70302, 1187, 76, 64268, 1107, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"5.1"],
Cell[92275, 1936, 149, 5, 16, "Caption",
  CellTags->"5.1"],
Cell[92427, 1943, 210, 7, 31, "MathCaption",
  CellTags->"5.1"],
Cell[92640, 1952, 102, 2, 30, "Input",
  CellTags->"5.1"],
Cell[92745, 1956, 193, 7, 31, "MathCaption",
  CellTags->"5.1"],
Cell[92941, 1965, 93, 2, 30, "Input",
  CellTags->"5.1"],
Cell[93037, 1969, 131, 4, 31, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[93193, 1977, 79, 2, 30, "Input",
  CellTags->"5.1"],
Cell[93275, 1981, 167, 5, 44, "Output",
  CellTags->"5.1"]
}, Open  ]],
Cell[93457, 1989, 255, 7, 52, "Text",
  CellTags->"5.1"],
Cell[93715, 1998, 172, 4, 53, "DisplayFormula",
  CellTags->"5.1"],
Cell[93890, 2004, 446, 15, 33, "Text",
  CellTags->"5.1"],
Cell[94339, 2021, 534, 13, 107, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[94898, 2038, 263, 12, 174, "Input",
  CellTags->"5.1"],
Cell[95164, 2052, 16169, 560, 186, 8416, 458, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.1"]
}, Open  ]],
Cell[111348, 2615, 251, 6, 65, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[111624, 2625, 137, 7, 84, "Input",
  CellTags->"5.1"],
Cell[111764, 2634, 122, 3, 29, "Output",
  CellTags->"5.1"]
}, Open  ]],
Cell[111901, 2640, 127, 4, 31, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[112053, 2648, 140, 5, 48, "Input",
  CellTags->"5.1"],
Cell[112196, 2655, 264, 7, 76, "Output",
  CellTags->"5.1"]
}, Open  ]],
Cell[112475, 2665, 251, 6, 65, "MathCaption",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[112751, 2675, 196, 8, 102, "Input",
  CellTags->"5.1"],

Cell[CellGroupData[{
Cell[112972, 2687, 13671, 417, 186, 4786, 301, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.1"],
Cell[126646, 3106, 12741, 393, 198, 4577, 286, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.1"]
}, Open  ]]
}, Open  ]],
Cell[139414, 3503, 502, 12, 93, "Text",
  CellTags->"5.1"],
Cell[139919, 3517, 971, 31, 48, "TopSpanBox",
  CellTags->"5.1"],
Cell[140893, 3550, 2812, 76, 49, "BottomBox",
  CellTags->"5.1"],
Cell[143708, 3628, 63, 1, 26, "Caption",
  CellTags->"5.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143808, 3634, 69, 1, 68, "Subsection",
  CellTags->{"5.2", "5.2.1"}],

Cell[CellGroupData[{
Cell[143902, 3639, 64, 1, 60, "Subsubsection",
  CellTags->"5.2.1"],
Cell[143969, 3642, 744, 16, 143, "Text",
  CellTags->"5.2.1"],
Cell[144716, 3660, 1270, 38, 50, "TopBox",
  CellTags->"5.2.1"],
Cell[145989, 3700, 966, 31, 32, "MiddleSpanBox",
  CellTags->"5.2.1"],
Cell[146958, 3733, 2016, 55, 49, "BottomBox",
  CellTags->"5.2.1"],
Cell[148977, 3790, 65, 1, 26, "Caption",
  CellTags->"5.2.1"],
Cell[149045, 3793, 1418, 42, 162, "Text",
  CellTags->"5.2.1"],
Cell[150466, 3837, 92, 1, 40, "MathCaption",
  CellTags->"5.2.1"],
Cell[150561, 3840, 143, 5, 54, "Input",
  CellTags->"5.2.1"],
Cell[150707, 3847, 199, 5, 54, "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{
Cell[150931, 3856, 81, 2, 39, "Input",
  CellTags->"5.2.1"],
Cell[151015, 3860, 114439, 3382, 296, 53981, 2630, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.1"]
}, Open  ]],
Cell[265469, 7245, 99, 1, 40, "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{
Cell[265593, 7250, 93, 2, 39, "Input",
  CellTags->"5.2.1"],
Cell[265689, 7254, 117852, 3445, 296, 47513, 2571, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.1"]
}, Open  ]],
Cell[383556, 10702, 2519, 69, 396, "Text",
  CellTags->"5.2.1"],
Cell[386078, 10773, 2280, 73, 202, "DefinitionBox3Col",
  CellTags->"5.2.1"],
Cell[388361, 10848, 114, 5, 16, "Caption",
  CellTags->"5.2.1"],
Cell[388478, 10855, 1424, 43, 219, "Text",
  CellTags->"5.2.1"],
Cell[389905, 10900, 234, 5, 54, "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{
Cell[390164, 10909, 146, 6, 69, "Input",
  CellTags->"5.2.1"],
Cell[390313, 10917, 278, 6, 88, "Output",
  CellTags->"5.2.1"]
}, Open  ]],
Cell[390606, 10926, 67, 1, 40, "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{
Cell[390698, 10931, 221, 12, 159, "Input",
  CellTags->"5.2.1"],
Cell[390922, 10945, 141227, 5085, 308, 80003, 4323, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.1"]
}, Open  ]],
Cell[532164, 16033, 632, 17, 99, "MathCaption",
  CellTags->"5.2.1"],

Cell[CellGroupData[{
Cell[532821, 16054, 318, 16, 219, "Input",
  CellTags->"5.2.1"],
Cell[533142, 16072, 154714, 7140, 308, 131296, 6845, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[687905, 23218, 68, 1, 60, "Subsubsection",
  CellTags->"5.2.2"],
Cell[687976, 23221, 929, 24, 143, "Text",
  CellTags->"5.2.2"],
Cell[688908, 23247, 1482, 43, 50, "TopBox",
  CellTags->"5.2.2"],
Cell[690393, 23292, 849, 28, 32, "MiddleSpanBox",
  CellTags->"5.2.2"],
Cell[691245, 23322, 347, 10, 48, "MiddleBox",
  CellTags->"5.2.2"],
Cell[691595, 23334, 846, 28, 32, "MiddleSpanBox",
  CellTags->"5.2.2"],
Cell[692444, 23364, 305, 8, 36, "BottomBox",
  CellTags->"5.2.2"],
Cell[692752, 23374, 64, 1, 26, "Caption",
  CellTags->"5.2.2"],
Cell[692819, 23377, 658, 21, 84, "Text",
  CellTags->"5.2.2"],
Cell[693480, 23400, 67225, 1276, 94, 61700, 1203, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"5.2.2"],
Cell[760708, 24678, 159, 5, 27, "Caption",
  CellTags->"5.2.2"],
Cell[760870, 24685, 68, 1, 40, "MathCaption",
  CellTags->"5.2.2"],
Cell[760941, 24688, 106, 2, 39, "Input",
  CellTags->"5.2.2"],
Cell[761050, 24692, 67, 1, 40, "MathCaption",
  CellTags->"5.2.2"],
Cell[761120, 24695, 97, 2, 39, "Input",
  CellTags->"5.2.2"],
Cell[761220, 24699, 114, 2, 40, "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{
Cell[761359, 24705, 82, 2, 39, "Input",
  CellTags->"5.2.2"],
Cell[761444, 24709, 169, 5, 44, "Output",
  CellTags->"5.2.2"]
}, Open  ]],
Cell[761628, 24717, 139, 5, 41, "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{
Cell[761792, 24726, 85, 2, 39, "Input",
  CellTags->"5.2.2"],
Cell[761880, 24730, 117917, 3416, 296, 47065, 2535, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.2"]
}, Open  ]],
Cell[879812, 28149, 1009, 29, 90, "Text",
  CellTags->"5.2.2"],
Cell[880824, 28180, 190, 5, 48, "MathCaption",
  CellTags->"5.2.2"],

Cell[CellGroupData[{
Cell[881039, 28189, 114, 2, 30, "Input",
  CellTags->"5.2.2"],
Cell[881156, 28193, 67405, 2582, 296, 44894, 2298, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.2.2"],
Cell[948564, 30777, 181, 5, 38, "Output",
  CellTags->"5.2.2"]
}, Open  ]],
Cell[948760, 30785, 634, 14, 124, "Text",
  CellTags->"5.2.2"],
Cell[949397, 30801, 755, 24, 84, "DefinitionBox3Col",
  CellTags->"5.2.2"],
Cell[950155, 30827, 122, 5, 26, "Caption",
  CellTags->"5.2.2"],
Cell[950280, 30834, 383, 13, 76, "Text",
  CellTags->"5.2.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[950712, 30853, 61, 1, 68, "Subsection",
  CellTags->"5.3"],
Cell[950776, 30856, 225, 5, 58, "Text",
  CellTags->"5.3"],
Cell[951004, 30863, 1274, 38, 50, "TopBox",
  CellTags->"5.3"],
Cell[952281, 30903, 967, 31, 32, "MiddleSpanBox",
  CellTags->"5.3"],
Cell[953251, 30936, 2017, 55, 49, "BottomBox",
  CellTags->"5.3"],
Cell[955271, 30993, 66, 1, 26, "Caption",
  CellTags->"5.3"],
Cell[955340, 30996, 510, 11, 117, "Text",
  CellTags->"5.3"],
Cell[955853, 31009, 91, 1, 40, "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{
Cell[955969, 31014, 91, 2, 39, "Input",
  CellTags->"5.3"],
Cell[956063, 31018, 120, 3, 44, "Output",
  CellTags->"5.3"]
}, Open  ]],
Cell[956198, 31024, 366, 9, 68, "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{
Cell[956589, 31037, 75, 2, 39, "Input",
  CellTags->"5.3"],
Cell[956667, 31041, 24612, 731, 296, 8938, 532, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.3"]
}, Open  ]],
Cell[981294, 31775, 475, 9, 109, "Text",
  CellTags->"5.3"],
Cell[981772, 31786, 585, 19, 48, "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{
Cell[982382, 31809, 94, 2, 30, "Input",
  CellTags->"5.3"],
Cell[982479, 31813, 123, 3, 42, "Output",
  CellTags->"5.3"]
}, Open  ]],
Cell[982617, 31819, 84, 1, 40, "MathCaption",
  CellTags->"5.3"],

Cell[CellGroupData[{
Cell[982726, 31824, 105, 2, 39, "Input",
  CellTags->"5.3"],
Cell[982834, 31828, 28674, 1039, 233, 13876, 850, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.3"]
}, Open  ]],
Cell[1011523, 32870, 309, 13, 60, "Text",
  CellTags->"5.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1011869, 32888, 61, 1, 68, "Subsection",
  CellTags->"5.4"],
Cell[1011933, 32891, 237, 6, 59, "Text",
  CellTags->"5.4"],
Cell[1012173, 32899, 1274, 38, 50, "TopBox",
  CellTags->"5.4"],
Cell[1013450, 32939, 967, 31, 32, "MiddleSpanBox",
  CellTags->"5.4"],
Cell[1014420, 32972, 2017, 55, 49, "BottomBox",
  CellTags->"5.4"],
Cell[1016440, 33029, 66, 1, 26, "Caption",
  CellTags->"5.4"],
Cell[1016509, 33032, 242, 6, 56, "MathCaption",
  CellTags->"5.4"],

Cell[CellGroupData[{
Cell[1016776, 33042, 126, 5, 54, "Input",
  CellTags->"5.4"],
Cell[1016905, 33049, 626, 16, 44, "Output",
  CellTags->"5.4"]
}, Open  ]],
Cell[1017546, 33068, 83, 1, 40, "MathCaption",
  CellTags->"5.4"],

Cell[CellGroupData[{
Cell[1017654, 33073, 75, 2, 39, "Input",
  CellTags->"5.4"],
Cell[1017732, 33077, 22048, 754, 198, 9372, 592, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.4"],
Cell[1039783, 33833, 174, 5, 38, "Output",
  CellTags->"5.4"]
}, Open  ]],
Cell[1039972, 33841, 352, 14, 60, "Text",
  CellTags->"5.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1040361, 33860, 76, 1, 68, "Subsection",
  CellTags->"5.5"],
Cell[1040440, 33863, 1167, 34, 125, "Text",
  CellTags->"5.5"],
Cell[1041610, 33899, 387, 14, 48, "TopSpanBox",
  CellTags->"5.5"],
Cell[1042000, 33915, 956, 26, 23, "MiddleBox",
  CellTags->"5.5"],
Cell[1042959, 33943, 973, 31, 20, "MiddleSpanBox",
  CellTags->"5.5"],
Cell[1043935, 33976, 1966, 51, 37, "BottomBox",
  CellTags->"5.5"],
Cell[1045904, 34029, 81, 1, 14, "Caption",
  CellTags->"5.5"],
Cell[1045988, 34032, 209, 7, 29, "MathCaption",
  CellTags->"5.5"],

Cell[CellGroupData[{
Cell[1046222, 34043, 150, 6, 57, "Input",
  CellTags->"5.5"],
Cell[1046375, 34051, 1301, 37, 41, "Output",
  CellTags->"5.5"]
}, Open  ]],
Cell[1047691, 34091, 105, 2, 28, "MathCaption",
  CellTags->"5.5"],

Cell[CellGroupData[{
Cell[1047821, 34097, 81, 2, 27, "Input",
  CellTags->"5.5"],
Cell[1047905, 34101, 90246, 2186, 186, 28082, 1413, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"5.5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

