(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59733,       2042]*)
(*NotebookOutlinePosition[     69560,       2331]*)
(*  CellTagsIndexPosition[     69418,       2322]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Controllability and Observability", "Section",
  CellTags->"7.0"],

Cell["\<\
This chapter describes the tools related to controllability and observability \
of state\[Hyphen]space systems, including the test functions themselves and \
other necessary constructs. \
\>", "Text",
  CellTags->"7.0"],

Cell[CellGroupData[{

Cell["7.1 Controllability and Observability Tests", "Subsection",
  CellTags->"7.1"],

Cell[TextData[{
  "A linear system is said to be ",
  StyleBox["completely controllable", "TI"],
  " if, for all initial times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and all initial states ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((t\_0)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", there exists some input function (or sequence for discrete systems) that \
drives the state vector to any final state ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((t\_1)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " at some finite time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1 > t\_0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". Controllability of the system is determined by matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ". The function ",
  StyleBox["Controllable", "MR"],
  " performs the test. \nAnother kind of controllability may be useful from a \
practical perspective, namely, complete ",
  StyleBox["output controllability", "TI"],
  ", which is defined as the ability to drive the output vector to the origin \
in finite time. This property involves all matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ". The test can be done using the function ",
  StyleBox["OutputControllable", "MR"],
  ". \nAnalogously, a linear system is said to be ",
  StyleBox["completely observable", "TI"],
  " if, for all initial times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", the state vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], \((t\_0)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " can be determined from the output function (or sequence) ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"y\"\>",
            "TB"], \((t\_1)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", defined over a finite time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1 > t\_0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". Consequently, observability involves the matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ". ",
  StyleBox["Observable", "MR"],
  " performs the test. "
}], "Text",
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Controllable",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["test",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["if",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllable",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.36, 0.57}},
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputControllable",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["test",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["if",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllable",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.36, 0.57}},
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Observable",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["test",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["if",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["observable",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.36, 0.57}},
  CellTags->"7.1"],

Cell["Testing controllability and observability properties. ", "Caption",
  CellTags->"7.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"7.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"7.1"],

Cell["\<\
It is easy to show that this system is neither controllable nor \
output controllable.  \
\>", "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{

Cell["\<\
ss = StateSpace[{{0, 1}, {-1, -2}},
 {{1}, {-1}}, {{1, 0}, {1, 1}}]\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"7.1"],

Cell[BoxData[
    \(StateSpace[{{0, 1}, {\(-1\), \(-2\)}}, {{1}, {\(-1\)}}, {{1, 0}, {1, 
          1}}]\)], "Output",
  CellLabel->"Out[2]= ",
  CellTags->"7.1"]
}, Open  ]],

Cell["This tests the controllability. ", "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{

Cell["Controllable[ss]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"7.1"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"7.1"]
}, Open  ]],

Cell["And here is the test for output controllability. ", "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{

Cell["OutputControllable[ss]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"7.1"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"7.1"]
}, Open  ]],

Cell["On the other hand, the system is completely observable. ", "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{

Cell["Observable[ss]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"7.1"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"7.1"]
}, Open  ]],

Cell[TextData[{
  "If for some reason the controllability and observability tests cannot be \
evaluated to ",
  StyleBox["True", "MR"],
  " or ",
  StyleBox["False", "MR"],
  ", they are returned partially unevaluated. In this sense, the tests behave \
more like the ",
  StyleBox["Mathematica", "TI"],
  " built\[Hyphen]in functions ",
  StyleBox["Positive", "MR"],
  ", ",
  StyleBox["Negative", "MR"],
  ", or ",
  StyleBox["Equal", "MR"],
  " rather than the ",
  StyleBox["*Q", "MR"],
  " functions, which ",
  StyleBox["always", "TI"],
  " return ",
  StyleBox["True", "MR"],
  " or ",
  StyleBox["False", "MR"],
  ". "
}], "Text",
  CellTags->"7.1"],

Cell[TextData[{
  "Controllability and observability tests do not necessarily return ",
  StyleBox["True", "MR"],
  " or ",
  StyleBox["False", "MR"],
  ". "
}], "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{

Cell["Controllable[undefinedsystem]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"7.1"],

Cell[BoxData[
    \(Controllable[undefinedsystem]\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"7.1"]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["ControllabilityTest",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(test\ to\ apply\ to\ find\ if\ the\ system\ is\ controllable
                \),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["ObservabilityTest",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(test\ to\ apply\ to\ find\ if\ the\ system\ is\ observable\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.34, 0.3, 0.36},
  RowLines->{True, False}},
  CellTags->"7.1"],

Cell["\<\
Options specific to controllability and observability test \
functions. \
\>", "Caption",
  CellTags->"7.1"],

Cell[TextData[{
  "Controllability and observability can be determined by testing either if \
the controllability or observability matrix has rank ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " is the dimension of the state space, or if the controllability or \
observability Gramian is singular. The tests can be chosen through the \
options ",
  StyleBox["ControllabilityTest", "MR"],
  " and ",
  StyleBox["ObservabilityTest", "MR"],
  ". Both accept a pure function or a list of pure functions to be applied to \
the input arguments in turn until one gives ",
  StyleBox["True", "MR"],
  " or ",
  StyleBox["False", "MR"],
  " or the list is exhausted. By default, both first try the matrix test and \
then the Gramian test. To disable this feature, simply select one desired \
method. "
}], "Text",
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ControllabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "FullRankControllabilityMatrix"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(test\ if\ the\ controllability\ matrix\ is\ full\ rank\ in\ 
                order\ to\ test\ controllability\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ControllabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "NonSingularControllabilityGramian"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(test\ if\ the\ controllability\ Gramian\ is\ nonsingular\ in\ 
                order\ to\ test\ controllability\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ControllabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "test"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["use",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["pure",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["test",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ControllabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{"test1", 
                      StyleBox[",",
                        "MR"], " ", "test2", 
                      StyleBox[",",
                        "MR"], " ", "\[Ellipsis]"}], 
                    StyleBox["}",
                      "MR"]}]}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["try",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["testi",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["turn",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["until",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["one",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["succeeds",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ObservabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "FullRankObservabilityMatrix"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(test\ if\ the\ observability\ matrix\ is\ full\ rank\ in\ 
                order\ to\ test\ controllability\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ObservabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "NonSingularObservabilityGramian"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(test\ if\ the\ observability\ Gramian\ is\ nonsingular\ in\ 
                order\ to\ test\ observability\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ObservabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", "test"}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["use",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["pure",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["test",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"ObservabilityTest", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  RowBox[{
                    StyleBox["{",
                      "MR"], 
                    RowBox[{"test1", 
                      StyleBox[",",
                        "MR"], " ", "test2", 
                      StyleBox[",",
                        "MR"], " ", "\[Ellipsis]"}], 
                    StyleBox["}",
                      "MR"]}]}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["try",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["testi",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["turn",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["until",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["one",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["succeeds",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"7.1"],

Cell["Selecting controllability and observability tests. ", "Caption",
  CellTags->"7.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Controllability and Observability Constructs", "Subsection",
  CellTags->"7.2"],

Cell["\<\
The controllability matrix for a linear system is defined as \
\>", 
  "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"C", "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox["\<\"B\"\>",
                  "TB"], 
                StyleBox[\("A" "B"\),
                  "TB"], 
                StyleBox[
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], "2"], 
                    StyleBox["\<\"B\"\>",
                      "TB"]}],
                  "InlineFormula"], 
                StyleBox["\[CenterEllipsis]",
                  "InlineFormula"], 
                StyleBox[
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], \(n - 1\)], 
                    StyleBox["\<\"B\"\>",
                      "TB"]}],
                  "InlineFormula"]}
              },
            ColumnAlignments->{Decimal}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"7.2"],

Cell[TextData[{
  "and can be obtained with ",
  StyleBox["ControllabilityMatrix", "MR"],
  ". The output controllability matrix, "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"P", "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox[\("C" "B"\),
                  "TB"], 
                StyleBox[\("C" "A" "B"\),
                  "TB"], 
                StyleBox[
                  RowBox[{
                    StyleBox["\<\"C\"\>",
                      "TB"], 
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], "2"], 
                    StyleBox["\<\"B\"\>",
                      "TB"]}],
                  "InlineFormula"], 
                StyleBox["\[CenterEllipsis]",
                  "InlineFormula"], 
                StyleBox[
                  RowBox[{
                    StyleBox["\<\"C\"\>",
                      "TB"], 
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], \(n - 1\)], 
                    StyleBox["\<\"B\"\>",
                      "TB"]}],
                  "InlineFormula"], 
                StyleBox["\<\"D\"\>",
                  "TB"]}
              },
            ColumnAlignments->{Decimal}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"7.2"],

Cell[TextData[{
  "can be found with ",
  StyleBox["OutputControllabilityMatrix", "MR"],
  ". The observability matrix, "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"O", "=", 
        RowBox[{"[", GridBox[{
              {
                StyleBox["\<\"C\"\>",
                  "TB"]},
              {
                StyleBox[\("C" "A"\),
                  "TB"]},
              {
                StyleBox[
                  RowBox[{
                    StyleBox["\<\"C\"\>",
                      "TB"], 
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], "2"]}],
                  "InlineFormula"]},
              {
                StyleBox["\[VerticalEllipsis]",
                  "InlineFormula"]},
              {
                StyleBox[
                  RowBox[{
                    StyleBox["\<\"C\"\>",
                      "TB"], 
                    SuperscriptBox[
                      StyleBox["\<\"A\"\>",
                        "TB"], \(n - 1\)]}],
                  "InlineFormula"]}
              },
            ColumnAlignments->{Decimal}], "]"}]}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"7.2"],

Cell[TextData[{
  "is obtainable with ",
  StyleBox["ObservabilityMatrix", "MR"],
  ". "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ControllabilityMatrix",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["returns",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllability",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["OutputControllabilityMatrix",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["returns",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["output",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllability",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ObservabilityMatrix",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["returns",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["observability",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell["Finding controllability and observability matrices. ", "Caption",
  CellTags->"7.2"],

Cell["This is a simple test system. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["\<\
system = StateSpace[
 {{-3, 1, 0}, {-5, 0, 1}, {-3, 0, 0}},
 {{1}, {2}, {3}},
 {{1, 0, 0}}
]\
\>", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    \(StateSpace[{{\(-3\), 1, 0}, {\(-5\), 0, 1}, {\(-3\), 0, 0}}, {{1}, {
          2}, {3}}, {{1, 0, 0}}]\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["This is its controllability matrix. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["ControllabilityMatrix[system]//MatrixForm", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", \(-1\), "1"},
            {"2", \(-2\), "2"},
            {"3", \(-3\), "3"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["\<\
Clearly, this is not a full\[Hyphen]rank matrix and, therefore, the \
system is not completely controllable. \
\>", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["Rank[%]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["We can come to this conclusion directly. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["Controllable[system]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["This is the observability matrix for the system. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["ObservabilityMatrix[system]//MatrixForm", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0"},
            {\(-3\), "1", "0"},
            {"4", \(-3\), "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[11]//MatrixForm= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["\<\
This is a full\[Hyphen]rank matrix, so the system is completely \
observable. \
\>", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["Rank[%]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"7.2"]
}, Open  ]],

Cell["Again, we can come to this conclusion directly. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["Observable[system]", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[13]= ",
  CellTags->"7.2"]
}, Open  ]],

Cell[TextData[{
  "Equally important in controllability and observability studies are the \
corresponding Gramians, which may be defined as (see, ",
  StyleBox["e.g.", "TI"],
  ", Moore (1981), Levine (1996))  "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox[
          StyleBox["\<\"W\"\>",
            "TB"], 
          StyleBox["\<\"c\"\>",
            "TB"], 
          StyleBox["\<\"2\"\>",
            "TB"]], "=", \(\[Integral]\_0\%\[Infinity]\), 
        SuperscriptBox["e", 
          RowBox[{
            StyleBox["\<\"A\"\>",
              "TB"], "\[Tau]"}]], 
        StyleBox["\<\"B\"\>",
          "TB"], 
        SuperscriptBox[
          StyleBox["\<\"B\"\>",
            "TB"], "T"], 
        SuperscriptBox["e", 
          RowBox[{
            SuperscriptBox[
              StyleBox["\<\"A\"\>",
                "TB"], "T"], "\[Tau]"}]], "d", "\[Tau]"}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"7.2"],

Cell["(the controllability Gramian) and ", "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        SubsuperscriptBox[
          StyleBox["\<\"W\"\>",
            "TB"], 
          StyleBox["\<\"o\"\>",
            "TB"], 
          StyleBox["\<\"2\"\>",
            "TB"]], "=", \(\[Integral]\_0\%\[Infinity]\), 
        SuperscriptBox["e", 
          RowBox[{
            SuperscriptBox[
              StyleBox["\<\"A\"\>",
                "TB"], "T"], "\[Tau]"}]], 
        SuperscriptBox[
          StyleBox["\<\"C\"\>",
            "TB"], "T"], 
        StyleBox["\<\"C\"\>",
          "TB"], 
        SuperscriptBox["e", 
          RowBox[{
            StyleBox["\<\"A\"\>",
              "TB"], "\[Tau]"}]], "d", "\[Tau]"}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"7.2"],

Cell["\<\
(the observability Gramian). Examples of using the Gramians can be \
found later in Section\[NonBreakingSpace]8.4. \
\>", "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ControllabilityGramian",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllability",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Gramian",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ObservabilityGramian",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["observability",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Gramian",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell["Finding controllability and observability Gramians. ", "Caption",
  CellTags->"7.2"],

Cell["\<\
This is a mixing tank system (to be described in detail later). \
\
\>", "MathCaption",
  CellTags->"7.2"],

Cell["\<\
StateSpace[
 {{0.9512, 0}, {0, 0.9048}},
 {{4.88, 4.88}, {-0.019, 0.0095}},
 {{0.01, 0}, {0, 1}},
 Sampled -> Period[5.]];\
\>", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"7.2"],

Cell["Here is its controllability Gramian. ", "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{

Cell["ControllabilityGramian[%]//MatrixForm", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"7.2"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"500.205002050021985`", \(-0.332677355206415503`\)},
            {\(-0.33267735520641537`\), "0.00248846126018656343`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[15]//MatrixForm= ",
  CellTags->"7.2"]
}, Open  ]],

Cell[TextData[{
  StyleBox["ControllabilityGramian", "MR"],
  " and ",
  StyleBox["ObservabilityGramian", "MR"],
  " rely on the function ",
  StyleBox["LyapunovSolve", "MR"],
  " to solve Lyapunov equations regarding ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["\<\"W\"\>",
            "TB"], 
          StyleBox["\<\"c\"\>",
            "TB"], 
          StyleBox["\<\"2\"\>",
            "TB"]], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox["\<\"W\"\>",
            "TB"], 
          StyleBox["\<\"o\"\>",
            "TB"], 
          StyleBox["\<\"2\"\>",
            "TB"]], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ":  "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"A\"\>",
                  "TB"], 
                SubsuperscriptBox[
                  StyleBox["\<\"W\"\>",
                    "TB"], 
                  StyleBox["\<\"c\"\>",
                    "TB"], 
                  StyleBox["\<\"2\"\>",
                    "TB"]], "+", 
                SubsuperscriptBox[
                  StyleBox["\<\"W\"\>",
                    "TB"], 
                  StyleBox["\<\"c\"\>",
                    "TB"], 
                  StyleBox["\<\"2\"\>",
                    "TB"]], 
                SuperscriptBox[
                  StyleBox["\<\"A\"\>",
                    "TB"], "T"], "=", "-", 
                StyleBox["\<\"B\"\>",
                  "TB"], 
                SuperscriptBox[
                  StyleBox["\<\"B\"\>",
                    "TB"], "T"]}],
              "InlineFormula"]},
          {
            StyleBox[
              RowBox[{
                SuperscriptBox[
                  StyleBox["\<\"A\"\>",
                    "TB"], "T"], 
                SubsuperscriptBox[
                  StyleBox["\<\"W\"\>",
                    "TB"], 
                  StyleBox["\<\"o\"\>",
                    "TB"], 
                  StyleBox["\<\"2\"\>",
                    "TB"]], "+", 
                SubsuperscriptBox[
                  StyleBox["\<\"W\"\>",
                    "TB"], 
                  StyleBox["\<\"o\"\>",
                    "TB"], 
                  StyleBox["\<\"2\"\>",
                    "TB"]], 
                StyleBox["\<\"A\"\>",
                  "TB"], "=", "-", 
                SuperscriptBox[
                  StyleBox["\<\"C\"\>",
                    "TB"], "T"], 
                StyleBox["\<\"C\"\>",
                  "TB"]}],
              "InlineFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"7.2"],

Cell[TextData[{
  "Consequently, these functions accept the same options as ",
  StyleBox["LyapunovSolve", "MR"],
  " does. For discrete\[Hyphen]time systems, ",
  StyleBox["ControllabilityGramian", "MR"],
  " and ",
  StyleBox["ObservabilityGramian", "MR"],
  " call ",
  StyleBox["DiscreteLyapunovSolve", "MR"],
  " appropriately. \nThe Gramian functions sometimes must reconstruct the \
full orthogonal basis of the vector space given a few orthogonal vectors \
belonging to the basis\[LongDash]a problem that may have more than one \
solution. In such cases, the choice between equivalent vectors is made \
randomly. You may disable this feature by setting the option ",
  StyleBox["RandomOrthogonalComplement", "MR"],
  " to ",
  StyleBox["False", "MR"],
  ". The same mechanism is used by several other functions, for example, \
Kalman transform functions and the ",
  StyleBox["KNVD", "MR"],
  " algorithm in ",
  StyleBox["StateFeedbackGains", "MR"],
  ". To have them all behave deterministically, you may change the global \
variable ",
  StyleBox["$RandomOrthogonalComplement", "MR"],
  " to ",
  StyleBox["False", "MR"],
  ". Of course, reseeding the random number generator with some number (using \
",
  StyleBox["SeedRandom", "MR"],
  ") will also make the result reproducible.   "
}], "Text",
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"RandomOrthogonalComplement", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  StyleBox["False",
                    "MR"]}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(set\ the\ seterministic\ behavior\ in\ a\ particular\ function
                \),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"$RandomOrthogonalComplement", " ", 
                  StyleBox["=",
                    "MR"], " ", 
                  StyleBox["False",
                    "MR"]}],
                "TraditionalForm"],
              "TI"]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(set\ the\ deterministic\ behavior\ in\ all\ functions\ that\ 
                  rely\ on\ the\ random - 
                number\ generator\ in\ reconstructing\ the\ orthogonal\ vector
                  \ basis\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"7.2"],

Cell["\<\
Canceling the use of random choice between equivalent orthogonal \
vectors. \
\>", "Caption",
  CellTags->"7.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.3 Dual System", "Subsection",
  CellTags->"7.3"],

Cell[TextData[{
  "The function ",
  StyleBox["DualSystem", "MR"],
  " returns the system that is dual to the input system. It is useful because \
observability tests are often implemented as controllability tests of the \
dual system to the one in question. "
}], "Text",
  CellTags->"7.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DualSystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["that",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["dual",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.32, 0.68}},
  CellTags->"7.3"],

Cell["Finding the dual system. ", "Caption",
  CellTags->"7.3"],

Cell["This is a system in state\[Hyphen]space form. ", "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{

Cell["\<\
StateSpace[{{0, 1}, {a1, a2}},
 {{1}, {-1}}, {{1, 0}, {1, 1}}]//ReviewForm\
\>", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"7.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1"},
                  {"a1", "a2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1"},
                  {\(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "0"},
                  {"1", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[16]//ReviewForm= ",
  CellTags->"7.3"]
}, Open  ]],

Cell["This is its dual system. ", "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{

Cell["DualSystem[%]//ReviewForm", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"7.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", \(Conjugate[a1]\)},
                  {"1", \(Conjugate[a2]\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "1"},
                  {"0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[17]//ReviewForm= ",
  CellTags->"7.3"]
}, Open  ]],

Cell[TextData[{
  "By default, ",
  StyleBox["DualSystem", "MR"],
  " assumes that all symbolic entries in state\[Hyphen]space representation \
can be complex. The user may disable this feature by setting the option ",
  StyleBox["ComplexVariables", "MR"],
  " to ",
  StyleBox["None", "MR"],
  ", in which case the built\[Hyphen]in function ",
  StyleBox["ComplexExpand", "MR"],
  " will be applied to the result. ",
  StyleBox["ComplexVariables", "MR"],
  " accepts also a list of variables which may be complex. In this case, all \
other variables are assumed to be real valued. "
}], "Text",
  CellTags->"7.3"],

Cell["\<\
If we assume that none of the symbolic entries are complex, a \
simpler result is returned. \
\>", "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{

Cell["DualSystem[%%, ComplexVariables -> None]//ReviewForm", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"7.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "a1"},
                  {"1", "a2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "1"},
                  {"0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[18]//ReviewForm= ",
  CellTags->"7.3"]
}, Open  ]],

Cell[TextData[{
  "Finally, here is the dual system if only ",
  StyleBox["a1", "MR"],
  " may be complex. "
}], "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{

Cell["DualSystem[%%%, ComplexVariables -> {a1}]//ReviewForm", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"7.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", \(Conjugate[a1]\)},
                  {"1", "a2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "1"},
                  {"0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[19]//ReviewForm= ",
  CellTags->"7.3"]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["ComplexVariables",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["All",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(which\ symbloic\ entries\ in\ state - 
                space\ representation\ should\ be\ assumed\ to\ be\ complex
                  \),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.27, 0.3, 0.43},
  RowLines->{True, False}},
  CellTags->"7.3"],

Cell[TextData[{
  "Option to ",
  StyleBox["DualSystem", "MR"],
  ". "
}], "Caption",
  CellTags->"7.3"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{2, Automatic}, {Automatic, 9}},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "7.0"->{
    Cell[1731, 51, 74, 1, 80, "Section",
      CellTags->"7.0"],
    Cell[1808, 54, 229, 5, 58, "Text",
      CellTags->"7.0"]},
  "7.1"->{
    Cell[2062, 63, 84, 1, 68, "Subsection",
      CellTags->"7.1"],
    Cell[2149, 66, 3468, 110, 243, "Text",
      CellTags->"7.1"],
    Cell[5620, 178, 1484, 43, 50, "TopBox",
      CellTags->"7.1"],
    Cell[7107, 223, 395, 14, 32, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[7505, 239, 1394, 38, 48, "MiddleBox",
      CellTags->"7.1"],
    Cell[8902, 279, 1483, 43, 36, "BottomBox",
      CellTags->"7.1"],
    Cell[10388, 324, 92, 1, 26, "Caption",
      CellTags->"7.1"],
    Cell[10483, 327, 64, 1, 40, "MathCaption",
      CellTags->"7.1"],
    Cell[10550, 330, 77, 2, 39, "Input",
      CellTags->"7.1"],
    Cell[10630, 334, 138, 4, 54, "MathCaption",
      CellTags->"7.1"],
    Cell[10793, 342, 136, 5, 54, "Input",
      CellTags->"7.1"],
    Cell[10932, 349, 162, 4, 53, "Output",
      CellTags->"7.1"],
    Cell[11109, 356, 74, 1, 40, "MathCaption",
      CellTags->"7.1"],
    Cell[11208, 361, 77, 2, 39, "Input",
      CellTags->"7.1"],
    Cell[11288, 365, 83, 3, 38, "Output",
      CellTags->"7.1"],
    Cell[11386, 371, 91, 1, 40, "MathCaption",
      CellTags->"7.1"],
    Cell[11502, 376, 83, 2, 39, "Input",
      CellTags->"7.1"],
    Cell[11588, 380, 83, 3, 26, "Output",
      CellTags->"7.1"],
    Cell[11686, 386, 98, 1, 28, "MathCaption",
      CellTags->"7.1"],
    Cell[11809, 391, 75, 2, 27, "Input",
      CellTags->"7.1"],
    Cell[11887, 395, 82, 3, 26, "Output",
      CellTags->"7.1"],
    Cell[11984, 401, 656, 25, 82, "Text",
      CellTags->"7.1"],
    Cell[12643, 428, 195, 7, 29, "MathCaption",
      CellTags->"7.1"],
    Cell[12863, 439, 90, 2, 27, "Input",
      CellTags->"7.1"],
    Cell[12956, 443, 107, 3, 26, "Output",
      CellTags->"7.1"],
    Cell[13078, 449, 1186, 38, 106, "DefinitionBox3Col",
      CellTags->"7.1"],
    Cell[14267, 489, 118, 4, 14, "Caption",
      CellTags->"7.1"],
    Cell[14388, 495, 974, 25, 129, "Text",
      CellTags->"7.1"],
    Cell[15365, 522, 391, 12, 38, "TopSpanBox",
      CellTags->"7.1"],
    Cell[15759, 536, 347, 10, 36, "MiddleBox",
      CellTags->"7.1"],
    Cell[16109, 548, 398, 12, 31, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[16510, 562, 349, 10, 36, "MiddleBox",
      CellTags->"7.1"],
    Cell[16862, 574, 369, 12, 31, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[17234, 588, 882, 25, 23, "MiddleBox",
      CellTags->"7.1"],
    Cell[18119, 615, 728, 22, 31, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[18850, 639, 1184, 33, 23, "MiddleBox",
      CellTags->"7.1"],
    Cell[20037, 674, 390, 12, 32, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[20430, 688, 345, 10, 48, "MiddleBox",
      CellTags->"7.1"],
    Cell[20778, 700, 394, 12, 32, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[21175, 714, 345, 10, 48, "MiddleBox",
      CellTags->"7.1"],
    Cell[21523, 726, 367, 12, 32, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[21893, 740, 882, 25, 35, "MiddleBox",
      CellTags->"7.1"],
    Cell[22778, 767, 726, 22, 32, "MiddleSpanBox",
      CellTags->"7.1"],
    Cell[23507, 791, 1184, 33, 36, "BottomBox",
      CellTags->"7.1"],
    Cell[24694, 826, 89, 1, 26, "Caption",
      CellTags->"7.1"]},
  "7.2"->{
    Cell[24820, 832, 89, 1, 68, "Subsection",
      CellTags->"7.2"],
    Cell[24912, 835, 107, 4, 42, "Text",
      CellTags->"7.2"],
    Cell[25022, 841, 1003, 30, 43, "DisplayFormula",
      CellTags->"7.2"],
    Cell[26028, 873, 162, 5, 43, "Text",
      CellTags->"7.2"],
    Cell[26193, 880, 1215, 36, 43, "DisplayFormula",
      CellTags->"7.2"],
    Cell[27411, 918, 152, 5, 43, "Text",
      CellTags->"7.2"],
    Cell[27566, 925, 1069, 34, 122, "DisplayFormula",
      CellTags->"7.2"],
    Cell[28638, 961, 119, 5, 43, "Text",
      CellTags->"7.2"],
    Cell[28760, 968, 395, 14, 48, "TopSpanBox",
      CellTags->"7.2"],
    Cell[29158, 984, 1354, 37, 48, "MiddleBox",
      CellTags->"7.2"],
    Cell[30515, 1023, 404, 14, 32, "MiddleSpanBox",
      CellTags->"7.2"],
    Cell[30922, 1039, 1507, 41, 48, "MiddleBox",
      CellTags->"7.2"],
    Cell[32432, 1082, 396, 14, 32, "MiddleSpanBox",
      CellTags->"7.2"],
    Cell[32831, 1098, 1352, 37, 49, "BottomBox",
      CellTags->"7.2"],
    Cell[34186, 1137, 90, 1, 26, "Caption",
      CellTags->"7.2"],
    Cell[34279, 1140, 72, 1, 40, "MathCaption",
      CellTags->"7.2"],
    Cell[34376, 1145, 161, 8, 99, "Input",
      CellTags->"7.2"],
    Cell[34540, 1155, 179, 4, 53, "Output",
      CellTags->"7.2"],
    Cell[34734, 1162, 78, 1, 40, "MathCaption",
      CellTags->"7.2"],
    Cell[34837, 1167, 102, 2, 39, "Input",
      CellTags->"7.2"],
    Cell[34942, 1171, 265, 9, 68, "Output",
      CellTags->"7.2"],
    Cell[35222, 1183, 159, 4, 44, "MathCaption",
      CellTags->"7.2"],
    Cell[35406, 1191, 68, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[35477, 1195, 79, 3, 26, "Output",
      CellTags->"7.2"],
    Cell[35571, 1201, 83, 1, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[35679, 1206, 82, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[35764, 1210, 84, 3, 26, "Output",
      CellTags->"7.2"],
    Cell[35863, 1216, 91, 1, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[35979, 1221, 101, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[36083, 1225, 263, 9, 68, "Output",
      CellTags->"7.2"],
    Cell[36361, 1237, 128, 4, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[36514, 1245, 69, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[36586, 1249, 80, 3, 26, "Output",
      CellTags->"7.2"],
    Cell[36681, 1255, 90, 1, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[36796, 1260, 80, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[36879, 1264, 83, 3, 26, "Output",
      CellTags->"7.2"],
    Cell[36977, 1270, 242, 6, 48, "Text",
      CellTags->"7.2"],
    Cell[37222, 1278, 740, 25, 34, "DisplayFormula",
      CellTags->"7.2"],
    Cell[37965, 1305, 69, 1, 31, "Text",
      CellTags->"7.2"],
    Cell[38037, 1308, 740, 25, 34, "DisplayFormula",
      CellTags->"7.2"],
    Cell[38780, 1335, 158, 4, 31, "Text",
      CellTags->"7.2"],
    Cell[38941, 1341, 396, 14, 39, "TopSpanBox",
      CellTags->"7.2"],
    Cell[39340, 1357, 1352, 37, 38, "MiddleBox",
      CellTags->"7.2"],
    Cell[40695, 1396, 397, 14, 33, "MiddleSpanBox",
      CellTags->"7.2"],
    Cell[41095, 1412, 1350, 37, 46, "BottomBox",
      CellTags->"7.2"],
    Cell[42448, 1451, 90, 1, 14, "Caption",
      CellTags->"7.2"],
    Cell[42541, 1454, 116, 4, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[42660, 1460, 192, 8, 87, "Input",
      CellTags->"7.2"],
    Cell[42855, 1470, 79, 1, 29, "MathCaption",
      CellTags->"7.2"],
    Cell[42959, 1475, 99, 2, 27, "Input",
      CellTags->"7.2"],
    Cell[43061, 1479, 304, 8, 52, "Output",
      CellTags->"7.2"],
    Cell[43380, 1490, 820, 30, 48, "Text",
      CellTags->"7.2"],
    Cell[44203, 1522, 1991, 60, 50, "DisplayFormula",
      CellTags->"7.2"],
    Cell[46197, 1584, 1327, 32, 236, "Text",
      CellTags->"7.2"],
    Cell[47527, 1618, 429, 14, 48, "TopSpanBox",
      CellTags->"7.2"],
    Cell[47959, 1634, 317, 10, 35, "MiddleBox",
      CellTags->"7.2"],
    Cell[48279, 1646, 432, 14, 32, "MiddleSpanBox",
      CellTags->"7.2"],
    Cell[48714, 1662, 447, 12, 62, "BottomBox",
      CellTags->"7.2"],
    Cell[49164, 1676, 122, 4, 26, "Caption",
      CellTags->"7.2"]},
  "7.3"->{
    Cell[49323, 1685, 56, 1, 68, "Subsection",
      CellTags->"7.3"],
    Cell[49382, 1688, 291, 7, 75, "Text",
      CellTags->"7.3"],
    Cell[49676, 1697, 1782, 51, 51, "DefinitionBox",
      CellTags->"7.3"],
    Cell[51461, 1750, 63, 1, 26, "Caption",
      CellTags->"7.3"],
    Cell[51527, 1753, 88, 1, 40, "MathCaption",
      CellTags->"7.3"],
    Cell[51640, 1758, 144, 5, 54, "Input",
      CellTags->"7.3"],
    Cell[51787, 1765, 1393, 45, 139, "Output",
      CellTags->"7.3"],
    Cell[53195, 1813, 67, 1, 40, "MathCaption",
      CellTags->"7.3"],
    Cell[53287, 1818, 87, 2, 39, "Input",
      CellTags->"7.3"],
    Cell[53377, 1822, 1399, 44, 124, "Output",
      CellTags->"7.3"],
    Cell[54791, 1869, 614, 15, 110, "Text",
      CellTags->"7.3"],
    Cell[55408, 1886, 142, 4, 54, "MathCaption",
      CellTags->"7.3"],
    Cell[55575, 1894, 114, 2, 54, "Input",
      CellTags->"7.3"],
    Cell[55692, 1898, 1373, 44, 124, "Output",
      CellTags->"7.3"],
    Cell[57080, 1945, 146, 5, 41, "MathCaption",
      CellTags->"7.3"],
    Cell[57251, 1954, 115, 2, 54, "Input",
      CellTags->"7.3"],
    Cell[57369, 1958, 1386, 44, 113, "Output",
      CellTags->"7.3"],
    Cell[58770, 2005, 828, 26, 85, "DefinitionBox3Col",
      CellTags->"7.3"],
    Cell[59601, 2033, 104, 5, 14, "Caption",
      CellTags->"7.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"7.0", 60584, 2064},
  {"7.1", 60724, 2069},
  {"7.2", 63889, 2160},
  {"7.3", 68052, 2279}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 74, 1, 80, "Section",
  CellTags->"7.0"],
Cell[1808, 54, 229, 5, 58, "Text",
  CellTags->"7.0"],

Cell[CellGroupData[{
Cell[2062, 63, 84, 1, 68, "Subsection",
  CellTags->"7.1"],
Cell[2149, 66, 3468, 110, 243, "Text",
  CellTags->"7.1"],
Cell[5620, 178, 1484, 43, 50, "TopBox",
  CellTags->"7.1"],
Cell[7107, 223, 395, 14, 32, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[7505, 239, 1394, 38, 48, "MiddleBox",
  CellTags->"7.1"],
Cell[8902, 279, 1483, 43, 36, "BottomBox",
  CellTags->"7.1"],
Cell[10388, 324, 92, 1, 26, "Caption",
  CellTags->"7.1"],
Cell[10483, 327, 64, 1, 40, "MathCaption",
  CellTags->"7.1"],
Cell[10550, 330, 77, 2, 39, "Input",
  CellTags->"7.1"],
Cell[10630, 334, 138, 4, 54, "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{
Cell[10793, 342, 136, 5, 54, "Input",
  CellTags->"7.1"],
Cell[10932, 349, 162, 4, 53, "Output",
  CellTags->"7.1"]
}, Open  ]],
Cell[11109, 356, 74, 1, 40, "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{
Cell[11208, 361, 77, 2, 39, "Input",
  CellTags->"7.1"],
Cell[11288, 365, 83, 3, 38, "Output",
  CellTags->"7.1"]
}, Open  ]],
Cell[11386, 371, 91, 1, 40, "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{
Cell[11502, 376, 83, 2, 39, "Input",
  CellTags->"7.1"],
Cell[11588, 380, 83, 3, 26, "Output",
  CellTags->"7.1"]
}, Open  ]],
Cell[11686, 386, 98, 1, 28, "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{
Cell[11809, 391, 75, 2, 27, "Input",
  CellTags->"7.1"],
Cell[11887, 395, 82, 3, 26, "Output",
  CellTags->"7.1"]
}, Open  ]],
Cell[11984, 401, 656, 25, 82, "Text",
  CellTags->"7.1"],
Cell[12643, 428, 195, 7, 29, "MathCaption",
  CellTags->"7.1"],

Cell[CellGroupData[{
Cell[12863, 439, 90, 2, 27, "Input",
  CellTags->"7.1"],
Cell[12956, 443, 107, 3, 26, "Output",
  CellTags->"7.1"]
}, Open  ]],
Cell[13078, 449, 1186, 38, 106, "DefinitionBox3Col",
  CellTags->"7.1"],
Cell[14267, 489, 118, 4, 14, "Caption",
  CellTags->"7.1"],
Cell[14388, 495, 974, 25, 129, "Text",
  CellTags->"7.1"],
Cell[15365, 522, 391, 12, 38, "TopSpanBox",
  CellTags->"7.1"],
Cell[15759, 536, 347, 10, 36, "MiddleBox",
  CellTags->"7.1"],
Cell[16109, 548, 398, 12, 31, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[16510, 562, 349, 10, 36, "MiddleBox",
  CellTags->"7.1"],
Cell[16862, 574, 369, 12, 31, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[17234, 588, 882, 25, 23, "MiddleBox",
  CellTags->"7.1"],
Cell[18119, 615, 728, 22, 31, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[18850, 639, 1184, 33, 23, "MiddleBox",
  CellTags->"7.1"],
Cell[20037, 674, 390, 12, 32, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[20430, 688, 345, 10, 48, "MiddleBox",
  CellTags->"7.1"],
Cell[20778, 700, 394, 12, 32, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[21175, 714, 345, 10, 48, "MiddleBox",
  CellTags->"7.1"],
Cell[21523, 726, 367, 12, 32, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[21893, 740, 882, 25, 35, "MiddleBox",
  CellTags->"7.1"],
Cell[22778, 767, 726, 22, 32, "MiddleSpanBox",
  CellTags->"7.1"],
Cell[23507, 791, 1184, 33, 36, "BottomBox",
  CellTags->"7.1"],
Cell[24694, 826, 89, 1, 26, "Caption",
  CellTags->"7.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24820, 832, 89, 1, 68, "Subsection",
  CellTags->"7.2"],
Cell[24912, 835, 107, 4, 42, "Text",
  CellTags->"7.2"],
Cell[25022, 841, 1003, 30, 43, "DisplayFormula",
  CellTags->"7.2"],
Cell[26028, 873, 162, 5, 43, "Text",
  CellTags->"7.2"],
Cell[26193, 880, 1215, 36, 43, "DisplayFormula",
  CellTags->"7.2"],
Cell[27411, 918, 152, 5, 43, "Text",
  CellTags->"7.2"],
Cell[27566, 925, 1069, 34, 122, "DisplayFormula",
  CellTags->"7.2"],
Cell[28638, 961, 119, 5, 43, "Text",
  CellTags->"7.2"],
Cell[28760, 968, 395, 14, 48, "TopSpanBox",
  CellTags->"7.2"],
Cell[29158, 984, 1354, 37, 48, "MiddleBox",
  CellTags->"7.2"],
Cell[30515, 1023, 404, 14, 32, "MiddleSpanBox",
  CellTags->"7.2"],
Cell[30922, 1039, 1507, 41, 48, "MiddleBox",
  CellTags->"7.2"],
Cell[32432, 1082, 396, 14, 32, "MiddleSpanBox",
  CellTags->"7.2"],
Cell[32831, 1098, 1352, 37, 49, "BottomBox",
  CellTags->"7.2"],
Cell[34186, 1137, 90, 1, 26, "Caption",
  CellTags->"7.2"],
Cell[34279, 1140, 72, 1, 40, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[34376, 1145, 161, 8, 99, "Input",
  CellTags->"7.2"],
Cell[34540, 1155, 179, 4, 53, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[34734, 1162, 78, 1, 40, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[34837, 1167, 102, 2, 39, "Input",
  CellTags->"7.2"],
Cell[34942, 1171, 265, 9, 68, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[35222, 1183, 159, 4, 44, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[35406, 1191, 68, 2, 27, "Input",
  CellTags->"7.2"],
Cell[35477, 1195, 79, 3, 26, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[35571, 1201, 83, 1, 29, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[35679, 1206, 82, 2, 27, "Input",
  CellTags->"7.2"],
Cell[35764, 1210, 84, 3, 26, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[35863, 1216, 91, 1, 29, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[35979, 1221, 101, 2, 27, "Input",
  CellTags->"7.2"],
Cell[36083, 1225, 263, 9, 68, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[36361, 1237, 128, 4, 29, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[36514, 1245, 69, 2, 27, "Input",
  CellTags->"7.2"],
Cell[36586, 1249, 80, 3, 26, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[36681, 1255, 90, 1, 29, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[36796, 1260, 80, 2, 27, "Input",
  CellTags->"7.2"],
Cell[36879, 1264, 83, 3, 26, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[36977, 1270, 242, 6, 48, "Text",
  CellTags->"7.2"],
Cell[37222, 1278, 740, 25, 34, "DisplayFormula",
  CellTags->"7.2"],
Cell[37965, 1305, 69, 1, 31, "Text",
  CellTags->"7.2"],
Cell[38037, 1308, 740, 25, 34, "DisplayFormula",
  CellTags->"7.2"],
Cell[38780, 1335, 158, 4, 31, "Text",
  CellTags->"7.2"],
Cell[38941, 1341, 396, 14, 39, "TopSpanBox",
  CellTags->"7.2"],
Cell[39340, 1357, 1352, 37, 38, "MiddleBox",
  CellTags->"7.2"],
Cell[40695, 1396, 397, 14, 33, "MiddleSpanBox",
  CellTags->"7.2"],
Cell[41095, 1412, 1350, 37, 46, "BottomBox",
  CellTags->"7.2"],
Cell[42448, 1451, 90, 1, 14, "Caption",
  CellTags->"7.2"],
Cell[42541, 1454, 116, 4, 29, "MathCaption",
  CellTags->"7.2"],
Cell[42660, 1460, 192, 8, 87, "Input",
  CellTags->"7.2"],
Cell[42855, 1470, 79, 1, 29, "MathCaption",
  CellTags->"7.2"],

Cell[CellGroupData[{
Cell[42959, 1475, 99, 2, 27, "Input",
  CellTags->"7.2"],
Cell[43061, 1479, 304, 8, 52, "Output",
  CellTags->"7.2"]
}, Open  ]],
Cell[43380, 1490, 820, 30, 48, "Text",
  CellTags->"7.2"],
Cell[44203, 1522, 1991, 60, 50, "DisplayFormula",
  CellTags->"7.2"],
Cell[46197, 1584, 1327, 32, 236, "Text",
  CellTags->"7.2"],
Cell[47527, 1618, 429, 14, 48, "TopSpanBox",
  CellTags->"7.2"],
Cell[47959, 1634, 317, 10, 35, "MiddleBox",
  CellTags->"7.2"],
Cell[48279, 1646, 432, 14, 32, "MiddleSpanBox",
  CellTags->"7.2"],
Cell[48714, 1662, 447, 12, 62, "BottomBox",
  CellTags->"7.2"],
Cell[49164, 1676, 122, 4, 26, "Caption",
  CellTags->"7.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49323, 1685, 56, 1, 68, "Subsection",
  CellTags->"7.3"],
Cell[49382, 1688, 291, 7, 75, "Text",
  CellTags->"7.3"],
Cell[49676, 1697, 1782, 51, 51, "DefinitionBox",
  CellTags->"7.3"],
Cell[51461, 1750, 63, 1, 26, "Caption",
  CellTags->"7.3"],
Cell[51527, 1753, 88, 1, 40, "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{
Cell[51640, 1758, 144, 5, 54, "Input",
  CellTags->"7.3"],
Cell[51787, 1765, 1393, 45, 139, "Output",
  CellTags->"7.3"]
}, Open  ]],
Cell[53195, 1813, 67, 1, 40, "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{
Cell[53287, 1818, 87, 2, 39, "Input",
  CellTags->"7.3"],
Cell[53377, 1822, 1399, 44, 124, "Output",
  CellTags->"7.3"]
}, Open  ]],
Cell[54791, 1869, 614, 15, 110, "Text",
  CellTags->"7.3"],
Cell[55408, 1886, 142, 4, 54, "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{
Cell[55575, 1894, 114, 2, 54, "Input",
  CellTags->"7.3"],
Cell[55692, 1898, 1373, 44, 124, "Output",
  CellTags->"7.3"]
}, Open  ]],
Cell[57080, 1945, 146, 5, 41, "MathCaption",
  CellTags->"7.3"],

Cell[CellGroupData[{
Cell[57251, 1954, 115, 2, 54, "Input",
  CellTags->"7.3"],
Cell[57369, 1958, 1386, 44, 113, "Output",
  CellTags->"7.3"]
}, Open  ]],
Cell[58770, 2005, 828, 26, 85, "DefinitionBox3Col",
  CellTags->"7.3"],
Cell[59601, 2033, 104, 5, 14, "Caption",
  CellTags->"7.3"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

