(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14695,        419]*)
(*NotebookOutlinePosition[     17469,        506]*)
(*  CellTagsIndexPosition[     17354,        498]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["ADDITIVE GmbH\n",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["Abt. Engineering & Science",
    FontFamily->"Times New Roman",
    FontSize->14,
    FontWeight->"Bold",
    Background->GrayLevel[0.666667]],
  StyleBox["\nRohrwiesenstra\[SZ]e 2\nD-61381 Friedrichsdorf/Ts.\n  Tel.:  \
+49 6172 5905 30\n  Fax:  +49 6172 77613\n  email: ",
    FontSize->14,
    FontWeight->"Bold"],
  ButtonBox["mathematica@additive-net.de",
    ButtonData:>{
      URL[ "mailto:mathematica@additive-net.de"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\n  www:  ",
    FontSize->14,
    FontWeight->"Bold"],
  ButtonBox["http://www.additive.net.de",
    ButtonData:>{
      URL[ "http://www.additive-net.de"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  Background->GrayLevel[0.666667]],

Cell[CellGroupData[{

Cell[TextData[{
  "Die ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Applications Library"
}], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Mathematica hat sich in den vergangenen Jahren als unentbehrliches Werkzeug \
im Ingenieurwesen etabliert. Es bietet dem professionellen Anwender, durch \
seinen m\[ADoubleDot]chtigen und fortschrittlichen Funktionsumfang, eine \
unerreichte Flexibilit\[ADoubleDot]t bei der Analyse, Modellierung und \
Visualisierung der w\[ADoubleDot]hrend der t\[ADoubleDot]glichen \
Ingenieurarbeit anfallenden Daten. Im Sommer 1994 startete Wolfram Research \
die Ver\[ODoubleDot]ffentlichung der Mathematica Anwendungs-Pakete, die dem \
Benutzer sofort einsetzbare Funktionen aus speziellen Anwendungsbereichen \
bieten. Dem Anwender wird durch diese Pakete der schrittweise Einstieg in die \
Thematik bis zum Expertenwissen leicht gemacht. Die Zahl der Zusatzpakete \
wurde seit dieser Zeit auf \[UDoubleDot]ber 30 Zusatzpakete erweitert.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Ein \[CapitalUDoubleDot]bersicht zu den Zusatzpaketen ist aktuell im INTERNET \
zu finden.\
\>", "Text"],

Cell[TextData[ButtonBox["http://www.additive-net.de/software/mathematica/\
packages/mma.packages.shtml",
  ButtonData:>{
    URL[ "http://www.additive-net.de/software/mathematica/packages/mma.\
packages.shtml"], None},
  ButtonStyle->"Hyperlink"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Control System", "TI",
    FontSlant->"Italic"],
  "\n1. Getting Started"
}], "Section",
  CellTags->"1.0"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is a collection of ",
  StyleBox["Mathematica", "TI"],
  " programs that extend ",
  StyleBox["Mathematica", "TI"],
  " to solve a wide range of control system problems. Both classical and \
modern approaches are supported for continuous\[Hyphen]time (analog) and \
discrete\[Hyphen]time (sampled) systems. This guide describes in detail the \
new data types introduced in ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " and the new functions that operate on these data types. Also given are a \
number of examples of how to use the ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " functions together with the rest of ",
  StyleBox["Mathematica", "TI"],
  ". It is beyond the scope of this guide to address those innumerable \
control problems that could be solved simply with \
step\[Hyphen]by\[Hyphen]step application of the usual ",
  StyleBox["Mathematica", "TI"],
  " functionality. Nor can the guide be considered an introduction to control \
systems theory. Although an attempt was made to put the new functions into \
the relevant control theory context, the guide is by no means a substitute \
for standard texts such as the ones listed in the References. \nThe many \
illustrations, solved examples, and other features included should make it \
possible for the interested reader to tackle most of the problems just after \
reading the corresponding parts of this guide. However, the guide is \
definitely not an introduction to ",
  StyleBox["Mathematica", "TI"],
  " itself. To gain the most from this application package, the reader is \
advised to consult the standard ",
  StyleBox["Mathematica", "TI"],
  " reference by Stephen Wolfram, ",
  StyleBox["Mathematica: A System for Doing Mathematics by Computer", "TI"],
  ", Second Edition (Addison\[Hyphen]Wesley, 1991). "
}], "Text",
  CellTags->"1.0"],

Cell[CellGroupData[{

Cell["1.1 Using the Package for the First Time", "Subsection",
  CellTags->"1.1"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is one of many available ",
  StyleBox["Mathematica", "TI"],
  " applications and is normally installed in a separate directory in \
parallel to them. If this has been done at the installation stage, the \
application package should be visible to ",
  StyleBox["Mathematica", "TI",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "without further effort on your part. Then, to make all the functionality \
of the application package available at once, you simply load ",
  StyleBox["Master.m", "MR"],
  " package with, for instance, the ",
  StyleBox["Needs", "MR"],
  " command"
}], "Text",
  CellTags->"1.1"],

Cell["\<\
This makes all the functionality of the application available. \
\
\>", "MathCaption",
  CellTags->"1.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"1.1"],

Cell[TextData[{
  "If you get a failure message at this stage, it is probably due to a \
nonstandard location of the application package on your system, and you will \
have to check that the directory enclosing the ",
  StyleBox["ControlSystems", "MR"],
  " directory is included in your ",
  StyleBox["$Path", "MR"],
  " variable. Commands such as  ",
  StyleBox["AppendTo[$Path,", "MR",
    FontFamily->"Courier"],
  " ",
  StyleBox["theDirectoryControlSystemsIsIn", "TI"],
  StyleBox["]", "MR"],
  "  can be used to inform ",
  StyleBox["Mathematica", "TI"],
  " of how to find the application. You may want to add this command to your \
",
  StyleBox["init.m", "MR"],
  " file to have it executed automatically at the outset of any of your ",
  StyleBox["Mathematica", "TI"],
  " sessions. The installation card that came with ",
  StyleBox["Control System Professional", "TI"],
  " contains the detailed instructions on the installation procedure. "
}], "Text",
  CellTags->"1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Structure of the Application", "Subsection",
  CellTags->"1.2"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " consists of the following packages. The packages listed in the first part \
of the table typically correspond to separate sections of this guide and can \
be loaded into your ",
  StyleBox["Mathematica", "TI"],
  " session independently (with or without prior loading of the ",
  StyleBox["Master.m", "MR"],
  " package). The packages in the second part of the table are supplemental \
to the ones in the first. "
}], "Text",
  CellTags->"1.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(Common . m\),
              "Text"], 
            
            StyleBox[\(control\ systems\ objects\ and\ conversion\ between\ \
them\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Conversions . m\),
              "Text"], 
            
            StyleBox[\(conversion\ between\ continuous - 
                time\ and\ discrete - time\ domains\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Simulations . m\),
              "Text"], 
            
            StyleBox[\(investigating\ system\ behavior\ in\ the\ time\ domain\
\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Plots . m\),
              "Text"], 
            
            StyleBox[\(classical\ methods\[LongDash]root\ locus\ and\ \
frequency\ response\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Connections . m\),
              "Text"], 
            
            StyleBox[\(system\ interconnections\ and\ manipulating\ system\ \
contents\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Properties . m\),
              "Text"], 
            StyleBox[\(controllability\ and\ observability\ properties\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Realizations . m\),
              "Text"], 
            
            StyleBox[\(equivalent\ and\ reduced\ representations\ of\ the\ \
same\ system\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(PoleAssignment . m\),
              "Text"], 
            StyleBox[\(pole\ assignment\ using\ state\ feedback\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(LQdesign . m\),
              "Text"], 
            
            StyleBox[\(optimal\ linear\ quadratic\ design\ of\ control\ \
systems\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Linearization . m\),
              "Text"], 
            StyleBox[\(local\ linearization\ of\ nonlinear\ systems\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Lyapunov . m\),
              "Text"], 
            StyleBox[\(Lyapunov\ equations\ solver\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Riccati . m\),
              "Text"], 
            StyleBox[\(Riccati\ equations\ solver\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(SolversCommon . m\),
              "Text"], 
            
            StyleBox[\(common\ definitions\ for\ the\ Lyapunov\ and\ Riccati\ \
equations\ solvers\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(SchurOrdered . m\),
              "Text"], 
            StyleBox[\(ordered\ Schur\ decomposition\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(CycleOptions . m\),
              "Text"], 
            StyleBox[\(options\ handling\ routine\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(EEPlotsExtensions . m\),
              "Text"], 
            RowBox[{
              StyleBox["extensions",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Electrical",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox["Engineering",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["package",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plotting",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["routines",
                SingleLetterItalics->False]}]},
          {
            StyleBox[\(Master . m\),
              "Text"], 
            StyleBox["indexfile",
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{
  RowLines->{
    False, False, False, False, False, False, False, False, False, True, 
      False}},
  CellTags->"1.2"],

Cell[TextData[{
  "Packages within ",
  StyleBox["Control System Professional",
    FontSlant->"Italic"],
  ". "
}], "Caption",
  CellTags->"1.2"],

Cell[TextData[{
  "Under MS\[Hyphen]DOS and Microsoft Windows 3.x, the same file structure is \
preserved, but file names are truncated to eight characters plus an extension \
to match the limitations of the file system. Because the \
MS\[Hyphen]DOS/Windows version is also used for OS/2 and Microsoft Windows \
NT, they inherit the truncated file names, although they can support long \
file names. \nAlso included in ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is the ",
  StyleBox["Mathematica", "TI"],
  " notebook ",
  StyleBox["Examples.ma", "MR"],
  ", which contains an on\[Hyphen]line version of all examples from this \
guide. Line\[Hyphen]by\[Hyphen]line execution of these examples may be a good \
way to get acquainted with the application package. "
}], "Text",
  CellTags->"1.2"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 f\\374r Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          StyleBox[ 
            OptionValueBox[ "FileName"], FontSize -> 10]}], "Header"], Cell[ 
        TextData[ {"- ", 
          StyleBox[ 
          "printed by Mathematica", FontSlant -> "Italic", FontSize -> 10], 
          " - "}], "PageHeader"], Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PageFooters->{{Inherited, Inherited, Inherited}, {Cell[ 
        TextData[ {
          ValueBox[ "Day"], ".", 
          ValueBox[ "Month"], ".", 
          ValueBox[ "Year"]}], "Text"], Cell[ 
        TextData[ {
          StyleBox[ "\[Copyright]2001 Additive GmbH", FontSize -> 10]}], 
        "PageFooter"], Cell[ 
        TextData[ {
          StyleBox[ 
          "Abt. Engineering & Science", FontSlant -> "Italic", FontSize -> 
            10]}], "PageHeader"]}},
PageFooterLines->{Inherited, True},
CellLabelAutoDelete->True,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1.0"->{
    Cell[4019, 117, 135, 5, 86, "Section",
      CellTags->"1.0"],
    Cell[4157, 124, 1976, 39, 185, "Text",
      CellTags->"1.0"]},
  "1.1"->{
    Cell[6158, 167, 81, 1, 47, "Subsection",
      CellTags->"1.1"],
    Cell[6242, 170, 726, 19, 71, "Text",
      CellTags->"1.1"],
    Cell[6971, 191, 115, 4, 25, "MathCaption",
      CellTags->"1.1"],
    Cell[7089, 197, 77, 2, 30, "Input",
      CellTags->"1.1"],
    Cell[7169, 201, 985, 24, 90, "Text",
      CellTags->"1.1"]},
  "1.2"->{
    Cell[8191, 230, 73, 1, 47, "Subsection",
      CellTags->"1.2"],
    Cell[8267, 233, 538, 12, 52, "Text",
      CellTags->"1.2"],
    Cell[8808, 247, 4876, 141, 311, "DefinitionBox",
      CellTags->"1.2"],
    Cell[13687, 390, 146, 6, 25, "Caption",
      CellTags->"1.2"],
    Cell[13836, 398, 831, 17, 90, "Text",
      CellTags->"1.2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.0", 16491, 467},
  {"1.1", 16637, 472},
  {"1.2", 16983, 483}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 821, 25, 198, "Text"],

Cell[CellGroupData[{
Cell[2563, 78, 166, 7, 59, "Section",
  Evaluatable->False],
Cell[2732, 87, 874, 13, 90, "Text",
  Evaluatable->False],
Cell[3609, 102, 114, 3, 33, "Text"],
Cell[3726, 107, 256, 5, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4019, 117, 135, 5, 86, "Section",
  CellTags->"1.0"],
Cell[4157, 124, 1976, 39, 185, "Text",
  CellTags->"1.0"],

Cell[CellGroupData[{
Cell[6158, 167, 81, 1, 47, "Subsection",
  CellTags->"1.1"],
Cell[6242, 170, 726, 19, 71, "Text",
  CellTags->"1.1"],
Cell[6971, 191, 115, 4, 25, "MathCaption",
  CellTags->"1.1"],
Cell[7089, 197, 77, 2, 30, "Input",
  CellTags->"1.1"],
Cell[7169, 201, 985, 24, 90, "Text",
  CellTags->"1.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8191, 230, 73, 1, 47, "Subsection",
  CellTags->"1.2"],
Cell[8267, 233, 538, 12, 52, "Text",
  CellTags->"1.2"],
Cell[8808, 247, 4876, 141, 311, "DefinitionBox",
  CellTags->"1.2"],
Cell[13687, 390, 146, 6, 25, "Caption",
  CellTags->"1.2"],
Cell[13836, 398, 831, 17, 90, "Text",
  CellTags->"1.2"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

